﻿-- Release Script 1.7

--
-- Disable foreign keys
--
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS = @@foreign_key_checks, foreign_key_checks = 0 */;

SET NAMES 'utf8';




--
-- Alter column `tag` on table `rmm_pra_tags`
--
ALTER TABLE rmm_pra_tags 
  CHANGE COLUMN IF EXISTS tag tag TEXT DEFAULT NULL;

--
-- Alter column `tag` on table `rmm_jra_tags`
--
ALTER TABLE rmm_jra_tags 
  CHANGE COLUMN IF EXISTS tag tag TEXT DEFAULT NULL;

--
-- Alter column `tag` on table `rmm_ora_tags`
--
ALTER TABLE rmm_ora_tags 
  CHANGE COLUMN IF EXISTS tag tag TEXT DEFAULT NULL;

--
-- Drop procedure `rpt_get_full_equipment_list`
--
DROP PROCEDURE IF EXISTS rpt_get_full_equipment_list;

DELIMITER $$

--
-- Create procedure `rpt_get_full_equipment_list`
--
CREATE PROCEDURE IF NOT EXISTS rpt_get_full_equipment_list(IN lang int)
BEGIN
  /*

   Modified Date: 2022-03-10
   Modified By: Jazmyn Zarichney
   Modification: Created to get an equipment list for equipment history report

   Modified Date: 2023-10-25
   Modified By: Pragati Das
   Modification: SOF-13978 - Renamed the column for pet_enable to status_enable
  
   Modified Date: 2024-01-17
   Modified By: Pragati Das
   Modification: PD-538 - Updated the SP to exclude NULL equipment identifier

   Modified Date: 2025-01-02
   Modified By: Naveen Kumar Vadlamudi
   Modification: PD-3254 - Updated the SP to fetch the active equipments using is_active flag.

   Modified Date: 2025-01-13
   Modified By: Pragati Das
   Modification: PD-3254 - Updated the SP to display the full equipment name in the drop down list.
  */
  SELECT
    preop_equipment_type.pet_id,
    CONCAT(CASE WHEN preop_equipment_type.pet_enable = 1 AND
        preop_equipment_type.pet_is_active = 1 THEN preop_equipment_type.pet_equipment_identifier ELSE CONCAT(preop_equipment_type.pet_equipment_identifier, ' - ', get_translation(9169, lang, 1)) END,
    ' - ', CASE WHEN preop_equipment.poe_enable = 1 THEN language_translation.ltr_text ELSE CONCAT(language_translation.ltr_text, ' - ', get_translation(9169, lang, 1)) END) AS poe_equip_desc,
    CASE WHEN preop_equipment_type.pet_enable = 1 AND
        preop_equipment_type.pet_is_active = 1 THEN 1 ELSE 0 END AS status_flag
  FROM preop_equipment_type
    INNER JOIN preop_equipment
      ON preop_equipment.poe_id = preop_equipment_type.pet_poe_id
    INNER JOIN language_translation
      ON preop_equipment.poe_equip_description = language_translation.ltr_tag
      AND preop_equipment.poe_tag_type = language_translation.ltr_tag_type
      AND language_translation.ltr_lng_id = lang
  WHERE language_translation.ltr_text IS NOT NULL
  AND preop_equipment_type.pet_equipment_identifier IS NOT NULL;
END
$$

DELIMITER ;

--
-- Drop procedure `rpt_equipment_history_tfsr_equipment`
--
DROP PROCEDURE IF EXISTS rpt_equipment_history_tfsr_equipment;

DELIMITER $$

--
-- Create procedure `rpt_equipment_history_tfsr_equipment`
--
CREATE PROCEDURE IF NOT EXISTS rpt_equipment_history_tfsr_equipment(IN equipment_ids text,
IN lang int)
BEGIN

  /*

  Created by : Jazmyn Zarichney
  Created On : 2022-03-20
  Purpose : SOF-13373 - Filter off equipment ID's for equipment history

  Modified by : Pragati Das
  Created On : 2024-01-19
  Purpose : PD-538 - Added And condition to filter out NULL equipment identifier

  Modified by : Naveen Kumar Vadlamudi
  Created On : 2025-01-03
  Purpose : Added extra filter condition to get is_active column data.

  Modified by : Pragati Das
  Created On : 2025-01-13
  Purpose : PD-3254 - Added new columns to display the inactive label in the report

  */

  SELECT
    pet_equipment_identifier,
    CASE WHEN preop_equipment_type.pet_enable = 1 AND
        preop_equipment_type.pet_is_active = 1 THEN preop_equipment_type.pet_equipment_identifier ELSE CONCAT(preop_equipment_type.pet_equipment_identifier, ' - ', get_translation(9169, lang, 1)) END AS pet_equipment_identifier_value,
    pet_poe_id,
    CASE WHEN preop_equipment.poe_enable = 1 THEN language_translation.ltr_text ELSE CONCAT(language_translation.ltr_text, ' - ', get_translation(9169, lang, 1)) END AS equip_name_value,
    language_translation.ltr_text AS equip_name,
    preop_equipment.poe_enable,
    preop_equipment_type.pet_is_active
  FROM preop_equipment_type
    INNER JOIN preop_equipment
      ON preop_equipment_type.pet_poe_id = preop_equipment.poe_id
    INNER JOIN language_translation
      ON language_translation.ltr_tag = preop_equipment.poe_equip_description
      AND language_translation.ltr_tag_type = preop_equipment.poe_tag_type
      AND language_translation.ltr_lng_id = lang
  WHERE ((FIND_IN_SET(preop_equipment_type.pet_id, equipment_ids) > 0)
  OR (preop_equipment_type.pet_id IS NOT NULL
  AND equipment_ids = ''))
  AND preop_equipment_type.pet_equipment_identifier IS NOT NULL;

END
$$

DELIMITER ;

--
-- Drop procedure `get_access_role_permission`
--
DROP PROCEDURE IF EXISTS get_access_role_permission;

DELIMITER $$

--
-- Create procedure `get_access_role_permission`
--
CREATE PROCEDURE IF NOT EXISTS get_access_role_permission(IN personId int, IN permissionId int)
BEGIN


  /*
  Created By: Vishnu Parkash
  Create On: 2020-05-13
  Purpose: Manage the permission  for the role for an employee
  
  Modified By:  James Coles
  Modified date: 2024-10-17
  Reason:  Added enable condition as it was returning a positive value for a role that the user did not have.

*/

  DECLARE person_id int;
  DECLARE permission_Id int;
  SET person_id = personId;
  SET permission_Id = permissionId;

  SELECT
    EXISTS (SELECT
        1
      FROM auth_user_sofvie
        INNER JOIN auth_user_role_sofvie
          ON auth_user_role_sofvie.aur_user_id = auth_user_sofvie.id
        INNER JOIN auth_role_permission_sofvie
          ON auth_role_permission_sofvie.arp_aro_id = auth_user_role_sofvie.aur_aro_id
        INNER JOIN auth_permission_sofvie
          ON auth_permission_sofvie.ape_id = auth_role_permission_sofvie.arp_ape_id
      WHERE auth_user_sofvie.user_per_id = person_id
      AND auth_user_sofvie.is_active = TRUE
      AND auth_role_permission_sofvie.arp_ape_id = permission_Id
      AND auth_role_permission_sofvie.arp_enable = TRUE
      AND aur_enable = 1) AS isPermits;


END
$$

DELIMITER ;

--
-- Drop procedure `get_root_cause_analysis_by_incident_id`
--
DROP PROCEDURE IF EXISTS get_root_cause_analysis_by_incident_id;

DELIMITER $$

--
-- Create procedure `get_root_cause_analysis_by_incident_id`
--
CREATE PROCEDURE IF NOT EXISTS get_root_cause_analysis_by_incident_id(IN incident_id int, IN lang varchar(2), IN per_id int)
BEGIN
  /*
    Modified by: Robert Rivest
    Modified Date: 2021-06-14
    Reason:  SOF-7846 - i18n - Modified to get the info for Actual from Preliminary Lists and translation of Fields
    
    Modified Date: 2021-07-07
    Modified By: Vishnu
    Modification: SOF-8178 - Modified for tag revamp

    Modified   : March 18th, 2022
    Modified by: James Coles
    Reason     : SOF-10397 - Validate parameters.
  
    Modified   : April 3rd, 2023
    Modified by: Sarath Sontam
    Reason     : SOF-13761 - get reviewed count and reviewed by per. 
  
    Modified   : 2023-07-17
    Modified by: Robert Rivest
    Reason     : SOF-13961 - changed join to v_employee to left Join
  
    Modified by: Suman Marlapudi
    Date       : 2023-11-30
    Reason     : SOF-14025 - Replace the deprecated SELECT INTO clause with variables.

    Modified by: Robert Rivest
    Date       : 2024-03-11
    Reason     : PD-1171 - add_rca_created_date to output

  */

  DECLARE lang_id int;

  SET lang_id := 0;

  SET lang_id = (SELECT
      lng_id
    FROM `language`
    WHERE lng_name = lang);

  SELECT
    RootCauseAnalysis.IncidentID,
    RootCauseAnalysis.ID,
    RootCauseAnalysis.SubmissionDate,
    RootCauseAnalysis.rca_created_date,
    v_employee.per_full_name AS SubmittedBy,
    RootCauseAnalysis.EventDetails,
    RootCauseAnalysis.InvestigationFindings,
    pit.ltr_text AS PreliminaryType,
    ac.ltr_text AS ActualType,
    it.ltr_text AS IncidentType,
    pitc.ltr_text AS PreliminaryIncidentTypeCategory,
    pitd.ltr_text AS PreliminaryIncidentTypeDetail,
    aitc.ltr_text AS ActualIncidentTypeCategory,
    aitd.ltr_text AS ActualIncidentTypeDetail,
    pl.ltr_text AS PotentialLoss,
    RootCauseAnalysis.LastUpdated,
    emp2.per_full_name AS LastUpdatedBy,
    (SELECT
        GROUP_CONCAT(CAST(emp.per_full_name AS char(80)))
      FROM RootCauseAnalysis_EmployeesInvolved
        JOIN v_employee emp
          ON RootCauseAnalysis_EmployeesInvolved.EmployeeID = emp.per_id
      WHERE RootCauseAnalysis_EmployeesInvolved.RootCauseAnalysisID = RootCauseAnalysis.ID
      GROUP BY RootCauseAnalysis_EmployeesInvolved.RootCauseAnalysisID) AS EmployeesInvolved,
    '' Cause,
    (SELECT
        ReportURL
      FROM Reports
      WHERE SSRSReportName = 'RootCauseAnalysisBasic' LIMIT 1) AS ReportURL,
    CASE WHEN (SELECT
            crw_id
          FROM common_reviewer
          WHERE crw_per_id = per_id
          AND crw_rca_id = RootCauseAnalysis.ID
          AND crw_enable = 1) THEN 1 ELSE 0 END AS rca_reviewed,
    COUNT(crw_id) AS rca_reviewed_count,
    (SELECT
        COUNT(1)
      FROM comment_user cu
      WHERE cu.com_cmt_id = 25
      AND cu.com_reference_id = RootCauseAnalysis.ID
      AND cu.com_enable = 1) AS commentCount,
    (SELECT
        COUNT(1)
      FROM comment_user cu
      WHERE cu.com_cmt_id = 25
      AND cu.com_reference_id = RootCauseAnalysis.ID
      AND cu.com_created_by_per_id = per_id
      AND cu.com_enable = 1) AS commentByPerCount
  FROM RootCauseAnalysis
    LEFT JOIN v_employee
      ON RootCauseAnalysis.SubmittedBy = v_employee.per_id
    LEFT JOIN v_employee emp2
      ON COALESCE(RootCauseAnalysis.LastUpdatedBy, -999) = emp2.per_id
    LEFT JOIN (SELECT
        *
      FROM v_ref_header_detail_list
        INNER JOIN language_translation
          ON v_ref_header_detail_list.rld_name = language_translation.ltr_tag
          AND v_ref_header_detail_list.rld_tag_type = language_translation.ltr_tag_type
          AND language_translation.ltr_lng_id = lang_id
      WHERE v_ref_header_detail_list.rlh_name = 'ref_preliminary_incident_type') pit
      ON pit.rld_id = RootCauseAnalysis.PreliminaryTypeID
    LEFT JOIN (SELECT
        *
      FROM v_ref_header_detail_list
        INNER JOIN language_translation
          ON v_ref_header_detail_list.rld_name = language_translation.ltr_tag
          AND v_ref_header_detail_list.rld_tag_type = language_translation.ltr_tag_type
          AND language_translation.ltr_lng_id = lang_id
      WHERE v_ref_header_detail_list.rlh_name = 'ref_preliminary_incident_type') ac
      ON ac.rld_id = RootCauseAnalysis.ActualTypeID
    LEFT JOIN (SELECT
        *
      FROM v_ref_header_detail_list
        INNER JOIN language_translation
          ON v_ref_header_detail_list.rld_name = language_translation.ltr_tag
          AND v_ref_header_detail_list.rld_tag_type = language_translation.ltr_tag_type
          AND language_translation.ltr_lng_id = lang_id
      WHERE v_ref_header_detail_list.rlh_name = 'ref_incident_type') it
      ON it.rld_id = RootCauseAnalysis.IncidentTypeID
    LEFT JOIN (SELECT
        *
      FROM v_ref_header_detail_list
        INNER JOIN language_translation
          ON v_ref_header_detail_list.rld_name = language_translation.ltr_tag
          AND v_ref_header_detail_list.rld_tag_type = language_translation.ltr_tag_type
          AND language_translation.ltr_lng_id = lang_id
      WHERE v_ref_header_detail_list.rlh_name = 'ref_potential_loss') pl
      ON pl.rld_id = RootCauseAnalysis.PotentialLossID
    LEFT JOIN (SELECT
        *
      FROM v_ref_header_detail_list
        INNER JOIN language_translation
          ON v_ref_header_detail_list.rld_name = language_translation.ltr_tag
          AND v_ref_header_detail_list.rld_tag_type = language_translation.ltr_tag_type
          AND language_translation.ltr_lng_id = lang_id
      WHERE v_ref_header_detail_list.rlh_name = 'ref_preliminary_incident_type_category') pitc
      ON pitc.rld_id = RootCauseAnalysis.PreliminaryIncidentTypeCategoryID
    LEFT JOIN (SELECT
        *
      FROM v_ref_header_detail_list
        INNER JOIN language_translation
          ON v_ref_header_detail_list.rld_name = language_translation.ltr_tag
          AND v_ref_header_detail_list.rld_tag_type = language_translation.ltr_tag_type
          AND language_translation.ltr_lng_id = lang_id
      WHERE v_ref_header_detail_list.rlh_name = 'ref_preliminary_incident_type_category') aitc
      ON aitc.rld_id = RootCauseAnalysis.ActualIncidentTypeCategoryID
    LEFT JOIN (SELECT
        *
      FROM v_ref_header_detail_list
        INNER JOIN language_translation
          ON v_ref_header_detail_list.rld_name = language_translation.ltr_tag
          AND v_ref_header_detail_list.rld_tag_type = language_translation.ltr_tag_type
          AND language_translation.ltr_lng_id = lang_id
      WHERE v_ref_header_detail_list.rlh_name = 'ref_preliminary_incident_type_detail') pitd
      ON pitd.rld_id = RootCauseAnalysis.PreliminaryIncidentTypeDetailID
    LEFT JOIN (SELECT
        *
      FROM v_ref_header_detail_list
        INNER JOIN language_translation
          ON v_ref_header_detail_list.rld_name = language_translation.ltr_tag
          AND v_ref_header_detail_list.rld_tag_type = language_translation.ltr_tag_type
          AND language_translation.ltr_lng_id = lang_id
      WHERE v_ref_header_detail_list.rlh_name = 'ref_preliminary_incident_type_detail') aitd
      ON aitd.rld_id = RootCauseAnalysis.ActualIncidentTypeDetailID
    LEFT JOIN common_reviewer
      ON RootCauseAnalysis.ID = common_reviewer.crw_rca_id
      AND crw_enable = 1
  WHERE IncidentID = incident_id
  AND COALESCE(IsArchived, 0) = 0
  GROUP BY RootCauseAnalysis.ID;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_equipment_status`
--
DROP PROCEDURE IF EXISTS rpt_equipment_status;

DELIMITER $$

--
-- Create procedure `rpt_equipment_status`
--
CREATE PROCEDURE IF NOT EXISTS rpt_equipment_status(IN start_date date,
IN end_date date,
IN site_ids text,
IN equipment_ids text,
IN lang int)
BEGIN

  /*

  Created By:Jaganjot Kaur
  Creation Date: 6th July 2021
  Description: Getting equiment status report details
  
  Change History
  Modified by : Robert Rivest
  Modified on: 2021-08-05
  Reason:  Added Lable Translations and Language Support

  Modified by : Jaganjot Kaur
  Modified on: 2021-12-20
  Reason:  Updating shift start and shift end labels

  Modified by : Jaganjot Kaur
  Modified on: 2022-17-02
  Reason: Updated SP for report performace

  Modified by : Jazmyn Zarichney
  Modified on: 2022-04-21
  Reason: Updating ltr_lang_ig to equal lang for labels
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-05-18
  Description: Adding enable check on language translations (SOF-11119) 
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-08-29
  Description: Updating the labels to use the language function (SOF-12027)
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-09-19
  Description: Passing a pre-op equipment enable check (SOF-11458)
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-09-23
  Description: Adding site_enable_status (SOF-11458)

  Modified By: Shane Robinson
  Modified Date: 2022-11-22
  Description: SOF-12606 - Updated the IsArchived in where clause <> 1 OR IsArchived IS NULL

  Modified by : Pragati/Jazmyn
  Modified date : 2023-01-17
  Purpose : SOF-13148 Updated SP for select all new logic

  Modified By: Robert Rivest
  Modified Date: 2023-02-17
  Description: SOF-13505 - Changed Query to use new table names and fieldnames

  Modified By: Robert Rivest and Jazmyn Zarichney
  Modified Date: 2023-04-20
  Description: SOF-14053 Rebuild SP to decrease load time

  Modified By: Pragati Das
  Modified Date: 2024-04-08
  Description: PD-1439 - Added inactive equipment label 

  Modified By: Pragati Das/ Vishnu
  Modified Date: 2024-12-30
  Description: PD-3254 - Added equipment status column

*/

  SELECT
    site_name.ltr_text AS Site,
    rld.rld_enable AS site_enable_status,
    SubmissionHeader.Workplace AS `SiteWorkplace`,
    preop_submission_header.psh_submissionheader_id,
    preop_equipment_type.pet_poe_id,
    CASE WHEN preop_equipment_type.pet_enable = 1 AND
        preop_equipment_type.pet_is_active = 1 THEN preop_equipment_type.pet_equipment_identifier ELSE CONCAT(preop_equipment_type.pet_equipment_identifier, ' - ', get_translation(9169, lang, 1)) END AS pet_equipment_identifier,
    SubmissionHeader.FormSubmissionDate,
    CASE WHEN preop_equipment.poe_enable = 1 THEN poedesc.ltr_text ELSE CONCAT(poedesc.ltr_text, ' - ', get_translation(9169, lang, 1)) END AS equipment_name,
    preop_equipment.poe_enable,
    preop_equipment_type.pet_enable,
    preop_submission_header.psh_id AS posh_id,
    preop_equipment_type.pet_is_active
  FROM SubmissionHeader
    INNER JOIN preop_submission_header
      ON SubmissionHeader.ID = preop_submission_header.psh_submissionheader_id
    INNER JOIN preop_equipment_type
      ON preop_submission_header.psh_pet_id = preop_equipment_type.pet_id
    INNER JOIN preop_equipment
      ON preop_equipment_type.pet_poe_id = preop_equipment.poe_id
    INNER JOIN language_translation poedesc
      ON poedesc.ltr_tag = preop_equipment.poe_equip_description
      AND poedesc.ltr_tag_type = poe_tag_type
      AND ltr_lng_id = lang 
    INNER JOIN ref_list_detail rld
      ON SubmissionHeader.Site = rld.rld_id
      AND rld.rld_rlh_id = 1
    INNER JOIN language_translation site_name
      ON rld.rld_name = site_name.ltr_tag
      AND site_name.ltr_lng_id = lang
      AND rld.rld_tag_type = site_name.ltr_tag_type
  WHERE CAST(SubmissionHeader.FormSubmissionDate AS date) BETWEEN start_date AND end_date
  AND (IsArchived <> 1
  OR IsArchived IS NULL)
  AND (IF(site_ids IS NOT NULL,
  ((FIND_IN_SET(SubmissionHeader.Site, site_ids) > 0)
  OR (site_ids IS NULL)), SubmissionHeader.Site IS NULL
  OR SubmissionHeader.Site IS NOT NULL))
  AND (IF(equipment_ids IS NOT NULL,
  ((FIND_IN_SET(preop_equipment_type.pet_poe_id, equipment_ids) > 0)
  OR (equipment_ids IS NULL)), preop_equipment_type.pet_poe_id IS NULL
  OR preop_equipment_type.pet_poe_id IS NOT NULL));

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_post_op_photos`
--
DROP PROCEDURE IF EXISTS rpt_post_op_photos;

DELIMITER $$

--
-- Create procedure `rpt_post_op_photos`
--
CREATE PROCEDURE IF NOT EXISTS rpt_post_op_photos(IN submission_id int, IN location varchar(255), IN language_id int)
BEGIN
  /*
  Updated by: Jaganjot Kaur
  Updated on: 7th June 2021
  Reason:  Needed to change the where clause for SUP% to %SUP%

  Updated on: 2nd Nov 2021
  Modified By: Jaganjot Kaur
  Description: Fetching image comments

  Updated on: 2022-01-14
  Modified By: Jazmyn Zarichney
  Description: Replacing strings with tags SOF-10161

  Modified by: Jaganjot Kaur
  Modified date: 26th Jan 2022
  Purpose: Updating the image comment id as is updated in the comment table

  Modified By: Jazmyn Zarichney
  Modified Date: 2022-05-17
  Description: Adding enable check on language translations (SOF-11119)
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-09-08
  Description: Updating the labels to use the language function (SOF-12027)

  Modified By: Pragati Das
  Modified Date: 2023-10-13
  Description: SOF-15150 - Added preop_attachments.poa_orientation in SELECT statement 
  
  Modified By:   James Coles
  Modified Date: 2023-10-18 
  Description:   SOF-14858 - Ensure the order of the images appearing on the report
                  is the same order as the order in which they were taken.

 Modified By   : Vishnu Prakash
 Modified Date : 2024-05-31
 Reason        : PD-450 - update the filter with  SUP. to SUP.galleryid- as we need to filter out the preop questions photos

  */

  DECLARE post_op_photos_label text;
  DECLARE photo_reference_label text;

  SET post_op_photos_label = get_translation(1958, language_id, 1);
  SET photo_reference_label = get_translation(1957, language_id, 1);
  SELECT
    CONCAT(location, '/', preop_attachments.poa_image_name) AS image_name,
    preop_attachments.poa_orientation,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_tag_type = 1
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          MAX(ltr_tag)
        FROM language_translation
        WHERE ltr_text = preop_attachments.poa_orientation)) AS Orientation,
    preop_attachments.poa_image_timestamp AS picStamp,
    post_op_photos_label AS post_op_photos_label,
    photo_reference_label AS photo_reference_label,
    (SELECT
        com_comment
      FROM comment_user
      WHERE com_cmt_id = 4
      AND com_reference_id = preop_attachments.poa_id) AS image_comment
  FROM preop_attachments
    LEFT JOIN preop_submission_header
      ON preop_attachments.poa_psh_id = preop_submission_header.psh_id
  WHERE preop_submission_header.psh_submissionheader_id = submission_id
  AND preop_attachments.poa_element_name LIKE '%SUP.galleryid-%'
  AND preop_attachments.poa_shift = 'After'
  ORDER BY preop_attachments.poa_image_index;


END
$$

DELIMITER ;

--
-- Drop procedure `rpt_equipment_history_sub_ids`
--
DROP PROCEDURE IF EXISTS rpt_equipment_history_sub_ids;

DELIMITER $$

--
-- Create procedure `rpt_equipment_history_sub_ids`
--
CREATE PROCEDURE IF NOT EXISTS rpt_equipment_history_sub_ids(IN sub_ids longtext,
IN lang int)
BEGIN

  /*

  Created by : Jazmyn Zarichney
  Created On : 2023-04-20
  Purpose : SOF-13373 - Filter off submission ID's for equipment history

  Modified by : Jazmyn Zarichney
  Modified On : 2023-04-24
  Purpose : SOF-14094 Fixing the load time of the equipment history

  Modified by : Suman Marlapudi & James Coles
  Modified On : 2023-06-22
  Purpose : SOF-14525 Replace the get_translation_from_ref_list_id function with joins to get the site
  
  Modified by : Pragati Das
  Modified On : 2023-08-04
  Purpose : SOF-14756 Added site enable status column

  Modified by : Naveen Kumar Vadlamudi
  Modified On : 2025-01-02
  Purpose : Added rld_is_active column for the procedure. 
  */

  DECLARE inactive_flag varchar(10);
  SET inactive_flag = (SELECT
      ltr_text
    FROM language_translation
    WHERE ltr_tag = 9169
    AND ltr_lng_id = lang
    AND ltr_tag_type = 1);

  SELECT
    SubmissionHeader.ID AS SubmissionHeaderID,
    SubmissionHeader.FormSubmissionDate AS FormSubmissionDt,
    FormFieldDescription.fieldKey AS fieldKey,
    SubmissionDetails_Explode.Value AS Value,
    SubmissionHeader.language AS form_lang,

    CASE WHEN rd.rld_enable = 1 AND
        rd.rld_is_active = 1 THEN lt.ltr_text ELSE CONCAT(lt.ltr_text, " ", inactive_flag) END AS Site
  FROM SubmissionHeader
    INNER JOIN ref_list_detail rd
      ON rd.rld_id = SubmissionHeader.site
    INNER JOIN language_translation lt
      ON lt.ltr_tag = rd.rld_name
      AND lt.ltr_lng_id = 1
      AND lt.ltr_tag_type = rd.rld_tag_type
    INNER JOIN SubmissionDetails
      ON SubmissionHeader.ID = SubmissionDetails.SubmissionHeaderID
    INNER JOIN SubmissionDetails_Explode
      ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
    INNER JOIN FormFieldDescription
      ON SubmissionDetails_Explode.FormFieldDescriptionID = FormFieldDescription.ID
  WHERE SubmissionHeader.FormDescriptionID = 1414
  AND (IF(sub_ids IS NOT NULL,
  ((FIND_IN_SET(SubmissionHeader.ID, sub_ids) > 0)
  OR (sub_ids IS NULL)), SubmissionHeader.ID IS NULL
  OR SubmissionHeader.ID IS NOT NULL));

END
$$

DELIMITER ;

--
-- Drop procedure `get_drilling_calculation_by_subid`
--
DROP PROCEDURE IF EXISTS get_drilling_calculation_by_subid;

DELIMITER $$

--
-- Create procedure `get_drilling_calculation_by_subid`
--
CREATE PROCEDURE IF NOT EXISTS get_drilling_calculation_by_subid(IN submission_id bigint)
BEGIN

  /*
     Creation Date: 2022-10-17
     Created By: Vishnu Prakash & Gowtham Ravindran
     Description: SP to get the Daily Drilling Report calculation for the given submission_id (SOF-12251)
     ************************************************************************************
     Change History
     ************************************************************************************
     Modifed Date: 2020-10-18
     Modified By: Gowtham Ravindran
     Comment: Added comments and changed DROP command to DELETE(SOF-12251)
  
     Modifed Date: 2020-10-19
     Modified By: Vishnu Prakash
     Comment: modified the time conversion
  
     Modifed Date: 2020-10-20
     Modified By: Vishnu Prakash
     Comment: update the query for the calculating the total shift hours to avoid the negative value
  
     Modifed Date: 2020-10-21
     Modified By: Vishnu Prakash
     Comment: total hours and total hours drilled calculation modified - returns with hours and minutes
  
  */

  DECLARE inc int;
  DECLARE total_shift_hours decimal(10, 2);
  DECLARE total_shift_mints decimal(10, 2);

  DECLARE total_hours_drilled double;
  DECLARE total_mints_drilled double;


  DECLARE total_prod_meters_drilled double;
  DECLARE total_cable_meters_drilled double;
  DECLARE total_redrill_meters double;

  DECLARE hours_difference decimal(10, 2);
  DECLARE drilling_length double;
  DECLARE redrill_meters double;

  DECLARE start_time time;
  DECLARE end_time time;

  SET inc = 1;
  SET total_shift_hours = 0;
  SET total_shift_mints = 0;

  SET hours_difference = 0;
  SET total_hours_drilled = 0;
  SET total_mints_drilled = 0;

  SET redrill_meters = 0;
  SET total_redrill_meters = 0;
  SET total_cable_meters_drilled = 0;
  SET total_prod_meters_drilled = 0;
  SET drilling_length = 0;


  -- Submission detail explode and form description table data
  CREATE TEMPORARY TABLE IF NOT EXISTS daily_drilling_calculation_explode_data (
    FormFieldDescriptionID int,
    Value text,
    fieldKey varchar(200),
    fieldType varchar(150)
  );

  -- ref_list_drilling_calculation_value
  CREATE TEMPORARY TABLE IF NOT EXISTS rld_dcv_value (
    ref_dcv_rld_id int(11),
    ref_dcv_hours_drilled tinyint(1),
    ref_dcv_production_meters_drilled tinyint(1),
    ref_dcv_cable_meters_drilled tinyint(1)
  );

  -- Clearing the Temp tables
  DELETE
    FROM daily_drilling_calculation_explode_data;
    DELETE
      FROM rld_dcv_value;

      INSERT INTO rld_dcv_value
        SELECT
          ref_dcv_rld_id,
          ref_dcv_hours_drilled,
          ref_dcv_production_meters_drilled,
          ref_dcv_cable_meters_drilled
        FROM ref_list_drilling_calculation_value;


      INSERT INTO daily_drilling_calculation_explode_data
        SELECT
          SubmissionDetails_Explode.FormFieldDescriptionID,
          SubmissionDetails_Explode.Value,
          fieldKey,
          fieldType
        FROM SubmissionHeader
          INNER JOIN SubmissionDetails
            ON SubmissionHeader.ID = SubmissionDetails.SubmissionHeaderID
          INNER JOIN SubmissionDetails_Explode
            ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
          INNER JOIN FormFieldDescription
            ON SubmissionDetails_Explode.FormFieldDescriptionID = FormFieldDescription.ID
        WHERE SubmissionHeaderID = submission_id;


      WHILE inc <= 20
      DO
        SET hours_difference = 0;

        IF EXISTS (SELECT
              1
            FROM daily_drilling_calculation_explode_data
            WHERE fieldKey = CONCAT('start_time_', inc)
            AND (SELECT
                1
              FROM daily_drilling_calculation_explode_data
              WHERE fieldKey = CONCAT('end_time_', inc))) THEN

          -- "Total Shift Hours"
          SELECT
            CAST(IFNULL(STR_TO_DATE(Value, '%l:%i %p'), '00:00:00') AS time) INTO end_time
          FROM daily_drilling_calculation_explode_data
          WHERE fieldKey = CONCAT('end_time_', inc);
          SELECT
            CAST(IFNULL(STR_TO_DATE(Value, '%l:%i %p'), '00:00:00') AS time) INTO start_time
          FROM daily_drilling_calculation_explode_data
          WHERE fieldKey = CONCAT('start_time_', inc);

          SET hours_difference = CAST(TIME_TO_SEC(TIMEDIFF(end_time, start_time)) / (60 * 60) AS decimal(10, 2));
          IF (hours_difference < 0) THEN
            SET hours_difference = hours_difference + 24;
          END IF;

          SET total_shift_hours = total_shift_hours + CAST(SUBSTRING_INDEX (hours_difference, '.', 1) AS UNSIGNED);
          SET total_shift_mints = total_shift_mints + CAST(CAST(SUBSTRING_INDEX (hours_difference, '.', -1) AS UNSIGNED) * 60 / 100 AS int);

          -- "Total Hours Drilled"
          IF EXISTS (SELECT
                1
              FROM daily_drilling_calculation_explode_data
              WHERE fieldKey = CONCAT('time_and_delays_code_', inc)
              AND CAST(VALUE AS int) IN (SELECT
                  ref_dcv_rld_id
                FROM rld_dcv_value
                WHERE ref_dcv_hours_drilled = 1)) THEN
            SET total_hours_drilled = total_hours_drilled + CAST(SUBSTRING_INDEX (hours_difference, '.', 1) AS UNSIGNED);
            SET total_mints_drilled = total_mints_drilled + +CAST(CAST(SUBSTRING_INDEX (hours_difference, '.', -1) AS UNSIGNED) * 60 / 100 AS int);
          END IF;

          -- "Total Production Meters Drilled"
          IF EXISTS (SELECT
                1
              FROM daily_drilling_calculation_explode_data
              WHERE fieldKey = CONCAT('drilling_code_', inc)
              AND CAST(VALUE AS int) IN (SELECT
                  ref_dcv_rld_id
                FROM rld_dcv_value
                WHERE ref_dcv_production_meters_drilled = 1)) THEN
            SELECT
              CAST(value AS double) INTO drilling_length
            FROM daily_drilling_calculation_explode_data
            WHERE fieldKey = CONCAT('drilling_length_', inc);
            SET total_prod_meters_drilled = total_prod_meters_drilled + drilling_length;
          END IF;

          -- "Total Cable Meters Drilled"
          IF EXISTS (SELECT
                1
              FROM daily_drilling_calculation_explode_data
              WHERE fieldKey = CONCAT('drilling_code_', inc)
              AND CAST(VALUE AS int) IN (SELECT
                  ref_dcv_rld_id
                FROM rld_dcv_value
                WHERE ref_dcv_cable_meters_drilled = 1)) THEN
            SELECT
              CAST(value AS double) INTO drilling_length
            FROM daily_drilling_calculation_explode_data
            WHERE fieldKey = CONCAT('drilling_length_', inc);
            SET total_cable_meters_drilled = total_cable_meters_drilled + drilling_length;
          END IF;

          -- "Total Redrill Meters"
          IF EXISTS (SELECT
                1
              FROM daily_drilling_calculation_explode_data
              WHERE fieldKey = CONCAT('status_code_', inc)
              AND CAST(VALUE AS int) IN (SELECT
                  ref_list_detail.rld_id
                FROM ref_list_detail
                WHERE ref_list_detail.rld_code = 'C'
                AND ref_list_detail.rld_rlh_id = 98)) THEN
            SELECT
              CAST(value AS double) INTO redrill_meters
            FROM daily_drilling_calculation_explode_data
            WHERE fieldKey = CONCAT('redrill_', inc);
            SET total_redrill_meters = total_redrill_meters + redrill_meters;
          END IF;

        END IF;

        SET inc = inc + 1;
      END WHILE;

      IF total_shift_mints >= 60 THEN
        SET total_shift_hours = total_shift_hours + CAST(total_shift_mints / 60 AS int);
        SET total_shift_mints = MOD(total_shift_mints, 60);
      END IF;

      IF total_mints_drilled >= 60 THEN
        SET total_hours_drilled = total_hours_drilled + CAST(total_mints_drilled / 60 AS int);
        SET total_mints_drilled = MOD(total_mints_drilled, 60);
      END IF;

      SELECT
        CAST(total_shift_hours AS int) AS total_shift_hours,
        CAST(total_shift_mints AS int) AS total_shift_mints,
        CAST(total_hours_drilled AS int) AS total_hours_drilled,
        CAST(total_mints_drilled AS int) AS total_mints_drilled,
        total_prod_meters_drilled,
        total_cable_meters_drilled,
        total_redrill_meters;

      -- Clearing the Temp tables
      DELETE
        FROM daily_drilling_calculation_explode_data;
        DELETE
          FROM rld_dcv_value;

          END
$$

DELIMITER ;

--
-- Drop procedure `api_timesheet_employee`
--
DROP PROCEDURE IF EXISTS api_timesheet_employee;

DELIMITER $$

--
-- Create procedure `api_timesheet_employee`
--
CREATE PROCEDURE IF NOT EXISTS api_timesheet_employee(IN start_date datetime, IN end_date datetime, IN submission_id int, IN language_id int, IN date_type int)
BEGIN
  /*
     Created by:    Naveen Kumar Vadlamudi
     Created Date:  2024-09-18
     Ticket Number: PD-2817 (Client API)
     Reason: API for timesheet module.
  
      Modified by   : Vinh Lam
      Modified Date : 2024-10-22
      Reason       : PD-2817 - Update orders.
  */


  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;


  IF submission_id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;


  WITH employee_id_cte
  AS
  (SELECT
      person.per_id AS per_id,
      employee.emp_id AS emp_id,
      TRIM(CONCAT(person.per_last_name, ', ', person.per_first_name, ' ', COALESCE(person.per_middle_name, ''))) AS per_full_name
    FROM person
      LEFT JOIN employee
        ON person.per_id = employee.emp_per_id),


  employee_cte
  AS
  (SELECT
      *,
      ROW_NUMBER() OVER (PARTITION BY HeaderId ORDER BY fieldKey ASC) AS ROW_ID
    FROM (SELECT
        SubmissionHeaderID AS HeaderID,
        FormFieldDescription.fieldKey,
        GROUP_CONCAT(REPLACE(SubmissionDetails_Explode.Value, '\\', '') SEPARATOR '; ') AS Employee,
        GROUP_CONCAT(employee_id_cte.emp_id) AS employee_id,
        COUNT(SubmissionDetails_Explode.Value) AS number_of_employees
      FROM SubmissionHeader
        INNER JOIN SubmissionDetails
          ON SubmissionDetails.SubmissionHeaderID = SubmissionHeader.ID
        INNER JOIN SubmissionDetails_Explode
          ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
        INNER JOIN FormDescription
          ON SubmissionHeader.FormDescriptionID = FormDescription.ID
        INNER JOIN FormFieldDescription
          ON SubmissionDetails_Explode.FormFieldDescriptionID = FormFieldDescription.ID
        INNER JOIN employee_id_cte
          ON employee_id_cte.per_full_name = SubmissionDetails_Explode.Value
      WHERE (FormDescription.ID = 1404)
      AND CASE WHEN use_id = TRUE THEN SubmissionDetails.SubmissionHeaderID = submission_id ELSE CASE WHEN date_type = header_date THEN SubmissionHeader.HeaderDate BETWEEN start_date AND end_date WHEN date_type = submission_date THEN SubmissionHeader.FormSubmissionDate BETWEEN start_date AND end_date WHEN date_type = creation_date THEN SubmissionHeader.FormCreationDate BETWEEN start_date AND end_date END END
      AND FormFieldDescription.fieldKey IN ('employee_1', 'employee_2', 'employee_3', 'employee_4', 'employee_5', 'employee_6', 'employee_7', 'employee_8', 'employee_9', 'employee_10')
      AND SubmissionDetails_Explode.Value IS NOT NULL
      AND SubmissionDetails_Explode.VALUE != ''

      GROUP BY SubmissionHeaderID,
               fieldKey) AS employee_data),


  pay_type_cte
  AS
  (SELECT
      SubmissionHeaderID AS HeaderID,
      ROW_NUMBER() OVER (PARTITION BY SubmissionHeaderID ORDER BY fieldKey ASC) AS ROW_ID,
      FormFieldDescription.fieldKey AS fk1,
      SubmissionDetails_Explode.Value AS employee_pay
    FROM SubmissionHeader
      INNER JOIN SubmissionDetails
        ON SubmissionDetails.SubmissionHeaderID = SubmissionHeader.ID
      INNER JOIN SubmissionDetails_Explode
        ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
      INNER JOIN FormDescription
        ON SubmissionHeader.FormDescriptionID = FormDescription.ID
      INNER JOIN FormFieldDescription
        ON SubmissionDetails_Explode.FormFieldDescriptionID = FormFieldDescription.ID
    WHERE (FormDescription.ID = 1404)
    AND CASE WHEN use_id = TRUE THEN SubmissionDetails.SubmissionHeaderID = submission_id ELSE CASE WHEN date_type = header_date THEN SubmissionHeader.HeaderDate BETWEEN start_date AND end_date WHEN date_type = submission_date THEN SubmissionHeader.FormSubmissionDate BETWEEN start_date AND end_date WHEN date_type = creation_date THEN SubmissionHeader.FormCreationDate BETWEEN start_date AND end_date END END
    AND FormFieldDescription.fieldKey IN ('employee_pay_1', 'employee_pay_2', 'employee_pay_3', 'employee_pay_4', 'employee_pay_5',
    'employee_pay_6', 'employee_pay_7', 'employee_pay_8', 'employee_pay_9', 'employee_pay_10')
    AND SubmissionDetails_Explode.Value IS NOT NULL
    AND SubmissionDetails_Explode.VALUE != ''),


  employee_hours_cte
  AS
  (SELECT
      SubmissionHeaderID AS HeaderID,
      FormFieldDescription.fieldKey AS fk2,
      ROW_NUMBER() OVER (PARTITION BY SubmissionHeaderID ORDER BY fieldKey ASC) AS ROW_ID,
      SubmissionDetails_Explode.Value AS employee_hours
    FROM SubmissionHeader
      INNER JOIN SubmissionDetails
        ON SubmissionDetails.SubmissionHeaderID = SubmissionHeader.ID
      INNER JOIN SubmissionDetails_Explode
        ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
      INNER JOIN FormDescription
        ON SubmissionHeader.FormDescriptionID = FormDescription.ID
      INNER JOIN FormFieldDescription
        ON SubmissionDetails_Explode.FormFieldDescriptionID = FormFieldDescription.ID
    WHERE (FormDescription.ID = 1404)
    AND CASE WHEN use_id = TRUE THEN SubmissionDetails.SubmissionHeaderID = submission_id ELSE CASE WHEN date_type = header_date THEN SubmissionHeader.HeaderDate BETWEEN start_date AND end_date WHEN date_type = submission_date THEN SubmissionHeader.FormSubmissionDate BETWEEN start_date AND end_date WHEN date_type = creation_date THEN SubmissionHeader.FormCreationDate BETWEEN start_date AND end_date END END
    AND FormFieldDescription.fieldKey IN ('hours_1', 'hours_2', 'hours_3', 'hours_4', 'hours_5', 'hours_6', 'hours_7', 'hours_8', 'hours_9', 'hours_10')
    AND SubmissionDetails_Explode.VALUE IS NOT NULL
    AND SubmissionDetails_Explode.VALUE != ''),

  occupation_cte
  AS
  (SELECT
      *,
      ROW_NUMBER() OVER (PARTITION BY HeaderId ORDER BY fk3 ASC) AS ROW_ID
    FROM (SELECT
        SubmissionHeaderID AS HeaderID,
        FormFieldDescription.fieldKey AS fk3,
        GROUP_CONCAT(CAST(SubmissionDetails_Explode.Value AS varchar(50)) SEPARATOR ', ') AS occupation
      FROM SubmissionHeader
        INNER JOIN SubmissionDetails
          ON SubmissionDetails.SubmissionHeaderID = SubmissionHeader.ID
        INNER JOIN SubmissionDetails_Explode
          ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
        INNER JOIN FormDescription
          ON SubmissionHeader.FormDescriptionID = FormDescription.ID
        INNER JOIN FormFieldDescription
          ON SubmissionDetails_Explode.FormFieldDescriptionID = FormFieldDescription.ID
      WHERE (FormDescription.ID = 1404)
      AND CASE WHEN use_id = TRUE THEN SubmissionDetails.SubmissionHeaderID = submission_id ELSE CASE WHEN date_type = header_date THEN SubmissionHeader.HeaderDate BETWEEN start_date AND end_date WHEN date_type = submission_date THEN SubmissionHeader.FormSubmissionDate BETWEEN start_date AND end_date WHEN date_type = creation_date THEN SubmissionHeader.FormCreationDate BETWEEN start_date AND end_date END END
      AND FormFieldDescription.fieldKey IN ('occupation_1', 'occupation_2', 'occupation_3', 'occupation_4', 'occupation_5', 'occupation_6', 'occupation_7', 'occupation_8', 'occupation_9', 'occupation_10')
      AND SubmissionDetails_Explode.VALUE IS NOT NULL
      AND SubmissionDetails_Explode.VALUE != ''
      GROUP BY SubmissionHeaderID,
               fieldKey) AS occupation_data)

  SELECT
    employee_cte.HeaderID AS sumbission_header_id,
    employee_cte.employee_id AS employee_id,
    employee_cte.Employee AS employee,
    occupation_cte.occupation,
    CASE WHEN ASCII(pay_type_cte.employee_pay) >= 48 AND
        ASCII(pay_type_cte.employee_pay) <= 57 THEN CAST(get_translation(pay_type_cte.employee_pay, language_id, 1) AS varchar(50)) ELSE CAST(pay_type_cte.employee_pay AS varchar(50)) END AS employee_pay_type,
    CAST(employee_hours_cte.employee_hours AS decimal(22, 1)) AS employee_hours,
    CAST(number_of_employees * employee_hours AS decimal(22, 1)) AS total_hours
  FROM employee_cte
    LEFT JOIN occupation_cte
      ON employee_cte.ROW_ID = occupation_cte.ROW_ID
      AND employee_cte.HeaderID = occupation_cte.HeaderID
    LEFT JOIN employee_hours_cte
      ON employee_cte.ROW_ID = employee_hours_cte.ROW_ID
      AND employee_cte.HeaderID = employee_hours_cte.HeaderID
    LEFT JOIN pay_type_cte
      ON employee_cte.ROW_ID = pay_type_cte.ROW_ID
      AND employee_cte.HeaderID = pay_type_cte.HeaderID;


END
$$

DELIMITER ;

--
-- Drop procedure `put_hazard_action`
--
DROP PROCEDURE IF EXISTS put_hazard_action;

DELIMITER $$

--
-- Create procedure `put_hazard_action`
--
CREATE PROCEDURE IF NOT EXISTS put_hazard_action(OUT ID int,
IN SubmissionHeaderID int,
IN hazard_type int,
IN hazard_identification int,
IN hazard_identification_score int,
IN hazard_description longtext,
IN potential_risk int,
IN potential_risk_score int,
IN immediate_action_required_and_performed tinyint,
IN immediate_action_taken longtext,
IN immediate_action_type int,
IN immediate_action_score int,
IN further_action_required tinyint,
IN recommended_action longtext,
IN action_type int,
IN action_by_who nvarchar(400),
IN is_group tinyint,
IN action_by_when date,
IN action_status varchar(200),
IN action_complete_by_who nvarchar(400),
IN action_completed_date date,
IN completed_action_taken longtext,
IN completed_action_type int,
IN completed_action_score int,
IN submitted_by int)
BEGIN

  /*
  created by Robert Rivest
  Created on 2020-03-01
  Purpose to work with SQL Listener to insert a new Hazard Action
  Modified Date: 2020-09-22
  Modified By: Robert Rivest
  Reason:  to update Created and Modifield dates and also the Created and Modified By Fields
  Modified By: Wu Liao
  Reason:  to update hazard_type, hazard_identification,potential_risk,immediate_action_type,action_type,completed_action_type from char to int.
  Modified Date: 2022-07-06
  Modified By: Rana Hussain
  Reason: To get the email address for action_by_who per id
  
  Modified Date: 2023-02-14
  Modified By: Wu Liao
  Reason: SOF-12953 To assign hazard action to multiple users

  Modified Date: 2023-06-14
  Modified By: Sarath Sontam
  Reason: SOF-14392 - insert hap_per_id for hap_per_id when user doesnt have can assign multiple users permission. 

  Modified Date: 2023-08-03
  Modified By: James Coles
  Reason: SOF-14597 - Remove modified date and modified by from the insert statements.

  Modified Date: 2023-09-05
  Modified By: James Coles
  Reason: SOF-14788 - Setting the sha_is_group_action field.

  Modified Date: 2023-10-21
  Modified By: Sarath/Vishnu
  Reason: PD-3037- Multiple Hazard Action Not Going into Database( issue found part of PD-3021- Fix for the HAP attachment issue)

  Modified Date: 2025-02-20
  Modified By: Bob Rivest
  Reason: PD-3481- Add COLLESCE to ensure that the output does not end up with Null Value

  */

  DECLARE action_by_who_count int;
  DECLARE action_by_who_id int;
  DECLARE sha_id int;
  DECLARE hac_id int;
  DECLARE emails_ids varchar(10000);
  SET emails_ids = '';

  SELECT
    LENGTH(action_by_who) + 1 - LENGTH(REPLACE(action_by_who, '|', '')) INTO action_by_who_count;

  IF action_by_who_count > 1 THEN    -- Multiple Users
    IF is_group = 1 THEN      -- Multiple Users Group Action
      SET action_by_who_id = NULL;
      INSERT INTO SubmissionHAP (SubmissionHeaderID
      , hazard_type
      , hazard_identification
      , hazard_identification_score
      , hazard_description
      , potential_risk
      , potential_risk_score
      , immediate_action_required_and_performed
      , immediate_action_taken
      , immediate_action_type
      , immediate_action_score
      , further_action_required
      , recommended_action
      , action_type
      , action_by_who
      , action_by_when
      , action_status
      , action_complete_by_who
      , action_completed_date
      , completed_action_taken
      , completed_action_type
      , completed_action_score
      , sha_created_date
      , sha_created_by_per_id
      , sha_is_group_action)
        VALUES (SubmissionHeaderID, hazard_type, hazard_identification, hazard_identification_score, hazard_description, potential_risk, potential_risk_score, COALESCE(immediate_action_required_and_performed, 0), immediate_action_taken, immediate_action_type, immediate_action_score, COALESCE(further_action_required, 0), recommended_action, action_type, action_by_who_id, action_by_when, action_status, action_complete_by_who, action_completed_date, completed_action_taken, completed_action_type, completed_action_score, CURRENT_TIMESTAMP(), submitted_by, 1);

      SELECT
        LAST_INSERT_ID() INTO sha_id;
      BEGIN
        DECLARE a int DEFAULT 0;
        DECLARE hap_per_id int;
        DECLARE email_list varchar(100);
          insert_ha_person_loop:
        LOOP
          SET hap_per_id = NULL;
          SET a = a + 1;
          IF a <= action_by_who_count THEN
            SELECT
              CAST(SPLIT_STR(action_by_who, '|', a) AS int) INTO hap_per_id;
            INSERT INTO submission_hazard_action_person (hap_sha_id
            , hap_per_id
            , hap_created_date
            , hap_created_by_per_id
            , hap_enable)
              VALUES (sha_id, hap_per_id, CURRENT_TIMESTAMP(), submitted_by, 1);
            SELECT
              email
            FROM auth_user_sofvie
            WHERE user_per_id = hap_per_id INTO email_list;
            SET emails_ids = CONCAT(emails_ids, '|', sha_id, ',', COALESCE(email_list,''));
            ITERATE insert_ha_person_loop;
          END IF;
          LEAVE insert_ha_person_loop;
        END LOOP insert_ha_person_loop;
      END;
    ELSE   -- Multiple Users Single Action
    BEGIN
      DECLARE a int DEFAULT 0;
      DECLARE hap_per_id int;
      DECLARE email_list varchar(100);
        insert_submission_hazard_action_loop:
      LOOP
        SET hap_per_id = NULL;
        SET a = a + 1;
        IF a <= action_by_who_count THEN
          SELECT
            CAST(SPLIT_STR(action_by_who, '|', a) AS int) INTO hap_per_id;
          INSERT INTO SubmissionHAP (SubmissionHeaderID
          , hazard_type
          , hazard_identification
          , hazard_identification_score
          , hazard_description
          , potential_risk
          , potential_risk_score
          , immediate_action_required_and_performed
          , immediate_action_taken
          , immediate_action_type
          , immediate_action_score
          , further_action_required
          , recommended_action
          , action_type
          , action_by_when
          , action_status
          , action_complete_by_who
          , action_completed_date
          , completed_action_taken
          , completed_action_type
          , completed_action_score
          , sha_created_date
          , sha_created_by_per_id
          , sha_is_group_action)
            VALUES (SubmissionHeaderID, hazard_type, hazard_identification, hazard_identification_score, hazard_description, potential_risk, potential_risk_score, COALESCE(immediate_action_required_and_performed, 0), immediate_action_taken, immediate_action_type, immediate_action_score, COALESCE(further_action_required, 0), recommended_action, action_type, action_by_when, action_status, action_complete_by_who, action_completed_date, completed_action_taken, completed_action_type, completed_action_score, CURRENT_TIMESTAMP(), submitted_by, 0);
          SELECT
            LAST_INSERT_ID() INTO sha_id;
          INSERT INTO submission_hazard_action_person (hap_sha_id
          , hap_per_id
          , hap_created_date
          , hap_created_by_per_id
          , hap_enable)
            VALUES (sha_id, hap_per_id, CURRENT_TIMESTAMP(), submitted_by, 1);
          SELECT
            email
          FROM auth_user_sofvie
          WHERE user_per_id = hap_per_id INTO email_list;
          SET emails_ids = CONCAT(emails_ids, '|', sha_id, ',', COALESCE(email_list,''));
          ITERATE insert_submission_hazard_action_loop;
        END IF;
        LEAVE insert_submission_hazard_action_loop;
      END LOOP insert_submission_hazard_action_loop;
    END;
    END IF;
    SELECT
      emails_ids;
  ELSE     -- Single User Single Action
    INSERT INTO SubmissionHAP (SubmissionHeaderID
    , hazard_type
    , hazard_identification
    , hazard_identification_score
    , hazard_description
    , potential_risk
    , potential_risk_score
    , immediate_action_required_and_performed
    , immediate_action_taken
    , immediate_action_type
    , immediate_action_score
    , further_action_required
    , recommended_action
    , action_type
    , action_by_when
    , action_status
    , action_complete_by_who
    , action_completed_date
    , completed_action_taken
    , completed_action_type
    , completed_action_score
    , sha_created_date
    , sha_created_by_per_id
    , sha_is_group_action)
      VALUES (SubmissionHeaderID, hazard_type, hazard_identification, hazard_identification_score, hazard_description, potential_risk, potential_risk_score, COALESCE(immediate_action_required_and_performed, 0), immediate_action_taken, immediate_action_type, immediate_action_score, COALESCE(further_action_required, 0), recommended_action, action_type, action_by_when, action_status, action_complete_by_who, action_completed_date, completed_action_taken, completed_action_type, completed_action_score, CURRENT_TIMESTAMP(), submitted_by, 0);

    SELECT
      LAST_INSERT_ID() INTO sha_id;

    IF NULLIF(action_by_who, '') IS NULL THEN
      SET action_by_who_id = submitted_by;
    ELSE
      SET action_by_who_id = CAST(action_by_who AS int);


      INSERT INTO submission_hazard_action_person (hap_sha_id
      , hap_per_id
      , hap_created_date
      , hap_created_by_per_id
      , hap_enable)
        VALUES (sha_id, action_by_who_id, CURRENT_TIMESTAMP(), submitted_by, 1);
    END IF;
    IF immediate_action_required_and_performed = 1
      AND further_action_required = 0 THEN
      INSERT INTO submission_hazard_action_completion (hac_sha_id
      , hac_completed_action_date
      , hac_completed_action_taken
      , hac_completed_action_score
      , hac_rld_completed_action_type_id
      , hac_created_date
      , hac_created_by_per_id
      , hac_enable)
        VALUES (sha_id, CURRENT_TIMESTAMP(), immediate_action_taken, immediate_action_score, immediate_action_type, CURRENT_TIMESTAMP(), submitted_by, 1);
      SELECT
        LAST_INSERT_ID() INTO hac_id;
      INSERT INTO submission_hazard_action_completed_person (hcp_created_date
      , hcp_enable
      , hcp_created_by_per_id
      , hcp_hac_id
      , hcp_per_id)
        VALUES (CURRENT_TIMESTAMP(), 1, submitted_by, hac_id, action_by_who_id);
    END IF;
    SELECT
      sha_id AS ID,
      (SELECT
          email
        FROM auth_user_sofvie
        WHERE user_per_id = action_by_who) AS email;
  END IF;
END
$$

DELIMITER ;

--
-- Drop procedure `put_general_action`
--
DROP PROCEDURE IF EXISTS put_general_action;

DELIMITER $$

--
-- Create procedure `put_general_action`
--
CREATE PROCEDURE IF NOT EXISTS put_general_action(OUT ID int, IN submission_header_id int, IN action_type_rld_id int, IN action_by_who_per_id varchar(400), IN is_group tinyint, IN action_by_when date, IN recommended_action text, IN created_by_per_id int)
BEGIN

  /*
  Created By: Robert Rivest
  Purpose: to Insert General Action record into submission_general_action table
  Created Date: 2020-06-14
  Created By: Robert Rivest
  Purpose: Change Curdate to current_timetamp to get full date and Time - SOF-7433
  Created Date: 2021-04-28
  Modified Date: 2022-07-06
  Modified By: Rana Hussain
  Reason: To get the email address for sga_action_by_who_per_id per id

  Modified Date: 2023-01-20
  Modified By: Wu Liao
  Reason: SOF-12955 To assign general action to multiple users

  Modified Date: 2025-02-20
  Modified By: Bob Rivest
  Reason: PD-3481- Add COLLESCE to ensure that the output does not end up with Null Value
  */

  DECLARE action_by_who_count int(11);
  DECLARE action_by_who_id int;
  DECLARE sga_id int;
  DECLARE emails_ids varchar(10000);
  SET emails_ids = '';

  SELECT
    LENGTH(action_by_who_per_id) + 1 - LENGTH(REPLACE(action_by_who_per_id, '|', '')) INTO action_by_who_count;

  IF action_by_who_count > 1 THEN    -- Multiple Users
    IF is_group = 1 THEN      -- Multiple Users Group Action
      SET action_by_who_id = NULL;

      INSERT INTO submission_general_action (sga_submission_header_id
      , sga_action_type_rld_id
      , sga_action_by_who_per_id
      , sga_action_by_when
      , sga_recommended_action
      , sga_is_group_action
      , sga_action_is_complete
      , sga_created_date
      , sga_modified_date
      , sga_created_by_per_id
      , sga_modified_by_per_id)
        VALUES (submission_header_id, action_type_rld_id, action_by_who_id, action_by_when, recommended_action, is_group, 0, CURRENT_TIMESTAMP(), CURRENT_TIMESTAMP(), created_by_per_id, created_by_per_id);

      SELECT
        LAST_INSERT_ID() INTO sga_id;
      BEGIN
        DECLARE a int DEFAULT 0;
        DECLARE gap_per_id int;
        DECLARE email_list varchar(100);
          insert_ga_person_loop:
        LOOP
          SET gap_per_id = NULL;
          SET a = a + 1;
          IF a <= action_by_who_count THEN
            SELECT
              CAST(SPLIT_STR(action_by_who_per_id, '|', a) AS int) INTO gap_per_id;
            INSERT INTO submission_general_action_person (gap_sga_id
            , gap_per_id
            , gap_created_date
            , gap_created_by_per_id
            , gap_modified_date
            , gap_modified_by_per_id
            , gap_enable)
              VALUES (sga_id, gap_per_id, CURRENT_TIMESTAMP(), created_by_per_id, NULL, NULL, 1);
            SELECT
              email
            FROM auth_user_sofvie
            WHERE user_per_id = gap_per_id INTO email_list;
            SET emails_ids = CONCAT(emails_ids, '|', sga_id, ',', COALESCE(email_list, ''));
            ITERATE insert_ga_person_loop;
          END IF;
          LEAVE insert_ga_person_loop;
        END LOOP insert_ga_person_loop;
      END;
    ELSE     -- Multiple Users Single Action
    BEGIN
      DECLARE a int(11);
      DECLARE gap_per_id int;
      DECLARE email_list varchar(100);

      SET a = 0;
        insert_submission_general_action_loop:
      LOOP
        SET gap_per_id = NULL;
        SET a = a + 1;
        IF a <= action_by_who_count THEN
          SELECT
            CAST(SPLIT_STR(action_by_who_per_id, '|', a) AS int) INTO gap_per_id;
          INSERT INTO submission_general_action (sga_submission_header_id
          , sga_action_type_rld_id
          , sga_action_by_who_per_id
          , sga_action_by_when
          , sga_recommended_action
          , sga_is_group_action
          , sga_action_is_complete
          , sga_created_date
          , sga_modified_date
          , sga_created_by_per_id
          , sga_modified_by_per_id)
            VALUES (submission_header_id, action_type_rld_id, gap_per_id, action_by_when, recommended_action, is_group, 0, CURRENT_TIMESTAMP(), CURRENT_TIMESTAMP(), created_by_per_id, created_by_per_id);
          SELECT
            LAST_INSERT_ID() INTO sga_id;
          INSERT INTO submission_general_action_person (gap_sga_id
          , gap_per_id
          , gap_created_date
          , gap_created_by_per_id
          , gap_modified_date
          , gap_modified_by_per_id
          , gap_enable)
            VALUES (sga_id, gap_per_id, CURRENT_TIMESTAMP(), created_by_per_id, NULL, NULL, 1);
          SELECT
            email
          FROM auth_user_sofvie
          WHERE user_per_id = gap_per_id INTO email_list;
          SET emails_ids = CONCAT(emails_ids, '|', sga_id, ',',COALESCE(email_list, ''));
          ITERATE insert_submission_general_action_loop;
        END IF;
        LEAVE insert_submission_general_action_loop;
      END LOOP insert_submission_general_action_loop;
    END;
    END IF;
    SELECT
      emails_ids;
  ELSE     -- Single User Single Action
    SET action_by_who_id = CAST(action_by_who_per_id AS int);
    INSERT INTO submission_general_action (sga_submission_header_id
    , sga_action_type_rld_id
    , sga_action_by_who_per_id
    , sga_action_by_when
    , sga_recommended_action
    , sga_is_group_action
    , sga_action_is_complete
    , sga_created_date
    , sga_modified_date
    , sga_created_by_per_id
    , sga_modified_by_per_id)
      VALUES (submission_header_id, action_type_rld_id, action_by_who_id, action_by_when, recommended_action, is_group, 0, CURRENT_TIMESTAMP(), CURRENT_TIMESTAMP(), created_by_per_id, created_by_per_id);

    SELECT
      LAST_INSERT_ID() INTO sga_id;
    INSERT INTO submission_general_action_person (gap_sga_id
    , gap_per_id
    , gap_created_date
    , gap_created_by_per_id
    , gap_modified_date
    , gap_modified_by_per_id
    , gap_enable)
      VALUES (sga_id, action_by_who_per_id, CURRENT_TIMESTAMP(), created_by_per_id, NULL, NULL, 1);

    SELECT
      sga_id AS ID,
      (SELECT
          email
        FROM auth_user_sofvie
        WHERE user_per_id = action_by_who_per_id) AS email;
  END IF;
END
$$

DELIMITER ;

--
-- Drop procedure `rpt_equipment_comments`
--
DROP PROCEDURE IF EXISTS rpt_equipment_comments;

DELIMITER $$

--
-- Create procedure `rpt_equipment_comments`
--
CREATE PROCEDURE IF NOT EXISTS rpt_equipment_comments(IN submissionheader_id longtext, IN comment_flag int)
BEGIN

  /*
  
  Created By: Pragati Das/James Coles
  Creation Date: 02-04-2024
  Description: PD-1349 - New SP for the comments
  
  Modified By: Naveen Vadlamudi/James Coles
  Creation Date: 02-04-2024
  Description: PD-1349 - New SP for the comments

  */

  SET @comment_flag = comment_flag;

  SET @sqlStatement = CONCAT("with cte as (select * 
    from preop_submission_header
    WHERE CASE WHEN ? = 1 THEN psh_submissionheader_id IN (SELECT
                psh_submissionheader_id
              FROM preop_submission_header
                INNER JOIN preop_submission_value psv
                  ON psv.psv_psh_id = preop_submission_header.psh_id
              WHERE (psv.psv_preop_question_identifier = 'comments'
              AND psv.psv_value IS NOT NULL
              AND LENGTH(psv.psv_value) > 0
              AND psh_submissionheader_id in( ", submissionheader_id, "   )))
              ELSE psh_submissionheader_id in( ", submissionheader_id, "  )  END
    )
    
    
    SELECT
        psh_submissionheader_id,
        psv_value,
        psv_preop_question_identifier
      FROM cte
        INNER JOIN preop_submission_value
          ON cte.psh_id = preop_submission_value.psv_psh_id
     AND (preop_submission_value.psv_preop_question_identifier LIKE 'measure-start-%'
       OR preop_submission_value.psv_preop_question_identifier LIKE 'measure-end-%' OR
       preop_submission_value.psv_preop_question_identifier IN( 'othercomments' , 'workplaceendshift', 'comments'   ) )
      AND preop_submission_value.psv_enable = 1
        GROUP BY psh_submissionheader_id,
               psv_preop_question_identifier ;");


  PREPARE sqlResults FROM @sqlStatement;
  EXECUTE sqlResults USING @comment_flag;
  DEALLOCATE PREPARE sqlResults;

END
$$

DELIMITER ;



--
-- Drop foreign key
--
ALTER TABLE RootCauseAnalysis
DROP FOREIGN KEY IF EXISTS RootCauseAnalysis_IncidentID_eeb77bbf_fk_Incidents_ID;


--
-- Set default database
--


drop procedure if EXISTS rpt_pre_op_submissions_by_user;

DELIMITER $$

--
-- Create procedure `rpt_pre_op_submissions_by_user`
--
CREATE PROCEDURE IF NOT EXISTS rpt_pre_op_submissions_by_user(IN StartDate DATE, IN EndDate DATE, IN user_ids TEXT, IN lang INT)
BEGIN

/* 
 Created by : Pragati Das
 Created On : 2025-02-15
 Purpose : PD-3319 Details for pre op submissions by job breakdown report
 */

SELECT
pet_id AS equipment_id,
SubmissionHeader.SubmittedBy_SupervisorID AS user_id,
CASE WHEN v_employee.is_active = 1 AND
        v_employee.emp_enable = 1 THEN v_employee.per_full_name 
ELSE CONCAT(v_employee.per_full_name,get_translation(9169, lang, 1)) END AS user_name,

CONCAT(CASE WHEN preop_equipment_type.pet_enable = 1 AND
preop_equipment_type.pet_is_active = 1 
THEN preop_equipment_type.pet_equipment_identifier 
ELSE CONCAT(preop_equipment_type.pet_equipment_identifier, ' - ', get_translation(9169, lang, 1)) END,' - ',
CASE WHEN preop_equipment.poe_enable = 1 
THEN get_translation(preop_equipment.poe_equip_description, lang, poe_tag_type) 
ELSE CONCAT(get_translation(preop_equipment.poe_equip_description, lang, poe_tag_type), ' - ', get_translation(9169, lang, 1)) END) AS equipment_name,

 COUNT(*) AS total,
  DATE(FormSubmissionDate) as submission_date
FROM preop_submission_header
  JOIN preop_equipment_type
    ON preop_submission_header.psh_pet_id = pet_id
  JOIN preop_equipment
    ON preop_equipment_type.pet_poe_id = preop_equipment.poe_id
  JOIN SubmissionHeader
    ON psh_submissionheader_id = SubmissionHeader.ID
    INNER JOIN v_employee
      ON SubmissionHeader.SubmittedBy_SupervisorID = v_employee.per_id
  INNER JOIN ref_list_detail
        ON SubmissionHeader.JobNumber = ref_list_detail.rld_id
WHERE SubmissionHeader.she_aco_id is NULL
AND IF(user_ids <> '', FIND_IN_SET(SubmissionHeader.SubmittedBy_SupervisorID, user_ids), 1=1)

AND DATE(FormSubmissionDate) BETWEEN StartDate AND EndDate
GROUP BY psh_pet_id,
         DATE(FormSubmissionDate),
SubmissionHeader.SubmittedBy_SupervisorID
ORDER BY psh_id DESC;

END
$$

DELIMITER ;

drop procedure if EXISTS rpt_pre_op_submissions_by_site;

DELIMITER $$

--
-- Create procedure `rpt_pre_op_submissions_by_site`
--
CREATE PROCEDURE IF NOT EXISTS rpt_pre_op_submissions_by_site(IN StartDate DATE, IN EndDate DATE, IN site_ids TEXT, IN lang INT)
BEGIN

/* 
 Created by : Pragati Das
 Created On : 2025-02-15
 Purpose : PD-3319 Details for pre op submissions by job breakdown report
 */

SELECT
  pet_id AS equipment_id,
  SubmissionHeader.Site AS site_id,
CASE WHEN (rld_enable = 1 AND rld_is_active = 1) THEN get_translation_from_ref_list_id(SubmissionHeader.Site, 'ref_site', lang) 
ELSE CONCAT(get_translation_from_ref_list_id(SubmissionHeader.Site, 'ref_site', lang),' ', get_translation(9169,lang,1) ) END site_name,
CONCAT(CASE WHEN preop_equipment_type.pet_enable = 1 AND
preop_equipment_type.pet_is_active = 1 
THEN preop_equipment_type.pet_equipment_identifier 
ELSE CONCAT(preop_equipment_type.pet_equipment_identifier, ' - ', get_translation(9169, lang, 1)) END,' - ',
CASE WHEN preop_equipment.poe_enable = 1 
THEN get_translation(preop_equipment.poe_equip_description, lang, poe_tag_type) 
ELSE CONCAT(get_translation(preop_equipment.poe_equip_description, lang, poe_tag_type), ' - ', get_translation(9169, lang, 1)) END) AS equipment_name,
  COUNT(*) AS total,
  DATE(FormSubmissionDate) as submission_date
FROM preop_submission_header
  JOIN preop_equipment_type
    ON preop_submission_header.psh_pet_id = pet_id
  JOIN preop_equipment
    ON preop_equipment_type.pet_poe_id = preop_equipment.poe_id
  JOIN SubmissionHeader
    ON psh_submissionheader_id = SubmissionHeader.ID
INNER JOIN ref_list_detail ON
ref_list_detail.rld_id = SubmissionHeader.Site
WHERE if(site_ids <> '', FIND_IN_SET(SubmissionHeader.Site, site_ids), 1=1)
AND SubmissionHeader.she_aco_id is NULL
AND DATE(FormSubmissionDate) BETWEEN StartDate AND EndDate
GROUP BY psh_pet_id,
         DATE(FormSubmissionDate),
         SubmissionHeader.Site
ORDER BY psh_id DESC;

END
$$

DELIMITER ;

drop procedure if EXISTS   rpt_pre_op_submissions_by_job;

DELIMITER $$

--
-- Create procedure `rpt_pre_op_submissions_by_job`
--
CREATE PROCEDURE IF NOT EXISTS rpt_pre_op_submissions_by_job(IN StartDate DATE, IN EndDate DATE, IN job_ids TEXT, IN lang INT)
BEGIN

/* 
 Created by : Pragati Das
 Created On : 2025-02-15
 Purpose : PD-3319 Details for pre op submissions by job breakdown report
 */

SELECT

pet_id AS equipment_id,
SubmissionHeader.JobNumber AS job_id,
CASE WHEN (rld_enable = 1 AND rld_is_active = 1) THEN get_translation_from_ref_list_id(SubmissionHeader.JobNumber, 'ref_job', lang) 
ELSE CONCAT(get_translation_from_ref_list_id(SubmissionHeader.JobNumber, 'ref_job', lang),' ', get_translation(9169,lang,1) ) END job_name,
CONCAT(CASE WHEN preop_equipment_type.pet_enable = 1 AND
preop_equipment_type.pet_is_active = 1 
THEN preop_equipment_type.pet_equipment_identifier 
ELSE CONCAT(preop_equipment_type.pet_equipment_identifier, ' - ', get_translation(9169, lang, 1)) END,' - ',
CASE WHEN preop_equipment.poe_enable = 1 
THEN get_translation(preop_equipment.poe_equip_description, lang, poe_tag_type) 
ELSE CONCAT(get_translation(preop_equipment.poe_equip_description, lang, poe_tag_type), ' - ', get_translation(9169, lang, 1)) END) AS equipment_name,  COUNT(*) AS total,
  DATE(FormSubmissionDate) as submission_date
FROM preop_submission_header
  JOIN preop_equipment_type
    ON preop_submission_header.psh_pet_id = pet_id
  JOIN preop_equipment
    ON preop_equipment_type.pet_poe_id = preop_equipment.poe_id
  JOIN SubmissionHeader
    ON psh_submissionheader_id = SubmissionHeader.ID
  INNER JOIN ref_list_detail
        ON SubmissionHeader.JobNumber = ref_list_detail.rld_id
WHERE SubmissionHeader.she_aco_id is NULL
AND IF(job_ids <> '', FIND_IN_SET(SubmissionHeader.JobNumber, job_ids), 1=1)
AND DATE(FormSubmissionDate) BETWEEN StartDate AND EndDate
GROUP BY psh_pet_id,
         DATE(FormSubmissionDate),
         SubmissionHeader.JobNumber
ORDER BY psh_id DESC;

END
$$

DELIMITER ;

drop procedure if EXISTS   rpt_pre_op_submissions_by_equipment;

DELIMITER $$

--
-- Create procedure `rpt_pre_op_submissions_by_equipment`
--
CREATE PROCEDURE IF NOT EXISTS rpt_pre_op_submissions_by_equipment(IN StartDate DATE, IN EndDate DATE, IN equipment_ids TEXT, IN lang INT)
BEGIN

/* 
 Created by : Pragati Das
 Created On : 2025-02-15
 Purpose : PD-3319 Details for pre op submissions by job breakdown report
 */

SELECT
  pet_id AS equipment_id,
  CONCAT(CASE WHEN preop_equipment_type.pet_enable = 1 AND
preop_equipment_type.pet_is_active = 1 
THEN preop_equipment_type.pet_equipment_identifier 
ELSE CONCAT(preop_equipment_type.pet_equipment_identifier, ' - ', get_translation(9169, lang, 1)) END,' - ',
CASE WHEN preop_equipment.poe_enable = 1 
THEN get_translation(preop_equipment.poe_equip_description, lang, poe_tag_type) 
ELSE CONCAT(get_translation(preop_equipment.poe_equip_description, lang, poe_tag_type), ' - ', get_translation(9169, lang, 1)) END) AS equipment_name, 
  COUNT(*) AS total,
  DATE(FormSubmissionDate) AS submission_date
FROM preop_submission_header
  JOIN preop_equipment_type
    ON preop_submission_header.psh_pet_id = pet_id
  JOIN preop_equipment
    ON preop_equipment_type.pet_poe_id = preop_equipment.poe_id
  JOIN SubmissionHeader
    ON psh_submissionheader_id = SubmissionHeader.ID
WHERE IF(equipment_ids <> '', FIND_IN_SET(psh_pet_id, equipment_ids), 1=1)

AND DATE(FormSubmissionDate) BETWEEN StartDate AND EndDate
GROUP BY psh_pet_id, submission_date
ORDER BY psh_id DESC;


END
$$

DELIMITER ;

drop procedure if EXISTS rpt_pre_op_submissions_by_breakdown;

DELIMITER $$

--
-- Create procedure `rpt_pre_op_submissions_by_breakdown`
--
CREATE PROCEDURE IF NOT EXISTS rpt_pre_op_submissions_by_breakdown(IN start_date DATE, IN end_date DATE, IN lang INT)
BEGIN

  /*

  Created By:Pragati Das
  Creation Date: 2025-02-12
  Description: PD-3319 - Pre-Op submission report
  
  */

SELECT
  pet_id AS equipment_id,
CONCAT(CASE WHEN preop_equipment_type.pet_enable = 1 AND
preop_equipment_type.pet_is_active = 1 
THEN preop_equipment_type.pet_equipment_identifier 
ELSE CONCAT(preop_equipment_type.pet_equipment_identifier, ' - ', get_translation(9169, lang, 1)) END,' - ',
CASE WHEN preop_equipment.poe_enable = 1 
THEN get_translation(preop_equipment.poe_equip_description, lang, poe_tag_type) 
ELSE CONCAT(get_translation(preop_equipment.poe_equip_description, lang, poe_tag_type), ' - ', get_translation(9169, lang, 1)) END) AS equipment_name,   
  COUNT(*) AS total,
  DATE(FormSubmissionDate) AS submission_date
FROM preop_submission_header
  JOIN preop_equipment_type
    ON preop_submission_header.psh_pet_id = pet_id
  JOIN preop_equipment
    ON preop_equipment_type.pet_poe_id = preop_equipment.poe_id
  JOIN SubmissionHeader
    ON psh_submissionheader_id = SubmissionHeader.ID
WHERE DATE(FormSubmissionDate) BETWEEN start_date AND end_date
GROUP BY psh_pet_id, submission_date
ORDER BY psh_id DESC;

END
$$

DELIMITER ;


--
-- Drop procedure `get_person_document`
--
DROP PROCEDURE IF EXISTS get_person_document;

DELIMITER $$

--
-- Create procedure `get_person_document`
--
CREATE PROCEDURE IF NOT EXISTS get_person_document (IN person_id int, IN start_date date, IN end_date date)
BEGIN


  /*
     Created by: Rana Hussain
     Modified on: 2022-02-24
     Reason: SOF-10407 - Security patch: Convert raw query to stored procedure

     Modified by: Gowtham Ravindran
     Modified on: 2023-01-01
     Reason: SOF-12703 Home Page Revamp

     Modified by: Robert Rivest
     Modified on: 2023-12-08
     Reason: PD-372 - Correct SQL to properly show persons pending document review and also include the date range
     
     Modified by: Gowtham Ravindran
     Modified on: 2025-01-30
     Reason: PD-3067 - Added Non Expiring documents to the condition
   
  */

  SELECT
    document_review_management.drm_id
  FROM document_review_management
    INNER JOIN document_review_management_reviewer
      ON document_review_management.drm_id = document_review_management_reviewer.drr_drm_id
  WHERE document_review_management.drm_enable = 1
  AND document_review_management_reviewer.drr_enable = 1
  AND document_review_management.drm_is_submitted = 1
  AND document_review_management_reviewer.drr_is_mandatory = 1
  AND document_review_management_reviewer.drr_per_id = person_id
  AND document_review_management_reviewer.drr_is_reviewed = 0
  AND CAST(document_review_management.drm_submitted_date AS date) BETWEEN CAST(start_date AS date) AND CAST(end_date AS date)
  AND (document_review_management.drm_non_expiring_document = 1
  OR DATEDIFF(document_review_management.drm_expiry_date, NOW()) > 0)
  GROUP BY drm_id;

END
$$

DELIMITER ;

--
-- Drop procedure `get_all_document`
--
DROP PROCEDURE IF EXISTS get_all_document;

DELIMITER $$

--
-- Create procedure `get_all_document`
--
CREATE PROCEDURE IF NOT EXISTS get_all_document (IN start_date date, IN end_date date, IN filter_per_id int, IN drm_grid_filter_type text)
BEGIN

  /*
     Created by: Rana Hussain
     Modified on: 2022-02-24
     Reason: SOF-10407 - Security patch: Convert raw query to stored procedure
     Modified by: Rana Hussain
     Modified on: 2022-09-02
     Reason: SOF-12179 - Changed to use submitted date instead of created date
     Modified by: Gowtham Ravindran
     Modified on: 2025-01-03
     Reason: PD-3067 - Added Grid filter conditions "a_to_me" : Tag(1062), // Assigned to be me
                									"c_by_me" : Tag(1063), // Created by me
               									 	"r_by_me" : Tag(10006), // Reviewed by me
  */

  SELECT
    document_review_management.drm_id
  FROM document_review_management
    LEFT JOIN document_review_management_reviewer
      ON document_review_management_reviewer.drr_drm_id = document_review_management.drm_id
  WHERE (document_review_management.drm_enable = 1
  AND (document_review_management.drm_submitted_date >= start_date
  AND document_review_management.drm_submitted_date <= end_date)
  OR (document_review_management.drm_is_submitted = 0
  AND document_review_management.drm_enable = 1
  AND ISNULL(document_review_management.drm_submitted_date)
  OR document_review_management.drm_submitted_date = ''))
  AND (CASE drm_grid_filter_type WHEN 'a_to_me' THEN (document_review_management_reviewer.drr_per_id = filter_per_id
        AND document_review_management_reviewer.drr_is_mandatory = 1) WHEN 'r_by_me' THEN (document_review_management_reviewer.drr_per_id = filter_per_id
        AND document_review_management_reviewer.drr_is_reviewed = 1) WHEN 'c_by_me' THEN (document_review_management.drm_created_by_per_id = filter_per_id) ELSE 1 END);

END
$$

DELIMITER ;

--
-- Alter table `distribution_group_email`
--
ALTER TABLE distribution_group_email
ENCRYPTED = YES;

--
-- Create column `dge_per_id` on table `distribution_group_email`
--
ALTER TABLE distribution_group_email
ADD COLUMN IF NOT EXISTS dge_per_id int(11) DEFAULT NULL;

--
-- Create column `dge_edl_id` on table `distribution_group_email`
--
ALTER TABLE distribution_group_email
ADD COLUMN IF NOT EXISTS dge_edl_id int(11) DEFAULT NULL;

--
-- Change columns order on table `distribution_group_email`
--
ALTER TABLE distribution_group_email
MODIFY dge_per_id int(11) DEFAULT NULL AFTER dge_email;
ALTER TABLE distribution_group_email
MODIFY dge_edl_id int(11) DEFAULT NULL AFTER dge_per_id;

--
-- Create foreign key
--
ALTER TABLE distribution_group_email
ADD CONSTRAINT FK_distribution_group_email_dge_edl_id FOREIGN KEY IF NOT EXISTS (dge_edl_id)
REFERENCES external_distribution_list (edl_id) ON DELETE NO ACTION;

--
-- Create foreign key
--
ALTER TABLE distribution_group_email
ADD CONSTRAINT FK_distribution_group_email_dge_per_id FOREIGN KEY IF NOT EXISTS (dge_per_id)
REFERENCES person (per_id) ON DELETE NO ACTION;

DELIMITER $$

--
-- Create procedure `api_decision_log_decision`
--
CREATE PROCEDURE IF NOT EXISTS api_decision_log_decision (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-10
     Reason    :    PD-2955 - Get data decision log decision.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  SELECT
    dl.dlm_id AS id,
    dl.dlm_date AS date,
    dl.dlm_created_date AS created_date,
    dl.dlm_submitted_date AS submitted_date,
    dl.dlm_modified_date AS modified_date,
    dl.dlm_description AS description,
    dl.dlm_context AS context
  FROM decision_log dl
  WHERE CASE WHEN use_id = TRUE THEN dl.dlm_id = id ELSE CASE WHEN date_type = header_date THEN dl.dlm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN dl.dlm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN dl.dlm_created_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN dl.dlm_modified_date BETWEEN start_date AND end_date END END
  AND dl.dlm_enable = 1
  GROUP BY dl.dlm_id;


END
$$

DELIMITER ;

--
-- Alter column `CreatedBy` on table `Incidents`
--
ALTER TABLE Incidents
CHANGE COLUMN IF EXISTS CreatedBy CreatedBy int(11) NOT NULL;

--
-- Create column `inc_minimum_incident_date` on table `Incidents`
--
ALTER TABLE Incidents
ADD COLUMN IF NOT EXISTS inc_minimum_incident_date date DEFAULT NULL;

--
-- Change columns order on table `Incidents`
--
ALTER TABLE Incidents
MODIFY inc_minimum_incident_date date DEFAULT NULL AFTER inc_is_quick_signoff;

--
-- Change columns order on table `RootCauseAnalysis`
--
ALTER TABLE RootCauseAnalysis
MODIFY rca_aco_id int(11) DEFAULT NULL AFTER ID;

--
-- Create foreign key
--
ALTER TABLE RootCauseAnalysis
ADD CONSTRAINT RootCauseAnalysis_IncidentID_eeb77bbf_fk_Incidents_ID FOREIGN KEY IF NOT EXISTS (IncidentID)
REFERENCES Incidents (ID);

--
-- Create column `pet_start_photos_required` on table `preop_equipment_type`
--
ALTER TABLE preop_equipment_type
ADD COLUMN IF NOT EXISTS pet_start_photos_required tinyint(4) NOT NULL DEFAULT 1;

--
-- Create column `pet_end_photos_required` on table `preop_equipment_type`
--
ALTER TABLE preop_equipment_type
ADD COLUMN IF NOT EXISTS pet_end_photos_required tinyint(4) NOT NULL DEFAULT 1;

--
-- Change columns order on table `preop_equipment_type`
--
ALTER TABLE preop_equipment_type
MODIFY pet_start_photos_required tinyint(4) NOT NULL DEFAULT 1 AFTER pet_is_active;
ALTER TABLE preop_equipment_type
MODIFY pet_end_photos_required tinyint(4) NOT NULL DEFAULT 1 AFTER pet_start_photos_required;

--
-- Drop procedure `get_preop_equip_question_lookup_distinct`
--
DROP PROCEDURE IF EXISTS get_preop_equip_question_lookup_distinct;

DELIMITER $$

--
-- Create procedure `get_preop_equip_question_lookup_distinct`
--
CREATE PROCEDURE IF NOT EXISTS get_preop_equip_question_lookup_distinct ()
BEGIN

  /*
       Modified   : 2023-02-15
       Modified by: Robert Rivest
       Reason     : SOF-13504 - Changed to work with new Field Names and new preop_equipment_type pet table

     Modified by: Vishnu Prakash
     Date       : 2024-11-14
     Reason     : PD-840 - Equipment-Pre-Op---Active-In-Active-Option

     Modified by: Vishnu Prakash
     Date       : 2025-01-27
     Reason     : PD-3270 - Equipment-Pre-Op-Turn off mandatory pictures
  */

  SELECT
    pet_id,
    pet_equipment_identifier,
    pet_poe_id,
    pet_start_photos_required,
    pet_end_photos_required
  FROM preop_equipment_type
  WHERE pet_enable = 1
  AND pet_is_active = 1;

END
$$

DELIMITER ;

--
-- Create column `pct_is_static` on table `preop_checkpoint_type`
--
ALTER TABLE preop_checkpoint_type
ADD COLUMN IF NOT EXISTS pct_is_static tinyint(4) DEFAULT 0;

--
-- Change columns order on table `preop_checkpoint_type`
--
ALTER TABLE preop_checkpoint_type
MODIFY pct_is_static tinyint(4) DEFAULT 0 AFTER pct_additional_info;

--
-- Drop procedure `get_hazard_by_score_by_type`
--
DROP PROCEDURE IF EXISTS get_hazard_by_score_by_type;

DELIMITER $$

--
-- Create procedure `get_hazard_by_score_by_type`
--
CREATE PROCEDURE IF NOT EXISTS get_hazard_by_score_by_type (IN filter_jobs text, IN filter_supervisors text, IN filter_start_date datetime, IN filter_end_date datetime, IN lang varchar(2))
BEGIN

  /*
  Creation Date: 2020-05-04
  Created By: Vishnu Prakash
  Description: hazard listing where toogles - score and type is TRUE
  *******************************************************************
  Change History
  *******************************************************************
  Modifed Date: 2021-04-08
  Modified By: Vishnu Prakash
  Comment: add condition 'and SubmissionHAP.sha_enable = true'

  Modifed Date: 2021-07-08
  Modified By: Gowtham Ravindran
  Comment: updated Language support for I18n and new Tag type field

  Modified Date: 2021-09-21
  Modified By: Gowtham Ravindran
  Modification: SOF-9033 -Changed the datatype of filter dates

  Modified Date: 2021-12-14
  Modified By: Sarath Sontam
  Modification: SOF-9899 - remove unused columns in select and simplify query to get right count. 

  Modified   : March 16th, 2022
  Modified by: James Coles
  Reason     : SOF-10397 - Validate parameters.
  
  Modified   : June 7th, 2023
  Modified by: James Coles, Suman Marlapudi
  Reason     : SOF-14391 - Remove temporary tables, use prepared statement instead.

  Modified by: Suman Marlapudi
  Date       : 2023-11-24
  Reason     : SOF-14025 - Replace the deprecated SELECT INTO clause with variables.

  Modified by: James Coles
  Date       : 2025-02-18
  Reason     : Fixing the filtering dates to header date

  */

  DECLARE sqlStatement longtext;
  DECLARE lang_id int;

  SET @filter_start_date = filter_start_date;
  SET @filter_end_date = filter_end_date;
  SET @lang = lang;
  SET lang_id := 0;

  SET lang_id = (SELECT
      lng_id
    FROM language
    WHERE lng_name = @lang);

  SET @lang_id = lang_id;


  SET @sqlStatement := CONCAT('
  WITH subQuery
  AS
  (SELECT
        SubmissionHAP.hazard_identification,
        SubmissionHAP.hazard_identification_score,
        ltr_text
      FROM SubmissionHAP
        JOIN SubmissionHeader
          ON SubmissionHAP.SubmissionHeaderID = SubmissionHeader.ID
        JOIN v_employee
          ON SubmissionHeader.SubmittedBy_SupervisorID = v_employee.per_id
        JOIN FormDescription
          ON SubmissionHeader.FormDescriptionID = FormDescription.ID
        LEFT JOIN (SELECT
            ref_list_detail.rld_id AS job_id,
            ref_list_detail.rld_code AS job
          FROM ref_list_detail
            INNER JOIN ref_list_header
              ON ref_list_detail.rld_rlh_id = ref_list_header.rlh_id
          WHERE ref_list_header.rlh_name = "ref_job") jobs
          ON jobs.job_id = SubmissionHeader.JobNumber
        JOIN ref_list_detail
          ON ref_list_detail.rld_id = SubmissionHAP.hazard_identification
          AND rld_rlh_id = 13
        JOIN language_translation
          ON ltr_tag = rld_name
          AND ltr_tag_type = rld_tag_type
          AND ltr_lng_id = ?
      WHERE jobs.job_id IN (', filter_jobs, ')
      AND (SubmissionHeader.IsArchived IS NULL
      OR SubmissionHeader.IsArchived = 0)
      AND v_employee.per_id IN (', filter_supervisors, ')
      AND HeaderDate BETWEEN ? AND ?
      AND SubmissionHAP.sha_enable = TRUE)
  SELECT
    ltr_text AS `key`,
    GROUP_CONCAT(DISTINCT hazard_identification) AS id,
    SUM(hazard_identification_score) AS value
  FROM subQuery
  WHERE hazard_identification <> ""
  GROUP BY ltr_text  ');

  PREPARE sqlResults FROM @sqlStatement;
  EXECUTE sqlResults USING @lang_id, @filter_start_date, @filter_end_date;
  DEALLOCATE PREPARE sqlResults;

END
$$

DELIMITER ;

--
-- Drop procedure `get_hazard_by_score_by_form`
--
DROP PROCEDURE IF EXISTS get_hazard_by_score_by_form;

DELIMITER $$

--
-- Create procedure `get_hazard_by_score_by_form`
--
CREATE PROCEDURE IF NOT EXISTS get_hazard_by_score_by_form (IN filter_jobs text, IN filter_supervisors text, IN filter_start_date datetime, IN filter_end_date datetime, IN lang varchar(2))
BEGIN

  /*
  Creation Date: 2020-05-04
  Created By: Vishnu Prakash
  Description: hazard listing where toogles - score and form is TRUE
  *******************************************************************
  Change History
  *******************************************************************
  Modifed Date: 2021-04-08
  Modified By: Vishnu Prakash
  Comment: add condition 'and SubmissionHAP.sha_enable = true'

  Modifed Date: 2021-07-08
  Modified By: Gowtham Ravindran
  Comment: updated Language support for I18n and new Tag type field

  Modified Date: 2021-09-21
  Modified By: Gowtham Ravindran
  Modification: SOF-9033 -Changed the datatype of filter dates

  Modified Date: 2021-12-14
  Modified By: Sarath Sontam
  Modification: SOF-9899 - remove unused columns in select and simplify query to get right count. 

  Modified   : March 16th, 2022
  Modified by: James Coles
  Reason     : SOF-10397 - Validate parameters.
   
  Modified   : June 7th, 2023
  Modified by: James Coles, Suman Marlapudi
  Reason     : SOF-14391 - Remove temporary tables, use prepared statement instead.

  Modified by: Suman Marlapudi
  Date       : 2023-11-24
  Reason     : SOF-14025 - Replace the deprecated SELECT INTO clause with variables.

  Modified by: James Coles
  Date       : 2025-02-18
  Reason     : Fixing the filtering dates to header date
   
   */

  DECLARE sqlStatement longtext;
  DECLARE lang_id int;

  SET @filter_jobs = filter_jobs;
  SET @filter_supervisors = filter_supervisors;
  SET @filter_start_date = filter_start_date;
  SET @filter_end_date = filter_end_date;
  SET @lang = lang;
  SET lang_id := 0;

  SET lang_id = (SELECT
      lng_id
    FROM language
    WHERE lng_name = @lang);

  SET @lang_id = lang_id;

  SET @sqlStatement := CONCAT('
  WITH subQuery
  AS
  (SELECT
        FormName,
        ltr_text,
        hazard_identification_score,
        hazard_identification
      FROM SubmissionHAP
        JOIN SubmissionHeader
          ON SubmissionHAP.SubmissionHeaderID = SubmissionHeader.ID
        JOIN v_employee
          ON SubmissionHeader.SubmittedBy_SupervisorID = v_employee.per_id
        JOIN FormDescription
          ON SubmissionHeader.FormDescriptionID = FormDescription.ID
        LEFT JOIN (SELECT
            ref_list_detail.rld_id AS job_id,
            ref_list_detail.rld_code AS job
          FROM ref_list_detail
            INNER JOIN ref_list_header
              ON ref_list_detail.rld_rlh_id = ref_list_header.rlh_id
          WHERE ref_list_header.rlh_name = "ref_job") jobs
          ON jobs.job_id = SubmissionHeader.JobNumber
        JOIN language_translation
          ON FormDescription.FormName = ltr_tag
          AND ltr_tag_type = 1
          AND ltr_lng_id = ?
      WHERE jobs.job_id IN (', filter_jobs, ')
      AND (SubmissionHeader.IsArchived IS NULL
      OR SubmissionHeader.IsArchived = 0)
      AND v_employee.per_id IN (', filter_supervisors, ')
      AND HeaderDate BETWEEN ? AND ?
      AND SubmissionHAP.sha_enable = TRUE)
  SELECT
    ltr_text AS `key`,
    GROUP_CONCAT(DISTINCT FormName) AS id,
    SUM(hazard_identification_score) AS value
  FROM subQuery
  WHERE hazard_identification <> ""
  GROUP BY ltr_text');

  PREPARE sqlResults FROM @sqlStatement;
  EXECUTE sqlResults USING @lang_id, @filter_start_date, @filter_end_date;
  DEALLOCATE PREPARE sqlResults;

END
$$

DELIMITER ;

--
-- Drop procedure `get_hazard_by_job_supervisor_date`
--
DROP PROCEDURE IF EXISTS get_hazard_by_job_supervisor_date;

DELIMITER $$

--
-- Create procedure `get_hazard_by_job_supervisor_date`
--
CREATE PROCEDURE IF NOT EXISTS get_hazard_by_job_supervisor_date (IN filter_supervisors longtext, IN filter_jobs longtext, IN filter_start_date varchar(25), IN filter_end_date varchar(25), IN lang varchar(2))
BEGIN

  /*
  Created by: Rana Hussain
  Date: May 05, 2020
  Name: get_hazard_by_jobs_supervisor_date

  Modifed Date: 2021-07-08
  Modified By: Robert Rivest
  Comment: updated Language support for I18n and new Tag type field

  Modified Date: 2021-09-21
  Modified By: Gowtham Ravindran
  Modification: SOF-9033 -Changed the datatype of filter dates

  Modified Date: 2022-04-28
  Modified By: Robert Rivest
  Modification: SOF-11152 -Changed to respect the ltr_enable field for translations

  Description: to retrieve satistics for hazard data for manipulation

  Modified   : 2022-05-11
  Modified by: Sarath Sontam
  Reason     : Update lang Varchar(5) to lang Varchar(2) as a part of pentest merging.
   
  Modified   : June 7th, 2023
  Modified by: James Coles, Suman Marlapudi
  Reason     : SOF-14391 - Remove temporary tables, use prepared statement instead.

  Modified by: Suman Marlapudi
  Date       : 2023-11-24
  Reason     : SOF-14025 - Replace the deprecated SELECT INTO clause with variables.

   */

  DECLARE sqlStatement longtext;
  DECLARE lang_id int;

  SET @filter_start_date = filter_start_date;
  SET @filter_end_date = filter_end_date;
  SET @lang = lang;
  SET lang_id := 0;

  SET lang_id = (SELECT
      lng_id
    FROM language
    WHERE lng_name = @lang);

  SET @lang_id = lang_id;


  SET @sqlStatement := CONCAT('
  SELECT
    FormSubmissionDate date,
    WEEKOFYEAR(FormSubmissionDate) week,
    MONTH(FormSubmissionDate) month,
    COUNT(*) count,
    SUM(hazard_identification_score) score
  FROM (SELECT

      (SELECT
          ltr_text
        FROM ref_list_detail
          JOIN language_translation
            ON ltr_tag = rld_name
            AND ltr_tag_type = rld_tag_type
            AND ltr_enable = 1
        WHERE ltr_lng_id = ?
        AND rld_id = SubmissionHAP.hazard_type) AS hazard_type,
      (SELECT
          ltr_text
        FROM ref_list_detail
          JOIN language_translation
            ON ltr_tag = rld_name
            AND ltr_tag_type = rld_tag_type
            AND ltr_enable = 1
        WHERE ltr_lng_id = ?
        AND rld_id = SubmissionHAP.hazard_identification) AS hazard_identification,
      (SELECT
          ltr_text
        FROM ref_list_detail
          JOIN language_translation
            ON ltr_tag = rld_name
            AND ltr_tag_type = rld_tag_type
            AND ltr_enable = 1
        WHERE ltr_lng_id = ?
        AND rld_id = SubmissionHAP.potential_risk) AS potential_risk,
      (SELECT
          ltr_text
        FROM ref_list_detail
          JOIN language_translation
            ON ltr_tag = rld_name
            AND ltr_tag_type = rld_tag_type
            AND ltr_enable = 1
        WHERE ltr_lng_id = ?
        AND rld_id = SubmissionHAP.action_type) AS action_type,
      SubmissionHAP.ID,
      SubmissionHAP.SubmissionHeaderID,
      SubmissionHAP.hazard_description,
      SubmissionHAP.immediate_action_required_and_performed,
      SubmissionHAP.immediate_action_taken,
      (SELECT
          ltr_text
        FROM ref_list_detail
          JOIN language_translation
            ON ltr_tag = rld_name
            AND ltr_tag_type = rld_tag_type
            AND ltr_enable = 1
        WHERE ltr_lng_id = ?
        AND rld_id = SubmissionHAP.immediate_action_type) AS immediate_action_type,
      SubmissionHAP.further_action_required,
      SubmissionHAP.recommended_action,
      SubmissionHAP.action_by_who,
      SubmissionHAP.action_by_when,
      SubmissionHAP.action_status,
      SubmissionHAP.action_complete_by_who,
      SubmissionHAP.action_completed_date,
      SubmissionHAP.completed_action_taken,
      (SELECT
          ltr_text
        FROM ref_list_detail
          JOIN language_translation
            ON ltr_tag = rld_name
            AND ltr_tag_type = rld_tag_type
            AND ltr_enable = 1
        WHERE ltr_lng_id = ?
        AND rld_id = SubmissionHAP.completed_action_type) AS completed_action_type,
      SubmissionHAP.hazard_identification_score,
      SubmissionHAP.potential_risk_score,
      SubmissionHAP.immediate_action_score,
      SubmissionHAP.completed_action_score,
      SubmissionID,
      FormCreationDate,
      FormSubmissionDate,
      (SELECT
          language_translation.ltr_text
        FROM language_translation
          JOIN ref_list_detail
            ON ltr_tag = rld_name
            AND ltr_tag_type = rld_tag_type
            AND ltr_enable = 1
        WHERE ltr_lng_id = ?
        AND rld_id = SubmissionHeader.Site) AS Site,
      JobNumber,
      (SELECT
          language_translation.ltr_text
        FROM language_translation
          JOIN ref_list_detail
            ON ltr_tag = rld_name
            AND ltr_tag_type = rld_tag_type
            AND ltr_enable = 1
        WHERE ltr_lng_id = ?
        AND rld_id = SubmissionHeader.SiteLevel) AS SiteLevel,
      Workplace,
      Supervisor,
      (SubmissionHeader.JobNumber + "_" + SubmissionHeader.Site + "_" + SubmissionHeader.SiteLevel) AS SubmissionHeaderLabel,
      SubmissionHeader.FormDescriptionID,
      (SELECT
          language_translation.ltr_text
        FROM language_translation
        WHERE ltr_lng_id = ?
        AND ltr_tag = FormDescription.FormName
        AND ltr_enable = 1
        AND ltr_tag_type = 1) AS FormName
    FROM SubmissionHAP
      JOIN SubmissionHeader
        ON SubmissionHAP.SubmissionHeaderID = SubmissionHeader.ID
      JOIN v_employee
        ON SubmissionHeader.SubmittedBy_SupervisorID = v_employee.per_id
      JOIN FormDescription
        ON SubmissionHeader.FormDescriptionID = FormDescription.ID
      LEFT JOIN (SELECT
          rld_id AS job_id,
          rld_code AS job
        FROM v_ref_header_detail_list
        WHERE v_ref_header_detail_list.rlh_name = "ref_job") jobs
        ON jobs.job_id = SubmissionHeader.JobNumber


    WHERE jobs.job_id IN (', filter_jobs, ')
    AND (SubmissionHeader.IsArchived IS NULL
    OR SubmissionHeader.IsArchived = 0)
    AND v_employee.per_id IN (', filter_supervisors, ')
    AND HeaderDate BETWEEN ? AND ?) a
  WHERE hazard_identification <> ""
  GROUP BY FormSubmissionDate
  ORDER BY FormSubmissionDate;
');

  PREPARE sqlResults FROM @sqlStatement;
  EXECUTE sqlResults USING @lang_id, @lang_id, @lang_id, @lang_id, @lang_id, @lang_id, @lang_id, @lang_id, @lang_id, @filter_start_date, @filter_end_date;
  DEALLOCATE PREPARE sqlResults;


END
$$

DELIMITER ;

--
-- Drop procedure `get_hazard_by_freq_by_type`
--
DROP PROCEDURE IF EXISTS get_hazard_by_freq_by_type;

DELIMITER $$

--
-- Create procedure `get_hazard_by_freq_by_type`
--
CREATE PROCEDURE IF NOT EXISTS get_hazard_by_freq_by_type (IN filter_jobs text, IN filter_supervisors text, IN filter_start_date datetime, IN filter_end_date datetime, IN lang varchar(5))
BEGIN

  /*
  Creation Date: 2020-05-04
  Created By: Vishnu Prakash
  Description: hazard listing where toogles - frequency and type is TRUE
  
  Change History
  
  Modifed Date: 2020-09-11
  Modified By: Robert Rivest
  Comment: Changed filter_jobs and filter_supervisors variable type to TEXT to handle larger strings

  Modifed Date : 2021-04-08
  Modified By  : Vishnu Prakash
  Comment      : added the validation 'sha_enable' as true 

  Modifed Date: 2021-07-08
  Modified By: Gowtham Ravindran
  Comment: updated Language support for I18n and new Tag type field

  Modified Date: 2021-09-21
  Modified By: Gowtham Ravindran
  Comment: SOF-9033 -Changed the datatype of filter dates

  Modified Date: 2021-12-14
  Modified By: Sarath Sontam
  Comment: SOF-9899 - remove unused columns in select and simplify query to get right count. 

  Modified Date: 2023-06-06
  Modified By: Suman Marlapudi, James Coles
  Comment: SOF-9899 - Removed the temporary tables and made the query more efficient.

  Modified by: Suman Marlapudi
  Date       : 2023-11-24
  Reason     : SOF-14025 - Replace the deprecated SELECT INTO clause with variables.

  Modified by: James Coles
  Date       : 2025-02-18
  Reason     : Fixing the filtering dates to header date

  */

  -- split the delimited with comma steing convert to a table
  DECLARE sqlStatement longtext;
  DECLARE lang_id int;

  SET @filter_start_date = filter_start_date;
  SET @filter_end_date = filter_end_date;
  SET @lang = lang;
  SET lang_id := 0;
  SET lang_id = (SELECT
      lng_id
    FROM language
    WHERE lng_name = @lang);

  SET @lang_id = lang_id;
  SET @sqlStatement := CONCAT('
  WITH subQuery
  AS
  (
  SELECT
        SubmissionHAP.hazard_identification ,
        ltr_text
      FROM SubmissionHAP
        JOIN SubmissionHeader
          ON SubmissionHAP.SubmissionHeaderID = SubmissionHeader.ID
        JOIN v_employee
          ON SubmissionHeader.SubmittedBy_SupervisorID = v_employee.per_id
        JOIN FormDescription
          ON SubmissionHeader.FormDescriptionID = FormDescription.ID
        INNER JOIN (SELECT
            ref_list_detail.rld_id AS job_id,
            ref_list_detail.rld_code AS job
          FROM ref_list_detail
            INNER JOIN ref_list_header
              ON ref_list_detail.rld_rlh_id = ref_list_header.rlh_id
          WHERE ref_list_header.rlh_name = "ref_job") jobs
          ON jobs.job_id = SubmissionHeader.JobNumber
        JOIN ref_list_detail
          ON ref_list_detail.rld_id = SubmissionHAP.hazard_identification
          AND rld_rlh_id = 13
        JOIN language_translation
          ON ltr_tag = rld_name
          AND ltr_tag_type = rld_tag_type
           AND ltr_lng_id = ?
       WHERE jobs.job_id IN (', filter_jobs, ')
      AND (SubmissionHeader.IsArchived IS NULL
      OR SubmissionHeader.IsArchived = 0)
      AND v_employee.per_id IN (', filter_supervisors, ')
      AND HeaderDate BETWEEN ? AND ?
      AND SubmissionHAP.sha_enable = TRUE
       )
  SELECT 
     ltr_text as "key",
     GROUP_CONCAT(DISTINCT hazard_identification) AS id,
     COUNT(*) AS value
  FROM subQuery
  WHERE hazard_identification <> ""
   GROUP BY ltr_text
  ');

  PREPARE sqlResults FROM @sqlStatement;
  EXECUTE sqlResults USING @lang_id, @filter_start_date, @filter_end_date;
  DEALLOCATE PREPARE sqlResults;

END
$$

DELIMITER ;

--
-- Drop procedure `get_hazard_by_freq_by_form`
--
DROP PROCEDURE IF EXISTS get_hazard_by_freq_by_form;

DELIMITER $$

--
-- Create procedure `get_hazard_by_freq_by_form`
--
CREATE PROCEDURE IF NOT EXISTS get_hazard_by_freq_by_form (IN filter_jobs text, IN filter_supervisors text, IN filter_start_date datetime, IN filter_end_date datetime, IN lang varchar(2))
BEGIN

  /*
  Creation Date: 2020-05-04
  Created By: Vishnu Prakash
  Description: hazard listing where toogles - frequency and form is TRUE
  *******************************************************************
  Change History
  *******************************************************************
  Modifed Date: YYYY-MM-DD
  Modified By: First and Last Name
  Comment: What has changed and reason for change
  Modifed Date: 2020-09-11
  Modified By: Robert Rivest
  Comment: Changed filter_jobs and filter_supervisors variable type to TEXT to handle larger strings

  Modifed Date: 2021-04-08
  Modified By: Vishnu Prakash
  Comment: add condition 'and SubmissionHAP.sha_enable = true'

  Modifed Date: 2021-07-08
  Modified By: Gowtham Ravindran
  Comment: updated Language support for I18n and new Tag type field

  Modified Date: 2021-09-21
  Modified By: Gowtham Ravindran
  Modification: SOF-9033 -Changed the datatype of filter dates

  Modified Date: 2021-12-14
  Modified By: Sarath Sontam
  Modification: SOF-9899 - remove unused columns in select and simplify query to get right count. 

  Modified   : March 16th, 2022
  Modified by: James Coles
  Reason     : SOF-10397 - Validate parameters.

  Modified   : June 7th, 2023
  Modified by: James Coles, Suman Marlapudi
  Reason     : SOF-14391 - Remove temporary tables, use prepared statement instead.

  Modified by: Suman Marlapudi
  Date       : 2023-11-24
  Reason     : SOF-14025 - Replace the deprecated SELECT INTO clause with variables.
 
  Modified by: James Coles
  Date       : 2025-02-18
  Reason     : Fixing the filtering dates to header date
   
  */

  DECLARE sqlStatement longtext;
  DECLARE lang_id int;

  SET @filter_start_date = filter_start_date;
  SET @filter_end_date = filter_end_date;
  SET @lang = lang;
  SET lang_id := 0;
  SET lang_id = (SELECT
      lng_id
    FROM language
    WHERE lng_name = @lang);

  SET @lang_id = lang_id;

  SET @sqlStatement := CONCAT('
  WITH subQuery
  AS
  (SELECT
        FormName,
        hazard_identification,
        hazard_identification_score,
        ltr_text
      FROM SubmissionHAP
        JOIN SubmissionHeader
          ON SubmissionHAP.SubmissionHeaderID = SubmissionHeader.ID
        JOIN v_employee
          ON SubmissionHeader.SubmittedBy_SupervisorID = v_employee.per_id
        JOIN FormDescription
          ON SubmissionHeader.FormDescriptionID = FormDescription.ID
        LEFT JOIN (SELECT
            ref_list_detail.rld_id AS job_id,
            ref_list_detail.rld_code AS job
          FROM ref_list_detail
            INNER JOIN ref_list_header
              ON ref_list_detail.rld_rlh_id = ref_list_header.rlh_id
          WHERE ref_list_header.rlh_name = "ref_job") jobs
          ON jobs.job_id = SubmissionHeader.JobNumber
        JOIN language_translation
          ON FormName = ltr_tag
          AND ltr_tag_type = 1
          AND ltr_lng_id = ?
      WHERE jobs.job_id IN (', filter_jobs, ')
      AND (SubmissionHeader.IsArchived IS NULL
      OR SubmissionHeader.IsArchived = 0)
      AND v_employee.per_id IN (', filter_supervisors, ')
      AND HeaderDate BETWEEN ? AND ?
      AND SubmissionHAP.sha_enable = TRUE)
  SELECT
    ltr_text AS `key`,
    GROUP_CONCAT(DISTINCT FormName) AS id,
    COUNT(*) AS value
  FROM subQuery
  WHERE hazard_identification <> ""
  GROUP BY FormName');

  PREPARE sqlResults FROM @sqlStatement;
  EXECUTE sqlResults USING @lang_id, @filter_start_date, @filter_end_date;
  DEALLOCATE PREPARE sqlResults;

END
$$

--
-- Create procedure `api_lesson_learned_document`
--
CREATE PROCEDURE IF NOT EXISTS api_lesson_learned_document (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-12
     Reason    :    PD-2956 - Get data lesson learned document.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  SELECT DISTINCT
    ll.llm_id AS id,
    ll.llm_date AS date,
    ll.llm_created_date AS created_date,
    ll.llm_submitted_date AS submitted_date,
    ll.llm_modified_date AS modified_date,
    ll.llm_title AS title,
    ll.llm_site_rld_id AS site_id,
    get_translation_from_ref_list_id(ll.llm_site_rld_id, 'ref_site', language_id) AS site,
    ll.llm_job_rld_id AS department_job_id,
    get_translation_from_ref_list_id(ll.llm_job_rld_id, 'ref_job', language_id) AS department_job,
    ll.llm_scope AS scope,
    ll.llm_summary AS summary,
    GROUP_CONCAT(llp.llp_per_id ORDER BY llp.llp_per_id SEPARATOR ', ') AS participant_id,
    GROUP_CONCAT(TRIM(CONCAT(per_participant.per_last_name, ", ", per_participant.per_first_name, " ", IFNULL(per_participant.per_middle_name, ''))) ORDER BY llp.llp_per_id SEPARATOR ', ') AS participant,
    ll.llm_other_participant AS other_participant,
    ll.llm_success AS successes_description,
    ll.llm_opportunity AS opportunities_description
  FROM lesson_learned ll
    LEFT JOIN lesson_learned_participant llp
      ON ll.llm_id = llp.llp_llm_id
    LEFT JOIN person per_participant
      ON llp.llp_per_id = per_participant.per_id
  WHERE CASE WHEN use_id = TRUE THEN ll.llm_id = id ELSE CASE WHEN date_type = header_date THEN ll.llm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN ll.llm_modified_date BETWEEN start_date AND end_date END END
  AND ll.llm_enable = 1
  GROUP BY ll.llm_id;


END
$$

--
-- Create procedure `api_decision_log_document`
--
CREATE PROCEDURE IF NOT EXISTS api_decision_log_document (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-10
     Reason    :    PD-2955 - Get hazard in decision log document.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  SELECT DISTINCT
    dl.dlm_id AS id,
    dl.dlm_date AS date,
    dl.dlm_created_date AS created_date,
    dl.dlm_submitted_date AS submitted_date,
    dl.dlm_modified_date AS modified_date,
    dl.dlm_site_rld_id AS site_id,
    get_translation_from_ref_list_id(dl.dlm_site_rld_id, 'ref_site', language_id) AS site,
    dl.dlm_due_date AS decision_due_date,
    dl.dlm_stakeholder AS stakeholders,
    GROUP_CONCAT(dlp.dlp_per_id ORDER BY dlp_per_id SEPARATOR ', ') AS decision_maker_id,
    GROUP_CONCAT(TRIM(CONCAT(per_participant.per_last_name, ", ", per_participant.per_first_name, " ", IFNULL(per_participant.per_middle_name, ''))) ORDER BY dlp_per_id SEPARATOR ', ') AS decision_maker
  FROM decision_log dl
    LEFT JOIN decision_log_participant dlp
      ON dl.dlm_id = dlp.dlp_dlm_id
    LEFT JOIN person per_participant
      ON dlp.dlp_per_id = per_participant.per_id
  WHERE CASE WHEN use_id = TRUE THEN dl.dlm_id = id ELSE CASE WHEN date_type = header_date THEN dl.dlm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN dl.dlm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN dl.dlm_created_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN dl.dlm_modified_date BETWEEN start_date AND end_date END END
  AND dl.dlm_enable = 1
  GROUP BY dl.dlm_id;


END
$$

--
-- Create procedure `api_lesson_learned_summary`
--
CREATE PROCEDURE IF NOT EXISTS api_lesson_learned_summary (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-12
     Reason    :    PD-2956 - Get data lesson learned summary.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;
  DECLARE active varchar(50);
  DECLARE draft varchar(50);

  SET active = get_translation(3557, language_id, 1);
  SET draft = get_translation(1399, language_id, 1);


  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  SELECT DISTINCT
    ll.llm_id AS id,
    ll.llm_date AS date,
    ll.llm_submitted_by_per_id AS submitted_by_id,
    TRIM(CONCAT(per_submit.per_last_name, ", ", per_submit.per_first_name, " ", IFNULL(per_submit.per_middle_name, ''))) AS submitted_by,
    ll.llm_title AS title,
    ll.llm_site_rld_id AS site_id,
    get_translation_from_ref_list_id(ll.llm_site_rld_id, 'ref_site', language_id) AS site,
    ll.llm_job_rld_id AS department_job_id,
    get_translation_from_ref_list_id(ll.llm_job_rld_id, 'ref_job', language_id) AS department_job,
    GROUP_CONCAT(llp.llp_per_id ORDER BY llp.llp_per_id SEPARATOR ', ') AS participant_id,
    GROUP_CONCAT(TRIM(CONCAT(per_participant.per_last_name, ", ", per_participant.per_first_name, " ", IFNULL(per_participant.per_middle_name, ''))) ORDER BY llp.llp_per_id SEPARATOR ', ') AS participant,
    CASE WHEN ll.llm_is_submitted = 1 THEN active ELSE draft END AS status,
    ll.llm_submitted_date AS submitted_date,
    ll.llm_created_date AS created_date,
    ll.llm_created_by_per_id AS created_by_id,
    TRIM(CONCAT(per_created.per_last_name, ", ", per_created.per_first_name, " ", IFNULL(per_created.per_middle_name, ''))) AS created_by

  FROM lesson_learned ll
    LEFT JOIN lesson_learned_participant llp
      ON ll.llm_id = llp.llp_llm_id

    LEFT JOIN person per_submit
      ON ll.llm_submitted_by_per_id = per_submit.per_id

    LEFT JOIN person per_created
      ON ll.llm_created_by_per_id = per_created.per_id

    LEFT JOIN person per_participant
      ON llp.llp_per_id = per_participant.per_id

    LEFT JOIN person per_modified
      ON ll.llm_modified_by_per_id = per_modified.per_id


  WHERE CASE WHEN use_id = TRUE THEN ll.llm_id = id ELSE CASE WHEN date_type = header_date THEN ll.llm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN ll.llm_modified_date BETWEEN start_date AND end_date END END
  AND ll.llm_enable = 1

  GROUP BY ll.llm_id;

END
$$

--
-- Create procedure `api_decision_log_summary`
--
CREATE PROCEDURE IF NOT EXISTS api_decision_log_summary (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-10
     Reason    :    PD-2955 - Get data decision log summary.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;
  DECLARE active varchar(50);
  DECLARE draft varchar(50);

  SET active = get_translation(3557, language_id, 1);
  SET draft = get_translation(1399, language_id, 1);


  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  SELECT DISTINCT
    dl.dlm_id AS id,
    dl.dlm_date AS date,
    dl.dlm_submitted_by_per_id AS submitted_by_id,
    TRIM(CONCAT(per_submit.per_last_name, ", ", per_submit.per_first_name, " ", IFNULL(per_submit.per_middle_name, ''))) AS submitted_by,
    dl.dlm_due_date AS due_date,
    dl.dlm_title AS title,
    dl.dlm_site_rld_id AS site_id,
    get_translation_from_ref_list_id(dl.dlm_site_rld_id, 'ref_site', language_id) AS site,
    CASE WHEN dl.dlm_is_submitted = 1 THEN active ELSE draft END AS status,
    dl.dlm_submitted_date AS submitted_date,
    dl.dlm_created_date AS created_date,
    dl.dlm_created_by_per_id AS created_by_id,
    TRIM(CONCAT(per_created.per_last_name, ", ", per_created.per_first_name, " ", IFNULL(per_created.per_middle_name, ''))) AS created_by,
    dl.dlm_modified_date AS modified_date,
    TRIM(CONCAT(per_modified.per_last_name, ", ", per_modified.per_first_name, " ", IFNULL(per_modified.per_middle_name, ''))) AS modified_by,
    GROUP_CONCAT(dlp.dlp_per_id ORDER BY dlp_per_id SEPARATOR ', ') AS decision_maker_id,
    GROUP_CONCAT(TRIM(CONCAT(per_participant.per_last_name, ", ", per_participant.per_first_name, " ", IFNULL(per_participant.per_middle_name, ''))) ORDER BY dlp_per_id SEPARATOR ', ') AS decision_maker
  FROM decision_log dl
    LEFT JOIN decision_log_participant dlp
      ON dl.dlm_id = dlp.dlp_dlm_id

    LEFT JOIN person per_submit
      ON dl.dlm_submitted_by_per_id = per_submit.per_id

    LEFT JOIN person per_created
      ON dl.dlm_created_by_per_id = per_created.per_id

    LEFT JOIN person per_participant
      ON dlp.dlp_per_id = per_participant.per_id

    LEFT JOIN person per_modified
      ON dl.dlm_modified_by_per_id = per_modified.per_id


  WHERE CASE WHEN use_id = TRUE THEN dl.dlm_id = id ELSE CASE WHEN date_type = header_date THEN dl.dlm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN dl.dlm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN dl.dlm_created_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN dl.dlm_modified_date BETWEEN start_date AND end_date END END
  AND dl.dlm_enable = 1

  GROUP BY dl.dlm_id;


END
$$

DELIMITER ;

--
-- Drop procedure `api_administration_list_header`
--
DROP PROCEDURE IF EXISTS api_administration_list_header;

DELIMITER $$

--
-- Create procedure `api_administration_list_header`
--
CREATE PROCEDURE IF NOT EXISTS api_administration_list_header (IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-11-12
     Reason    :    PD-3094 - Get ref list header.

     Modified by:    Vinh Lam
     Modified Date:  2024-11-22
     Reason    :    PD-3094 - Add additional columns and description.

     Modified by:    Vinh Lam
     Modified Date:  2024-12-05
     Reason    :    Update naming from ref to administration.

     Modified by:    Vinh Lam
     Modified Date:  2024-12-13
     Reason    :    Add enable flag in response.

     Modified by:    Vinh Lam
     Modified Date:  2024-01-24
     Reason    :    Rename alias.
  */

  SELECT
    rlh_id AS list_header_id,
    get_translation(rlh_display_name, language_id, rlh_tag_type) AS list_name,
    get_translation(rlh_description, language_id, rlh_tag_type) AS list_description,
    rlh_enable AS list_enable
  FROM ref_list_header;


END
$$

--
-- Create procedure `api_lesson_learned_reviewer`
--
CREATE PROCEDURE IF NOT EXISTS api_lesson_learned_reviewer (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-12
     Reason    :    PD-2956 - Get data lesson learned reviewer.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  SELECT
    ll.llm_id AS id,
    ll.llm_date AS date,
    ll.llm_created_date AS created_date,
    ll.llm_submitted_date AS submitted_date,
    ll.llm_modified_date AS modified_date,
    lla.lla_per_id AS reviewer_id,
    TRIM(CONCAT(per_decision.per_last_name, ", ", per_decision.per_first_name, " ", IFNULL(per_decision.per_middle_name, ''))) AS reviewer,
    lla.lla_position AS position_id,
    lt.ltr_text AS position,
    lla.lla_created_date AS review_date
  FROM lesson_learned ll
    LEFT JOIN lesson_learned_acknowledged lla
      ON ll.llm_id = lla.lla_llm_id
    LEFT JOIN person per_decision
      ON lla.lla_per_id = per_decision.per_id
    LEFT JOIN ref_list_detail rld
      ON rld.rld_id = lla.lla_position
    LEFT JOIN language_translation lt
      ON rld.rld_name = lt.ltr_tag
      AND lt.ltr_lng_id = language_id
      AND rld.rld_tag_type = lt.ltr_tag_type
  WHERE CASE WHEN use_id = TRUE THEN ll.llm_id = id ELSE CASE WHEN date_type = header_date THEN ll.llm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN ll.llm_modified_date BETWEEN start_date AND end_date END END
  AND ll.llm_enable = 1
  AND lla.lla_enable = 1;


END
$$

--
-- Create procedure `api_decision_log_reviewer`
--
CREATE PROCEDURE IF NOT EXISTS api_decision_log_reviewer (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-10
     Reason    :    PD-2955 - Get data decision log reviewer.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  SELECT
    dl.dlm_id AS id,
    dl.dlm_date AS date,
    dl.dlm_created_date AS created_date,
    dl.dlm_submitted_date AS submitted_date,
    dl.dlm_modified_date AS modified_date,
    dla.dla_per_id AS reviewer_id,
    TRIM(CONCAT(per_decision.per_last_name, ", ", per_decision.per_first_name, " ", IFNULL(per_decision.per_middle_name, ''))) AS reviewer,
    dla.dla_position AS position_id,
    lt.ltr_text AS position,
    dla.dla_created_date AS review_date
  FROM decision_log dl
    LEFT JOIN decision_log_acknowledged dla
      ON dl.dlm_id = dla.dla_dlm_id
    LEFT JOIN person per_decision
      ON dla.dla_per_id = per_decision.per_id
    LEFT JOIN ref_list_detail rld
      ON rld.rld_id = dla.dla_position
    LEFT JOIN language_translation lt
      ON rld.rld_name = lt.ltr_tag
      AND lt.ltr_lng_id = language_id
      AND rld.rld_tag_type = lt.ltr_tag_type
  WHERE CASE WHEN use_id = TRUE THEN dl.dlm_id = id ELSE CASE WHEN date_type = header_date THEN dl.dlm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN dl.dlm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN dl.dlm_created_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN dl.dlm_modified_date BETWEEN start_date AND end_date END END
  AND dl.dlm_enable = 1
  AND dla.dla_enable = 1;


END
$$

DELIMITER ;

--
-- Drop procedure `api_administration_list_detail`
--
DROP PROCEDURE IF EXISTS api_administration_list_detail;

DELIMITER $$

--
-- Create procedure `api_administration_list_detail`
--
CREATE PROCEDURE IF NOT EXISTS api_administration_list_detail (IN administration_list_header_id varchar(255), IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-11-12
     Reason    :    PD-3094 - Get ref list detail.

     Modified by:    Vinh Lam
     Modified Date:  2024-11-22
     Reason    :    PD-3094 - Add additional columns and description.

     Modified by:    Vinh Lam
     Modified Date:  2024-12-05
     Reason    :    Update naming from ref to administration.

     Modified by:    Vinh Lam
     Modified Date:  2024-12-13
     Reason    :    Add enable flag in response.

     Modified by:    Vinh Lam
     Modified Date:  2024-12-16
     Reason    :    Add active flag in response.

     Modified by:    Vinh Lam
     Modified Date:  2024-01-24
     Reason    :    Rename alias.
  */

  WITH CTE
  AS
  (SELECT DISTINCT
      rlh.rlh_display_name AS display_name,
      lt.ltr_text AS translated_value
    FROM ref_list_header rlh
      LEFT JOIN language_translation lt
        ON lt.ltr_tag = rlh.rlh_display_name
        AND rlh.rlh_tag_type = lt.ltr_tag_type
        AND lt.ltr_lng_id = language_id)


  SELECT
    rld.rld_rlh_id AS list_header_id,
    cte.translated_value AS list_name,
    rld.rld_id AS list_detail_id,
    lt.ltr_text AS list_detail_value,
    rld.rld_enable AS list_enable,
    rld.rld_is_active AS list_active
  FROM ref_list_detail rld
    INNER JOIN ref_list_header rlh
      ON rld.rld_rlh_id = rlh.rlh_id
    LEFT JOIN CTE cte
      ON cte.display_name = rlh.rlh_display_name
    LEFT JOIN language_translation lt
      ON rld.rld_name = lt.ltr_tag
      AND rld.rld_tag_type = lt.ltr_tag_type
  WHERE lt.ltr_enable = 1
  AND lt.ltr_lng_id = language_id
  AND (CASE WHEN administration_list_header_id IS NOT NULL THEN rld.rld_rlh_id = administration_list_header_id ELSE 1 = 1 END);

END
$$

--
-- Create procedure `api_lesson_learned_submission_comment`
--
CREATE PROCEDURE IF NOT EXISTS api_lesson_learned_submission_comment (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-12
     Reason    :    PD-2956 - Get data lesson learned submission comment.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  SELECT
    ll.llm_id AS id,
    ll.llm_date AS date,
    ll.llm_created_date AS created_date,
    ll.llm_submitted_date AS submitted_date,
    ll.llm_modified_date AS modified_date,
    cus.com_created_by_per_id AS name_id,
    TRIM(CONCAT(p.per_last_name, ", ", p.per_first_name, " ", IFNULL(p.per_middle_name, ''))) AS name,
    cus.com_position_id AS position_id,
    lt.ltr_text AS position,
    cus.com_comment AS comment,
    cus.com_created_date AS comment_created_date,
    cus.com_modified_date AS comment_modified_date
  FROM comment_user cus
    LEFT JOIN person p
      ON cus.com_created_by_per_id = p.per_id
    LEFT JOIN lesson_learned ll
      ON cus.com_reference_id = ll.llm_id
    LEFT JOIN ref_list_detail rld
      ON rld.rld_id = cus.com_position_id
    LEFT JOIN language_translation lt
      ON rld.rld_name = lt.ltr_tag
      AND lt.ltr_lng_id = language_id
      AND rld.rld_tag_type = lt.ltr_tag_type
  WHERE CASE WHEN use_id = TRUE THEN ll.llm_id = id ELSE CASE WHEN date_type = header_date THEN ll.llm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN ll.llm_modified_date BETWEEN start_date AND end_date END END
  AND ll.llm_enable = 1
  AND cus.com_enable = 1
  AND cus.com_cmt_id = 23;


END
$$

--
-- Create procedure `api_lesson_learned_attachment`
--
CREATE PROCEDURE IF NOT EXISTS api_lesson_learned_attachment (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-12
     Reason    :    PD-2956 - Get data lesson learned attachment.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  WITH CommentData
  AS
  (SELECT
      comment_user.com_reference_id,
      GROUP_CONCAT(comment_user.com_comment SEPARATOR '; ') AS attachment_comment
    FROM comment_user
      JOIN comment_table
        ON comment_table.cmt_id = comment_user.com_cmt_id
    WHERE comment_table.cmt_id = 2
    AND comment_user.com_enable = 1
    AND comment_table.cmt_enable = 1
    GROUP BY comment_user.com_reference_id)

  SELECT
    ll.llm_id AS id,
    ll.llm_date AS date,
    ll.llm_created_date AS created_date,
    ll.llm_submitted_date AS submitted_date,
    ll.llm_modified_date AS modified_date,
    CONCAT('lessons_learned/', lla.lat_file_name) AS file_name,
    lla.lat_attachment_timestamp AS time_stamp,
    cus.attachment_comment AS comment
  FROM lesson_learned_attachment lla
    LEFT JOIN lesson_learned ll
      ON lla.lat_llm_id = ll.llm_id
    LEFT JOIN CommentData cus
      ON lla.lat_id = cus.com_reference_id

  WHERE CASE WHEN use_id = TRUE THEN ll.llm_id = id ELSE CASE WHEN date_type = header_date THEN ll.llm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN ll.llm_modified_date BETWEEN start_date AND end_date END END
  AND ll.llm_enable = 1
  AND lla.lat_enable = 1
  ORDER BY lla.lat_id, lla.lat_attachment_index;


END
$$

--
-- Create procedure `api_decision_log_submission_comment`
--
CREATE PROCEDURE IF NOT EXISTS api_decision_log_submission_comment (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-10
     Reason    :    PD-2955 - Get data decision log submission comment.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  SELECT
    dl.dlm_id AS id,
    dl.dlm_date AS date,
    dl.dlm_created_date AS created_date,
    dl.dlm_submitted_date AS submitted_date,
    dl.dlm_modified_date AS modified_date,
    cus.com_created_by_per_id AS name_id,
    TRIM(CONCAT(p.per_last_name, ", ", p.per_first_name, " ", IFNULL(p.per_middle_name, ''))) AS name,
    cus.com_position_id AS position_id,
    lt.ltr_text AS position,
    cus.com_comment AS comment,
    cus.com_created_date AS comment_created_date,
    cus.com_modified_date AS comment_modified_date
  FROM comment_user cus
    LEFT JOIN person p
      ON cus.com_created_by_per_id = p.per_id
    LEFT JOIN decision_log dl
      ON cus.com_reference_id = dl.dlm_id
    LEFT JOIN ref_list_detail rld
      ON rld.rld_id = cus.com_position_id
    LEFT JOIN language_translation lt
      ON rld.rld_name = lt.ltr_tag
      AND lt.ltr_lng_id = language_id
      AND rld.rld_tag_type = lt.ltr_tag_type
  WHERE CASE WHEN use_id = TRUE THEN dl.dlm_id = id ELSE CASE WHEN date_type = header_date THEN dl.dlm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN dl.dlm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN dl.dlm_created_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN dl.dlm_modified_date BETWEEN start_date AND end_date END END
  AND dl.dlm_enable = 1
  AND cus.com_enable = 1
  AND cus.com_cmt_id = 24;


END
$$

--
-- Create procedure `api_decision_log_attachment`
--
CREATE PROCEDURE IF NOT EXISTS api_decision_log_attachment (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-10
     Reason    :    PD-2955 - Get data decision log document.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  WITH CommentData
  AS
  (SELECT
      comment_user.com_reference_id,
      GROUP_CONCAT(comment_user.com_comment SEPARATOR '; ') AS attachment_comment
    FROM comment_user
      JOIN comment_table
        ON comment_table.cmt_id = comment_user.com_cmt_id
    WHERE comment_table.cmt_id = 3
    AND comment_user.com_enable = 1
    AND comment_table.cmt_enable = 1
    GROUP BY comment_user.com_reference_id)

  SELECT
    dla.dat_dlm_id AS ID,
    dl.dlm_date AS date,
    dl.dlm_created_date AS created_date,
    dl.dlm_submitted_date AS submitted_date,
    dl.dlm_modified_date AS modified_date,
    CONCAT('decision_log/', dla.dat_file_name) AS file_name,
    dla.dat_attachment_timestamp AS time_stamp,
    cus.attachment_comment AS comment
  FROM decision_log_attachment dla
    LEFT JOIN decision_log dl
      ON dla.dat_dlm_id = dl.dlm_id
    LEFT JOIN CommentData cus
      ON dla.dat_id = cus.com_reference_id

  WHERE CASE WHEN use_id = TRUE THEN dl.dlm_id = id ELSE CASE WHEN date_type = header_date THEN dl.dlm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN dl.dlm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN dl.dlm_created_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN dl.dlm_modified_date BETWEEN start_date AND end_date END END
  AND dl.dlm_enable = 1
  AND dla.dat_enable = 1
  ORDER BY dla.dat_id, dla.dat_attachment_index;


END
$$

DELIMITER ;

--
-- Drop procedure `get_all_documents`
--
DROP PROCEDURE IF EXISTS get_all_documents;

DELIMITER $$

--
-- Create procedure `get_all_documents`
--
CREATE PROCEDURE IF NOT EXISTS get_all_documents (IN lang_id int, IN doc_list longtext, per_id int)
BEGIN

  /*
      Created By:     James Coles
      Created Date:   2023-10-27
      Reason:         SOF-15350 - Add efficiencies to documents.
  
      Modified By:     Robert Rivest
      Modified Date:   2023-11-10
      Reason:         SOF-15439 - Add drr_is_reviewed to rev filter to capture if user reviewed the document
  
      Modified By:     Robert Rivest
      Modified Date:   2023-12-12
      Reason:         PD-372 - add group by drm.drm_id to correct incorrect document count

      Modified by:   James Coles
      Modified Date: 2024-11-28
      Reason:        PD-3201 - Add Middle name to the grid.
  
  */

  DECLARE expired varchar(100);
  DECLARE draft varchar(100);
  DECLARE Active varchar(100);
  DECLARE of_word varchar(100);
  DECLARE na varchar(100);
  SET expired = get_translation(3494, lang_id, 1);
  SET draft = get_translation(1399, lang_id, 1);
  SET Active = get_translation(3557, lang_id, 1);
  SET of_word = get_translation(1131, lang_id, 1);
  SET na = get_translation(1381, lang_id, 1);

  SELECT
    drm_url AS url,
    TRIM(CONCAT(p.`per_last_name`, ', ', p.`per_first_name`, ' ', COALESCE(p.`per_middle_name`, ''))) AS sub_by,
    drm.drm_id AS id,
    CONCAT((SELECT
        COUNT(1)
      FROM document_review_management_reviewer drmr
      WHERE drr_drm_id = drm.drm_id
      AND drmr.drr_is_reviewed = 1
      AND drmr.drr_is_mandatory = 1
      AND drmr.drr_enable = 1), ' ', of_word, ' ',
    ((SELECT
        COUNT(1)
      FROM document_review_management_reviewer drmr
      WHERE drr_drm_id = drm.drm_id
      AND drmr.drr_enable = 1
      AND drmr.drr_is_mandatory = 1
      AND drmr.drr_enable = 1) + (SELECT
        COUNT(1)
      FROM document_review_management_external_reviewer drmr
      WHERE drmr.der_drm_id = drm.drm_id
      AND drmr.der_enable = 1
      AND drmr.der_enable = 1))) AS all_rev,
    drm.drm_created_date AS created_date,
    drm.drm_submitted_date AS submitted_date,
    drm.drm_review_by_date,
    drm.drm_created_by_per_id AS created_by,
    drm.drm_modified_by_per_id AS modified_by,
    drm.drm_modified_date AS modified_date,
    IFNULL(drm.drm_expiry_date, na) exp_date,
    drm.drm_review_by_date AS rev_by_date,
    document_type.ltr_text AS doc_type_name,
    drm.drm_document_type_rld_id AS drm_document_type_rld_name,
    drm.drm_attachment_type AS attach_type,
    drm.drm_filename AS file,
    drm.drm_description AS `desc`,
    drm.drm_is_submitted AS is_sub,

    (SELECT
        COUNT(1)
      FROM document_review_management_external_reviewer drmr
      WHERE drmr.der_drm_id = drm.drm_id
      AND drmr.der_enable = 1) + (SELECT
        COUNT(1)
      FROM document_review_management_reviewer drmr
      WHERE drr_enable = 1
      AND drmr.drr_drm_id = drm.drm_id
      AND drmr.drr_is_reviewed = 1) AS all_rev_count,


    CONCAT(dlp.per_last_name, ', ', dlp.per_first_name) AS dlo_person,
    IFNULL(dl.dlo_enable, TRUE) AS dlo_enable,
    IF(NOW() > drm.drm_expiry_date, expired, IF(drm.drm_is_submitted, Active, draft)) status,
    IF((SELECT
        COUNT(1)
      FROM document_review_management_reviewer
      WHERE drr_drm_id = drm_id
      AND drr_per_id = per_id
      AND drr_is_reviewed = 1) > 0, TRUE, FALSE) rev,
    (SELECT
        COUNT(1)
      FROM comment_user
      WHERE com_cmt_id = 22
      AND com_reference_id = drm.drm_id
      AND comment_user.com_enable = 1) AS commentCount,
    (SELECT
        COUNT(1)
      FROM comment_user
      WHERE com_cmt_id = 22
      AND com_reference_id = drm.drm_id
      AND comment_user.com_enable = 1
      AND comment_user.com_created_by_per_id = per_id) AS commentByPerCount
  FROM document_review_management drm
    LEFT JOIN person p
      ON drm.drm_created_by_per_id = p.per_id
    INNER JOIN ref_list_detail rld
      ON drm.drm_document_type_rld_id = rld.rld_id
      AND rld.rld_rlh_id = 55
    INNER JOIN language_translation document_type
      ON rld.rld_name = document_type.ltr_tag
      AND rld.rld_tag_type = document_type.ltr_tag_type
      AND document_type.ltr_lng_id = lang_id
    LEFT JOIN document_lock dl
      ON dl.dlo_document_id = drm.drm_id
      AND dl.dlo_dlt_id = 8
    LEFT JOIN person dlp
      ON dlp.per_id = dl.dlo_per_id
  WHERE FIND_IN_SET(drm_id, doc_list)
  GROUP BY drm.drm_id
  ORDER BY drm.drm_submitted_date;

END
$$

--
-- Create procedure `get_emails_from_ids`
--
CREATE PROCEDURE IF NOT EXISTS get_emails_from_ids (IN account_ids text, IN external_ids text, IN group_ids text, OUT emails text)
BEGIN

  /*
    Created By:   Sarath Sontam
    Created Date: 2024-12-12
    Purpose:      This SP takes comma seperated account_ids(per_ids), comma seperated external_distribution_ids and comma seperated distribution_group_ids and  returns comma seperated emails 

  */
  SET @account_emails = (SELECT
      GROUP_CONCAT(email SEPARATOR '|')
    FROM auth_user_sofvie
    WHERE FIND_IN_SET(auth_user_sofvie.user_per_id, account_ids)
    AND auth_user_sofvie.is_active = 1
    AND auth_user_sofvie.is_staff != 1);

  SET @external_emails = (SELECT
      GROUP_CONCAT(edl_email SEPARATOR '|')
    FROM external_distribution_list
    WHERE FIND_IN_SET(external_distribution_list.edl_id, external_ids)
    AND external_distribution_list.edl_enable = 1);

  SET @group_emails_account = (SELECT
      GROUP_CONCAT(auth_user_sofvie.email SEPARATOR '|')
    FROM distribution_group_email
      JOIN auth_user_sofvie
        ON dge_per_id = user_per_id
    WHERE FIND_IN_SET(distribution_group_email.dge_dig_id, group_ids)
    AND dge_per_id IS NOT NULL
    AND distribution_group_email.dge_enable = 1
    AND auth_user_sofvie.is_active = 1
    AND auth_user_sofvie.is_staff != 1);

  SET @group_emails_external = (SELECT
      GROUP_CONCAT(external_distribution_list.edl_email SEPARATOR '|')
    FROM distribution_group_email
      JOIN external_distribution_list
        ON dge_edl_id = edl_id
    WHERE FIND_IN_SET(distribution_group_email.dge_dig_id, group_ids)
    AND dge_edl_id IS NOT NULL
    AND distribution_group_email.dge_enable = 1
    AND external_distribution_list.edl_enable = 1);

  SELECT
    CONCAT_WS('|', @account_emails, @external_emails, @group_emails_account, @group_emails_external) AS emails;



END
$$

DELIMITER ;

--
-- Drop procedure `get_edl_list`
--
DROP PROCEDURE IF EXISTS get_edl_list;

DELIMITER $$

--
-- Create procedure `get_edl_list`
--
CREATE PROCEDURE IF NOT EXISTS get_edl_list ()
BEGIN
  /*
     Created by: Rana Hussain
     Modified on: 2022-02-25
     Reason: SOF-10407 - Security patch: Convert raw query to stored procedure
  
     Modified Date : 2023-03-30
     Modified By  : Gowtham Ravindran
     Comment      : SOF-13700 - Trimming the Trailing comma
  
     Modified Date : 2023-05-03
     Modified By  : Gowtham Ravindran
     Comment      : SOF-14003 - Membership Feature change
  
     Modified Date : 2024-04-04
     Modified By  : Gowtham Ravindran/Sarath Sontam
     Comment      : PD-900 - add category
  
     Modified Date : 2024-10-03
     Modified By  : Gowtham Ravindran
     Comment      : PD-2826 - Changed the schema of distribution group email table to include primary keys of person and external distribution contact
   
  */

  SELECT
    edl_id AS id,
    CONCAT(edl_last_name, ', ', edl_first_name) AS name,
    edl_email AS email,
    'all' AS emp_data_visibility,
    1 AS emp_membership,
    0 AS is_staff,
    'external' AS category
  FROM external_distribution_list
  WHERE edl_enable = 1
  AND edl_email IS NOT NULL
  UNION ALL
  SELECT
    a.id,
    a.name,
    TRIM(TRAILING ',' FROM CONCAT(GROUP_CONCAT(a.email), ',')) AS email,
    'all' AS emp_data_visibility,
    1 AS emp_membership,
    0 AS is_staff,
    'group' AS category
  FROM (SELECT
      distribution_group_email.dge_dig_id AS id,
      distribution_group.dig_group_name AS name,
      auth_user_sofvie.email AS email
    FROM distribution_group_email
      INNER JOIN distribution_group
        ON distribution_group_email.dge_dig_id = distribution_group.dig_id
        AND dig_enable = 1
      JOIN auth_user_sofvie
        ON distribution_group_email.dge_per_id = auth_user_sofvie.user_per_id
    UNION ALL
    SELECT
      distribution_group_email.dge_dig_id AS id,
      distribution_group.dig_group_name AS name,
      external_distribution_list.edl_email AS email
    FROM distribution_group_email
      INNER JOIN distribution_group
        ON distribution_group_email.dge_dig_id = distribution_group.dig_id
        AND dig_enable = 1
      JOIN external_distribution_list
        ON distribution_group_email.dge_edl_id = external_distribution_list.edl_id) a
  GROUP BY a.name
  ORDER BY 1;

END
$$

DELIMITER ;

--
-- Drop procedure `api_client_membership_info`
--
DROP PROCEDURE IF EXISTS api_client_membership_info;

DELIMITER $$

--
-- Create procedure `api_client_membership_info`
--
CREATE PROCEDURE IF NOT EXISTS api_client_membership_info (IN start_date datetime, IN end_date datetime, IN language_id int, IN filter_condition int)
BEGIN
  /*
     Created by:    Naveen Kumar Vadlamudi
     Created Date:  2024-08-26
     Ticket Number: PD-2335 (Client API)
     Reason: Normalized the APIs for data consistency. 

     Created by:    Naveen Kumar Vadlamudi
     Created Date:  2024-10-09
     Ticket Number: PD-2335 (Client API)
     Reason: Filter condition parameter issue.

     Created by:    Naveen Kumar Vadlamudi
     Created Date:  2024-12-10
     Ticket Number: PD-3245 (Client API)
     Reason: Bug in data returning from backend.

  */

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;



  WITH employee_job_info
  AS
  (SELECT
      ejo_emp_id,
      ejo_job_id,
      get_translation_from_ref_list_id(ejo_job_id, 'ref_job', language_id) AS job
    FROM employee_job
    WHERE ejo_enable = 1),

  employee_site_info
  AS
  (SELECT
      esi_emp_id,
      esi_sit_id,
      get_translation_from_ref_list_id(esi_sit_id, 'ref_site', language_id) AS site
    FROM employee_site
    WHERE esi_enable = 1),

  job_n_site_info
  AS
  (SELECT
      *
    FROM employee_site_info AS esi
      LEFT JOIN employee_job_info AS eji
        ON esi.esi_emp_id = eji.ejo_emp_id)


  SELECT
    e.emp_per_id AS employee_person_id,
    e.emp_employee_number AS employee_number,
    jnsi.ejo_job_id AS job_id,
    jnsi.job,
    jnsi.esi_sit_id AS site_id,
    jnsi.site
  FROM person AS p
    LEFT JOIN employee AS e
      ON p.per_id = e.emp_per_id
    LEFT JOIN auth_user_sofvie AS aus
      ON p.per_id = aus.user_per_id
    LEFT JOIN job_n_site_info AS jnsi
      ON jnsi.esi_emp_id = e.emp_id
  WHERE CASE WHEN filter_condition = 1 THEN p.per_enable = 1
        AND aus.is_active = 1
        AND p.per_id != 1 WHEN filter_condition = 2 THEN e.emp_enable = 1
        AND aus.is_active = 0 WHEN filter_condition = 3 THEN e.emp_enable = 0 ELSE 1 = 1 END
  AND p.per_created_date BETWEEN start_date AND end_date;

END
$$

--
-- Create procedure `rpt_archived_useful_links`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_useful_links (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*

 Created By: Naveen Kumar Vadlamudi 
 Created Date: 2024-12-12
 Purpose: PD-2869 - Report - Archived Items - Data and Date Updates
 
  */

  SELECT
    ulm.ulm_link AS useful_links,
    ulm.ulm_id AS id,
    ulm.ulm_description AS useful_link_description,
    archived_context.aco_created_date AS useful_links_archived_date,
    archived_by.per_full_name AS useful_links_archived_by,
    DATE(ulm_created_date) AS useful_links_created_date,
    created_by.per_full_name AS useful_links_created_by,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS useful_links_archived_position,
    archived_context.aco_context AS useful_link_context
  FROM useful_link_management ulm
    LEFT JOIN archived_context
      ON archived_context.aco_id = ulm.ulm_aco_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
    LEFT JOIN v_employee created_by
      ON ulm.ulm_created_by_per_id = created_by.per_id
  WHERE ulm.ulm_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_training_records`
--
DROP PROCEDURE IF EXISTS rpt_archived_training_records;

DELIMITER $$

--
-- Create procedure `rpt_archived_training_records`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_training_records (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(Training Records)
  
  
 Created By: Pragati Das
 Created Date: 2023-08-29
 Purpose: SOF-13836 - Added DATE function to get data for today

 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
 Modified By: Pragati Das
 Modified Date: 2023-10-27
 Purpose: SOF-14837- Archive - Context - Reporting - Updated the SP to filter data based on the 
          created datefrom the new archive table 

 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-06
 Purpose: Report - Archived Items - Data and Date Updates
  */
  SELECT
    assigned_to.per_full_name AS training_record_assigned_to,
    get_translation_from_ref_list_id(etr_training_code_id, 'ref_training_code', lang) AS training_record_training_code,
    get_translation_from_ref_list_id(etr_training_type_id, 'ref_training_type', lang) AS training_record_training_type,
    archived_context.aco_created_date AS training_record_archived_date,
    archived_by.per_full_name AS training_record_archived_by,
    created_by.per_full_name AS training_record_created_by,
    DATE(etr_created_date) AS training_record_created_date,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS training_record_archived_position,
    archived_context.aco_context AS training_record_context
  FROM employee_training
    LEFT JOIN archived_context
      ON archived_context.aco_id = employee_training.etr_aco_id
    LEFT JOIN v_employee created_by
      ON employee_training.etr_created_by_per_id = created_by.per_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
    LEFT JOIN v_employee assigned_to
      ON employee_training.etr_emp_id = assigned_to.emp_id
  WHERE etr_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date
  ;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_roles`
--
DROP PROCEDURE IF EXISTS rpt_archived_roles;

DELIMITER $$

--
-- Create procedure `rpt_archived_roles`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_roles (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(Role (Custom Roles))
 
 Created By: Pragati Das
 Created Date: 2023-08-29
 Purpose: SOF-13836 - Added DATE function to get data for today
  
 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
 Modified By: Pragati Das
 Modified Date: 2023-10-27
 Purpose: SOF-14837- Archive - Context - Reporting - Updated the SP to filter data based on the 
          created datefrom the new archive table 

 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-06
 Purpose: Report - Archived Items - Data and Date Updates

  */

  SELECT

    ars.aro_id AS roles_ID,
    get_translation(ars.aro_name, lang, 2) AS roles_name,
    archived_context.aco_created_date AS roles_archived_date,
    archived_by.per_full_name AS roles_archived_by,
    DATE(ars.aro_created_date) AS roles_created_date,
    created_by.per_full_name AS roles_created_by,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS roles_archived_position,
    archived_context.aco_context AS roles_context
  FROM auth_role_sofvie ars
    LEFT JOIN archived_context
      ON archived_context.aco_id = ars.aro_aco_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
    LEFT JOIN v_employee created_by
      ON ars.aro_created_by_per_id = created_by.per_id
  WHERE ars.aro_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date
  ;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_pra`
--
DROP PROCEDURE IF EXISTS rpt_archived_pra;

DELIMITER $$

--
-- Create procedure `rpt_archived_pra`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_pra (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(PRA)
  
 Created By: Pragati Das
 Created Date: 2023-08-29
 Purpose: SOF-13836 - Added DATE function to get data for today
 
 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
 Modified By: Pragati Das
 Modified Date: 2023-10-27
 Purpose: SOF-14837- Archive - Context - Reporting - Updated the SP to filter data based on the 
          created datefrom the new archive table

 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-06
 Purpose: Report - Archived Items - Data and Date Updates

  */


  SELECT
    rmm_pra_title AS projectprocess_risk_assessment_title,
    rmm_pra_id AS projectprocess_risk_assessment_ID,
    archived_context.aco_created_date AS projectprocess_risk_assessment_archived_date,
    archived_by.per_full_name AS projectprocess_risk_assessment_archived_by,
    DATE(rmm_pra_created_date) AS projectprocess_risk_assessment_created_date,
    created_by.per_full_name AS projectprocess_risk_assessment_created_by,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS projectprocess_risk_assessment_archived_position,
    get_translation_from_ref_list_id(rmm_pra.rmm_pra_site_id, 'ref_site', lang) AS projectprocess_risk_assessment_site,
    archived_context.aco_context AS projectprocess_risk_assessment_context
  FROM rmm_pra
    LEFT JOIN archived_context
      ON archived_context.aco_id = rmm_pra.rmm_pra_aco_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
    LEFT JOIN v_employee created_by
      ON rmm_pra.rmm_pra_created_by_per_id = created_by.per_id
  WHERE rmm_pra.rmm_pra_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_ora`
--
DROP PROCEDURE IF EXISTS rpt_archived_ora;

DELIMITER $$

--
-- Create procedure `rpt_archived_ora`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_ora (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(ORA)
 
 Created By: Pragati Das
 Created Date: 2023-08-29
 Purpose: SOF-13836 - Added DATE function to get data for today
 
 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
 Modified By: Pragati Das
 Modified Date: 2023-10-27
 Purpose: SOF-14837- Archive - Context - Reporting - Updated the SP to filter data based on the 
          created datefrom the new archive table 

 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-06
 Purpose: Report - Archived Items - Data and Date Updates

  */


  SELECT
    rmm_ora_title AS organization_risk_assessment_title,
    rmm_ora_id AS organization_risk_assessment_ID,
    archived_context.aco_created_date AS organization_risk_assessment_date,
    archived_by.per_full_name AS organization_risk_assessment_archived_by,
    DATE(rmm_ora_created_date) AS organization_risk_assessment_created_date,
    created_by.per_full_name AS organization_risk_assessment_created_by,
    get_translation_from_ref_list_id(rmm_ora.rmm_ora_site_id, 'ref_site', lang) AS organization_risk_assessment_site,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS organization_risk_assessment_archived_position,
    archived_context.aco_context AS organization_risk_assessment_context
  FROM rmm_ora
    LEFT JOIN archived_context
      ON archived_context.aco_id = rmm_ora.rmm_ora_aco_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
    LEFT JOIN v_employee created_by
      ON rmm_ora.rmm_ora_created_by_per_id = created_by.per_id
  WHERE rmm_ora.rmm_ora_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_lockout_tagout`
--
DROP PROCEDURE IF EXISTS rpt_archived_lockout_tagout;

DELIMITER $$

--
-- Create procedure `rpt_archived_lockout_tagout`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_lockout_tagout (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(Lockout/Tagout)
 
 Created By: Pragati Das
 Created Date: 2023-08-29
 Purpose: SOF-13836 - Added DATE function to get data for today
  
 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
 Modified By: Pragati Das
 Modified Date: 2023-10-27
 Purpose: SOF-14837- Archive - Context - Reporting - Updated the SP to filter data based on the 
          created datefrom the new archive table
 
 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-06
 Purpose: Report - Archived Items - Data and Date Updates

  */

  SELECT
    lockout_tagout_header.lth_title AS lockout_tagout_title,
    lockout_tagout_header.lth_id AS lockout_tagout_ID,
    archived_context.aco_created_date AS lockout_tagout_archived_date,
    archived_by.per_full_name AS lockout_tagout_archived_by,
    DATE(lockout_tagout_header.lth_modified_date) AS lockout_tagout_modified_date,
    modified_by.per_full_name AS lockout_tagout_modified_by,
    get_translation_from_ref_list_id(common_header_data.chd_site_id, 'ref_site', lang) AS lockout_tagout_site,
    get_translation_from_ref_list_id(common_header_data.chd_job_id, 'ref_job', lang) AS lockout_tagout_department,
    get_translation_from_ref_list_id(common_header_data.chd_level_id, 'ref_level', lang) AS lockout_tagout_area,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS lockout_tagout_archived_position,
    archived_context.aco_context AS lockout_tagout_context
  FROM lockout_tagout_header
    LEFT JOIN archived_context
      ON archived_context.aco_id = lockout_tagout_header.lth_aco_id
    LEFT JOIN v_employee modified_by
      ON lockout_tagout_header.lth_modified_by_per_id = modified_by.per_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
    INNER JOIN common_header_data
      ON lockout_tagout_header.lth_chd_id = common_header_data.chd_id
  WHERE lockout_tagout_header.lth_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_lessons_learned`
--
DROP PROCEDURE IF EXISTS rpt_archived_lessons_learned;

DELIMITER $$

--
-- Create procedure `rpt_archived_lessons_learned`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_lessons_learned (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(Lesson Learned)
  
  Created By: Pragati Das
 Created Date: 2023-08-29
 Purpose: SOF-13836 - Added DATE function to get data for today
 
 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
 Modified By: Pragati Das
 Modified Date: 2023-10-27
 Purpose: SOF-14837- Archive - Context - Reporting - Updated the SP to filter data based on the 
          created datefrom the new archive table 
 
 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-06
 Purpose: Report - Archived Items - Data and Date Updates
  */

  SELECT

    llm_id AS lessons_learned_ID,
    llm_title AS lessons_learned_title,
    archived_context.aco_created_date AS lessons_learned_date_archived,
    archived_by.per_full_name AS lessons_learned_archived_by,
    DATE(lesson_learned.llm_submitted_date) AS lessons_learned_submission_date,
    submitted_by.per_full_name AS lessons_learned_submitted_by,
    get_translation_from_ref_list_id(lesson_learned.llm_site_rld_id, 'ref_site', lang) AS lessons_learned_site,
    get_translation_from_ref_list_id(lesson_learned.llm_job_rld_id, 'ref_job', lang) AS lessons_learned_department,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS lessons_learned_archived_position,
    archived_context.aco_context AS lessons_learned_context
  FROM lesson_learned
    LEFT JOIN archived_context
      ON archived_context.aco_id = lesson_learned.llm_aco_id
    LEFT JOIN v_employee submitted_by
      ON lesson_learned.llm_submitted_by_per_id = submitted_by.per_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
  WHERE llm_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_jra`
--
DROP PROCEDURE IF EXISTS rpt_archived_jra;

DELIMITER $$

--
-- Create procedure `rpt_archived_jra`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_jra (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(JRA)
 
 Created By: Pragati Das
 Created Date: 2023-08-29
 Purpose: SOF-13836 - Added DATE function to get data for today
  
  
 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
 Modified By: Pragati Das
 Modified Date: 2023-10-27
 Purpose: SOF-14837- Archive - Context - Reporting - Updated the SP to filter data based on the 
          created datefrom the new archive table 
 
 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-06
 Purpose: Report - Archived Items - Data and Date Updates

  */


  SELECT
    rmm_jra_title AS job_risk_assessment_title,
    rmm_jra_id AS job_risk_assessment_ID,
    archived_context.aco_created_date AS job_risk_assessment_archived_date,
    archived_by.per_full_name AS job_risk_assessment_archived_by,
    DATE(rmm_jra_created_date) AS job_risk_assessment_created_date,
    created_by.per_full_name AS job_risk_assessment_created_by,
    get_translation_from_ref_list_id(rmm_jra.rmm_jra_site_id, 'ref_site', lang) AS job_risk_assessment_site,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS job_risk_assessment_archived_position,
    archived_context.aco_context AS job_risk_assessment_context
  FROM rmm_jra
    LEFT JOIN archived_context
      ON archived_context.aco_id = rmm_jra.rmm_jra_aco_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
    LEFT JOIN v_employee created_by
      ON rmm_jra.rmm_jra_created_by_per_id = created_by.per_id
  WHERE rmm_jra.rmm_jra_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_incident_analysis`
--
DROP PROCEDURE IF EXISTS rpt_archived_incident_analysis;

DELIMITER $$

--
-- Create procedure `rpt_archived_incident_analysis`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_incident_analysis (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(Incident Analysis)
  
  
 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
 Modified By: Pragati Das
 Modified Date: 2023-10-27
 Purpose: SOF-14837- Archive - Context - Reporting - Updated the SP to filter data based on the 
          created datefrom the new archive table 

 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-05
 Purpose: Report - Archived Items - Data and Date Updates

  */

  SELECT
    RootCauseAnalysis.ID AS incident_analysis_submission_ID,
    RootCauseAnalysis.EventDetails AS incident_analysis_details,
    archived_context.aco_created_date AS incident_analysis_date_archived,
    archived_by.per_full_name AS incident_analysis_archived_by,
    DATE(RootCauseAnalysis.SubmissionDate) AS incident_analysis_submission_date,
    submitted_by.per_full_name AS incident_analysis_submitted_by,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS incident_analysis_archived_position,
    archived_context.aco_context AS incident_analysis_context
  FROM RootCauseAnalysis
    LEFT JOIN archived_context
      ON archived_context.aco_id = RootCauseAnalysis.rca_aco_id
    LEFT JOIN v_employee submitted_by
      ON RootCauseAnalysis.SubmittedBy = submitted_by.per_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
  WHERE DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date
  AND RootCauseAnalysis.IsArchived = 1;



END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_incidents`
--
DROP PROCEDURE IF EXISTS rpt_archived_incidents;

DELIMITER $$

--
-- Create procedure `rpt_archived_incidents`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_incidents (IN start_date date, IN end_date date, IN lang int)
BEGIN
  /*
     Created by : Sarath Sontam
     Date        : 2024-01-04
     Reason      : PD-430 - Get archived incidents

  
     Modified By: Naveen Kumar Vadlamudi 
     Modified Date: 2024-12-05
     Purpose: Report - Archived Items - Data and Date Updates
  */

  SELECT
    IncidentNumber AS incidents_number,
    Incidents.CreationDate AS incidents_created_date,
    inc_created.per_full_name AS incidents_submitted_by,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS incidents_archived_position,
    archived_context.aco_context AS incidents_context,
    archived_context.aco_created_date AS incidents_archived_date,
    archived_created.per_full_name AS incidents_archived_by
  FROM archived_context
    JOIN Incidents
      ON aco_id = inc_aco_id
    JOIN v_employee inc_created
      ON Incidents.CreatedBy = inc_created.per_id
    JOIN v_employee archived_created
      ON archived_context.aco_created_by_per_id = archived_created.per_id
  WHERE DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date;
END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_hours_log`
--
DROP PROCEDURE IF EXISTS rpt_archived_hours_log;

DELIMITER $$

--
-- Create procedure `rpt_archived_hours_log`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_hours_log (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(Hours log)
  
  Created By: Pragati Das
 Created Date: 2023-08-29
 Purpose: SOF-13836 - Added DATE function to get data for today
 
 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item

 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-05
 Purpose: Report - Archived Items - Data and Date Updates
 

  */
  SELECT
    whl_id AS hours_log_ID,
    whl_hours_worked AS hours_log_worked,
    archived_context.aco_created_date AS hours_log_archived_date,
    archived_by.per_full_name AS hours_log_archived_by,
    DATE(whl_created_date) AS hours_log_created_date,
    created_by.per_full_name AS hours_log_created_by,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS hours_log_archived_position,
    archived_context.aco_context AS hours_log_context
  FROM work_hours_log whl
    LEFT JOIN archived_context
      ON archived_context.aco_id = whl.whl_aco_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
    LEFT JOIN v_employee created_by
      ON whl.whl_created_by_per_id = created_by.per_id
  WHERE whl.whl_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date
  ;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_documents`
--
DROP PROCEDURE IF EXISTS rpt_archived_documents;

DELIMITER $$

--
-- Create procedure `rpt_archived_documents`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_documents (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(Documents)
 
 Created By: Pragati Das
 Created Date: 2023-08-29
 Purpose: SOF-13836 - Added DATE function to get data for today
 
 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
  Modified By: Pragati Das
 Modified Date: 2023-10-27
 Purpose: SOF-14837- Archive - Context - Reporting - Updated the SP to filter data based on the 
          created datefrom the new archive table 

 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-05
 Purpose: Report - Archived Items - Data and Date Updates
 
  */

  SELECT
    drm_description AS documents_description,
    archived_context.aco_created_date AS documents_archived_date,
    archived_by.per_full_name AS documents_archived_by,
    DATE(drm_submitted_date) AS documents_submitted_date,
    submitted_by.per_full_name AS documents_submitted_by,
    drm_id AS documents_id,
    drm_filename AS documents_filename,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS documents_archived_position,
    archived_context.aco_context AS documents_context

  FROM document_review_management
    LEFT JOIN archived_context
      ON archived_context.aco_id = document_review_management.drm_aco_id
    LEFT JOIN v_employee submitted_by
      ON archived_context.aco_created_by_per_id = submitted_by.per_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
  WHERE document_review_management.drm_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_distribution_groups`
--
DROP PROCEDURE IF EXISTS rpt_archived_distribution_groups;

DELIMITER $$

--
-- Create procedure `rpt_archived_distribution_groups`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_distribution_groups (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(Distribution group)
 
 Created By: Pragati Das
 Created Date: 2023-08-29
 Purpose: SOF-13836 - Added DATE function to get data for today
  
 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
  
 Modified By: Pragati Das
 Modified Date: 2023-10-27
 Purpose: SOF-14837- Archive - Context - Reporting - Updated the SP to filter data based on the 
          created datefrom the new archive table


 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2025-01-06
 Purpose: Report - Archived Items - Data and Date Updates (Updated the procedure to remove email and add names)

  */



  SELECT
    fetch_archived_distributions.distribution_groups_ID,
    fetch_archived_distributions.distribution_groups_name,
    GROUP_CONCAT(DISTINCT fetch_archived_distributions.per_full_name SEPARATOR '; ') AS distribution_groups_user_names,
    fetch_archived_distributions.distribution_groups_archived_date,
    fetch_archived_distributions.distribution_groups_archived_by,
    fetch_archived_distributions.distribution_groups_created_by,
    fetch_archived_distributions.distribution_groups_created_date,
    fetch_archived_distributions.distribution_groups_archived_position,
    fetch_archived_distributions.distribution_groups_context
  FROM (SELECT
      dg.dig_group_name AS distribution_groups_name,
      CASE WHEN distribution_names.per_full_name IS NULL THEN '' WHEN CONCAT(edl.edl_first_name, edl.edl_last_name) IS NOT NULL THEN CONCAT(edl.edl_first_name, ', ', edl.edl_last_name) ELSE distribution_names.per_full_name END AS per_full_name,
      dge.dge_email,
      dg.dig_id AS distribution_groups_ID,
      archived_context.aco_created_date AS distribution_groups_archived_date,
      archived_by.per_full_name AS distribution_groups_archived_by,
      DATE(dg.dig_created_date) AS distribution_groups_created_date,
      created_by.per_full_name AS distribution_groups_created_by,
      get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', 1) AS distribution_groups_archived_position,
      archived_context.aco_context AS distribution_groups_context
    FROM distribution_group dg
      LEFT JOIN archived_context
        ON archived_context.aco_id = dg.dig_aco_id
      INNER JOIN distribution_group_email dge
        ON dg.dig_id = dge.dge_dig_id
      LEFT JOIN v_employee AS distribution_names
        ON dge.dge_email = distribution_names.email
        AND dge.dge_email IS NOT NULL
      LEFT JOIN external_distribution_list edl
        ON dge.dge_edl_id = edl.edl_id
      LEFT JOIN v_employee archived_by
        ON archived_context.aco_created_by_per_id = archived_by.per_id
      LEFT JOIN v_employee created_by
        ON dg.dig_created_by_per_id = created_by.per_id
    WHERE dg.dig_enable = 0
    AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date) AS fetch_archived_distributions
  GROUP BY fetch_archived_distributions.distribution_groups_ID;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_distribution_contacts`
--
DROP PROCEDURE IF EXISTS rpt_archived_distribution_contacts;

DELIMITER $$

--
-- Create procedure `rpt_archived_distribution_contacts`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_distribution_contacts (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(Distribution contacts)
 
 Created By: Pragati Das
 Created Date: 2023-08-29
 Purpose: SOF-13836 - Added DATE function to get data for today
 
 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
 Modified By: Pragati Das
 Modified Date: 2023-10-27
 Purpose: SOF-14837- Archive - Context - Reporting - Updated the SP to filter data based on the 
          created datefrom the new archive table

 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-05
 Purpose: Report - Archived Items - Data and Date Updates

  */

  SELECT

    edl_id AS distribution_contacts_ID,
    edl_email distribution_contacts_email,
    archived_context.aco_created_date AS distribution_contacts_archived_date,
    archived_by.per_full_name AS distribution_contacts_archived_by,
    DATE(edl_created_date) AS distribution_contacts_created_date,
    created_by.per_full_name AS distribution_contacts_created_by,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS distribution_contacts_archived_position,
    archived_context.aco_context AS distribution_contacts_context
  FROM external_distribution_list edl
    LEFT JOIN archived_context
      ON archived_context.aco_id = edl.edl_aco_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
    LEFT JOIN v_employee created_by
      ON edl.edl_created_by_per_id = created_by.per_id
  WHERE edl.edl_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date;
END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_decision_log`
--
DROP PROCEDURE IF EXISTS rpt_archived_decision_log;

DELIMITER $$

--
-- Create procedure `rpt_archived_decision_log`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_decision_log (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(Decision log)
 
 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
 Modified By: Pragati Das
 Modified Date: 2023-10-27
 Purpose: SOF-14837- Archive - Context - Reporting - Updated the SP to filter data based on the 
          created datefrom the new archive table 


 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-05
 Purpose: Report - Archived Items - Data and Date Updates
 
  */

  SELECT

    decision_log.dlm_title AS decision_log_title,
    decision_log.dlm_id AS decision_log_ID,
    archived_context.aco_created_date AS decision_log_archived_date,
    archived_by.per_full_name AS decision_log_archived_by,
    DATE(decision_log.dlm_created_date) AS decision_log_created_date,
    created_by.per_full_name AS decision_log_created_by,
    get_translation_from_ref_list_id(decision_log.dlm_site_rld_id, 'ref_site', lang) AS decision_log_site,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS decision_log_archived_position,
    archived_context.aco_context AS decision_log_context
  FROM decision_log
    LEFT JOIN archived_context
      ON archived_context.aco_id = decision_log.dlm_aco_id
    LEFT JOIN v_employee created_by
      ON decision_log.dlm_created_by_per_id = created_by.per_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
  WHERE decision_log.dlm_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_custom_lists`
--
DROP PROCEDURE IF EXISTS rpt_archived_custom_lists;

DELIMITER $$

--
-- Create procedure `rpt_archived_custom_lists`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_custom_lists (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(Custom Lists)

 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
 Modified By: Pragati Das
 Modified Date: 2023-10-27
 Purpose: SOF-14837- Archive - Context - Reporting - Updated the SP to filter data based on the 
          created datefrom the new archive table 

 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-05
 Purpose: Report - Archived Items - Data and Date Updates
  
  */

  SELECT
    get_translation(clh.clh_display_name, lang, 2) AS custom_lists_FormName,
    clh.clh_id AS custom_lists_ID,
    archived_context.aco_created_date AS custom_lists_archived_date,
    archived_by.per_full_name AS custom_lists_archived_by,
    DATE(clh.clh_created_date) AS custom_lists_created_date,
    created_by.per_full_name AS custom_lists_created_by,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS custom_lists_archived_position,
    archived_context.aco_context AS custom_lists_context
  FROM custom_list_header clh
    LEFT JOIN archived_context
      ON archived_context.aco_id = clh.clh_aco_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
    LEFT JOIN v_employee created_by
      ON clh.clh_created_by_per_id = created_by.per_id
  WHERE clh.clh_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_bowtie`
--
DROP PROCEDURE IF EXISTS rpt_archived_bowtie;

DELIMITER $$

--
-- Create procedure `rpt_archived_bowtie`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_bowtie (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-05-15
 Purpose: SOF-13836 - Archived Non Submissions report(Bowtie)
 
 Created By: Pragati Das
 Created Date: 2023-08-29
 Purpose: SOF-13836 - Added DATE function to get data for today

 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
 Modified By: Naveen Kumar Vadlamudi
 Modified Date: 2024-11-28
 Purpose: PD-2869 - Report archived items


 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-04
 Purpose: Report - Archived Items - Data and Date Updates
 
  */


  SELECT
    rmm_bow_title AS bowtie_risk_assessment_title,
    rmm_bow_id AS bowtie_risk_assessment_ID,
    archived_context.aco_created_date AS bowtie_risk_assessment_archived_date,
    archived_by.per_full_name AS bowtie_risk_assessment_archived_by,
    DATE(rmm_bow_created_date) AS bowtie_risk_assessment_created_date,
    created_by.per_full_name AS bowtie_risk_assessment_created_by,
    get_translation_from_ref_list_id(rmm_bowtie.rmm_bow_site_id, 'ref_site', lang) AS bowtie_risk_assessment_site,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS bowtie_risk_assessment_archived_position,
    archived_context.aco_context AS bowtie_risk_assessment_context
  FROM rmm_bowtie
    LEFT JOIN archived_context
      ON archived_context.aco_id = rmm_bowtie.rmm_bow_aco_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
    LEFT JOIN v_employee created_by
      ON rmm_bowtie.rmm_bow_created_by_per_id = created_by.per_id
  WHERE rmm_bowtie.rmm_bow_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date;

END
$$

--
-- Create procedure `rpt_get_user_permission`
--
CREATE PROCEDURE IF NOT EXISTS rpt_get_user_permission (IN permission varchar(255), IN keycloakId varchar(255))
BEGIN

  /*
     Created by: Sarath Sontam
     Created on: 2025-01-30
     Reason: PD-3348 - check if user has permission to view reports based on keycloak id
   
  */

  SELECT
    ape_id
  FROM auth_role_permission_sofvie
    JOIN auth_role_sofvie
      ON auth_role_permission_sofvie.arp_aro_id = auth_role_sofvie.aro_id
    JOIN auth_permission_sofvie
      ON ape_id = arp_ape_id
    JOIN auth_user_role_sofvie
      ON aur_aro_id = aro_id
    JOIN keycloak_user
      ON keycloak_user.kcu_user_id = auth_user_role_sofvie.aur_user_id
  WHERE auth_permission_sofvie.ape_name = permission
  AND kcu_keycloak_id = keycloakId
  AND arp_enable = 1
  AND aur_enable = 1;
END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_custom_forms`
--
DROP PROCEDURE IF EXISTS rpt_archived_custom_forms;

DELIMITER $$

--
-- Create procedure `rpt_archived_custom_forms`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_custom_forms (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report(Custom Forms)

 Created By: Vishnu Prakash
 Created Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
 Modified By: Pragati Das
 Modified Date: 2023-10-27
 Purpose: SOF-14837- Archive - Context - Reporting - Updated the SP to filter data based on the 
          created datefrom the new archive table 


 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-04
 Purpose: Report - Archived Items - Data and Date Updates
  */


  SELECT


    get_translation(fob_name, lang, fob_tag_type) AS custom_forms_FormName,
    fb.fob_id AS custom_forms_ID,
    archived_context.aco_created_date AS custom_forms_archived_date,
    archived_by.per_full_name AS custom_forms_archived_by,
    DATE(fb.fob_created_date) AS custom_forms_created_date,
    created_by.per_full_name AS custom_forms_created_by,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS custom_forms_archived_position,
    archived_context.aco_context AS custom_forms_context

  FROM form_builder fb
    LEFT JOIN archived_context
      ON archived_context.aco_id = fb.fob_aco_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
    LEFT JOIN v_employee created_by
      ON fb.fob_created_by_per_id = created_by.per_id
  WHERE fb.fob_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date
  ;

END
$$

DELIMITER ;

--
-- Drop index `IX_SupervisorTargets` from table `SupervisorTargets`
--
ALTER TABLE SupervisorTargets
DROP INDEX IF EXISTS IX_SupervisorTargets;

--
-- Create column `sta_bulk_create_identifier` on table `SupervisorTargets`
--
ALTER TABLE SupervisorTargets
ADD COLUMN IF NOT EXISTS sta_bulk_create_identifier varchar(255) DEFAULT NULL;

--
-- Change columns order on table `SupervisorTargets`
--
ALTER TABLE SupervisorTargets
MODIFY sta_bulk_create_identifier varchar(255) DEFAULT NULL AFTER EffectiveEnd;

--
-- Create index `UK_SupervisorTargets` on table `SupervisorTargets`
--
ALTER TABLE SupervisorTargets
ADD UNIQUE INDEX UK_SupervisorTargets (FrequencyID, FDFormID, sta_per_id, EffectiveOn, EffectiveEnd, sta_created_date);

--
-- Drop procedure `rpt_get_target_effective_end`
--
DROP PROCEDURE IF EXISTS rpt_get_target_effective_end;

DELIMITER $$

--
-- Create procedure `rpt_get_target_effective_end`
--
CREATE PROCEDURE IF NOT EXISTS rpt_get_target_effective_end (IN supervisor_id varchar(255), IN pre_defined_form_ids varchar(255), IN custom_form_ids varchar(255))
BEGIN

  /*

  Created by : Shane Robinson
  Created On : 2024-05-07
  Purpose : PD-887 - Converted inline queries in the BI code into SPs

  Created by : Sarath/Pragati
  Created On : 2024-11-28
  Purpose : PD-2706 - Added form ids to re-use this SP for both pre-defined and custom forms

  */

  SELECT
    MAX(IFNULL(EffectiveEnd, 'no-effective-end')) AS EffectiveEnd,
    t.FDFormID,
    t.sta_fob_id,
    t.FrequencyID
  FROM SupervisorTargets t
  WHERE (IF(pre_defined_form_ids IS NOT NULL,
  FIND_IN_SET(t.FDFormID, pre_defined_form_ids), 1 = 1)
  OR IF(custom_form_ids IS NOT NULL,
  FIND_IN_SET(t.sta_fob_id, custom_form_ids), 1 = 1))
  AND sta_per_id = supervisor_id
  GROUP BY t.FDFormID,
           t.sta_fob_id,
           t.FrequencyID
  ORDER BY t.ID DESC
  ;


END
$$

DELIMITER ;

--
-- Drop procedure `rpt_all_targets_change_details`
--
DROP PROCEDURE IF EXISTS rpt_all_targets_change_details;

DELIMITER $$

--
-- Create procedure `rpt_all_targets_change_details`
--
CREATE PROCEDURE IF NOT EXISTS rpt_all_targets_change_details (IN start_date date, IN end_date date, IN per_id text, IN language_id int)
BEGIN

  /*
    Created By : Bob/Pragati
    Created Date: 2023-01-16
    Purpose: SOF-13316 - Created new SP to get the Traget counts
  
    Created By : Bob/Pragati
    Created Date: 2023-01-23
    Purpose: SOF-13316 - Added sta_fob_id in the group by clause

    Created By : Pragati
    Created Date: 2025-02-18
    Purpose: PD-2706 - Added addtional conditions to get change log
  */
  SELECT
    CASE WHEN t.FrequencyID = 30 THEN get_translation(2890, language_id, 1) WHEN t.FrequencyID = 90 THEN get_translation(2891, language_id, 1) WHEN t.FrequencyID = 182 THEN get_translation(2892, language_id, 1) WHEN t.FrequencyID = 365 THEN get_translation(2893, language_id, 1) END AS frequencyname,
    t.FrequencyID,
    t.FDFormID,
    t.sta_fob_id,
    rl.ltr_text AS formname,
    t.Target,
    fl.ltr_text AS customformname,
    sta_context,
    EffectiveOn
  FROM SupervisorTargets t
    LEFT JOIN Reports r
      ON r.SingleFormReportID = t.FDFormID
    LEFT JOIN form_builder f
      ON f.fob_id = t.sta_fob_id
    LEFT JOIN language_translation rl
      ON rl.ltr_tag = r.ReportName
      AND rl.ltr_tag_type = 1
      AND rl.ltr_lng_id = language_id
    LEFT JOIN language_translation fl
      ON fl.ltr_tag = f.fob_name
      AND fl.ltr_tag_type = f.fob_tag_type
      AND fl.ltr_lng_id = language_id
  WHERE (CAST(t.EffectiveOn AS date) >= CAST(start_date AS date)
  AND CAST(t.EffectiveOn AS date) <= CAST(end_date AS date)
  OR (CAST(t.EffectiveOn AS date) <= CAST(start_date AS date)
  AND CAST(t.EffectiveEnd AS date) >= CAST(start_date AS date)
  AND CAST(t.EffectiveEnd AS date) <= CAST(end_date AS date)))
  AND t.sta_per_id = per_id
  GROUP BY t.FDFormID,
           t.sta_fob_id,
           t.FrequencyID
  ORDER BY t.ID DESC;
END
$$

DELIMITER ;

--
-- Drop procedure `get_user_deactivation_target_count`
--
DROP PROCEDURE IF EXISTS get_user_deactivation_target_count;

DELIMITER $$

--
-- Create procedure `get_user_deactivation_target_count`
--
CREATE PROCEDURE IF NOT EXISTS get_user_deactivation_target_count (IN person_id int)
BEGIN

  /* 
      Created by: Sontam Sarath
      Modified on: 2022-03-03
      Reason: SOF-10404 - Security patch: Convert raw query to stored procedure

      Modified By  : James Coles
      Modified Date: 2024-02-12
      Reson        : PD-2254   Change to use sta_per_id
  */

  SELECT
    CAST(IFNULL(SUM(Target), 0) AS int) AS target_count
  FROM SupervisorTargets
  WHERE sta_per_id = person_id
  AND sta_enable = 1
  AND EffectiveEnd IS NULL;
END
$$

DELIMITER ;

--
-- Drop procedure `get_target_frequency_site`
--
DROP PROCEDURE IF EXISTS get_target_frequency_site;

DELIMITER $$

--
-- Create procedure `get_target_frequency_site`
--
CREATE PROCEDURE IF NOT EXISTS get_target_frequency_site (IN person_Id int)
BEGIN

  /* 
      Created by: Sontam Sarath
      Modified on: 2023-01-04
      Reason: SOF-13140 - create new procedure to get target frequency of all persons at logged in person site.

    Modified By:    Vishnu
    Modified Date:  2023-05-08
    Reason:  SOF-14000 -Membership - SP updates - employee_site and employee_job

    Modified By: Gowtham Ravindran
    Modified Date: 2023-10-11
    Description: SOF-14751 - Replace view employee_membership_site and employee_membership_job with employee_membership_site_all and employee_membership_job_all for better performance.
                'site_ids'/'job_ids' parameter is considered and filtered only if user is set to custom membership, else 'site_ids'/'job_ids' paramerter is ignored and not filter 
                 user based on given site_ids.
  
     Modified By  : James Coles
     Modified Date: 2024-02-12
     Reason        : PD-2254   Change to use sta_per_id


*/


  SELECT
    CASE WHEN SupervisorTargets.FDFormID IS NOT NULL THEN FDFormID ELSE sta_fob_id END AS form_id,
    SUM(target) AS target,
    CASE WHEN SupervisorTargets.FDFormID IS NOT NULL THEN ReportName ELSE form_builder.fob_name END AS form_name,
    freq.rld_code,
    freq.rld_name AS frequency,
    DATE_FORMAT(SupervisorTargets.EffectiveOn, '%Y-%m') AS EffectiveOn,
    GROUP_CONCAT(person_sites.person_sites_per_id) AS person_id
  FROM SupervisorTargets
    LEFT JOIN Reports
      ON SupervisorTargets.FDFormID = Reports.SingleFormReportID
      AND SupervisorTargets.FDFormID IS NOT NULL
    LEFT JOIN form_builder
      ON form_builder.fob_id = SupervisorTargets.sta_fob_id
      AND sta_fob_id IS NOT NULL
    INNER JOIN (SELECT
        *
      FROM ref_list_detail
      WHERE rld_rlh_id = 12) freq
      ON SupervisorTargets.FrequencyID = freq.rld_code
    INNER JOIN (SELECT DISTINCT
        v_employee.per_id AS person_sites_per_id
      FROM employee_membership_site_all
        INNER
        JOIN v_employee
          ON employee_membership_site_all.emp_id = v_employee.emp_id
      WHERE CASE WHEN employee_membership_site_all.site_id = 'all' THEN TRUE ELSE employee_membership_site_all.site_id IN (SELECT
              site_id
            FROM employee_membership_site_all
              INNER JOIN v_employee
                ON employee_membership_site_all.emp_id = v_employee.emp_id
            WHERE v_employee.per_id = person_id
            AND employee_membership_site_all.esi_enable = 1) END) AS person_sites
      ON sta_per_id = person_sites.person_sites_per_id
  WHERE SupervisorTargets.sta_enable = 1
  GROUP BY form_id,
           freq.rld_code;
END
$$

DELIMITER ;

--
-- Drop procedure `get_target_frequency_company`
--
DROP PROCEDURE IF EXISTS get_target_frequency_company;

DELIMITER $$

--
-- Create procedure `get_target_frequency_company`
--
CREATE PROCEDURE IF NOT EXISTS get_target_frequency_company ()
BEGIN

  /* 
      Created by: Sontam Sarath
      Modified on: 2023-01-04
      Reason: SOF-13140 - create new procedure to get target frequency company wide for all persons who has site.

    Modified By:    Vishnu
    Modified Date:  2023-05-08
    Reason:  SOF-14000 -Membership - SP updates - employee_site and employee_job

    Modified by: James Coles
    Date       : 2023-09-15
    Reason     : SOF-15126 - Remove rld_ deleted references.

    Modified By: Gowtham Ravindran
    Modified Date: 2023-10-11
    Description: SOF-14751 - Replace view employee_membership_site and employee_membership_job with employee_membership_site_all and employee_membership_job_all for better performance.
                'site_ids'/'job_ids' parameter is considered and filtered only if user is set to custom membership, else 'site_ids'/'job_ids' paramerter is ignored and not filter 
                 user based on given site_ids.
  
     Modified By  : James Coles
     Modified Date: 2024-02-12
     Reason        : PD-2254   Change to use sta_per_id.
 
 */


  SELECT
    CASE WHEN SupervisorTargets.FDFormID IS NOT NULL THEN FDFormID ELSE sta_fob_id END AS form_id,
    SUM(target) AS target,
    CASE WHEN SupervisorTargets.FDFormID IS NOT NULL THEN ReportName ELSE form_builder.fob_name END AS form_name,
    freq.rld_code,
    freq.rld_name AS frequency,
    DATE_FORMAT(SupervisorTargets.EffectiveOn, '%Y-%m') AS EffectiveOn,
    GROUP_CONCAT(person_with_sites.per_id) AS person_id
  FROM SupervisorTargets
    LEFT JOIN Reports
      ON SupervisorTargets.FDFormID = Reports.SingleFormReportID
      AND SupervisorTargets.FDFormID IS NOT NULL
    LEFT JOIN form_builder
      ON form_builder.fob_id = SupervisorTargets.sta_fob_id
      AND sta_fob_id IS NOT NULL
    INNER JOIN (SELECT
        *
      FROM ref_list_detail
      WHERE rld_rlh_id = 12) freq
      ON SupervisorTargets.FrequencyID = freq.rld_code
    INNER JOIN (SELECT DISTINCT
        v_employee.per_id,
        v_employee.per_full_name
      FROM employee_membership_site_all
        INNER
        JOIN v_employee
          ON employee_membership_site_all.emp_id = v_employee.emp_id
      WHERE CASE WHEN employee_membership_site_all.site_id = 'all' THEN TRUE ELSE employee_membership_site_all.site_id IN (SELECT
              rld_id
            FROM ref_list_detail
            WHERE rld_rlh_id = 1
            AND rld_enable = 1) END) AS person_with_sites
      ON sta_per_id = person_with_sites.per_id
  WHERE SupervisorTargets.sta_enable = 1
  GROUP BY form_id,
           freq.rld_code;
END
$$

DELIMITER ;

--
-- Drop procedure `get_target_frequency`
--
DROP PROCEDURE IF EXISTS get_target_frequency;

DELIMITER $$

--
-- Create procedure `get_target_frequency`
--
CREATE PROCEDURE IF NOT EXISTS get_target_frequency (IN person_id int)
BEGIN

  /* 
      Created by: Sontam Sarath
      Modified on: 2022-03-03
      Reason: SOF-10404 - Security patch: Convert raw query to stored procedure

     Modified by: Vishnu Prakash
     Modified on: 2022-09-08
     Reason: SOF-12082 - Targets - Custom Forms - API - get-all-targets-statistics endpoint

     Modified by: Sarath Sontam
     Modified on: 2022-12-19
     Reason: SOF-13140 - Targets - add effective on in select.

     Modified by: Sarath Sontam
     Modified on: 2024-03-20
     Reason: PD-1326 - Targets - No changes on devcore. Promoting SP to test to makesure all column names in select match case. 

     Modified By  : James Coles
     Modified Date: 2024-02-12
     Reason        : PD-2254   Change to use sta_per_id

  */


  SELECT
    CASE WHEN SupervisorTargets.FDFormID IS NOT NULL THEN FDFormID ELSE sta_fob_id END AS form_id,
    target,
    CASE WHEN SupervisorTargets.FDFormID IS NOT NULL THEN ReportName ELSE form_builder.fob_name END AS form_name,
    freq.rld_code,
    freq.rld_name AS frequency,
    DATE_FORMAT(SupervisorTargets.EffectiveOn, '%Y-%m') AS EffectiveOn
  FROM SupervisorTargets
    LEFT JOIN Reports
      ON SupervisorTargets.FDFormID = Reports.SingleFormReportID
      AND SupervisorTargets.FDFormID IS NOT NULL
    LEFT JOIN form_builder
      ON form_builder.fob_id = SupervisorTargets.sta_fob_id
      AND sta_fob_id IS NOT NULL
    INNER JOIN (SELECT
        *
      FROM ref_list_detail
      WHERE rld_rlh_id = 12) freq
      ON SupervisorTargets.FrequencyID = freq.rld_code
      AND SupervisorTargets.sta_per_id = person_id
      AND SupervisorTargets.sta_enable = 1;
END
$$

DELIMITER ;

--
-- Drop procedure `get_supervisor_targets_by_per_id`
--
DROP PROCEDURE IF EXISTS get_supervisor_targets_by_per_id;

DELIMITER $$

--
-- Create procedure `get_supervisor_targets_by_per_id`
--
CREATE PROCEDURE IF NOT EXISTS get_supervisor_targets_by_per_id (IN per_id int)
BEGIN
  /*     
     Created Date : 2022-02-10
     Modified By  : James Coles, Zach Ross
     Comment      : Returning all tartgets for a person.

     Modified Date : 2022-09-07
     Modified By  : Sarath Sontam
     Comment      : Add new custom form id in select

     Modified By  : James Coles
     Modified Date: 2024-02-12
     Reason        : PD-2254   Change to use sta_per_id

  */
  SELECT
    SupervisorTargets.ID,
    SupervisorTargets.FDFormID,
    SupervisorTargets.sta_fob_id,
    SupervisorTargets.sta_per_id AS SupervisorID,
    SupervisorTargets.FrequencyID,
    SupervisorTargets.Target,
    SupervisorTargets.EffectiveOn,
    SupervisorTargets.EffectiveEnd
  FROM v_employee AS Supervisors
    INNER JOIN SupervisorTargets
      ON Supervisors.per_id = SupervisorTargets.sta_per_id
  WHERE Supervisors.per_id = per_id
  AND sta_enable = 1;
END
$$

DELIMITER ;

--
-- Drop procedure `get_employee_target_submissions`
--
DROP PROCEDURE IF EXISTS get_employee_target_submissions;

DELIMITER $$

--
-- Create procedure `get_employee_target_submissions`
--
CREATE PROCEDURE IF NOT EXISTS get_employee_target_submissions (IN per_id int)
BEGIN

  /*
     Created by: James Coles
     Modified on: 2022-05-04
     Reason: SOF-11222 - Security patch: Convert raw query to stored procedure
     
     Modified by: Vishnu Prakash
     Modified on: 2022-09-08
     Reason: SOF-12081 - Targets - Custom Forms - API - get-employee-target-submissions endpoint

      Modified By  : James Coles
      Modified Date: 2024-02-12
      Reason        : PD-2254   Change to use sta_per_id

  */

  SELECT
    CASE WHEN SupervisorTargets.FDFormID IS NOT NULL THEN FDFormID ELSE sta_fob_id END AS form_id,
    target,
    CASE WHEN SupervisorTargets.FDFormID IS NOT NULL THEN ReportName ELSE form_builder.fob_name END AS form_name,
    IFNULL(rpt_output_type, 'pageable/pdf') AS rpt_output_type,
    freq.rld_code,
    freq.rld_name AS frequency,
    CASE WHEN SupervisorTargets.FDFormID IS NOT NULL THEN 'Predefined' ELSE 'Custom' END AS form_type
  FROM SupervisorTargets
    LEFT JOIN Reports
      ON SupervisorTargets.FDFormID = Reports.SingleFormReportID
      AND SupervisorTargets.FDFormID IS NOT NULL
    LEFT JOIN form_builder
      ON form_builder.fob_id = SupervisorTargets.sta_fob_id
      AND sta_fob_id IS NOT NULL
    INNER JOIN ref_list_detail freq
      ON SupervisorTargets.FrequencyID = freq.rld_code
      AND rld_rlh_id = 12
  WHERE SupervisorTargets.sta_per_id = per_id
  AND SupervisorTargets.sta_enable = 1;

END
$$

DELIMITER ;

--
-- Drop procedure `get_employee_targets`
--
DROP PROCEDURE IF EXISTS get_employee_targets;

DELIMITER $$

--
-- Create procedure `get_employee_targets`
--
CREATE PROCEDURE IF NOT EXISTS get_employee_targets (IN lang_name varchar(2), IN per_id int)
BEGIN

  /*
     Created by: James Coles
     Modified on: 2022-05-04
     Reason: SOF-11222 - Security patch: Convert raw query to stored procedure
    
     Modified by: Vishnu Prakash
     Modified on: 2022-09-07
     Reason: SOF-12080 - Targets - Custom Forms - API modification - get-employee-targets

     Modified by: Robert Rivest
     Modified on: 2022-11-21
     Reason: SOF-12883 - Targets - Add Target FrequencyID to Payload for Mobile

     Modified by: Sarath Sontam
     Modified on: 2022-12-15
     Reason: SOF-13140 - Targets - add effective on in select. 

     Modified by: Suman Marlapudi
     Date       : 2023-11-24
     Reason     : SOF-14025 - Replace the deprecated SELECT INTO clause with variables.

     Modified By  : James Coles
     Modified Date: 2024-02-12
     Reason        : PD-2254   Change to use sta_per_id

  */

  DECLARE lang_ID int;
  SET lang_ID = (SELECT
      lng_ID
    FROM language
    WHERE language.lng_name = lang_name);

  SELECT DISTINCT
    CASE WHEN FDFormID IS NOT NULL THEN FDFormID ELSE sta_fob_id END AS form_id,
    target,
    CASE WHEN form_trans.ltr_text IS NOT NULL THEN form_trans.ltr_text ELSE fb_lng.ltr_text END AS form_name,
    CASE WHEN FDFormID IS NOT NULL THEN 'Predefined' ELSE 'Custom' END AS form_type,
    freq.rld_code,
    lang.ltr_text AS frequency,
    SupervisorTargets.FrequencyID,
    DATE_FORMAT(SupervisorTargets.EffectiveOn, '%Y-%m') AS EffectiveOn
  FROM SupervisorTargets
    LEFT JOIN Reports
      ON Reports.SingleFormReportID = SupervisorTargets.FDFormID
    LEFT JOIN (SELECT
        rld_code,
        rld_name,
        rld_tag_type
      FROM ref_list_detail
      WHERE rld_rlh_id = 12) freq
      ON freq.rld_code = SupervisorTargets.FrequencyID
    LEFT JOIN language_translation lang
      ON freq.rld_name = lang.ltr_tag
      AND freq.rld_tag_type = lang.ltr_tag_type
      AND lang.ltr_tag_type = 1
    LEFT JOIN language_translation form_trans
      ON Reports.ReportName = form_trans.ltr_tag
      AND form_trans.ltr_tag_type = 1
    LEFT JOIN language l1
      ON l1.lng_id = lang.ltr_lng_id
    LEFT JOIN language l2
      ON l2.lng_id = form_trans.ltr_lng_id
    LEFT JOIN form_builder fb
      ON fb.fob_id = SupervisorTargets.sta_fob_id
    LEFT JOIN language_translation fb_lng
      ON fb_lng.ltr_tag = fb.fob_name
      AND fb.fob_tag_type = fb_lng.ltr_tag_type
  WHERE l1.lng_name = lang_name
  AND (l2.lng_name = lang_name
  OR fb_lng.ltr_lng_id = lang_ID)
  AND SupervisorTargets.sta_per_id = per_id
  AND SupervisorTargets.sta_enable = 1;



END
$$

DELIMITER ;

--
-- Drop procedure `rpt_targets_change_log_header`
--
DROP PROCEDURE IF EXISTS rpt_targets_change_log_header;

DELIMITER $$

--
-- Create procedure `rpt_targets_change_log_header`
--
CREATE PROCEDURE IF NOT EXISTS rpt_targets_change_log_header (IN per_id int, IN lang int, IN start_date date, IN end_date date)
BEGIN

  /* 
     # Created Date: 2020-08-09
     # Created By: Gowtham Ravindran
     # Usage: Header info for Targets Change Log report
  
     # Modified Date: 2021-09-16
     # Modified By: Vishnu Prakash
     # Change log: SOF-9026 - Data issue in Target change log Report - addd casting for the date filter 
  
     # Modified Date: 2021-09-20
     # Modified By: Jaganjot Kaur
     # Change log: SOF-9104 - Order of targets was not correct
  
     Modified By: Jazmyn Zarichney
     Modified Date: 2022-05-04
     Description: Adding enable check on language translations (SOF-11119)
   
     Modified By: Jazmyn Zarichney
     Modified Date: 2022-09-08
     Description: Updating the labels to use the language function (SOF-12027)   
  
     Modified By: Pragati Das
     Modified Date: 2024-08-23
     Description: PD-2768 - Added DISTINCT function to the role to remove 
                  duplicates and enable check for current role

     Modified By  : James Coles
     Modified Date: 2024-02-12
     Reason        : PD-2254   Change to use sta_per_id

  */

  DECLARE summary_label text;
  DECLARE employee_name_label text;
  DECLARE role_label text;
  DECLARE number_of_forms_with_targets_label text;
  DECLARE changed_within_time_frame_selected_label text;

  SET summary_label = get_translation(1311, lang, 1);
  SET employee_name_label = get_translation(204, lang, 1);
  SET role_label = get_translation(1245, lang, 1);
  SET number_of_forms_with_targets_label = get_translation(2446, lang, 1);
  SET changed_within_time_frame_selected_label = get_translation(2447, lang, 1);

  SELECT
    v_employee.per_full_name,
    COUNT(SupervisorTargets.FDFormID) AS activeTargets,

    (SELECT
        GROUP_CONCAT(DISTINCT (language_translation.ltr_text) SEPARATOR ', ')
      FROM auth_user_role_sofvie
        LEFT JOIN auth_role_sofvie
          ON auth_user_role_sofvie.aur_aro_id = auth_role_sofvie.aro_id
        LEFT JOIN language_translation
          ON language_translation.ltr_tag = auth_role_sofvie.aro_name
          AND language_translation.ltr_tag_type = auth_role_sofvie.aro_tag_type
      WHERE auth_user_role_sofvie.aur_user_id = v_employee.user_id
      AND language_translation.ltr_lng_id = lang
      AND auth_user_role_sofvie.aur_enable = 1) AS role,
    summary_label AS summary_label,
    employee_name_label AS employee_name_label,
    role_label AS role_label,
    number_of_forms_with_targets_label AS number_of_forms_with_targets_label,
    changed_within_time_frame_selected_label AS changed_within_time_frame_selected_label

  FROM SupervisorTargets

    INNER JOIN v_employee
      ON SupervisorTargets.sta_per_id = v_employee.per_id

  WHERE SupervisorTargets.sta_per_id = per_id
  AND SupervisorTargets.EffectiveEnd IS NULL
  GROUP BY v_employee.per_id

  UNION



  (SELECT
      GROUP_CONCAT(t.stc_formId ORDER BY t.ltr_text ASC) AS formID,
      COUNT(DISTINCT (stc_formId)) AS 'Changed',
      GROUP_CONCAT(DISTINCT (ltr_text) ORDER BY t.ltr_text ASC) AS Formnames,
      ' ',
      ' ',
      ' ',
      ' ',
      ' '
    FROM (SELECT
        CASE WHEN sub_tbl.stc_formId IS NOT NULL THEN sub_tbl.stc_formId ELSE sub_tbl.stc_fob_id END AS stc_formId,
        CASE WHEN sub_tbl.ltr_text IS NOT NULL THEN sub_tbl.ltr_text ELSE sub_tbl.custom_form_lang_text END AS ltr_text

      FROM (SELECT DISTINCT
          supervisor_target_comment.stc_formId,
          supervisor_target_comment.stc_fob_id,
          language_translation.ltr_text,
          custom_form_lang.ltr_text AS custom_form_lang_text
        FROM supervisor_target_comment
          LEFT JOIN Reports
            ON Reports.SingleFormReportID = supervisor_target_comment.stc_formId
          LEFT JOIN language_translation
            ON ltr_tag = Reports.ReportName
            AND ltr_tag_type = 1
            AND ltr_enable = 1
            AND ltr_lng_id = lang
          LEFT JOIN form_builder
            ON form_builder.fob_id = supervisor_target_comment.stc_fob_id
          LEFT JOIN language_translation AS custom_form_lang
            ON custom_form_lang.ltr_tag = form_builder.fob_name
            AND custom_form_lang.ltr_tag_type = form_builder.fob_tag_type
            AND custom_form_lang.ltr_enable = 1
            AND custom_form_lang.ltr_lng_id = lang
        WHERE stc_per_id = per_id
        AND CAST(stc_created_date AS date)
        BETWEEN CAST(start_date AS date) AND CAST(end_date AS date)) sub_tbl
      ORDER BY ltr_text) t
    ORDER BY t.ltr_text, stc_formId);

END
$$

--
-- Create procedure `api_target_change_log`
--
CREATE PROCEDURE IF NOT EXISTS api_target_change_log (IN employee_person_id int, IN start_date datetime, IN end_date datetime, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-10-03
     Reason    :    Client API- Get change log data for targets.
     
     Modified by:    Vinh Lam
     Created Date:  2025-02-18
     Reason    :    PD-2952 - Remove commented code.
  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;

  IF employee_person_id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  SELECT DISTINCT
    supervisor_target_comment.stc_per_id AS employee_person_id,

    TRIM(CONCAT(employee.per_last_name, ", ", employee.per_first_name, " ", IFNULL(employee.per_middle_name, ''))) AS employee_name,

    stc_created_date AS created_date,

    COALESCE(supervisor_target_comment.stc_formId, supervisor_target_comment.stc_fob_id) AS form_id,

    (SELECT
        ltr_text
      FROM language_translation
      WHERE ltr_tag_type = (CASE WHEN supervisor_target_comment.stc_fob_id
          IS NULL THEN 1 ELSE 2 END)
      AND ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag = (CASE WHEN supervisor_target_comment.stc_fob_id IS NULL THEN (SELECT
                FormName
              FROM FormDescription
              WHERE supervisor_target_comment.stc_formId = FormDescription.FormID LIMIT 1) ELSE (SELECT
              fob_name
            FROM form_builder
            WHERE supervisor_target_comment.stc_fob_id = form_builder.fob_id LIMIT 1) END)) AS form_name,

    supervisor_target_comment.stc_change_type AS type_id,

    (SELECT
        ltr_text
      FROM language_translation
      WHERE ltr_tag = supervisor_target_comment.stc_change_type
      AND ltr_tag_type = language_id
      AND ltr_lng_id = 1) AS change_type_id,

    CASE WHEN (supervisor_target_comment.stc_change_type = 1060 OR
        supervisor_target_comment.stc_change_type = 1106 OR
        stc_change_type = 1107) THEN (
          CASE WHEN stc_change_type = 1107 THEN CASE WHEN (SELECT
                        MIN(stc_id)
                      FROM supervisor_target_comment
                      WHERE stc_change_type = 1107) = supervisor_target_comment.stc_id THEN supervisor_target_comment.stc_comment ELSE supervisor_target_comment.stc_comment END ELSE (SELECT
                  ltr_text
                FROM language_translation
                WHERE ltr_tag = supervisor_target_comment.stc_comment
                AND ltr_tag_type = 1
                AND ltr_lng_id = language_id) END) ELSE supervisor_target_comment.stc_comment END AS change_type,

    CASE WHEN supervisor_target_comment.stc_comment = 8696 THEN supervisor_target_comment.stc_created_date ELSE NULL END AS date_archived,

    supervisor_target_comment.stc_created_by_per_id AS modified_by_id,

    v_employee.per_full_name AS modified_by
  FROM supervisor_target_comment
    LEFT JOIN SupervisorTargets st
      ON (st.FDFormID = supervisor_target_comment.stc_formId
      OR st.sta_fob_id = supervisor_target_comment.stc_fob_id)
    LEFT JOIN v_employee
      ON v_employee.per_id = supervisor_target_comment.stc_created_by_per_id
    LEFT JOIN person employee
      ON supervisor_target_comment.stc_per_id = employee.per_id
  WHERE CASE WHEN use_id = TRUE THEN supervisor_target_comment.stc_per_id = employee_person_id
        AND CAST(stc_created_date AS date) BETWEEN start_date AND end_date ELSE CAST(stc_created_date AS date) BETWEEN start_date AND end_date END
  AND supervisor_target_comment.stc_enable = 1;


END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_targets`
--
DROP PROCEDURE IF EXISTS rpt_archived_targets;

DELIMITER $$

--
-- Create procedure `rpt_archived_targets`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_targets (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
  Created By: Pragati Das
  Created Date: 2023-08-17
  Purpose: SOF-13836 - Archived Non Submissions report(Targets)
  
  Created By: Pragati Das
  Created Date: 2023-08-29
  Purpose: SOF-13836 - Added DATE function to get data for today
  
  Modified By: Vishnu Prakash
  Modified Date: 2023-11-01
  Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
  
     Modified By  : James Coles
     Modified Date: 2024-02-12
     Reason        : PD-2254   Change to use sta_per_id
                                                       
*/


  SELECT
    get_translation((CASE WHEN SupervisorTargets.sta_fob_id IS NULL THEN (SELECT
              FormName
            FROM FormDescription
            WHERE SupervisorTargets.FDFormID = FormDescription.FormID
            GROUP BY FormDescription.FormID) ELSE (SELECT
            fob_name
          FROM form_builder
          WHERE SupervisorTargets.sta_fob_id = form_builder.fob_id) END), lang, (CASE WHEN SupervisorTargets.sta_fob_id
        IS NULL THEN 1 ELSE 2 END)) AS targets_form_Name,
    assigned_to.per_full_name AS targets_assigned_to,
    SupervisorTargets.EffectiveEnd AS targets_archived_date,
    SupervisorTargets.ID AS targets_ID,
    archived_by.per_full_name AS targets_archived_by,
    created_by.per_full_name AS targets_created_by,
    SupervisorTargets.sta_per_id AS SupervisorID,
    SupervisorTargets.FDFormID,
    SupervisorTargets.sta_fob_id,
    SupervisorTargets.sta_per_id,
    (SELECT
        stc_comment
      FROM supervisor_target_comment
      WHERE supervisor_target_comment.stc_id = (SELECT
          MAX(stc_id)
        FROM supervisor_target_comment
        WHERE (stc_formId = SupervisorTargets.FDFormID
        OR stc_fob_id = SupervisorTargets.sta_fob_id)
        AND supervisor_target_comment.stc_per_id = SupervisorTargets.sta_per_id
        AND stc_change_type = 3915)) AS targets_record_context,
    get_translation_from_ref_list_id((SELECT
        emp_pos_id
      FROM employee
      WHERE employee.emp_per_id = (SELECT
          supervisor_target_comment.stc_created_by_per_id
        FROM supervisor_target_comment
        WHERE supervisor_target_comment.stc_id = (SELECT
            MAX(stc_id)
          FROM supervisor_target_comment
          WHERE (stc_formId = SupervisorTargets.FDFormID
          OR stc_fob_id = SupervisorTargets.sta_fob_id)
          AND supervisor_target_comment.stc_per_id = SupervisorTargets.sta_per_id
          AND stc_change_type = 3915))), 'ref_position', lang) AS targets_record_archived_position
  FROM SupervisorTargets
    LEFT JOIN v_employee created_by
      ON SupervisorTargets.sta_created_by_per_id = created_by.per_id
    LEFT JOIN v_employee archived_by
      ON SupervisorTargets.sta_modified_by_per_id = archived_by.per_id
    LEFT JOIN v_employee assigned_to
      ON SupervisorTargets.sta_per_id = assigned_to.per_id
    LEFT JOIN SupervisorTargets ActiveSupervisorTargets
      ON (ActiveSupervisorTargets.FDFormID = SupervisorTargets.FDFormID
      OR ActiveSupervisorTargets.sta_fob_id = SupervisorTargets.sta_fob_id)
      AND ActiveSupervisorTargets.sta_per_id = SupervisorTargets.sta_per_id
      AND ActiveSupervisorTargets.sta_enable = 1
  WHERE SupervisorTargets.sta_enable = 0
  AND DATE(SupervisorTargets.EffectiveEnd) BETWEEN start_date AND end_date
  AND ActiveSupervisorTargets.ID IS NULL
  GROUP BY SupervisorTargets.sta_per_id,
           SupervisorTargets.FDFormID,
           SupervisorTargets.sta_fob_id;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_all_targets_sites`
--
DROP PROCEDURE IF EXISTS rpt_all_targets_sites;

DELIMITER $$

--
-- Create procedure `rpt_all_targets_sites`
--
CREATE PROCEDURE IF NOT EXISTS rpt_all_targets_sites (IN start_date varchar(255), IN end_date varchar(255), IN site_ids text, IN language_id int, IN frequency int, IN report_type varchar(255))
BEGIN
  /*
      Created By : Sarath Sontam
      Created Date: 2023-05-02
      Purpose: SOF-14001 - Created new SP for the updated Target Status reports for report type site

      Modified By: Sarath Sontam
      Modified Date: 2023-11-3
      Description: SOF-14751 - Update employee_membership_site to employee_membership_site_all

     Modified By  : James Coles
     Modified Date: 2024-02-12
     Reason        : PD-2254   Change to use sta_per_id


    */
  SELECT DISTINCT
    SupervisorTargets.ID,
    SupervisorTargets.sta_per_id AS SupervisorID,
    COALESCE(SUBSTRING(SupervisorTargets.EffectiveOn, 1, 7), SUBSTRING(start_date, 1, 7)) AS EffectiveOn,
    COALESCE(SUBSTRING(SupervisorTargets.EffectiveEnd, 1, 7), SUBSTRING(end_date, 1, 7)) AS EffectiveEnd,
    SupervisorTargets.Target AS Target_Monthly,
    SupervisorTargets.FrequencyID,
    CASE WHEN SupervisorTargets.sta_fob_id IS NULL THEN SupervisorTargets.FDFormID ELSE SupervisorTargets.sta_fob_id END AS FDFormID,
    CASE WHEN SupervisorTargets.sta_fob_id IS NULL THEN 'pre_defined_form' ELSE 'custom_form' END AS form_type,
    get_translation((CASE WHEN SupervisorTargets.sta_fob_id IS NULL THEN (SELECT
              FormName
            FROM FormDescription
            WHERE SupervisorTargets.FDFormID = FormDescription.FormID
            GROUP BY FormDescription.FormID) ELSE (SELECT
            fob_name
          FROM form_builder
          WHERE SupervisorTargets.sta_fob_id = form_builder.fob_id) END), language_id, (CASE WHEN SupervisorTargets.sta_fob_id
        IS NULL THEN 1 ELSE 2 END)) AS Form_Name,

    v_employee.per_full_name,
    v_employee.per_id,
    employee_membership_site_all.site_id AS site_id
  FROM SupervisorTargets
    LEFT JOIN v_employee
      ON SupervisorTargets.sta_per_id = v_employee.per_id
    LEFT JOIN employee_membership_site_all
      ON employee_membership_site_all.emp_id = v_employee.emp_id
      AND employee_membership_site_all.esi_enable = 1
  WHERE FrequencyID = frequency
  AND SupervisorTargets.EffectiveOn <= end_date
  AND IF(site_ids IS NOT NULL, IF(v_employee.emp_membership <> 1, FIND_IN_SET(employee_membership_site_all.site_id, site_ids) > 0, 1 = 1), employee_membership_site_all.site_id);
END
$$

DELIMITER ;

--
-- Drop procedure `rpt_all_targets_jobs`
--
DROP PROCEDURE IF EXISTS rpt_all_targets_jobs;

DELIMITER $$

--
-- Create procedure `rpt_all_targets_jobs`
--
CREATE PROCEDURE IF NOT EXISTS rpt_all_targets_jobs (IN start_date varchar(255), IN end_date varchar(255), IN job_ids text, IN language_id int, IN frequency int, IN report_type varchar(255))
BEGIN
  /*
    Created By : Sarath Sontam
    Created Date: 2023-05-02
    Purpose: SOF-14001 - Created new SP for the updated Target Status reports for report type job
    
    Modified By: Sarath Sontam
    Modified Date: 2023-10-11
    Description: SOF-14751 - Update employee_membership_job to employee_membership_job_all
  
     Modified By  : James Coles
     Modified Date: 2024-02-12
     Reason        : PD-2254   Change to use sta_per_id

  */
  SELECT DISTINCT
    SupervisorTargets.ID,
    COALESCE(SUBSTRING(SupervisorTargets.EffectiveEnd, 1, 7), SUBSTRING(start_date, 1, 7)) AS EffectiveEnd,
    COALESCE(SUBSTRING(SupervisorTargets.EffectiveOn, 1, 7), SUBSTRING(end_date, 1, 7)) AS EffectiveOn,
    SupervisorTargets.sta_per_id AS SupervisorID,
    SupervisorTargets.Target AS Target_Monthly,
    SupervisorTargets.FrequencyID,
    CASE WHEN SupervisorTargets.sta_fob_id IS NULL THEN SupervisorTargets.FDFormID ELSE SupervisorTargets.sta_fob_id END AS FDFormID,
    CASE WHEN SupervisorTargets.sta_fob_id IS NULL THEN 'pre_defined_form' ELSE 'custom_form' END AS form_type,
    get_translation((CASE WHEN SupervisorTargets.sta_fob_id IS NULL THEN (SELECT
              FormName
            FROM FormDescription
            WHERE SupervisorTargets.FDFormID = FormDescription.FormID
            GROUP BY FormDescription.FormID) ELSE (SELECT
            fob_name
          FROM form_builder
          WHERE SupervisorTargets.sta_fob_id = form_builder.fob_id) END), language_id, (CASE WHEN SupervisorTargets.sta_fob_id
        IS NULL THEN 1 ELSE 2 END)) AS Form_Name,
    v_employee.per_full_name,
    v_employee.per_id,
    employee_membership_job_all.job_id AS job_id
  FROM SupervisorTargets
    LEFT JOIN v_employee
      ON SupervisorTargets.sta_per_id = v_employee.per_id
    LEFT JOIN employee_membership_job_all
      ON employee_membership_job_all.emp_id = v_employee.emp_id
      AND employee_membership_job_all.ejo_enable = 1
  WHERE FrequencyID = frequency
  AND SupervisorTargets.EffectiveOn <= end_date
  AND IF(job_ids IS NOT NULL, IF(v_employee.emp_membership <> 1, FIND_IN_SET(employee_membership_job_all.job_id, job_ids) > 0, 1 = 1), employee_membership_job_all.job_id);
END
$$

DELIMITER ;

--
-- Drop procedure `get_all_top_forms`
--
DROP PROCEDURE IF EXISTS get_all_top_forms;

DELIMITER $$

--
-- Create procedure `get_all_top_forms`
--
CREATE PROCEDURE IF NOT EXISTS get_all_top_forms (IN lang_id int, IN mode varchar(255))
BEGIN

  /*
    Purpose: To get listing of all current Forms for use in the APP in various areas.
    Created By: Robert Rivest
    Created On: 2019-08-01
    
    Modified On: 2020-08-13
    Modified By: Robert Rivest
    Reason: To only show Forms that are enabled.
    
    Modified On: 2021-05-15
    Modified By: Zach Ross
    Reason: SOF-7928 - i18n - Added subquery to get formname.
    
    Modified On: 2021-07-07
    Modified By: Zach Ross
    Reason: SOF-8178 - Modified for tag revamp.
    
    Modified On: 2022-04-20
    Modified By: Robert Rivest
    Reason: Added ltr_enable to only select enabled translations.
    
    Modified On: 2022-09-01
    Modified By: Vishnu Prakash
    Reason: SOF-12078 - Targets - Custom Forms - API - Working on get-all-targets endpoint.
    
    Modified On: 2022-10-24
    Modified By: Sarath Sontam
    Reason: SOF-12562 - Added status_flag in select columns and all/active filter in where condition.
  
  
    Modified on: 2024-12-10
    Modified by: James Coles
    Reason:      PD-2554 - Add multiple user targets.
  
  */

  SELECT
    FormDescription.ID AS FormDescriptionID,
    FormDescription.FormID,
    FormDescription.FormVersion,
    get_translation(FormDescription.FormName, lang_id, 1) AS FormName,
    Reports.ReportURL,
    'Predefined' AS FormType,
    MobileForms.mfo_enable AS status_flag,
    IFNULL(get_translation(fc.category, 1, 1), get_translation(fc.category, 1, 2)) AS FormCategory
  FROM FormDescription
    JOIN (SELECT
        FormID,
        MAX(FormVersion) MaxVersion
      FROM FormDescription
      GROUP BY FormID) maxv
      ON FormDescription.FormID = maxv.FormID
      AND FormDescription.FormVersion = maxv.MaxVersion
    LEFT JOIN Form f
      ON f.FormID = maxv.FormID
    LEFT JOIN FormCategories fc
      ON f.FormCategoryId = fc.id
    LEFT OUTER JOIN Reports
      ON FormDescription.FormID = SingleFormReportID
    LEFT OUTER JOIN MobileForms
      ON MobileForms.FormID = FormDescription.FormID

  WHERE IF(mode = 'active', MobileForms.mfo_enable = 1, 1 = 1)
  AND FormDescription.FormID NOT IN (224335, 220234, 221746, 248310, 248322, 339913, 372298, 131200, 372308, 372318, 372328, 777777, 888888)


  UNION
  SELECT
    IFNULL(fob_fbc_id, fob_fca_id) AS FormDescriptionID,
    fob_id AS FormID,
    1 AS FormVersion,
    fname.ltr_text AS FormName,
    '' AS ReportURL,
    'Custom' AS FormType,
    form_builder.fob_enable AS status_flag,
    IFNULL(get_translation(fbc.fbc_name, 1, fbc.fbc_tag_type), get_translation(fc.category, 1, 1)) AS FormCategory

  FROM form_builder
    INNER JOIN language_translation fname
      ON fname.ltr_tag = form_builder.fob_name
      AND fname.ltr_tag_type = form_builder.fob_tag_type
    INNER JOIN language_translation fdname
      ON fdname.ltr_tag = form_builder.fob_description
      AND fdname.ltr_tag_type = form_builder.fob_tag_type
    LEFT JOIN form_builder_category fbc
      ON form_builder.fob_fbc_id = fbc.fbc_id
    LEFT JOIN FormCategories fc
      ON form_builder.fob_fca_id = fc.id
  WHERE fname.ltr_lng_id = 1
  AND fdname.ltr_lng_id = 1
  AND IF(mode = 'active', form_builder.fob_enable = 1, 1 = 1)
  ORDER BY FormCategory, FormName;

END
$$

--
-- Create procedure `api_lesson_learned_general_action_image`
--
CREATE PROCEDURE IF NOT EXISTS api_lesson_learned_general_action_image (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-12
     Reason    :    PD-2955 - Get general action image section in lesson learned.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;
  DECLARE initial_image varchar(50);
  DECLARE followup_image varchar(50);

  SET initial_image = get_translation(1914, language_id, 1);
  SET followup_image = get_translation(1917, language_id, 1);
  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;


  WITH Comments_CTE
  AS
  (SELECT
      com_reference_id,
      com_comment,
      com_id
    FROM comment_user
      JOIN comment_table
        ON comment_table.cmt_id = comment_user.com_cmt_id
    WHERE comment_user.com_enable = 1
    AND com_cmt_id = 7
    AND comment_table.cmt_enable = 1)

  SELECT
    ll.llm_id AS id,
    ll.llm_date AS date,
    ll.llm_created_date AS created_date,
    ll.llm_submitted_date AS submitted_date,
    ll.llm_modified_date AS modified_date,
    CASE WHEN sgaa.gaa_type = 'INITIAL' THEN initial_image ELSE followup_image END AS images_section,
    CONCAT('general_action/', sgaa.gaa_file_name) AS image_url,
    ccte.com_comment AS image_comment
  FROM lesson_learned_general_action llga
    INNER JOIN submission_general_action sga
      ON llga.llg_sga_id = sga.sga_id
    INNER JOIN lesson_learned ll
      ON ll.llm_id = llga.llg_llm_id
      AND ll.llm_enable = 1
    LEFT JOIN submission_general_action_attachment sgaa
      ON sga.sga_id = sgaa.gaa_sga_id
    LEFT JOIN Comments_CTE AS ccte
      ON sgaa.gaa_id = ccte.com_reference_id
  WHERE CASE WHEN use_id = TRUE THEN ll.llm_id = id ELSE CASE WHEN date_type = header_date THEN ll.llm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN ll.llm_modified_date BETWEEN start_date AND end_date END END
  AND sgaa.gaa_file_name IS NOT NULL
  AND ll.llm_enable = 1
  AND sgaa.gaa_enable = 1
  AND sga.sga_enable = 1
  ;


END
$$

--
-- Create procedure `api_lesson_learned_general_action`
--
CREATE PROCEDURE IF NOT EXISTS api_lesson_learned_general_action (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-12
     Reason    :    PD-2956 - Get data lesson learned - general action.
  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;
  DECLARE individual_action varchar(50);
  DECLARE group_action varchar(50);

  SET individual_action = get_translation(9514, language_id, 1);
  SET group_action = get_translation(9513, language_id, 1);

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  SELECT
    ll.llm_id AS id,
    ll.llm_date AS date,
    ll.llm_created_date AS created_date,
    ll.llm_submitted_date AS submitted_date,
    ll.llm_modified_date AS modified_date,
    sga.sga_action_type_rld_id AS action_type_id,
    lt.ltr_text AS action_type,
    GROUP_CONCAT(DISTINCT by_who.per_id ORDER BY by_who.per_id SEPARATOR '; ') AS by_who_id,
    GROUP_CONCAT(DISTINCT TRIM(CONCAT(by_who.per_last_name, ", ", by_who.per_first_name, " ", IFNULL(by_who.per_middle_name, ''))) ORDER BY by_who.per_id SEPARATOR '; ') AS by_who,
    sga.sga_action_by_when AS by_when,
    sga.sga_recommended_action AS recommended_action,
    GROUP_CONCAT(DISTINCT completed_by_who.per_id ORDER BY completed_by_who.per_id SEPARATOR ';') AS completed_by_who_id,
    GROUP_CONCAT(DISTINCT TRIM(CONCAT(completed_by_who.per_last_name, ", ", completed_by_who.per_first_name, " ", IFNULL(completed_by_who.per_middle_name, ''))) ORDER BY completed_by_who.per_id SEPARATOR '; ') AS completed_by_who,
    sgac.gac_completed_action_date AS completed_action_date,
    sgac.gac_completed_action_taken AS completed_action_taken,
    sgac.gac_rld_completed_action_type_id AS completed_action_type_id,
    lt_completed.ltr_text AS completed_action_type,
    CASE WHEN sga.sga_is_group_action = 0 OR
        sga.sga_is_group_action IS NULL THEN individual_action ELSE group_action END AS group_action_type
  FROM lesson_learned_general_action llga
    LEFT JOIN submission_general_action sga
      ON llga.llg_sga_id = sga.sga_id
      AND llga.llg_enable = 1
    LEFT JOIN submission_general_action_completion sgac
      ON sga.sga_id = sgac.gac_sga_id
      AND sgac.gac_enable = 1
    LEFT JOIN lesson_learned ll
      ON llga.llg_llm_id = ll.llm_id
      AND ll.llm_enable = 1
    LEFT JOIN person submit
      ON submit.per_id = sga.sga_created_by_per_id
    LEFT JOIN submission_general_action_person
      ON sga.sga_id = submission_general_action_person.gap_sga_id
    LEFT JOIN person by_who
      ON submission_general_action_person.gap_per_id = by_who.per_id
    LEFT JOIN person completed_by_who
      ON completed_by_who.per_id = sga.sga_completed_action_by_who_per_id
    INNER JOIN ref_list_detail rld
      ON rld.rld_id = sga.sga_action_type_rld_id
    INNER JOIN language_translation lt
      ON rld.rld_name = lt.ltr_tag
      AND lt.ltr_tag_type = rld.rld_tag_type
      AND lt.ltr_lng_id = language_id
    LEFT JOIN (SELECT
        rld.rld_id,
        lt.ltr_text
      FROM language_translation lt
        INNER JOIN ref_list_detail rld
          ON rld.rld_name = lt.ltr_tag
      WHERE lt.ltr_lng_id = language_id
      AND lt.ltr_enable = 1) lt_completed
      ON lt_completed.rld_id = sgac.gac_rld_completed_action_type_id
  WHERE CASE WHEN use_id = TRUE THEN ll.llm_id = id ELSE CASE WHEN date_type = header_date THEN ll.llm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN ll.llm_modified_date BETWEEN start_date AND end_date END END
  AND sga.sga_enable = 1
  GROUP BY sga.sga_id,
           ll.llm_id
  ;

END
$$

--
-- Create procedure `api_decision_log_general_action_image`
--
CREATE PROCEDURE IF NOT EXISTS api_decision_log_general_action_image (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-11
     Reason    :    PD-2955 - Get general action image section in decision log.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;
  DECLARE initial_image varchar(50);
  DECLARE followup_image varchar(50);

  SET initial_image = get_translation(1914, language_id, 1);
  SET followup_image = get_translation(1917, language_id, 1);
  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;


  WITH Comments_CTE
  AS
  (SELECT
      com_reference_id,
      com_comment,
      com_id
    FROM comment_user
      JOIN comment_table
        ON comment_table.cmt_id = comment_user.com_cmt_id
    WHERE comment_user.com_enable = 1
    AND com_cmt_id = 7
    AND comment_table.cmt_enable = 1)

  SELECT
    dl.dlm_id AS id,
    dl.dlm_date AS date,
    dl.dlm_created_date AS created_date,
    dl.dlm_submitted_date AS submitted_date,
    dl.dlm_modified_date AS modified_date,
    CASE WHEN sgaa.gaa_type = 'INITIAL' THEN initial_image ELSE followup_image END AS images_section,
    CONCAT('general_action/', sgaa.gaa_file_name) AS image_url,
    ccte.com_comment AS image_comment
  FROM decision_log_general_action dlga
    INNER JOIN submission_general_action sga
      ON dlga.dlg_sga_id = sga.sga_id
    INNER JOIN decision_log dl
      ON dl.dlm_id = dlga.dlg_dlm_id
      AND dl.dlm_enable = 1
    LEFT JOIN submission_general_action_attachment sgaa
      ON sga.sga_id = sgaa.gaa_sga_id
    LEFT JOIN Comments_CTE AS ccte
      ON sgaa.gaa_id = ccte.com_reference_id
  WHERE CASE WHEN use_id = TRUE THEN dl.dlm_id = id ELSE CASE WHEN date_type = header_date THEN dl.dlm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN dl.dlm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN dl.dlm_created_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN dl.dlm_modified_date BETWEEN start_date AND end_date END END
  AND sgaa.gaa_file_name IS NOT NULL
  AND dl.dlm_enable = 1
  AND sgaa.gaa_enable = 1
  AND sga.sga_enable = 1
  ;


END
$$

--
-- Create procedure `api_decision_log_general_action`
--
CREATE PROCEDURE IF NOT EXISTS api_decision_log_general_action (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-11
     Reason    :    PD-2955 - Get general action section in decision log.
  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;
  DECLARE individual_action varchar(50);
  DECLARE group_action varchar(50);

  SET individual_action = get_translation(9514, language_id, 1);
  SET group_action = get_translation(9513, language_id, 1);

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  SELECT
    dl.dlm_id AS id,
    dl.dlm_date AS date,
    dl.dlm_created_date AS created_date,
    dl.dlm_submitted_date AS submitted_date,
    dl.dlm_modified_date AS modified_date,
    sga.sga_action_type_rld_id AS action_type_id,
    lt.ltr_text AS action_type,
    GROUP_CONCAT(DISTINCT by_who.per_id ORDER BY by_who.per_id SEPARATOR '; ') AS by_who_id,
    GROUP_CONCAT(DISTINCT TRIM(CONCAT(by_who.per_last_name, ", ", by_who.per_first_name, " ", IFNULL(by_who.per_middle_name, ''))) ORDER BY by_who.per_id SEPARATOR '; ') AS by_who,
    sga.sga_action_by_when AS by_when,
    sga.sga_recommended_action AS recommended_action,
    GROUP_CONCAT(DISTINCT completed_by_who.per_id ORDER BY completed_by_who.per_id SEPARATOR ';') AS completed_by_who_id,
    GROUP_CONCAT(DISTINCT TRIM(CONCAT(completed_by_who.per_last_name, ", ", completed_by_who.per_first_name, " ", IFNULL(completed_by_who.per_middle_name, ''))) ORDER BY completed_by_who.per_id SEPARATOR '; ') AS completed_by_who,
    sgac.gac_completed_action_date AS completed_action_date,
    sgac.gac_completed_action_taken AS completed_action_taken,
    sgac.gac_rld_completed_action_type_id AS completed_action_type_id,
    lt_completed.ltr_text AS completed_action_type,
    CASE WHEN sga.sga_is_group_action = 0 OR
        sga.sga_is_group_action IS NULL THEN individual_action ELSE group_action END AS group_action_type
  FROM decision_log_general_action dlga
    LEFT JOIN submission_general_action sga
      ON dlga.dlg_sga_id = sga.sga_id
      AND dlga.dlg_enable = 1
    LEFT JOIN submission_general_action_completion sgac
      ON sga.sga_id = sgac.gac_sga_id
      AND sgac.gac_enable = 1
    LEFT JOIN decision_log dl
      ON dlga.dlg_dlm_id = dl.dlm_id
      AND dl.dlm_enable = 1
    LEFT JOIN person submit
      ON submit.per_id = sga.sga_created_by_per_id
    LEFT JOIN submission_general_action_person
      ON sga.sga_id = submission_general_action_person.gap_sga_id
    LEFT JOIN person by_who
      ON submission_general_action_person.gap_per_id = by_who.per_id
    LEFT JOIN person completed_by_who
      ON completed_by_who.per_id = sga.sga_completed_action_by_who_per_id
    INNER JOIN ref_list_detail rld
      ON rld.rld_id = sga.sga_action_type_rld_id
    INNER JOIN language_translation lt
      ON rld.rld_name = lt.ltr_tag
      AND lt.ltr_tag_type = rld.rld_tag_type
      AND lt.ltr_lng_id = language_id
    LEFT JOIN (SELECT
        rld.rld_id,
        lt.ltr_text
      FROM language_translation lt
        INNER JOIN ref_list_detail rld
          ON rld.rld_name = lt.ltr_tag
      WHERE lt.ltr_lng_id = language_id
      AND lt.ltr_enable = 1) lt_completed
      ON lt_completed.rld_id = sgac.gac_rld_completed_action_type_id
  WHERE CASE WHEN use_id = TRUE THEN dl.dlm_id = id ELSE CASE WHEN date_type = header_date THEN dl.dlm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN dl.dlm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN dl.dlm_created_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN dl.dlm_modified_date BETWEEN start_date AND end_date END END
  AND sga.sga_enable = 1
  GROUP BY sga.sga_id,
           dl.dlm_id
  ;

END
$$

DELIMITER ;

--
-- Drop procedure `api_pre_op_header`
--
DROP PROCEDURE IF EXISTS api_pre_op_header;

DELIMITER $$

--
-- Create procedure `api_pre_op_header`
--
CREATE PROCEDURE IF NOT EXISTS api_pre_op_header (IN start_date datetime, IN end_date datetime, IN submission_header_id int, IN language_id int, IN date_type int)
BEGIN
  /*
      Created by   : James Coles, Vinh Lam, Naveen Vadlamudi
      Created Date : 2024-03-14
      Reason       : Client API.

      Modified By   : Vinh Lam
      Modified Date : 2024-04-17
      Reason        : PD-1549 - Add creation date, submission date and modified date. Add date_type as an input:
                      date_type: 1: header_date, 2: submission_date, 3: creation_date, add alias.

      Modified By   : Vinh Lam
      Modified Date : 2024-05-28
      Reason        : PD-1647 - Add equipment name, equipment id and equipment status.

      Modified By   : Vinh Lam
      Modified Date : 2024-07-15
      Reason        : PD-2247 - Return IDs columns.

      Modified By   : Vinh Lam
      Modified Date : 2024-08-08
      Reason        : Update alias for equipment_name.

      Modified By   : Vinh Lam
      Modified Date : 2024-01-07
      Reason        : Add pet_id to the response, change equipment_id to equipment_name.

      Modified By   : Vinh Lam
      Modified Date : 2024-01-24
      Reason        : Update alias.
  
  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE status_label text;
  SET status_label = get_translation(3457, language_id, 1);

  IF submission_header_id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;


  SELECT
  DISTINCT
    sh.ID AS submission_header_id,
    sh.HeaderDate AS header_date,
    sh.FormSubmissionDate AS submission_date,
    sh.FormCreationDate AS creation_date,
    sh.she_modified_date AS modified_date,
    sh.SubmittedBy_SupervisorID AS submitted_by_id,
    CONCAT(submit.per_last_name, ', ', submit.per_first_name) submitted_by,
    sh.HeaderDate AS date,
    sh.Site AS site_id,
    lts.ltr_text site_name,
    sh.JobNumber AS department_job_id,
    job.rld_code AS department_job,
    sh.SiteLevel AS area_level_id,
    ltl.ltr_text AS area_level,
    sh.Supervisor AS supervisor_id,
    CONCAT(supervisor.per_last_name, ', ', supervisor.per_first_name) AS supervisor,
    sh.Workplace AS workplace,
    preop_equipment.poe_equip_description AS equipment_type_id,
    get_translation(preop_equipment.poe_equip_description, language_id, preop_equipment.poe_tag_type) AS equipment_type,
    preop_equipment_type.pet_id AS equipment_id,
    preop_equipment_type.pet_equipment_identifier AS equipment_identifier,
    (SELECT
        preop_submission_value.psv_value
      FROM preop_submission_header
        INNER JOIN preop_submission_value
          ON preop_submission_header.psh_id = preop_submission_value.psv_psh_id
      WHERE (preop_submission_header.psh_submissionheader_id = psh.psh_submissionheader_id)
      AND preop_submission_value.psv_preop_question_identifier = 'preop_equipment_status') AS equipment_status
  FROM preop_submission_header psh
    INNER JOIN SubmissionHeader sh
      ON psh.psh_submissionheader_id = sh.ID
    INNER JOIN preop_equipment_type
      ON psh.psh_pet_id = preop_equipment_type.pet_id
    INNER JOIN preop_equipment
      ON preop_equipment_type.pet_poe_id = preop_equipment.poe_id
    INNER JOIN preop_submission_value
      ON psh.psh_id = preop_submission_value.psv_psh_id
    INNER JOIN ref_list_detail site
      ON site.rld_id = sh.Site
    INNER JOIN language_translation lts
      ON lts.ltr_tag = site.rld_name
      AND lts.ltr_lng_id = language_id
      AND lts.ltr_tag_type = site.rld_tag_type
    INNER JOIN ref_list_detail job
      ON job.rld_id = sh.JobNumber
    INNER JOIN ref_list_detail level
      ON level.rld_id = sh.SiteLevel
    INNER JOIN language_translation ltl
      ON ltl.ltr_tag = level.rld_name
      AND ltl.ltr_lng_id = language_id
      AND ltl.ltr_tag_type = site.rld_tag_type
    INNER JOIN person submit
      ON sh.SubmittedBy_SupervisorID = submit.per_id
    INNER JOIN person supervisor
      ON sh.Supervisor = supervisor.per_id
  WHERE sh.FormDescriptionID = 1389
  AND CASE WHEN use_id = TRUE THEN sh.ID = submission_header_id ELSE CASE WHEN date_type = header_date THEN sh.HeaderDate BETWEEN start_date AND end_date WHEN date_type = submission_date THEN sh.FormSubmissionDate BETWEEN start_date AND end_date WHEN date_type = creation_date THEN sh.FormCreationDate BETWEEN start_date AND end_date END END;


END
$$

DELIMITER ;

--
-- Drop procedure `rpt_loto_additional_details`
--
DROP PROCEDURE IF EXISTS rpt_loto_additional_details;

DELIMITER $$

--
-- Create procedure `rpt_loto_additional_details`
--
CREATE PROCEDURE IF NOT EXISTS rpt_loto_additional_details (IN ID int, IN language_id int)
BEGIN

  /* 

  Created by : Jazmyn Zarichney 
  Created On : 2022-11-12
  Purpose : SOF-12715: Creating the LOTO SP to build the report

  Modified By :Pragati Das
  Modified Date : 2023-04-05
  Purpose : SOF-13692 - Added a field onto the LOTO report

  Modified By : Vinh Lam
  Modified Date : 2025-01-14
  Purpose : PD-2906 - Fixing language_translation.ltr_lng_id = 1 to language_translation.ltr_lng_id = language_id
   */

  DECLARE additional_details_label text;
  DECLARE procedure_version_label text;
  DECLARE approved_by_label text;
  DECLARE procedure_completed_by_label text;
  DECLARE type_of_intervention_label text;
  DECLARE equipment_type_label text;
  DECLARE equipment_number_label text;
  DECLARE comments_label text;
  DECLARE procedure_revision_label text;
  DECLARE yes_label text;
  DECLARE no_label text;
  DECLARE lock_removal_label text;
  DECLARE lock_status_label text;

  SET additional_details_label = get_translation(22, language_id, 1);
  SET procedure_version_label = get_translation(9436, language_id, 1);
  SET approved_by_label = get_translation(2118, language_id, 1);
  SET procedure_completed_by_label = get_translation(9271, language_id, 1);
  SET type_of_intervention_label = get_translation(9272, language_id, 1);
  SET equipment_type_label = get_translation(1239, language_id, 1);
  SET equipment_number_label = get_translation(1235, language_id, 1);
  SET comments_label = get_translation(81, language_id, 1);
  SET procedure_revision_label = get_translation(9287, language_id, 1);
  SET yes_label = get_translation(1379, language_id, 1);
  SET no_label = get_translation(1380, language_id, 1);
  SET lock_removal_label = get_translation(9425, language_id, 1);
  SET lock_status_label = get_translation(9568, language_id, 1);


  SELECT
    (SELECT
        ltr_text
      FROM language_translation
        INNER JOIN ref_list_detail
          ON language_translation.ltr_tag = ref_list_detail.rld_name
          AND language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
          AND language_translation.ltr_lng_id = language_id
      WHERE ref_list_detail.rld_id = lsu_rld_type_of_intervention_id) AS lsu_rld_type_of_intervention_id, # type of intervention
    (GROUP_CONCAT(DISTINCT (SELECT
        per_full_name
      FROM v_employee
      WHERE v_employee.per_id = lsc_per_id) SEPARATOR ', ')) AS lsc_per_id, # procedure completed by
    lsu_document_version_number, # version number
    lsu_lth_equipment_number, # equipment number
    (SELECT
        GROUP_CONCAT(b.per_full_name SEPARATOR '; ') AS val
      FROM common_approver a
        INNER JOIN v_employee b
          ON a.cap_per_id = b.per_id
      WHERE a.cap_lth_id = lockout_tagout_submission.lsu_lth_id
      AND a.cap_enable = 1) AS approvers,
    (SELECT
        b.ltr_text
      FROM lockout_tagout_equipment a
        INNER JOIN language_translation b
          ON b.ltr_tag = a.lte_name
          AND b.ltr_tag_type = 2
          AND b.ltr_lng_id = language_id
      WHERE a.lte_id = lockout_tagout_submission.lsu_lte_id) AS equipment_type,
    additional_details_label AS additional_details_label,
    procedure_version_label AS procedure_version_label,
    approved_by_label AS approved_by_label,
    procedure_completed_by_label AS procedure_completed_by_label,
    type_of_intervention_label AS type_of_intervention_label,
    equipment_type_label AS equipment_type_label,
    equipment_number_label AS equipment_number_label,
    comments_label AS comments_label,
    procedure_revision_label AS procedure_revision_label,
    yes_label AS yes_label,
    no_label AS no_label,
    lock_removal_label AS lock_removal_label,
    lsu_is_revision_needed AS revision_needed,
    lsu_comments AS revision_comments,
    lockout_tagout_header.lth_lte_id,
    lockout_tagout_equipment.lte_id,
    equipment_pic.lta_filename AS equipment_picture,
    lock_status_label AS lock_status_label,
    get_translation_from_ref_list_id(lockout_tagout_submission.lsu_rld_lock_status_id, 'ref_loto_status', language_id) AS lock_status
  FROM lockout_tagout_submission
    INNER JOIN lockout_tagout_submission_completed_by
      ON lockout_tagout_submission.lsu_id = lockout_tagout_submission_completed_by.lsc_lsu_id
    LEFT JOIN lockout_tagout_submission_step
      ON lockout_tagout_submission_step.lss_lsu_id = lockout_tagout_submission.lsu_id
    LEFT JOIN lockout_tagout_step
      ON lockout_tagout_submission_step.lss_lts_id = lockout_tagout_step.lts_id
    LEFT JOIN lockout_tagout_header
      ON lockout_tagout_header.lth_id = lockout_tagout_step.lts_lth_id
    LEFT JOIN lockout_tagout_equipment
      ON lockout_tagout_equipment.lte_id = lockout_tagout_header.lth_lte_id
    LEFT JOIN lockout_tagout_attachment equipment_pic
      ON equipment_pic.lta_lte_id = lockout_tagout_equipment.lte_id
    INNER JOIN common_approver
      ON common_approver.cap_lth_id = lockout_tagout_submission.lsu_lth_id
    LEFT JOIN lockout_tagout_attachment
      ON lockout_tagout_attachment.lta_lts_id = lockout_tagout_step.lts_id
  WHERE lockout_tagout_submission.lsu_she_id = ID
  GROUP BY lts_id;

END
$$

--
-- Create procedure `api_target_planned_vs_actual`
--
CREATE PROCEDURE IF NOT EXISTS api_target_planned_vs_actual (IN employee_person_id int, IN start_date datetime, IN end_date datetime, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-10-08
     Reason    :    Client API- Get change log data for targets.

     Modified By  : James Coles
     Modified Date: 2024-02-12
     Reason        : PD-2254   Change to use sta_per_id

     Modified By  : Vinh Lam
     Modified Date: 2024-02-18
     Reason        : PD-2952 - Remove comments code
  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;

  IF employee_person_id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  WITH cte
  AS
  (SELECT
      CASE WHEN fd.FormID = 777777 THEN custom_form_master.cfm_fob_id ELSE fd.FormID END AS form_id,
      sh.SubmittedBy_SupervisorID,
      COUNT(*) AS actual_count,
      DATE_FORMAT(sh.FormSubmissionDate, '%Y-%m') AS yearmonth,
      YEAR(sh.FormSubmissionDate) AS year
    FROM SubmissionHeader sh
      INNER JOIN v_employee
        ON sh.SubmittedBy_SupervisorID = v_employee.per_id
      INNER JOIN FormDescription AS fd
        ON sh.FormDescriptionID = fd.ID
      LEFT JOIN custom_form_master
        ON custom_form_master.cfm_submission_header_id = sh.ID
    WHERE (sh.IsArchived IS NULL
    OR sh.IsArchived = 0)
    AND sh.FormSubmissionDate BETWEEN start_date AND end_date
    GROUP BY sh.SubmittedBy_SupervisorID,
             custom_form_master.cfm_fob_id,
             fd.FormID,
             yearmonth),
  employee_profile
  AS
  (SELECT
      person.per_id,
      employee.emp_mvc_id AS emp_membership,
      GROUP_CONCAT(DISTINCT ref_list_detail.rld_name SEPARATOR ',') AS sites,
      GROUP_CONCAT(DISTINCT ref_list_detail.rld_id SEPARATOR ',') AS siteIds,
      GROUP_CONCAT(DISTINCT em_site_all.site_id SEPARATOR ',') AS membership_siteIds,
      GROUP_CONCAT(DISTINCT rld_name SEPARATOR ',') AS membership_sites
    FROM person
      LEFT JOIN employee
        ON person.per_id = employee.emp_per_id
      LEFT JOIN auth_user_sofvie
        ON person.per_id = auth_user_sofvie.user_per_id
      LEFT JOIN employee_site
        ON employee.emp_id = employee_site.esi_emp_id
        AND employee_site.esi_enable = 1
      LEFT JOIN ref_list_detail
        ON employee_site.esi_sit_id = ref_list_detail.rld_id
      LEFT JOIN employee_membership_site_all em_site_all
        ON em_site_all.emp_per_id = person.per_id
        AND em_site_all.esi_enable = 1
    GROUP BY person.per_id)
  SELECT DISTINCT
    person_employee.per_id AS employee_per_id,
    TRIM(CONCAT(person_employee.per_last_name, ", ", person_employee.per_first_name, " ", IFNULL(person_employee.per_middle_name, ''))) AS employee,
    SupervisorTargets.FrequencyID AS frequency_id,
    get_translation(freq.rld_name, 1, 1) AS frequency,
    SupervisorTargets.EffectiveOn AS effective_on,
    SupervisorTargets.EffectiveEnd AS effective_end,
    SupervisorTargets.sta_per_id AS supervisor_id,
    TRIM(CONCAT(supervisor.per_last_name, ", ", supervisor.per_first_name, " ", IFNULL(supervisor.per_middle_name, ''))) AS supervisor,
    COALESCE(SupervisorTargets.sta_fob_id, SupervisorTargets.FDFormID) AS form_id,
    (SELECT
        ltr_text
      FROM language_translation
      WHERE ltr_tag_type = (CASE WHEN SupervisorTargets.sta_fob_id
          IS NULL THEN 1 ELSE 2 END)
      AND ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag =
      CASE WHEN SupervisorTargets.sta_fob_id IS NULL THEN (SELECT
                FormName
              FROM FormDescription
              WHERE SupervisorTargets.FDFormID = FormID LIMIT 1) ELSE (SELECT
              fob_name
            FROM form_builder
            WHERE SupervisorTargets.sta_fob_id = fob_id LIMIT 1) END) AS form_name,
    (SELECT
        GROUP_CONCAT(auth_role_sofvie.aro_name SEPARATOR ',')
      FROM (((auth_user_role_sofvie
        LEFT JOIN auth_user_sofvie
          ON (auth_user_role_sofvie.aur_user_id = auth_user_sofvie.id))
        LEFT JOIN auth_role_sofvie
          ON (auth_role_sofvie.aro_id = auth_user_role_sofvie.aur_aro_id))
        LEFT JOIN person pers
          ON (auth_user_sofvie.user_per_id = pers.per_id))
      WHERE pers.per_id = person_employee.per_id
      AND auth_user_role_sofvie.aur_enable = 1) AS role_id,
    (SELECT
        GROUP_CONCAT(get_translation(auth_role_sofvie.aro_name, language_id, auth_role_sofvie.aro_tag_type) SEPARATOR ',')
      FROM (((auth_user_role_sofvie
        LEFT JOIN auth_user_sofvie
          ON (auth_user_role_sofvie.aur_user_id = auth_user_sofvie.id))
        LEFT JOIN auth_role_sofvie
          ON (auth_role_sofvie.aro_id = auth_user_role_sofvie.aur_aro_id))
        LEFT JOIN person pers
          ON (auth_user_sofvie.user_per_id = pers.per_id))
      WHERE pers.per_id = person_employee.per_id
      AND auth_user_role_sofvie.aur_enable = 1) AS role_name,
    CASE WHEN employee_profile.emp_membership = 1 THEN COALESCE(employee_profile.membership_sites, employee_profile.membership_siteIds) ELSE COALESCE(employee_profile.sites, employee_profile.siteIds) END AS site_id,
    (SELECT
        GROUP_CONCAT(ltr_text)
      FROM ref_site
      WHERE ref_site.lng_id = language_id
      AND FIND_IN_SET(rld_name, CASE WHEN employee_profile.emp_membership = 1 THEN COALESCE(employee_profile.membership_sites, employee_profile.membership_siteIds) ELSE COALESCE(employee_profile.sites, employee_profile.siteIds) END)) AS site_name,
    SupervisorTargets.Target AS planned_target,
    cte.year AS year,
    cte.yearmonth AS 'year_month',
    cte.actual_count AS actual_target
  FROM SupervisorTargets
    LEFT JOIN person
      ON SupervisorTargets.sta_per_id = person.per_id
    LEFT JOIN employee
      ON employee.emp_per_id = person.per_id
    INNER JOIN auth_user_role_sofvie
      ON auth_user_role_sofvie.aur_user_id = person.per_id
      AND auth_user_role_sofvie.aur_enable = 1
    INNER JOIN auth_role_sofvie
      ON auth_role_sofvie.aro_id = auth_user_role_sofvie.aur_aro_id
      AND auth_role_sofvie.aro_enable = 1
    LEFT JOIN employee_profile
      ON employee_profile.per_id = SupervisorTargets.sta_per_id
    LEFT JOIN person person_employee
      ON SupervisorTargets.sta_per_id = person_employee.per_id
    LEFT JOIN person supervisor
      ON SupervisorTargets.sta_per_id = supervisor.per_id
    LEFT JOIN cte
      ON SupervisorTargets.sta_per_id = cte.SubmittedBy_SupervisorID
      AND SupervisorTargets.FDFormID = cte.form_id
    INNER JOIN (SELECT
        *
      FROM ref_list_detail
      WHERE rld_rlh_id = 12) freq
      ON SupervisorTargets.FrequencyID = freq.rld_code
  WHERE CASE WHEN use_id = TRUE THEN SupervisorTargets.sta_per_id = employee_person_id
        AND SupervisorTargets.EffectiveOn <= end_date ELSE SupervisorTargets.EffectiveOn <= end_date END
  AND SupervisorTargets.sta_enable = 1
  AND SupervisorTargets.Target != 0
  GROUP BY SupervisorTargets.ID,
           cte.yearmonth;

END
$$

DELIMITER ;

--
-- Drop procedure `get_positive_id_list`
--
DROP PROCEDURE IF EXISTS get_positive_id_list;

DELIMITER $$

--
-- Create procedure `get_positive_id_list`
--
CREATE PROCEDURE IF NOT EXISTS get_positive_id_list (IN person_id int, IN supervisors longtext, IN jobs longtext, IN start_date datetime, IN end_date datetime, OUT error_msg longtext)
BEGIN

  /*
  Creation Date: 2020-05-02
  Created By:Robert Rivest
  Description: To retrieve a listing of all Positive ID data using a series of filters
     
  Change History
  Modified by: Zach Ross
  Modified on: 2020-08-13
  Change:  Modified to get both submission_date and header_date.

  Modified Date: 2020-09-25
  Modified By: Vishnu/Rana
  Description: Optimize the condition on the filtering jobs and supervisors

  Modified Date: 2020-11-18
  Modified By: James Coles
  Description:  SOF-5358 - Duplicated data appearing in the grid after user likes a positive recognition that recognizes more than one person.

  Modified Date: 2021-06-29
  Modified By: Vishnu
  Description: i18n - join changes 

  Modified Date: 2021-11-11
  Modified By: Sarath Sontam
  Description: Modify SP at multiple place to fit with new PID page updates. 

  Modified Date: 2022-01-06
  Modified By: Sarath Sontam
  Description: Modify SP to get concatenated per_ids and person names for each submission, insteadof individual rows for each person

  Modified Date: 2022-02-11
  Modified By: Sarath Sontam
  Description: Return parent form - submission header Id and parent form - form description from Submission Header

  Modified Date: 2022-11-17
  Modified By: Sarath Sontam
  Description: SOF-12695 filter data with new enable column - spr_enable = True

  Modified by: Suman Marlapudi
  Date       : 2023-11-27
  Reason     : SOF-14025 - Replace the deprecated SELECT INTO clause with variables.

  Modified by: Robert Rivest
  Date       : 2024-03-07
  Reason     : PD-1171 Add form creation date to the output

  Modified by: James Coles
  Date       : 2025-02-18
  Reason     : Fixing the filtering dates to header date
  */

  DECLARE lang varchar(50);
  DECLARE lang_id int;

  SET lang = (SELECT
      upr_language
    FROM user_profile
    WHERE user_profile.upr_per_id = person_id);

  SET lang_id = (SELECT
      language.lng_id
    FROM language
    WHERE lng_name = lang);

  SELECT
    SubmissionPositiveRecognition.id pid_id,
    super.per_full_name submitted_by_name,
    super.per_id submitted_by,
    SubmissionPositiveRecognition.EventDescription,
    GROUP_CONCAT(SubmissionPositiveRecognitionPerson.RecognitionOf SEPARATOR '; ') AS RecognitionOf,
    GROUP_CONCAT(rec_person.per_full_name SEPARATOR '; ') AS RecognitionOfName,
    SubmissionHeader.FormSubmissionDate submission_date,
    SubmissionHeader.FormCreationDate creation_date,
    SubmissionHeader.HeaderDate header_date,
    SubmissionHeader.JobNumber,
    lang_site.ltr_text AS Site,
    ref_job.rld_code AS job,
    lang_RecognitionType.ltr_text AS type,
    SubmissionPositiveRecognitionLike.ID AS like_id,
    COALESCE(SubmissionPositiveRecognitionLike.ID, 0) MyLikeID,
    SubmissionHeader.ID AS parent_submission_id,
    SubmissionHeader.FormDescriptionID AS parent_form_description_id
  FROM SubmissionPositiveRecognition
    LEFT JOIN SubmissionPositiveRecognitionPerson
      ON SubmissionPositiveRecognition.id = SubmissionPositiveRecognitionPerson.SubmissionPositiveRecognitionID
    JOIN SubmissionHeader
      ON SubmissionHeader.id = SubmissionPositiveRecognition.SubmissionHeaderID
    JOIN v_employee super
      ON super.per_id = SubmissionHeader.SubmittedBy_SupervisorID
    LEFT JOIN v_employee rec_person
      ON rec_person.per_id = SubmissionPositiveRecognitionPerson.RecognitionOf
    LEFT JOIN ref_list_detail ref_site
      ON ref_site.rld_id = SubmissionHeader.Site
      AND ref_site.rld_rlh_id = 1
    LEFT JOIN language_translation lang_site
      ON lang_site.ltr_tag = ref_site.rld_name
      AND lang_site.ltr_lng_id = lang_id
      AND lang_site.ltr_tag_type = ref_site.rld_tag_type
    LEFT JOIN ref_list_detail ref_job
      ON ref_job.rld_id = SubmissionHeader.JobNumber
      AND ref_job.rld_rlh_id = 3
      AND ref_job.rld_enable = 1
    LEFT JOIN ref_list_detail ref_RecognitionType
      ON ref_RecognitionType.rld_id = SubmissionPositiveRecognition.RecognitionType
      AND ref_RecognitionType.rld_rlh_id = 36
    LEFT JOIN language_translation lang_RecognitionType
      ON lang_RecognitionType.ltr_tag = ref_RecognitionType.rld_name
      AND lang_RecognitionType.ltr_lng_id = lang_id
      AND lang_RecognitionType.ltr_tag_type = ref_RecognitionType.rld_tag_type
    LEFT JOIN SubmissionPositiveRecognitionLike
      ON SubmissionPositiveRecognitionLike.SubmissionPositiveRecognitionID = SubmissionPositiveRecognition.ID
      AND SubmissionPositiveRecognitionLike.SigningAccount = person_id
  WHERE COALESCE(SubmissionHeader.IsArchived, 0) = 0
  AND SubmissionPositiveRecognition.RecognitionType IS NOT NULL
  AND CAST(SubmissionHeader.HeaderDate AS date) BETWEEN start_date AND end_date
  AND FIND_IN_SET(SubmissionPositiveRecognitionPerson.RecognitionOf, supervisors)
  AND FIND_IN_SET(ref_job.rld_id, jobs)
  AND SubmissionPositiveRecognition.spr_enable = 1
  GROUP BY pid_id
  ORDER BY pid_id DESC, SubmissionPositiveRecognitionPerson.RecognitionOf;



  SET error_msg = '';
  SET error_msg = (SELECT
      supervisors);

END
$$

DELIMITER ;

--
-- Drop procedure `get_submission_hap_by_filters_users_jobs`
--
DROP PROCEDURE IF EXISTS get_submission_hap_by_filters_users_jobs;

DELIMITER $$

--
-- Create procedure `get_submission_hap_by_filters_users_jobs`
--
CREATE PROCEDURE IF NOT EXISTS get_submission_hap_by_filters_users_jobs (IN start_date date, IN end_date date, IN filter_type varchar(255), IN filter_values longtext, IN toggle varchar(255), IN user_ids longtext, IN job_ids longtext, IN lng_id varchar(2))
BEGIN

  /* 
      Created by: Sontam Sarath
      Modified on: 2022-03-03
      Reason: SOF-10404 - Security patch: Convert raw query to stored procedure
    
      Modified   : March 18th, 2022
      Modified by: James Coles
      Reason     : SOF-10397 - Validate parameters. Changed the language parameter.
  
      Modified   : 2023-05-31
      Modified by: Sontam Sarath
      Reason     : SOF-14227 - update all subqueries of langugae translations to fucntions, get action_by_who from submission_hazard_action_person table, and remove duplicate output columns for action_type, potential_risk, hazard_identification
  
      Modified   : 2024-03-05
      Modified by: Robert Rivest
      Reason     : Reason: PD-1171 - change sha_modified_date to modified_date
  
      Modified   : 2024-05-01
      Modified by: Sarath Sontam
      Reason     : PD-1496 - group Action assigned to and completed by, if its a group action. (1.6 release)
      
      Modified   : 2024-07-10
      Modified by: Vishnu Prkash 
      Reason     : PD-2149 - Hazard-Page--Custom-Form-Name-and-Redirect (1.6.1 release)
    
      Modified by: James Coles
      Date       : 2025-02-18
      Reason     : Fixing the filtering dates to header date
  */


  SET @start_date = start_date;
  SET @end_date = end_date;
  SET @filter_type = filter_type;
  SET @filter_values = filter_values;
  SET @toggle = toggle;
  SET @user_ids = user_ids;
  SET @job_ids = job_ids;
  SET @lng_id = lng_id;

  WITH v_employee
  AS
  (SELECT
      *
    FROM person),

  custom_form_data
  AS
  (SELECT
      SubmissionHeader.ID AS customSubmissionHeaderID,
      form_builder.*,
      get_translation(form_builder.fob_name, 1, form_builder.fob_tag_type) AS formname
    FROM custom_form_master
      INNER JOIN SubmissionHeader
        ON SubmissionHeader.ID = custom_form_master.cfm_submission_header_id
      INNER JOIN form_builder
        ON form_builder.fob_id = custom_form_master.cfm_fob_id
    GROUP BY SubmissionHeader.ID)

  SELECT
    *,
    GROUP_CONCAT(a.per_full_name SEPARATOR '; ') AS ActionAssignedTo,
    CONCAT(a.JobNumber, "_", a.Site, "_", a.SiteLevel) AS SubmissionHeaderLabel
  FROM (SELECT
      SubmissionHAP.ID,
      SubmissionHAP.SubmissionHeaderID,
      SubmissionID,
      FormCreationDate,
      FormSubmissionDate,
      FormDescription.FormID,
      CASE WHEN FormDescription.FormID != 777777 THEN get_translation(FormDescription.FormName, 1, 1) ELSE (SELECT
              get_translation(custom_form_data.fob_name, 1, fob_tag_type)
            FROM custom_form_data
            WHERE custom_form_data.customSubmissionHeaderID = SubmissionHAP.SubmissionHeaderID) END AS FormName,
      CASE WHEN FormDescription.FormID != 777777 THEN SubmissionHeader.FormDescriptionID ELSE (SELECT
              CONCAT('custom-', custom_form_data.fob_id)
            FROM custom_form_data
            WHERE custom_form_data.customSubmissionHeaderID = SubmissionHAP.SubmissionHeaderID) END AS reportFormName,


      TRIM(CONCAT(submitted_by.`per_last_name`, ', ', submitted_by.`per_first_name`, ' ', COALESCE(submitted_by.`per_middle_name`, ''))) AS SubmittedBy,
      SubmissionHeader.FormDescriptionID,
      submitted_by.per_id AS submitted_by_per_id,
      SubmissionHeader.HeaderDate,
      get_translation_from_ref_list_id(SubmissionHeader.Site, 'ref_site', 1) AS Site,
      get_translation_from_ref_list_id(SubmissionHeader.JobNumber, 'ref_job', 1) AS JobNumber,
      get_translation_from_ref_list_id(SubmissionHeader.SiteLevel, 'ref_level', 1) AS SiteLevel,
      SubmissionHeader.Workplace,
      SubmissionHeader.Supervisor,
      SubmissionHAP.hazard_description,
      get_translation_from_ref_list_id(SubmissionHAP.hazard_type, 'ref_hazard_type', 1) AS hazard_type,
      get_translation_from_ref_list_id(SubmissionHAP.hazard_identification, 'ref_hazard_identification', 1) AS hazard_identification,
      get_translation_from_ref_list_id(SubmissionHAP.potential_risk, 'ref_potential_loss', 1) AS potential_risk,
      CASE WHEN SubmissionHAP.immediate_action_required_and_performed = 1 THEN get_translation(1379, 1, 1) ELSE get_translation(1380, 1, 1) END AS immediate_action_required_and_performed,
      SubmissionHAP.immediate_action_taken,
      get_translation_from_ref_list_id(SubmissionHAP.immediate_action_type, 'ref_action_type', 1) AS immediate_action_type,
      CASE WHEN SubmissionHAP.further_action_required = 1 THEN get_translation(1379, 1, 1) ELSE get_translation(1380, 1, 1) END AS further_action_required,
      SubmissionHAP.recommended_action,
      get_translation_from_ref_list_id(SubmissionHAP.action_type, 'ref_action_type', 1) AS action_type,
      SubmissionHAP.action_by_when,
      SubmissionHAP.action_status,
      SubmissionHAP.sha_created_date,
      SubmissionHAP.sha_created_by_per_id,
      SubmissionHAP.sha_modified_date,
      SubmissionHAP.sha_modified_by_per_id,
      submission_hazard_action_completion.hac_completed_action_date AS action_completed_date,
      get_translation_from_ref_list_id(submission_hazard_action_completion.hac_rld_completed_action_type_id, 'ref_action_type', @lng_id) AS completed_action_type,
      TRIM(CONCAT(by_who.`per_last_name`, ', ', by_who.`per_first_name`, ' ', COALESCE(by_who.`per_middle_name`, ''))) AS per_full_name,
      submission_hazard_action_completion.hac_completed_action_taken AS completed_action_taken,
      GROUP_CONCAT(TRIM(CONCAT(completed_by_who.`per_last_name`, ', ', completed_by_who.`per_first_name`, ' ', COALESCE(completed_by_who.`per_middle_name`, ''))) SEPARATOR ';') AS action_complete_by_who,
      (SELECT
          COUNT(*)
        FROM SubmissionHAPAttachments
        WHERE SubmissionHAPID = SubmissionHAP.ID
        AND AttachmentType = "INITIAL") AS initial_attachments_count,
      (SELECT
          COUNT(*)
        FROM SubmissionHAPAttachments
        WHERE SubmissionHAPID = SubmissionHAP.ID
        AND AttachmentType = "FOLLOWUP") AS followup_attachments_count
    FROM SubmissionHAP
      INNER JOIN SubmissionHeader
        ON SubmissionHAP.SubmissionHeaderID = SubmissionHeader.ID
      INNER JOIN FormDescription
        ON SubmissionHeader.FormDescriptionID = FormDescription.ID
      LEFT JOIN submission_hazard_action_person
        ON SubmissionHAP.ID = submission_hazard_action_person.hap_sha_id
      LEFT JOIN v_employee by_who
        ON submission_hazard_action_person.hap_per_id = by_who.per_id
      LEFT JOIN v_employee submitted_by
        ON SubmissionHeader.SubmittedBy_SupervisorID = submitted_by.per_id
      LEFT JOIN submission_hazard_action_completion
        ON SubmissionHAP.ID = submission_hazard_action_completion.hac_sha_id
      LEFT JOIN submission_hazard_action_completed_person
        ON submission_hazard_action_completion.hac_id = submission_hazard_action_completed_person.hcp_hac_id
      LEFT JOIN v_employee completed_by_who
        ON submission_hazard_action_completed_person.hcp_per_id = completed_by_who.per_id
    WHERE (SubmissionHeader.IsArchived IS NULL
    OR SubmissionHeader.IsArchived = 0)
    AND SubmissionHAP.sha_enable = TRUE
    AND CASE WHEN @start_date <> '' AND
        @end_date <> '' THEN CAST(HeaderDate AS date) BETWEEN @start_date AND @end_date ELSE TRUE END
    AND CASE WHEN @toggle = 'type' AND
        @filter_type = 'hazard_identification' THEN FIND_IN_SET(SubmissionHAP.hazard_identification, @filter_values) ELSE TRUE END
    AND CASE WHEN @toggle = 'type' AND
        @filter_type = 'potential_risk' THEN FIND_IN_SET(SubmissionHAP.potential_risk, @filter_values) ELSE TRUE END
    AND CASE WHEN @toggle = 'type' AND
        @filter_type = 'action_type' THEN FIND_IN_SET(SubmissionHAP.immediate_action_type, @filter_values)
          OR FIND_IN_SET(SubmissionHAP.completed_action_type, @filter_values) ELSE TRUE END
    AND CASE WHEN @toggle = 'form' THEN FIND_IN_SET(FormDescription.FormName, @filter_values) ELSE TRUE END
    AND CASE WHEN @user_ids <> '' THEN FIND_IN_SET(submission_hazard_action_person.hap_per_id, @user_ids) ELSE TRUE END
    AND CASE WHEN @job_ids <> '' THEN FIND_IN_SET(SubmissionHeader.JobNumber, @job_ids) ELSE TRUE END
    GROUP BY submission_hazard_action_person.hap_id) AS a
  GROUP BY a.ID,
           a.SubmissionHeaderID;
END
$$

DELIMITER ;

--
-- Drop procedure `get_all_submission_hap_by_filter`
--
DROP PROCEDURE IF EXISTS get_all_submission_hap_by_filter;

DELIMITER $$

--
-- Create procedure `get_all_submission_hap_by_filter`
--
CREATE PROCEDURE IF NOT EXISTS get_all_submission_hap_by_filter (IN lng_id int, IN start_date date, IN end_date date, IN site_ids longtext, IN job_ids longtext, IN filter_type varchar(255), IN filter_values longtext, IN person_id int)
BEGIN

  /* 
      Created by: Sontam Sarath
      Modified on: 2022-03-03
      Reason: SOF-10404 - Security patch: Convert raw query to stored procedure
  
      Modified   : March 3rd, 2022
      Modified by: James Coles
      Reason     : SOF-10397 - Validate parameter person_id.

      Modified: Sontam Sarath
      Modified by: 2022-11-11
      Reason: SOF-12484 - Get parent form name and custom form name
      
      Modified: Gowtham Ravindran
      Modified by: 2023-01-27
      Reason: SOF-13364 - Home page phase2    
      
      Modified By: Sarath Sontam
      Modified on: 2023-03-16
      Reason: Read action_by_who from submission_hazard_action_person.hap_per_id

      Modified By: James Coles
      Modified on: 2023-08-03
      Reason: SOF-14822 - Get enabled submission_hazard_action_person.hap_per_id for the response.

      Modified By: Suman Marlapudi
      Modified on: 2023-08-03
      Reason: SOF-14025 - Replaced the SELECT INTO by using a variable.

      Modified By: Robert Rivest
      Modified on: 2024-03-05
      Reason: PD-1171 - add sha_modified_by to the output payload

      Modified   : 2024-07-30
      Modified by: Vishnu Prkash 
      Reason     : PD-885- Haps page custom form name and redirect

    Modified by: James Coles
    Date       : 2025-02-18
    Reason     : Fixing the filtering dates to header date
  
  */


  SET @lng_id = lng_id;
  SET @start_date = start_date;
  SET @end_date = end_date;
  SET @job_ids = job_ids;
  SET @site_ids = site_ids;
  SET @filter_type = filter_type;
  SET @filter_values = filter_values;
  SET @person_id = person_id;
  SET @users := (SELECT
      COUNT(per_id)
    FROM person
    WHERE person.per_id = @person_id);

  IF (@users > 0) THEN

    WITH custom_form_data
    AS
    (SELECT
        SubmissionHeader.ID AS customSubmissionHeaderID,
        form_builder.*,
        get_translation(form_builder.fob_name, 1, form_builder.fob_tag_type) AS formname
      FROM custom_form_master
        INNER JOIN SubmissionHeader
          ON SubmissionHeader.ID = custom_form_master.cfm_submission_header_id
        INNER JOIN form_builder
          ON form_builder.fob_id = custom_form_master.cfm_fob_id
      GROUP BY SubmissionHeader.ID)


    SELECT
      Site.rld_id AS SiteId,
      CASE WHEN SubmissionHeader.FormDescriptionID = 1403 THEN (SELECT
                ltr_text
              FROM custom_form_master
                JOIN form_builder
                  ON fob_id = cfm_fob_id
                JOIN language_translation
                  ON ltr_lng_id = @lng_id
                  AND ltr_tag = fob_name
                  AND ltr_tag_type = fob_tag_type
              WHERE cfm_submission_header_id = SubmissionHeader.ID) ELSE (SELECT
              ltr_text
            FROM language_translation
            WHERE ltr_tag = FormDescription.FormName
            AND ltr_tag_type = 1
            AND ltr_lng_id = @lng_id) END AS FormName,
      CASE WHEN FormDescription.FormID != 777777 THEN SubmissionHeader.FormDescriptionID ELSE (SELECT
              CONCAT('custom-', custom_form_data.fob_id)
            FROM custom_form_data
            WHERE custom_form_data.customSubmissionHeaderID = SubmissionHAP.SubmissionHeaderID) END AS reportFormName,

      (SELECT
          ltr_text
        FROM ref_list_detail
          JOIN language_translation
            ON ltr_tag = rld_name
            AND ltr_enable = 1
            AND ltr_tag_type = rld_tag_type
        WHERE ltr_lng_id = @lng_id
        AND rld_id = SubmissionHAP.hazard_type) AS hazard_type,
      (SELECT
          ltr_text
        FROM ref_list_detail
          JOIN language_translation
            ON ltr_tag = rld_name
            AND ltr_enable = 1
            AND ltr_tag_type = rld_tag_type
        WHERE ltr_lng_id = @lng_id
        AND rld_id = SubmissionHAP.hazard_identification) AS hazard_identification,
      (SELECT
          ltr_text
        FROM ref_list_detail
          JOIN language_translation
            ON ltr_tag = rld_name
            AND ltr_enable = 1
            AND ltr_tag_type = rld_tag_type
        WHERE ltr_lng_id = @lng_id
        AND rld_id = SubmissionHAP.potential_risk) AS potential_risk,
      (SELECT
          ltr_text
        FROM ref_list_detail
          JOIN language_translation
            ON ltr_tag = rld_name
            AND ltr_enable = 1
            AND ltr_tag_type = rld_tag_type
        WHERE ltr_lng_id = @lng_id
        AND rld_id = SubmissionHAP.action_type) AS action_type,
      SubmissionHAP.ID,
      SubmissionHAP.SubmissionHeaderID,
      SubmissionHAP.hazard_description,
      SubmissionHAP.immediate_action_required_and_performed,
      SubmissionHAP.immediate_action_taken,
      (SELECT
          ltr_text
        FROM ref_list_detail
          JOIN language_translation
            ON ltr_tag = rld_name
            AND ltr_enable = 1
            AND ltr_tag_type = rld_tag_type
        WHERE ltr_lng_id = @lng_id
        AND rld_id = SubmissionHAP.immediate_action_type) AS immediate_action_type,
      SubmissionHAP.further_action_required,
      SubmissionHAP.recommended_action,
      GROUP_CONCAT(submission_hazard_action_person.hap_per_id SEPARATOR '; ') AS action_by_who,
      SubmissionHAP.action_by_when,
      SubmissionHAP.action_status,
      SubmissionHAP.action_complete_by_who,
      SubmissionHAP.action_completed_date,
      SubmissionHAP.completed_action_taken,
      (SELECT
          ltr_text
        FROM ref_list_detail
          JOIN language_translation
            ON ltr_tag = rld_name
            AND ltr_enable = 1
            AND ltr_tag_type = rld_tag_type
        WHERE ltr_lng_id = @lng_id
        AND rld_id = SubmissionHAP.completed_action_type) AS completed_action_type,
      SubmissionHAP.hazard_identification_score,
      SubmissionHAP.potential_risk_score,
      SubmissionHAP.immediate_action_score,
      SubmissionHAP.completed_action_score,
      SubmissionID,
      FormCreationDate,
      FormSubmissionDate,
      SubmissionHAP.sha_modified_date AS modified_date,
      (SELECT
          language_translation.ltr_text
        FROM language_translation
          JOIN ref_list_detail
            ON language_translation.ltr_tag = rld_name
            AND ltr_enable = 1
            AND language_translation.ltr_tag_type = rld_tag_type
        WHERE ltr_lng_id = @lng_id
        AND rld_id = SubmissionHeader.Site) AS Site,
      (SELECT
          language_translation.ltr_text
        FROM language_translation
          JOIN ref_list_detail
            ON language_translation.ltr_tag = rld_name
            AND ltr_enable = 1
            AND language_translation.ltr_tag_type = rld_tag_type
        WHERE ltr_lng_id = @lng_id
        AND rld_id = SubmissionHeader.JobNumber) AS JobNumber,
      (SELECT
          language_translation.ltr_text
        FROM language_translation
          JOIN ref_list_detail
            ON language_translation.ltr_tag = rld_name
            AND ltr_enable = 1
            AND language_translation.ltr_tag_type = rld_tag_type
        WHERE ltr_lng_id = @lng_id
        AND rld_id = SubmissionHeader.SiteLevel) AS SiteLevel,
      Workplace,
      HeaderDate,
      v_employee.per_full_name AS SubmittedBy,
      SubmissionHeader.SubmittedBy_SupervisorID AS submitted_by_per_id,
      Supervisor,
      CONCAT(SubmissionHeader.JobNumber, '_', SubmissionHeader.Site, '_', SubmissionHeader.SiteLevel, '_', SubmissionHeader.HeaderDate) AS SubmissionHeaderLabel,
      CASE WHEN SubmissionHeader.FormDescriptionID = 1403 THEN (SELECT
                CONCAT('custom-', cfm_fob_id)
              FROM custom_form_master
              WHERE cfm_submission_header_id = SubmissionHeader.ID) ELSE SubmissionHeader.FormDescriptionID END AS FormDescriptionID,
      FormDescription.FormID,
      (SELECT
          COUNT(*)
        FROM SubmissionHAPAttachments
        WHERE SubmissionHAPID = SubmissionHAP.ID
        AND AttachmentType = 'INITIAL') AS initial_attachments_count,
      (SELECT
          COUNT(*)
        FROM SubmissionHAPAttachments
        WHERE SubmissionHAPID = SubmissionHAP.ID
        AND AttachmentType = 'FOLLOWUP') AS followup_attachments_count,
      '' AS FollowupAttachments,
      '' AS InitialAttachments,
      GROUP_CONCAT(action.per_full_name SEPARATOR '; ') AS ActionAssignedTo
    FROM SubmissionHAP
      INNER JOIN SubmissionHeader
        ON SubmissionHAP.SubmissionHeaderID = SubmissionHeader.ID
      INNER JOIN FormDescription
        ON SubmissionHeader.FormDescriptionID = FormDescription.ID
      LEFT JOIN v_employee
        ON SubmissionHeader.SubmittedBy_SupervisorID = v_employee.per_id
      LEFT JOIN submission_hazard_action_person
        ON submission_hazard_action_person.hap_sha_id = SubmissionHAP.ID
        AND submission_hazard_action_person.hap_enable = 1
      LEFT JOIN v_employee action
        ON submission_hazard_action_person.hap_per_id = action.per_id
        AND submission_hazard_action_person.hap_enable = 1
      LEFT JOIN ref_list_detail job
        ON job.rld_id = SubmissionHeader.JobNumber
      LEFT JOIN ref_list_detail Site
        ON Site.rld_id = SubmissionHeader.Site
    WHERE (SubmissionHeader.IsArchived IS NULL
    OR SubmissionHeader.IsArchived = 0)
    AND SubmissionHAP.sha_enable = TRUE
    AND CASE WHEN @start_date <> '' AND
        @end_date <> '' THEN CAST(HeaderDate AS date) BETWEEN @start_date AND @end_date ELSE TRUE END
    AND CASE WHEN @filter_type = 'hazard_identification' THEN FIND_IN_SET(SubmissionHAP.hazard_identification, @filter_values) ELSE TRUE END
    AND CASE WHEN @filter_type = 'potential_risk' THEN FIND_IN_SET(SubmissionHAP.potential_risk, @filter_values) ELSE TRUE END
    AND CASE WHEN @filter_type = 'action_type' THEN FIND_IN_SET(SubmissionHAP.immediate_action_type, @filter_values)
          OR FIND_IN_SET(SubmissionHAP.completed_action_type, @filter_values) ELSE TRUE END
    AND CASE WHEN @site_ids <> '' THEN FIND_IN_SET(Site.rld_id, @site_ids)
          OR SubmissionHeader.SubmittedBy_SupervisorID = @person_id ELSE TRUE END
    AND CASE WHEN @job_ids <> '' THEN FIND_IN_SET(job.rld_id, @job_ids)
          OR SubmissionHeader.SubmittedBy_SupervisorID = @person_id ELSE TRUE END
    GROUP BY SubmissionHAP.ID
    ORDER BY FormSubmissionDate DESC, FormCreationDate DESC;


  END IF;


END
$$

--
-- Create procedure `api_lesson_learned_hazard_action_image`
--
CREATE PROCEDURE IF NOT EXISTS api_lesson_learned_hazard_action_image (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-13
     Reason    :    PD-2956 - Get hazard images in lesson learned.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  WITH Comments_CTE
  AS
  (SELECT
      com_reference_id,
      com_comment,
      com_id
    FROM comment_user
      JOIN comment_table
        ON comment_table.cmt_id = comment_user.com_cmt_id
    WHERE comment_user.com_enable = 1
    AND com_cmt_id = 5
    AND comment_table.cmt_enable = 1)

  SELECT
    ll.llm_id AS id,
    ll.llm_date AS date,
    ll.llm_created_date AS created_date,
    ll.llm_submitted_date AS submitted_date,
    ll.llm_modified_date AS modified_date,
    sh1.AttachmentFileName AS image_url,
    sh1.haa_image_timestamp AS image_stamp,
    ccte.com_comment AS image_comment
  FROM lesson_learned_hazard_action llha
    INNER JOIN SubmissionHAP sha
      ON llha.llh_sha_id = sha.ID
      AND llha.llh_enable = 1
    INNER JOIN lesson_learned ll
      ON ll.llm_id = llha.llh_llm_id
    LEFT JOIN SubmissionHAPAttachments sh1
      ON sha.ID = sh1.SubmissionHAPID
    LEFT JOIN Comments_CTE AS ccte
      ON sh1.ID = ccte.com_reference_id
  WHERE CASE WHEN use_id = TRUE THEN ll.llm_id = id ELSE CASE WHEN date_type = header_date THEN ll.llm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN ll.llm_modified_date BETWEEN start_date AND end_date END END
  AND sh1.AttachmentFileName IS NOT NULL
  AND sh1.haa_enable = 1
  AND ll.llm_enable = 1
  AND sha.sha_enable = 1;

END
$$

--
-- Create procedure `api_lesson_learned_hazard_action`
--
CREATE PROCEDURE IF NOT EXISTS api_lesson_learned_hazard_action (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-13
     Reason    :    PD-2956 - Get hazard section in lesson learned.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;
  DECLARE yes varchar(50);
  DECLARE no varchar(50);
  DECLARE individual_action varchar(50);
  DECLARE group_action varchar(50);

  SET yes = get_translation(1379, language_id, 1);
  SET no = get_translation(1380, language_id, 1);
  SET individual_action = get_translation(9514, language_id, 1);
  SET group_action = get_translation(9513, language_id, 1);

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  SELECT
    ll.llm_id AS id,
    ll.llm_date AS date,
    ll.llm_created_date AS created_date,
    ll.llm_submitted_date AS submitted_date,
    ll.llm_modified_date AS modified_date,
    get_translation_from_ref_list_id(shap.hazard_type, 'ref_hazard_type', language_id) AS hazard_type,
    get_translation_from_ref_list_id(shap.hazard_identification, 'ref_hazard_identification', language_id) AS hazard_identification,
    shap.hazard_description AS hazard_description,
    COALESCE(get_translation_from_ref_list_id(shap.potential_risk, 'ref_potential_loss', language_id),
    get_translation_from_ref_list_id(shap.potential_risk, 'ref_potential_risk', language_id)) AS potential_loss,
    CASE WHEN shap.immediate_action_required_and_performed = 0 OR
        shap.immediate_action_required_and_performed IS NULL THEN no WHEN shap.immediate_action_required_and_performed = 1 THEN yes ELSE shap.immediate_action_required_and_performed END AS immediate_action_required_and_performed,
    shap.immediate_action_taken,
    get_translation_from_ref_list_id(shap.immediate_action_type, 'ref_action_type', language_id) AS immediate_action_type,
    CASE WHEN shap.further_action_required = 0 OR
        shap.further_action_required IS NULL THEN no WHEN shap.further_action_required = 1 THEN yes ELSE shap.further_action_required END AS further_action_required,
    shap.recommended_action,
    get_translation_from_ref_list_id(shap.action_type, 'ref_action_type', language_id) AS action_type,
    CASE WHEN shap.sha_is_group_action = 0 OR
        shap.sha_is_group_action IS NULL THEN individual_action ELSE group_action END AS group_action_type,
    GROUP_CONCAT(DISTINCT by_who.per_id ORDER BY by_who.per_id SEPARATOR ';') AS action_by_who_id,
    GROUP_CONCAT(DISTINCT TRIM(CONCAT(by_who.per_last_name, ", ", by_who.per_first_name, " ", IFNULL(by_who.per_middle_name, ''))) ORDER BY by_who.per_id SEPARATOR '; ') AS action_by_who,
    shap.action_by_when,
    shap.action_status,
    shap.action_completed_date,
    GROUP_CONCAT(DISTINCT completed_by_who.per_id ORDER BY completed_by_who.per_id SEPARATOR '; ') AS completed_by_who_id,
    GROUP_CONCAT(DISTINCT TRIM(CONCAT(completed_by_who.per_last_name, ", ", completed_by_who.per_first_name, " ", IFNULL(completed_by_who.per_middle_name, ''))) ORDER BY completed_by_who.per_id SEPARATOR ';') AS completed_by_who,
    shap.completed_action_taken,
    get_translation_from_ref_list_id(shap.completed_action_type, 'ref_action_type', language_id) AS completed_action_type,
    shap.hazard_identification_score,
    shap.potential_risk_score,
    shap.immediate_action_score,
    shap.completed_action_score
  FROM lesson_learned_hazard_action llha
    INNER JOIN SubmissionHAP AS shap
      ON shap.ID = llha.llh_sha_id
      AND llha.llh_enable = 1
    INNER JOIN lesson_learned ll
      ON llha.llh_llm_id = ll.llm_id
      AND ll.llm_enable = 1
    LEFT JOIN submission_hazard_action_person
      ON shap.ID = submission_hazard_action_person.hap_sha_id
    LEFT JOIN person by_who
      ON submission_hazard_action_person.hap_per_id = by_who.per_id
    LEFT JOIN submission_hazard_action_completion
      ON shap.ID = submission_hazard_action_completion.hac_sha_id
    LEFT JOIN submission_hazard_action_completed_person
      ON submission_hazard_action_completion.hac_id = submission_hazard_action_completed_person.hcp_hac_id
    LEFT JOIN person completed_by_who
      ON submission_hazard_action_completed_person.hcp_per_id = completed_by_who.per_id
  WHERE CASE WHEN use_id = TRUE THEN ll.llm_id = id ELSE CASE WHEN date_type = header_date THEN ll.llm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN ll.llm_submitted_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN ll.llm_modified_date BETWEEN start_date AND end_date END END
  AND shap.sha_enable = 1
  AND submission_hazard_action_person.hap_enable = 1
  AND (CASE WHEN submission_hazard_action_completion.hac_enable IS NOT NULL THEN submission_hazard_action_completion.hac_enable = 1 ELSE 1 = 1 END)
  GROUP BY ll.llm_id,
           shap.ID
  ;

END
$$

--
-- Create procedure `api_decision_log_hazard_action_image`
--
CREATE PROCEDURE IF NOT EXISTS api_decision_log_hazard_action_image (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-10
     Reason    :    PD-2955 - Get hazard images in decision log.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  WITH Comments_CTE
  AS
  (SELECT
      com_reference_id,
      com_comment,
      com_id
    FROM comment_user
      JOIN comment_table
        ON comment_table.cmt_id = comment_user.com_cmt_id
    WHERE comment_user.com_enable = 1
    AND com_cmt_id = 5
    AND comment_table.cmt_enable = 1)

  SELECT
    dl.dlm_id AS id,
    dl.dlm_date AS date,
    dl.dlm_created_date AS created_date,
    dl.dlm_submitted_date AS submitted_date,
    dl.dlm_modified_date AS modified_date,
    sh1.AttachmentFileName AS image_url,
    sh1.haa_image_timestamp AS image_stamp,
    ccte.com_comment AS image_comment
  FROM decision_log_hazard_action dlha
    INNER JOIN SubmissionHAP sha
      ON dlha.dlh_sha_id = sha.ID
      AND dlha.dlh_enable = 1
    INNER JOIN decision_log dl
      ON dl.dlm_id = dlha.dlh_dlm_id
    LEFT JOIN SubmissionHAPAttachments sh1
      ON sha.ID = sh1.SubmissionHAPID
    LEFT JOIN Comments_CTE AS ccte
      ON sh1.ID = ccte.com_reference_id
  WHERE CASE WHEN use_id = TRUE THEN dl.dlm_id = id ELSE CASE WHEN date_type = header_date THEN dl.dlm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN dl.dlm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN dl.dlm_created_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN dl.dlm_modified_date BETWEEN start_date AND end_date END END
  AND sh1.AttachmentFileName IS NOT NULL
  AND sh1.haa_enable = 1
  AND dl.dlm_enable = 1
  AND sha.sha_enable = 1;

END
$$

--
-- Create procedure `api_decision_log_hazard_action`
--
CREATE PROCEDURE IF NOT EXISTS api_decision_log_hazard_action (IN id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-12-11
     Reason    :    PD-2955 - Get hazard section in decision log.

  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE modified_date int(11) DEFAULT 4;
  DECLARE yes varchar(50);
  DECLARE no varchar(50);
  DECLARE individual_action varchar(50);
  DECLARE group_action varchar(50);

  SET yes = get_translation(1379, language_id, 1);
  SET no = get_translation(1380, language_id, 1);
  SET individual_action = get_translation(9514, language_id, 1);
  SET group_action = get_translation(9513, language_id, 1);

  IF id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  SELECT DISTINCT
    dl.dlm_id AS id,
    dl.dlm_date AS date,
    dl.dlm_created_date AS created_date,
    dl.dlm_submitted_date AS submitted_date,
    dl.dlm_modified_date AS modified_date,
    get_translation_from_ref_list_id(shap.hazard_type, 'ref_hazard_type', language_id) AS hazard_type,
    get_translation_from_ref_list_id(shap.hazard_identification, 'ref_hazard_identification', language_id) AS hazard_identification,
    shap.hazard_description AS hazard_description,
    COALESCE(get_translation_from_ref_list_id(shap.potential_risk, 'ref_potential_loss', language_id),
    get_translation_from_ref_list_id(shap.potential_risk, 'ref_potential_risk', language_id)) AS potential_loss,
    CASE WHEN shap.immediate_action_required_and_performed = 0 OR
        shap.immediate_action_required_and_performed IS NULL THEN no WHEN shap.immediate_action_required_and_performed = 1 THEN yes ELSE shap.immediate_action_required_and_performed END AS immediate_action_required_and_performed,
    shap.immediate_action_taken,
    get_translation_from_ref_list_id(shap.immediate_action_type, 'ref_action_type', language_id) AS immediate_action_type,
    CASE WHEN shap.further_action_required = 0 OR
        shap.further_action_required IS NULL THEN no WHEN shap.further_action_required = 1 THEN yes ELSE shap.further_action_required END AS further_action_required,
    shap.recommended_action,
    get_translation_from_ref_list_id(shap.action_type, 'ref_action_type', language_id) AS action_type,
    CASE WHEN shap.sha_is_group_action = 0 OR
        shap.sha_is_group_action IS NULL THEN individual_action ELSE group_action END AS group_action_type,
    GROUP_CONCAT(DISTINCT by_who.per_id ORDER BY by_who.per_id SEPARATOR ';') AS action_by_who_id,
    GROUP_CONCAT(DISTINCT TRIM(CONCAT(by_who.per_last_name, ", ", by_who.per_first_name, " ", IFNULL(by_who.per_middle_name, ''))) ORDER BY by_who.per_id SEPARATOR '; ') AS action_by_who,
    shap.action_by_when,
    shap.action_status,
    shap.action_completed_date,
    GROUP_CONCAT(DISTINCT completed_by_who.per_id ORDER BY completed_by_who.per_id SEPARATOR '; ') AS completed_by_who_id,
    GROUP_CONCAT(DISTINCT TRIM(CONCAT(completed_by_who.per_last_name, ", ", completed_by_who.per_first_name, " ", IFNULL(completed_by_who.per_middle_name, ''))) ORDER BY completed_by_who.per_id SEPARATOR ';') AS completed_by_who,
    shap.completed_action_taken,
    get_translation_from_ref_list_id(shap.completed_action_type, 'ref_action_type', language_id) AS completed_action_type,
    shap.hazard_identification_score,
    shap.potential_risk_score,
    shap.immediate_action_score,
    shap.completed_action_score
  FROM decision_log_hazard_action dlha
    INNER JOIN SubmissionHAP AS shap
      ON shap.ID = dlha.dlh_sha_id
      AND dlha.dlh_enable = 1
    INNER JOIN decision_log dl
      ON dlha.dlh_dlm_id = dl.dlm_id
      AND dl.dlm_enable = 1
    LEFT JOIN submission_hazard_action_person
      ON shap.ID = submission_hazard_action_person.hap_sha_id
    LEFT JOIN person by_who
      ON submission_hazard_action_person.hap_per_id = by_who.per_id
    LEFT JOIN submission_hazard_action_completion
      ON shap.ID = submission_hazard_action_completion.hac_sha_id
    LEFT JOIN submission_hazard_action_completed_person
      ON submission_hazard_action_completion.hac_id = submission_hazard_action_completed_person.hcp_hac_id
    LEFT JOIN person completed_by_who
      ON submission_hazard_action_completed_person.hcp_per_id = completed_by_who.per_id
  WHERE CASE WHEN use_id = TRUE THEN dl.dlm_id = id ELSE CASE WHEN date_type = header_date THEN dl.dlm_date BETWEEN start_date AND end_date WHEN date_type = submission_date THEN dl.dlm_submitted_date BETWEEN start_date AND end_date WHEN date_type = creation_date THEN dl.dlm_created_date BETWEEN start_date AND end_date WHEN date_type = modified_date THEN dl.dlm_modified_date BETWEEN start_date AND end_date END END
  AND shap.sha_enable = 1
  AND submission_hazard_action_person.hap_enable = 1
  AND (CASE WHEN submission_hazard_action_completion.hac_enable IS NOT NULL THEN submission_hazard_action_completion.hac_enable = 1 ELSE 1 = 1 END)
  GROUP BY dl.dlm_id,
           shap.ID
  ;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_lineup_external_distribution`
--
DROP PROCEDURE IF EXISTS rpt_lineup_external_distribution;

DELIMITER $$

--
-- Create procedure `rpt_lineup_external_distribution`
--
CREATE PROCEDURE IF NOT EXISTS rpt_lineup_external_distribution (IN lineup_ids text)
BEGIN

  /*
  
   Created By: Jazmyn Zarichney
   Creation Date: 2022-04-19
   Description: Turning inline query to SP for lineup and lineup draft external distribution list

   Modified By: Pragati Das
   Modified Date: 2024-06-21
   Description: PD-2181 - Removed email ID from the distributor column
  
   Modified By: Sarath Sontam/ Pragati Das / Gowtham Ravindran
   Modified Date: 2024-07-25
   Description: PD-2364 - Fetching names based on the new Lineup distribution change
  
   Modified By: Pragati Das
   Modified Date: 2024-10-02
   Description: PD-2827 - Update fetch Distribution Contacts names based on the new changes to Distribution group email table.

  */


  SELECT
    lid_lineup_id,
    GROUP_CONCAT(DISTINCT
    CASE WHEN lid_per_id IS NOT NULL THEN CONCAT(full_name.per_last_name, ', ', full_name.per_first_name, ' ', IFNULL(full_name.per_middle_name, '')) WHEN lid_edl_id IS NOT NULL THEN CONCAT(external_distribution_list.edl_last_name, ', ', external_distribution_list.edl_first_name) WHEN distribution_group_email.dge_edl_id IS NOT NULL THEN CONCAT(edl_group.edl_last_name, ', ', edl_group.edl_first_name) WHEN lid_dig_id IS NOT NULL THEN CONCAT(group_per_full_name.per_last_name, ', ', group_per_full_name.per_first_name, ' ', IFNULL(group_per_full_name.per_middle_name, '')) ELSE NULL END
    SEPARATOR '; ') AS Distributors
  FROM lineup_distribution
    LEFT JOIN person AS full_name
      ON lid_per_id = full_name.per_id
    LEFT JOIN external_distribution_list
      ON lid_edl_id = external_distribution_list.edl_id
    LEFT JOIN distribution_group
      ON lid_dig_id = distribution_group.dig_id
    LEFT JOIN distribution_group_email
      ON lineup_distribution.lid_dig_id = distribution_group_email.dge_dig_id
      AND distribution_group_email.dge_enable = 1
    LEFT JOIN external_distribution_list AS edl_group
      ON distribution_group_email.dge_edl_id = edl_group.edl_id
    LEFT JOIN auth_user_sofvie
      ON distribution_group_email.dge_per_id = auth_user_sofvie.user_per_id
    LEFT JOIN person AS group_per_full_name
      ON auth_user_sofvie.user_per_id = group_per_full_name.per_id
    LEFT JOIN LineupFormHeader
      ON lineup_distribution.lid_lineup_id = LineupFormHeader.ID
  WHERE lid_lineup_id = lineup_ids
  AND lineup_distribution.lid_enable = 1
  GROUP BY lid_lineup_id;


END
$$

DELIMITER ;

--
-- Create table `lineup_workplace_level`
--
CREATE TABLE IF NOT EXISTS lineup_workplace_level (
  lwl_id int(11) NOT NULL AUTO_INCREMENT,
  lwl_lwp_id int(11) DEFAULT NULL,
  lwl_rld_level_id int(11) DEFAULT NULL,
  lwl_created_by_per_id int(11) DEFAULT NULL,
  lwl_created_date datetime DEFAULT NULL,
  lwl_modified_by_per_id int(11) DEFAULT NULL,
  lwl_modified_date datetime DEFAULT NULL,
  lwl_enable tinyint(4) DEFAULT NULL,
  lwl_enote varchar(400) DEFAULT NULL,
  PRIMARY KEY (lwl_id)
)
ENGINE = INNODB,
CHARACTER SET utf8mb3,
COLLATE utf8mb3_general_ci;

--
-- Create foreign key
--
ALTER TABLE lineup_workplace_level
ADD CONSTRAINT FK_lineup_workplace_level_lwl_created_by_per_id FOREIGN KEY IF NOT EXISTS (lwl_created_by_per_id)
REFERENCES person (per_id) ON DELETE NO ACTION;

--
-- Create foreign key
--
ALTER TABLE lineup_workplace_level
ADD CONSTRAINT FK_lineup_workplace_level_lwl_lwp_id FOREIGN KEY IF NOT EXISTS (lwl_lwp_id)
REFERENCES LineupWorkplaces (ID) ON DELETE NO ACTION;

--
-- Create foreign key
--
ALTER TABLE lineup_workplace_level
ADD CONSTRAINT FK_lineup_workplace_level_lwl_modified_by_per_id FOREIGN KEY IF NOT EXISTS (lwl_modified_by_per_id)
REFERENCES person (per_id) ON DELETE NO ACTION;

--
-- Create foreign key
--
ALTER TABLE lineup_workplace_level
ADD CONSTRAINT FK_lineup_workplace_level_lwl_rld_level_id FOREIGN KEY IF NOT EXISTS (lwl_rld_level_id)
REFERENCES ref_list_detail (rld_id) ON DELETE NO ACTION;

DELIMITER $$

--
-- Create procedure `workplacelevels`
--
CREATE PROCEDURE IF NOT EXISTS workplacelevels ()
BEGIN

  DECLARE int_records_count int(11);
  DECLARE current_record int(11);
  DECLARE levels text;
  DECLARE current text;
  DECLARE enabled tinyint;
  DECLARE counter_2 int(11);
  DECLARE pipes int(11);
  DECLARE current_workplace int(11);
  DECLARE support int(11) DEFAULT get_support_account();

  TRUNCATE lineup_workplace_level;

  SET int_records_count = (SELECT
      COUNT(*)
    FROM LineupWorkplaces
    WHERE TRIM(WorkplaceLevel) <> '');
  SET current_record = 1;
  WHILE current_record < int_records_count DO

    SELECT
      lw.WorkplaceLevel,
      lw.ID,
      lw.lwp_enable INTO levels, current_workplace, enabled
    FROM LineupWorkplaces lw
    WHERE TRIM(WorkplaceLevel) <> ''
    LIMIT 1 OFFSET current_record;

    SET counter_2 = 1;
    SET pipes = (SELECT
        LENGTH(levels) - LENGTH(REPLACE(levels, '|', '')));

    WHILE counter_2 <= pipes + 1 DO

      SET current = SUBSTRING_INDEX (levels, '|', 1);

      INSERT INTO lineup_workplace_level (lwl_lwp_id, lwl_rld_level_id, lwl_created_by_per_id, lwl_created_date, lwl_enote, lwl_enable)
        VALUES (current_workplace, current, support, NOW(), 'PD-2916 - Workplace level schema change.', enabled);
      SET levels = SUBSTRING(levels FROM CHAR_LENGTH(current) + 2);

      SET counter_2 = counter_2 + 1;

    END WHILE;


    SET current_record = current_record + 1;


  END WHILE;

END
$$

DELIMITER ;

--
-- Drop procedure `get_lineup_workplaces`
--
DROP PROCEDURE IF EXISTS get_lineup_workplaces;

DELIMITER $$

--
-- Create procedure `get_lineup_workplaces`
--
CREATE PROCEDURE IF NOT EXISTS get_lineup_workplaces (IN lineup_id int)
BEGIN
  /*
  CREATED BY: Robert Rivest
  Created DATE: 2020-04-27
  Purpose: to retrive a lineup's List of workplaces for EDIT
  NOTE: Bob needs to review code to determine if/when we can remove one of the ID calls. SOF-2339

  Modified by Robert Rivest
  Modified On: 2020-04-30
  Modification:  Removed the REdundant field LineupWorkplaces.ID

  Modified by Robert Rivest
  Modified On: 2020-11-11
  Modification: Added WorkplaceJRA as a field to be output

  Modified By: Robert Rivest
  Modified Date: 2023-05-10
  Description: SOF-14122- change field name from wp_jte_id to wp_jra_id and also changed contraint to poing to rmm_jra

  Modified By: James Coles
  Modified Date: 2024-11-20
  Description: PD-2844 - Added a new table to store workplace levels.

 */
  SELECT
    ID,
    LineupWorkplaces.LineupID,
    IFNULL(GROUP_CONCAT(DISTINCT lwl.lwl_rld_level_id SEPARATOR '|'), '') AS WorkplaceLevel,
    RTRIM(LineupWorkplaces.WorkplaceLineup) AS WorkplaceLineup,
    RTRIM(LineupWorkplaces.WorkplaceName) AS WorkplaceName,
    LineupWorkplaces.ID AS WorkplaceID,
    LineupWorkplaces.lwp_jra_id AS WorkplaceJRA
  FROM LineupWorkplaces
    INNER JOIN lineup_workplace_level lwl
      ON LineupWorkplaces.ID = lwl.lwl_lwp_id
  WHERE LineupWorkplaces.LineupID = lineup_id
  AND LineupWorkplaces.lwp_enable = 1
  AND lwl.lwl_enable = 1
  GROUP BY ID;

END
$$

DELIMITER ;

--
-- Drop procedure `api_lineup_header`
--
DROP PROCEDURE IF EXISTS api_lineup_header;

DELIMITER $$

--
-- Create procedure `api_lineup_header`
--
CREATE PROCEDURE IF NOT EXISTS api_lineup_header (IN submission_header_id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-06-21
     Reason    :    Client API- Get header data for Lineup.

     Modified by:    Vinh Lam
     Modified Date:  2024-01-08
     Reason    :    PD-3296 - Remove workplace name in header as duplicated with details endpoint.
  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;

  IF submission_header_id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  WITH translation
  AS
  (SELECT
      language_translation.ltr_text,
      ref_list_detail.rld_id,
      ref_list_detail.rld_code
    FROM language_translation
      INNER JOIN ref_list_detail
        ON language_translation.ltr_tag = ref_list_detail.rld_name
        AND language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
    WHERE language_translation.ltr_lng_id = language_id
    AND language_translation.ltr_enable = 1)

  SELECT
    lfh.lfh_title AS title,
    sh.ID AS submission_header_id,
    sh.HeaderDate AS header_date,
    sh.FormCreationDate AS creation_date,
    sh.FormSubmissionDate AS submission_date,
    sh.SubmittedBy_SupervisorID AS submitted_by_id,
    CONCAT(submit.per_last_name, ", ", submit.per_first_name) AS submitted_by,
    sh.she_modified_date AS modified_date,
    sh.she_modified_by_per_id AS modified_by_id,
    CONCAT(modified.per_last_name, ", ", modified.per_first_name) AS modified_by,
    sh.Supervisor AS supervisor_id,
    CONCAT(supervisor.per_last_name, ", ", supervisor.per_first_name) AS supervisor,
    sh.Site AS site_id,
    site_trans.ltr_text AS site,
    project_trans.ltr_text AS project,
    shift_trans.ltr_text AS shift,
    crew_trans.ltr_text AS crew,
    sh.JobNumber AS department_job_id,
    job_trans.rld_code AS department_job,
    lfh.ClientRep AS client_representative,
    lfh.ContactInfo AS contact_information,
    lfh.SafetyTopic AS safety_topic,
    lfh.CommunicationNotes AS communication_notes,
    lfh.WorkplaceImpacts AS workplace_impacts
  FROM LineupFormHeader lfh
    INNER JOIN SubmissionHeader sh
      ON lfh.SubmissionHeaderID = sh.ID
    LEFT JOIN person submit
      ON submit.per_id = sh.SubmittedBy_SupervisorID
    LEFT JOIN person modified
      ON modified.per_id = sh.she_modified_by_per_id
    LEFT JOIN person supervisor
      ON supervisor.per_id = sh.Supervisor
    LEFT JOIN translation site_trans
      ON site_trans.rld_id = lfh.Site
    LEFT JOIN translation project_trans
      ON project_trans.rld_id = lfh.JobNumber
    LEFT JOIN translation shift_trans
      ON shift_trans.rld_id = lfh.Shift
    LEFT JOIN translation crew_trans
      ON crew_trans.rld_id = lfh.Crew
    LEFT JOIN translation job_trans
      ON job_trans.rld_id = sh.JobNumber
    LEFT JOIN LineupWorkplaces lwp
      ON lwp.LineupID = lfh.ID
      AND lwp.lwp_enable = 1
    LEFT JOIN lineup_workplace_level lwl
      ON lwl.lwl_lwp_id = lwp.ID
      AND lwl.lwl_enable = 1
    LEFT JOIN translation area
      ON area.rld_id = lwl.lwl_rld_level_id
  WHERE CASE WHEN use_id = TRUE THEN sh.ID = submission_header_id ELSE CASE WHEN date_type = header_date THEN sh.FormCreationDate BETWEEN start_date AND end_date WHEN date_type = submission_date THEN sh.FormSubmissionDate BETWEEN start_date AND end_date WHEN date_type = creation_date THEN sh.HeaderDate BETWEEN start_date AND end_date END END
  AND sh.she_enable = 1
  AND (sh.IsArchived = 0
  OR sh.IsArchived IS NULL)
  AND lfh.lfh_enable = 1
  GROUP BY sh.ID;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_lineup_header_draft_by_id`
--
DROP PROCEDURE IF EXISTS rpt_lineup_header_draft_by_id;

DELIMITER $$

--
-- Create procedure `rpt_lineup_header_draft_by_id`
--
CREATE PROCEDURE IF NOT EXISTS rpt_lineup_header_draft_by_id (IN lineup_id int, IN language_id int)
BEGIN


  /*
  Creation Date: 3rd June 2021
  Created By: Jaganjot Kaur
  Description: Records for the get detail for line up draft
  
  Modifed Date: 2022-01-24
  Modified By: Jazmyn Zarichney
  Comment: 2022-01-24
 
  Modifed Date: 2022-04-27
  Modified By: Pragati Das
  Comment: SOF-11078 - Updated the FormName column with the correct ltr_tag to get Lineup report title 

  Modified By: Jazmyn Zarichney
  Modified Date: 2022-05-18
  Description: Adding enable check on language translations (SOF-11119)

  Modified By: Pragati Das
  Modified Date: 2022-08-16
  Description: Updated the SP with correct tag type (equipment.poe_tag_type) (SOF-11465) 
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-09-07
  Description: Updating the labels to use the language function (SOF-12027) 

  Modified By: Paragti 
  Modified Date: 2022-11-15
  Description: SOF-12860 - Corrected the ltr_tag for line_item_step_label 

  Modified By: Robert Rivest
  Modified Date: 2023-05-10
  Description: SOF-14122- change field name from wp_jte_id to wp_jra_id and also changed contraint to poing to rmm_jra
  
  Modified   : 2023-08-24
  Modified by: James Coles
  Reason     : SOF-14401 - Lineup add standard fields.

  Modified   : 2023-12-04
  Modified by: James Coles
  Reason     : SOF-7210 - Lineup JRA.

  Modified   : 2024-03-01
  Modified by: Shane Robinson
  Reason     : PD-1141 - Updated report labels to match the app fields.

  Modified   : 2024-03-21
  Modified by: Pragati Das
  Reason     : PD-1172 - Updated the SP to add only the required fields in the 
               SELECT

  Modified by:  James Coles
  Modified Date:  2024-06-27
  Purpose :  PD-1628 - Lineup Title implementaion.

  Modified by:  Pragati Das/James Coles
  Modified Date:  2024-01-03
  Purpose :  PD-2844 - Lineup workplace level updates

*/

  DECLARE submission_id_label text;
  DECLARE lineup_date_label text;
  DECLARE site_label text;
  DECLARE shift_label text;
  DECLARE client_rep_label text;
  DECLARE safety_topic_label text;
  DECLARE communication_notes_label text;
  DECLARE workplace_impacts_label text;
  DECLARE submitted_by_label text;
  DECLARE supervisor_label text;
  DECLARE project_label text;
  DECLARE crew_label text;
  DECLARE contact_info_label text;
  DECLARE lineup_label text;
  DECLARE level_label text;
  DECLARE workplace_name_label text;
  DECLARE lineup_details_label text;
  DECLARE reference_JRA_label text;
  DECLARE special_PPE_label text;
  DECLARE work_alone_label text;
  DECLARE header_label text;
  DECLARE line_item_step_label text;
  DECLARE threat_label text;
  DECLARE control_measures_label text;
  DECLARE equipment_number_label text;
  DECLARE equipment_type_label text;
  DECLARE equipment_location_label text;
  DECLARE FormName text;
  DECLARE title_label text;

  SET title_label = get_translation(1304, language_id, 1);
  SET submission_id_label = get_translation(2398, language_id, 1);
  SET lineup_date_label = get_translation(124, language_id, 1);
  SET site_label = get_translation(828, language_id, 1);
  SET shift_label = get_translation(820, language_id, 1);
  SET client_rep_label = get_translation(1204, language_id, 1);
  SET safety_topic_label = get_translation(815, language_id, 1);
  SET communication_notes_label = get_translation(1206, language_id, 1);
  SET workplace_impacts_label = get_translation(1207, language_id, 1);
  SET submitted_by_label = get_translation(1168, language_id, 1);
  SET supervisor_label = get_translation(844, language_id, 1);
  SET project_label = get_translation(1278, language_id, 1);
  SET crew_label = get_translation(1203, language_id, 1);
  SET contact_info_label = get_translation(1205, language_id, 1);
  SET lineup_label = get_translation(1630, language_id, 1);
  SET level_label = get_translation(621, language_id, 1);
  SET workplace_name_label = get_translation(1971, language_id, 1);
  SET lineup_details_label = get_translation(1972, language_id, 1);
  SET reference_JRA_label = get_translation(2408, language_id, 1);
  SET special_PPE_label = get_translation(834, language_id, 1);
  SET work_alone_label = get_translation(1973, language_id, 1);
  SET header_label = get_translation(1901, language_id, 1);
  SET line_item_step_label = get_translation(8444, language_id, 1);
  SET threat_label = get_translation(2115, language_id, 1);
  SET control_measures_label = get_translation(2109, language_id, 1);
  SET equipment_number_label = get_translation(1235, language_id, 1);
  SET equipment_type_label = get_translation(1239, language_id, 1);
  SET equipment_location_label = get_translation(451, language_id, 1);
  SET FormName = get_translation(993, language_id, 1);

  SELECT
    LineupFormHeader.ID,
    LineupFormHeader.Site,
    LineupFormHeader.lfh_created_date,
    LineupFormHeader.SubmissionHeaderID,
    DATE(LineupFormHeader.LineupDate) AS LineupDate,
    LineupFormHeader.ClientRep,
    LineupFormHeader.ContactInfo,
    LineupFormHeader.SafetyTopic,
    LineupFormHeader.CommunicationNotes,
    LineupFormHeader.WorkplaceImpacts,
    LineupFormHeader.lfh_title,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
        INNER JOIN ref_list_detail
          ON language_translation.ltr_tag = ref_list_detail.rld_name
      WHERE language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
      AND language_translation.ltr_lng_id = language_id
      AND language_translation.ltr_enable = 1
      AND ref_list_detail.rld_id = LineupFormHeader.Site) AS site_name,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
        INNER JOIN ref_list_detail
          ON language_translation.ltr_tag = ref_list_detail.rld_name
      WHERE language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
      AND language_translation.ltr_lng_id = language_id
      AND language_translation.ltr_enable = 1
      AND ref_list_detail.rld_id = LineupFormHeader.Shift) AS shift_name,
    (SELECT
        rld_code
      FROM ref_list_detail
      WHERE rld_id = LineupFormHeader.JobNumber) AS project,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
        INNER JOIN ref_list_detail
          ON language_translation.ltr_tag = ref_list_detail.rld_name
      WHERE language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
      AND language_translation.ltr_lng_id = language_id
      AND language_translation.ltr_enable = 1
      AND ref_list_detail.rld_id = LineupFormHeader.Crew) AS crew_name,
    (SELECT
        GROUP_CONCAT(get_translation_from_ref_list_id(lwl_rld_level_id, 'ref_level', language_id))
      FROM lineup_workplace_level
      WHERE lwl_lwp_id = LineupWorkplaces.ID
      AND lwl_enable = 1) AS level,
    LineupWorkplaces.ID AS WorkplaceID,
    (SELECT
        GROUP_CONCAT(lwl_rld_level_id)
      FROM lineup_workplace_level
      WHERE lwl_lwp_id = LineupWorkplaces.ID
      AND lwl_enable = 1) AS WorkplaceLevel,
    REPLACE(LineupWorkplaces.WorkplaceLevel, '|', ',') AS WorkplaceLevelNoSpace,
    LineupWorkplaces.WorkplaceName,
    LineupWorkplaces.WorkplaceLineup,
    CONCAT(workers.per_last_name, ', ', workers.per_first_name) AS `WorkerName`,
    workers.per_id,
    LineupWorkers.WorkerAlone,
    CASE WHEN LineupWorkers.WorkerAlone = 1 THEN (SELECT
              ltr_text
            FROM language_translation
            WHERE ltr_tag = 1379
            AND ltr_lng_id = language_id
            AND ltr_enable = 1
            AND ltr_tag_type = 1) ELSE (SELECT
            ltr_text F
          FROM language_translation
          WHERE ltr_tag = 1380
          AND ltr_lng_id = language_id
          AND ltr_enable = 1
          AND ltr_tag_type = 1) END AS worker_alone,
    GROUP_CONCAT(DISTINCT (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag_type = 1
      AND ltr_tag = (SELECT
          rld_name
        FROM ref_list_detail
        WHERE rld_id = LineupWorkersPPE.PPEID)) SEPARATOR ', ') AS `ppe`,
    created.per_full_name AS Creator,
    updated.per_full_name AS Updater,
    supervisor.per_full_name AS SupervisorName,
    employeedet.per_full_name AS EmployeeName,
    LineupWorkers.WorkerID AS WorkerId,
    LineupWorkplaces.lwp_jra_id AS WorkplaceJRA,
    GROUP_CONCAT(DISTINCT rmm_jra.rmm_jra_title) AS JRAReference,
    employeedet.per_full_name AS SubmittedBy_name,
    submission_id_label AS submission_id_label,
    lineup_date_label AS lineup_date_label,
    site_label AS site_label,
    shift_label AS shift_label,
    client_rep_label AS client_rep_label,
    safety_topic_label AS safety_topic_label,
    communication_notes_label AS communication_notes_label,
    workplace_impacts_label AS workplace_impacts_label,
    submitted_by_label AS submitted_by_label,
    supervisor_label AS supervisor_label,
    project_label AS project_label,
    crew_label AS crew_label,
    contact_info_label AS contact_info_label,
    lineup_label AS lineup_label,
    level_label AS level_label,
    workplace_name_label AS workplace_name_label,
    lineup_details_label AS lineup_details_label,
    reference_JRA_label AS reference_JRA_label,
    special_PPE_label AS special_PPE_label,
    work_alone_label AS work_alone_label,
    header_label AS header_label,
    line_item_step_label AS line_item_step_label,
    threat_label AS threat_label,
    control_measures_label AS control_measures_label,
    equipment_number_label AS equipment_number_label,
    equipment_type_label AS equipment_type_label,
    equipment_location_label AS equipment_location_label,
    FormName AS FormName,
    title_label AS title_label
  FROM LineupFormHeader
    LEFT OUTER JOIN LineupWorkplaces
      ON LineupWorkplaces.LineupID = LineupFormHeader.id
    LEFT OUTER JOIN LineupWorkers
      ON LineupWorkplaces.id = LineupWorkers.WorkplaceID
    LEFT OUTER JOIN LineupWorkersPPE
      ON LineupWorkers.WorkerID = LineupWorkersPPE.WorkerID
    LEFT OUTER JOIN ref_list_detail
      ON ref_list_detail.rld_id = LineupWorkersPPE.PPEID
    LEFT OUTER JOIN v_employee created
      ON LineupFormHeader.lfh_created_by_per_id = created.per_id
    LEFT OUTER JOIN v_employee updated
      ON LineupFormHeader.lfh_modified_by_per_id = updated.per_id
    LEFT OUTER JOIN v_employee supervisor
      ON LineupFormHeader.Supervisor = supervisor.per_id
    LEFT OUTER JOIN v_employee employeedet
      ON LineupFormHeader.SubmittedBy = employeedet.per_id
    LEFT OUTER JOIN person workers
      ON LineupWorkers.WorkerName = workers.per_id
    LEFT OUTER JOIN rmm_jra_lineup_steps
      ON rmm_jra_lineup_steps.rmm_jls_lineup_id = LineupFormHeader.id
    LEFT OUTER JOIN lineup_jra
      ON LineupWorkplaces.id = lineup_jra.ljr_lwp_id
    LEFT JOIN rmm_jra
      ON lineup_jra.ljr_jra_id = rmm_jra.rmm_jra_id
  WHERE LineupFormHeader.id = lineup_id
  GROUP BY LineupWorkplaces.id,
           LineupWorkplaces.WorkplaceLevel,
           LineupWorkplaces.WorkplaceName,
           CONCAT(workers.per_last_name, ', ', workers.per_first_name),
           LineupWorkers.WorkerID;
END
$$

DELIMITER ;

--
-- Drop procedure `rpt_lineup_header`
--
DROP PROCEDURE IF EXISTS rpt_lineup_header;

DELIMITER $$

--
-- Create procedure `rpt_lineup_header`
--
CREATE PROCEDURE IF NOT EXISTS rpt_lineup_header (IN ID int, IN language_id int)
BEGIN


  /*
  Creation Date: 3rd June 2021
  Created By: Jaganjot Kaur
  Description: Records for the get distribution details list
  
  Change History
  
  Modifed Date: 2022-01-24 
  Modified By: Jazmyn Zarichney 
  Comment: Replacing strings with language tags (SOF-10161)
 
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-05-18
  Description: Adding enable check on language translations (SOF-11119)

  Modified By: Pragati
  Modified Date: 2022-05-31
  Description: Update SP-s having selects hardcoded for tag type 1 (SOF-11269)
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-09-07
  Description: Updating the labels to use the language function (SOF-12027)

  Modified By: Paragti 
  Modified Date: 2022-11-15
  Description: SOF-12860 - Corrected the ltr_tag for line_item_step_label 

  Modified By: Robert Rivest
  Modified Date: 2023-05-10
  Description: SOF-14122- change field name from wp_jte_id to wp_jra_id and also changed contraint to poing to rmm_jra
  
  Modified   : 2023-08-24
  Modified by: James Coles
  Reason     : SOF-14401 - Lineup add standard fields.

  Modified   : 2023-12-04
  Modified by: James Coles
  Reason     : SOF-7210 - Lineup JRA.

  Modified   : 2024-03-01
  Modified by: Shane Robinson
  Reason     : PD-1141 - Updated report labels to match the app fields.

  Modified   : 2024-03-15
  Modified by: Pragati Das
  Reason     : PD-1172 - Updated lineup_date to display the DATE label

  Modified   : 2024-03-21
  Modified by: Pragati Das
  Reason     : PD-1172 - Updated the SP to add only the required fields in the 
               SELECT

  Modified by:  James Coles
  Modified Date:  2024-06-27
  Purpose :  PD-1628 - Lineup Title implementaion.
  
  Modified by:  Pragati Das/James Coles
  Modified Date:  2024-01-03
  Purpose :  PD-2844 - Lineup workplace level updates

  */

  DECLARE submission_id_label text;
  DECLARE lineup_date_label text;
  DECLARE site_label text;
  DECLARE shift_label text;
  DECLARE client_rep_label text;
  DECLARE safety_topic_label text;
  DECLARE communication_notes_label text;
  DECLARE workplace_impacts_label text;
  DECLARE submitted_by_label text;
  DECLARE supervisor_label text;
  DECLARE project_label text;
  DECLARE crew_label text;
  DECLARE contact_info_label text;
  DECLARE lineup_label text;
  DECLARE level_label text;
  DECLARE workplace_name_label text;
  DECLARE lineup_details_label text;
  DECLARE reference_JRA_label text;
  DECLARE special_PPE_label text;
  DECLARE work_alone_label text;
  DECLARE header_label text;
  DECLARE line_item_step_label text;
  DECLARE threat_label text;
  DECLARE control_measures_label text;
  DECLARE FormName text;
  DECLARE title_label text;

  SET title_label = get_translation(1304, language_id, 1);
  SET submission_id_label = get_translation(2398, language_id, 1);
  SET lineup_date_label = get_translation(124, language_id, 1);
  SET site_label = get_translation(828, language_id, 1);
  SET shift_label = get_translation(820, language_id, 1);
  SET client_rep_label = get_translation(1204, language_id, 1);
  SET safety_topic_label = get_translation(815, language_id, 1);
  SET communication_notes_label = get_translation(1206, language_id, 1);
  SET workplace_impacts_label = get_translation(1207, language_id, 1);
  SET submitted_by_label = get_translation(1168, language_id, 1);
  SET supervisor_label = get_translation(844, language_id, 1);
  SET project_label = get_translation(1278, language_id, 1);
  SET crew_label = get_translation(1203, language_id, 1);
  SET contact_info_label = get_translation(1205, language_id, 1);
  SET lineup_label = get_translation(1630, language_id, 1);
  SET level_label = get_translation(621, language_id, 1);
  SET workplace_name_label = get_translation(1971, language_id, 1);
  SET lineup_details_label = get_translation(1972, language_id, 1);
  SET reference_JRA_label = get_translation(2408, language_id, 1);
  SET special_PPE_label = get_translation(834, language_id, 1);
  SET work_alone_label = get_translation(1973, language_id, 1);
  SET header_label = get_translation(1901, language_id, 1);
  SET line_item_step_label = get_translation(8444, language_id, 1);
  SET threat_label = get_translation(2115, language_id, 1);
  SET control_measures_label = get_translation(2109, language_id, 1);
  SET FormName = get_translation(1630, language_id, 1);

  SELECT
    LineupFormHeader.ID,
    LineupFormHeader.Site,
    LineupFormHeader.lfh_created_date,
    LineupFormHeader.SubmissionHeaderID,
    DATE(LineupFormHeader.LineupDate) AS LineupDate,
    LineupFormHeader.ClientRep,
    LineupFormHeader.ContactInfo,
    LineupFormHeader.SafetyTopic,
    LineupFormHeader.CommunicationNotes,
    LineupFormHeader.WorkplaceImpacts,
    COALESCE(LineupFormHeader.lfh_title, '') lfh_title,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
        INNER JOIN ref_list_detail
          ON language_translation.ltr_tag = ref_list_detail.rld_name
      WHERE language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
      AND language_translation.ltr_lng_id = language_id
      AND language_translation.ltr_enable = 1
      AND ref_list_detail.rld_id = LineupFormHeader.Site) AS site_name,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
        INNER JOIN ref_list_detail
          ON language_translation.ltr_tag = ref_list_detail.rld_name
      WHERE language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
      AND language_translation.ltr_lng_id = language_id
      AND language_translation.ltr_enable = 1
      AND ref_list_detail.rld_id = LineupFormHeader.Shift) AS shift_name,
    (SELECT
        rld_code
      FROM ref_list_detail
      WHERE rld_id = LineupFormHeader.JobNumber) AS project,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
        INNER JOIN ref_list_detail
          ON language_translation.ltr_tag = ref_list_detail.rld_name
      WHERE language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
      AND language_translation.ltr_lng_id = language_id
      AND language_translation.ltr_enable = 1
      AND ref_list_detail.rld_id = LineupFormHeader.Crew) AS crew_name,
    (SELECT
        GROUP_CONCAT(get_translation_from_ref_list_id(lwl_rld_level_id, 'ref_level', language_id))
      FROM lineup_workplace_level
      WHERE lwl_lwp_id = LineupWorkplaces.ID
      AND lwl_enable = 1) AS level,
    (SELECT
        ltr_text
      FROM language_translation
      WHERE ltr_tag = 1379
      AND ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag_type = 1) AS yes_value,
    (SELECT
        ltr_text
      FROM language_translation
      WHERE ltr_tag = 1380
      AND ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag_type = 1) AS no_value,
    employeedet.per_full_name AS SubmittedBy_name,
    LineupWorkplaces.ID AS WorkplaceID,
    --  REPLACE(LineupWorkplaces.WorkplaceLevel, '|', ', ') AS WorkplaceLevel, 
    (SELECT
        GROUP_CONCAT(lwl_rld_level_id)
      FROM lineup_workplace_level
      WHERE lwl_lwp_id = LineupWorkplaces.ID
      AND lwl_enable = 1) AS WorkplaceLevel,
    REPLACE(LineupWorkplaces.WorkplaceLevel, '|', ',') AS WorkplaceLevelNoSpace,
    LineupWorkplaces.WorkplaceName,
    LineupWorkplaces.WorkplaceLineup,
    CONCAT(workers.per_last_name, ', ', workers.per_first_name) AS `WorkerName`,
    workers.per_id,
    LineupWorkers.WorkerAlone,
    CASE WHEN LineupWorkers.WorkerAlone = 1 THEN (SELECT
              ltr_text
            FROM language_translation
            WHERE ltr_tag = 1379
            AND ltr_lng_id = language_id
            AND ltr_enable = 1
            AND ltr_tag_type = 1) ELSE (SELECT
            ltr_text
          FROM language_translation
          WHERE ltr_tag = 1380
          AND ltr_lng_id = language_id
          AND ltr_enable = 1
          AND ltr_tag_type = 1) END AS worker_alone,
    GROUP_CONCAT(DISTINCT (SELECT
        language_translation.ltr_text
      FROM language_translation
        INNER JOIN ref_list_detail
          ON language_translation.ltr_tag = ref_list_detail.rld_name
      WHERE language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
      AND language_translation.ltr_lng_id = language_id
      AND language_translation.ltr_enable = 1
      AND ref_list_detail.rld_id = LineupWorkersPPE.PPEID) SEPARATOR ', ') AS `ppe`,
    created.per_full_name AS Creator,
    updated.per_full_name AS Updater,
    supervisor.per_full_name AS SupervisorName,
    employeedet.per_full_name AS EmployeeName,
    LineupWorkers.WorkerID AS WorkerId,
    LineupWorkplaces.lwp_jra_id AS WorkplaceJRA,
    GROUP_CONCAT(DISTINCT rmm_jra.rmm_jra_title) AS JRAReference,
    submission_id_label AS submission_id_label,
    lineup_date_label AS lineup_date_label,
    site_label AS site_label,
    shift_label AS shift_label,
    client_rep_label AS client_rep_label,
    safety_topic_label AS safety_topic_label,
    communication_notes_label AS communication_notes_label,
    workplace_impacts_label AS workplace_impacts_label,
    submitted_by_label AS submitted_by_label,
    supervisor_label AS supervisor_label,
    project_label AS project_label,
    crew_label AS crew_label,
    contact_info_label AS contact_info_label,
    lineup_label AS lineup_label,
    level_label AS level_label,
    workplace_name_label AS workplace_name_label,
    lineup_details_label AS lineup_details_label,
    reference_JRA_label AS reference_JRA_label,
    special_PPE_label AS special_PPE_label,
    work_alone_label AS work_alone_label,
    header_label AS header_label,
    line_item_step_label AS line_item_step_label,
    threat_label AS threat_label,
    control_measures_label AS control_measures_label,
    FormName AS FormName,
    title_label AS title_label
  FROM LineupFormHeader
    LEFT OUTER JOIN LineupWorkplaces
      ON LineupWorkplaces.LineupID = LineupFormHeader.ID
    LEFT OUTER JOIN LineupWorkers
      ON LineupWorkplaces.ID = LineupWorkers.WorkplaceID
    LEFT OUTER JOIN LineupWorkersPPE
      ON LineupWorkers.WorkerID = LineupWorkersPPE.WorkerID
    LEFT OUTER JOIN ref_list_detail
      ON ref_list_detail.rld_id = LineupWorkersPPE.PPEID
    LEFT OUTER JOIN v_employee created
      ON LineupFormHeader.lfh_created_by_per_id = created.per_id
    LEFT OUTER JOIN v_employee updated
      ON LineupFormHeader.lfh_modified_by_per_id = updated.per_id
    LEFT OUTER JOIN v_employee supervisor
      ON LineupFormHeader.Supervisor = supervisor.per_id
    LEFT OUTER JOIN v_employee employeedet
      ON LineupFormHeader.SubmittedBy = employeedet.per_id
    LEFT OUTER JOIN person workers
      ON LineupWorkers.WorkerName = workers.per_id
    LEFT OUTER JOIN rmm_jra_lineup_steps
      ON rmm_jra_lineup_steps.rmm_jls_lineup_id = LineupFormHeader.ID
    LEFT OUTER JOIN lineup_jra
      ON LineupWorkplaces.ID = lineup_jra.ljr_lwp_id
    LEFT JOIN rmm_jra
      ON lineup_jra.ljr_jra_id = rmm_jra.rmm_jra_id
  WHERE LineupFormHeader.SubmissionHeaderID = ID
  GROUP BY LineupWorkplaces.ID,
           LineupWorkplaces.WorkplaceLevel,
           LineupWorkplaces.WorkplaceName,
           CONCAT(workers.per_last_name, ', ', workers.per_first_name),
           LineupWorkers.WorkerID;

END
$$

DELIMITER ;

--
-- Drop procedure `sp_RemoveLineupItem`
--
DROP PROCEDURE IF EXISTS sp_RemoveLineupItem;

DELIMITER $$

--
-- Create procedure `sp_RemoveLineupItem`
--
CREATE PROCEDURE IF NOT EXISTS sp_RemoveLineupItem (IN _ID int, IN _Type nvarchar(16), OUT _ErrorMsg longtext)
BEGIN

  /*
  Creation Date: 2020-04-28
  Created By: Vishnu Prakash
  Description: remove the line up item
  
  Change History
  
  Modifed Date: 2023-08-25
  Modified By: Rana Hussain
  Comment: SOF-14946 added two more option to delete the rmm_jra_step and lineup_images when deleting the workplace/lineup.

  Modifed Date: 2023-09-05
  Modified By: Wu Liao
  Comment: SOF-14410 delete image comments when deleting the workplace/lineup.

  Modified Date: 2024-01-15
  Modified By: James Coles
  Coomment: PD-2948 - Delete the lineup levels when deleting the workplace.

  */



  DECLARE `_rollback` bool DEFAULT 0;
  -- We will use this variable to track if an error occurred during the transaction
  DECLARE CONTINUE HANDLER FOR SQLEXCEPTION SET `_rollback` = 1;
  -- if an error occurs, the bool will be set to true

  START TRANSACTION;

    IF _Type = 'Workplace' THEN

      DELETE
        FROM LineupEquipment
        WHERE WorkplaceID = _ID;

        DELETE
          FROM LineupWorkers
          WHERE WorkplaceID = _ID;

          DELETE
            FROM LineupWorkersPPE
            WHERE WorkplaceID = _ID;

            DELETE
              FROM comment_user
              WHERE com_cmt_id = 16
                AND com_reference_id IN (SELECT
                    lim_id
                  FROM lineup_image
                  WHERE lim_lwp_id = _ID);

              DELETE
                FROM lineup_image
                WHERE lim_lwp_id = _ID;

                DELETE
                  FROM rmm_jra_lineup_steps
                  WHERE rmm_jls_workplace_id = _ID;

                  DELETE
                    FROM LineupWorkplaces
                    WHERE ID = _ID;

                    DELETE
                      FROM lineup_workplace_level
                      WHERE lwl_lwp_id = _ID;


                      ELSEIF _Type = 'Worker' THEN

                        DELETE
                          FROM LineupEquipment
                          WHERE WorkerID = _ID;

                          DELETE
                            FROM LineupWorkers
                            WHERE WorkerID = _ID;

                            DELETE
                              FROM LineupWorkersPPE
                              WHERE WorkerID = _ID;



                              ELSEIF _Type = 'Equipment' THEN

                                DELETE
                                  FROM LineupEquipment
                                  WHERE EquipmentID = _ID;

                                  END IF;

                                  SET _ErrorMsg = '';


                                  IF `_rollback` = 1 THEN
                                    ROLLBACK;
                                    SET _ErrorMsg = (SELECT
                                        'Error removing lineup Items.');
                                  ELSE
                                    COMMIT;
                                  END IF;


                                  END
                                  $$

  DELIMITER ;

  --
  -- Drop procedure `rpt_lineup_draft_detail`
  --
  DROP PROCEDURE IF EXISTS rpt_lineup_draft_detail;

  DELIMITER $$

  --
  -- Create procedure `rpt_lineup_draft_detail`
  --
  CREATE PROCEDURE IF NOT EXISTS rpt_lineup_draft_detail (IN id int, IN workerid int, IN workname varchar(255), IN workeridppe int, IN lineupworkplaceid int, IN language_id int)
BEGIN


  /*
  Creation Date: 3rd June 2021
  Created By:  Jaganjot Kaur
  Description: Records for the get distribution details list
  
  Change History
  
  Modifed Date: 2022-01-24
  Modified By: Jazmyn Zarichney
  Comment: Replacing strings with language tags (SOF-10161)
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-05-18
  Description: Adding enable check on language translations (SOF-11119)

  Modified By: Pragati Das
  Modified Date: 2022-08-15
  Description: Updated the SP with correct tag type (equipment.poe_tag_type) (SOF-11465) 
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-09-07
  Description: Updating the labels to use the language function (SOF-12027)

  Modified By: Robert Rivest
  Modified Date: 2023-02-23
  Description: SOF-13505 - Changed Query to use new table names and fieldnames 

  Modified   : 2023-08-24
  Modified by: James Coles
  Reason     : SOF-14401 - Lineup add standard fields.

  Modified by:  Pragati Das/James Coles
  Modified Date:  2024-01-03
  Purpose :  PD-2844 - Lineup workplace level updates
  
*/

  DECLARE equipment_number_label text;
  DECLARE equipment_type_label text;
  DECLARE equipment_location_label text;

  SET equipment_number_label = get_translation(1235, language_id, 1);
  SET equipment_type_label = get_translation(1239, language_id, 1);
  SET equipment_location_label = get_translation(451, language_id, 1);

  SELECT
    LineupFormHeader.*,
    LineupWorkplaces.ID AS WorkplaceID,
    LineupWorkers.WorkerID,
    (SELECT
        GROUP_CONCAT(lwl_rld_level_id)
      FROM lineup_workplace_level
      WHERE lwl_lwp_id = LineupWorkplaces.ID
      AND lwl_enable = 1) AS WorkplaceLevel,
    LineupWorkplaces.WorkplaceName,
    LineupWorkplaces.WorkplaceLineup,
    workers.per_last_name,
    ', ',
    workers.per_first_name AS `WorkerName`,
    LineupWorkers.WorkerAlone,
    LineupEquipment.EquipmentNumber,
    LineupEquipment.EquipmentType,
    LineupEquipment.EquipmentLocation,
    created.per_full_name AS Creator,
    updated.per_full_name AS Updater,
    supervisor.per_full_name AS SupervisorName,
    employeedet.per_full_name AS EmployeeName,
    equipment.poe_equip_description AS EquipmentDescription,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_tag = equipment.poe_equip_description
      AND ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag_type = equipment.poe_tag_type) AS equipment_type,
    equipment_number_label AS equipment_number_label,
    equipment_type_label AS equipment_type_label,
    equipment_location_label AS equipment_location_label
  FROM LineupFormHeader
    LEFT OUTER JOIN LineupWorkplaces
      ON LineupWorkplaces.LineupID = LineupFormHeader.ID
    LEFT OUTER JOIN LineupWorkers
      ON LineupWorkplaces.ID = LineupWorkers.WorkplaceID
    LEFT OUTER JOIN LineupEquipment
      ON LineupWorkers.WorkerID = LineupEquipment.WorkerID
    LEFT OUTER JOIN v_employee created
      ON LineupFormHeader.lfh_created_by_per_id = created.per_id
    LEFT OUTER JOIN v_employee updated
      ON LineupFormHeader.lfh_modified_by_per_id = updated.per_id
    LEFT OUTER JOIN v_employee supervisor
      ON LineupFormHeader.Supervisor = supervisor.per_id
    LEFT OUTER JOIN v_employee employeedet
      ON LineupFormHeader.SubmittedBy = employeedet.per_id
    LEFT OUTER JOIN preop_equipment equipment
      ON LineupEquipment.EquipmentType = equipment.poe_id
    LEFT OUTER JOIN person workers
      ON LineupWorkers.WorkerName = workers.per_id
  WHERE LineupFormHeader.ID = ID
  AND workers.per_id IN (workerid)
  AND LineupWorkplaces.WorkplaceName IN (workname)
  AND LineupWorkers.WorkerID IN (workeridppe)
  AND LineupWorkplaces.ID IN (lineupworkplaceid)
  GROUP BY LineupWorkplaces.WorkplaceLevel,
           LineupWorkplaces.WorkplaceName,
           workerid,
           LineupEquipment.EquipmentNumber,
           LineupEquipment.EquipmentType,
           LineupEquipment.EquipmentLocation
  ORDER BY CONCAT(workers.per_last_name, ', ', workers.per_first_name);

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_lineup_details`
--
DROP PROCEDURE IF EXISTS rpt_lineup_details;

DELIMITER $$

--
-- Create procedure `rpt_lineup_details`
--
CREATE PROCEDURE IF NOT EXISTS rpt_lineup_details (IN id int, IN workerid int, IN workname varchar(255), IN workeridppe int, IN lineupworkplaceid int, IN language_id int)
BEGIN


  /*
  Creation Date: 3rd June 2021
  Created By:  Jaganjot Kaur
  Description: Records for the get distribution details list
  
  Change History 
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-05-18
  Description: Adding enable check on language translations (SOF-11119)

  Modified By: Pragati Das
  Modified Date: 2022-08-10
  Description: Added LineupWorkers.WorkerID in the SELECT 

  Modified By: Pragati Das
  Modified Date: 2022-08-15
  Description: Updated the SP with correct tag type (equipment.poe_tag_type) (SOF-11465) 
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-09-08
  Description: Updating the labels to use the language function (SOF-12027)

  Modified By: Robert Rivest
  Modified Date: 2023-02-23
  Description: SOF-13505 - Changed Query to use new table names and fieldnames 

  Modified By  : James Coles
  Modified Date: 2023-08-24
  Description  : SOF-14401 - Add standard fields to lineup tables.

  Modified by:  Pragati Das/James Coles
  Modified Date:  2024-01-03
  Purpose :  PD-2844 - Lineup workplace level updates
  
*/

  DECLARE equipment_number_label text;
  DECLARE equipment_type_label text;
  DECLARE equipment_location_label text;

  SET equipment_number_label = get_translation(1235, language_id, 1);
  SET equipment_type_label = get_translation(1239, language_id, 1);
  SET equipment_location_label = get_translation(451, language_id, 1);

  SELECT
    LineupFormHeader.*,
    LineupWorkplaces.ID AS WorkplaceID,
    LineupWorkers.WorkerID,
    (SELECT
        GROUP_CONCAT(lwl_rld_level_id)
      FROM lineup_workplace_level
      WHERE lwl_lwp_id = LineupWorkplaces.ID
      AND lwl_enable = 1) AS WorkplaceLevel,
    LineupWorkplaces.WorkplaceName,
    LineupWorkplaces.WorkplaceLineup,
    workers.per_last_name,
    ', ',
    workers.per_first_name AS `WorkerName`,
    LineupWorkers.WorkerAlone,
    LineupEquipment.EquipmentNumber,
    LineupEquipment.EquipmentType,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_tag = equipment.poe_equip_description
      AND ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag_type = equipment.poe_tag_type) AS equipment_type,
    LineupEquipment.EquipmentLocation,
    created.per_full_name AS Creator,
    updated.per_full_name AS Updater,
    supervisor.per_full_name AS SupervisorName,
    employeedet.per_full_name AS EmployeeName,
    equipment.poe_equip_description AS EquipmentDescription,
    equipment_number_label AS equipment_number_label,
    equipment_type_label AS equipment_type_label,
    equipment_location_label AS equipment_location_label
  FROM LineupFormHeader
    LEFT OUTER JOIN LineupWorkplaces
      ON LineupWorkplaces.LineupID = LineupFormHeader.ID
    LEFT OUTER JOIN LineupWorkers
      ON LineupWorkplaces.ID = LineupWorkers.WorkplaceID
    LEFT OUTER JOIN LineupEquipment
      ON LineupWorkers.WorkerID = LineupEquipment.WorkerID
    LEFT OUTER JOIN v_employee created
      ON LineupFormHeader.lfh_created_by_per_id = created.per_id
    LEFT OUTER JOIN v_employee updated
      ON LineupFormHeader.lfh_modified_by_per_id = updated.per_id
    LEFT OUTER JOIN v_employee supervisor
      ON LineupFormHeader.Supervisor = supervisor.per_id
    LEFT OUTER JOIN v_employee employeedet
      ON LineupFormHeader.SubmittedBy = employeedet.per_id
    LEFT OUTER JOIN preop_equipment equipment
      ON LineupEquipment.EquipmentType = equipment.poe_id
    LEFT OUTER JOIN person workers
      ON LineupWorkers.WorkerName = workers.per_id
  WHERE LineupFormHeader.SubmissionHeaderID = ID
  AND workers.per_id IN (workerid)
  AND LineupWorkplaces.WorkplaceName IN (workname)
  AND LineupWorkers.WorkerID IN (workeridppe)
  AND LineupWorkplaces.ID IN (lineupworkplaceid)
  GROUP BY LineupWorkplaces.WorkplaceName,
           workerid,
           LineupEquipment.EquipmentNumber,
           LineupEquipment.EquipmentType,
           LineupEquipment.EquipmentLocation
  ORDER BY CONCAT(workers.per_last_name, ', ', workers.per_first_name);

END
$$

DELIMITER ;

--
-- Drop procedure `copy_lineup`
--
DROP PROCEDURE IF EXISTS copy_lineup;

DELIMITER $$

--
-- Create procedure `copy_lineup`
--
CREATE PROCEDURE IF NOT EXISTS copy_lineup (OUT new_lineup_id int, IN lineup_id int, IN per_id int)
BEGIN

  /*
      Created By: James Coles
      Date:       2023-11-14
      Reason:     SOF-7210 - Copy lineup, move logic to the database.  
  
      Modified By: Rana Hussain / Robert Rivest
      Date:       2024-01-29
      Reason:     PD-858 - Correct field name for worker table lw.LineupId
  
      Modified By: Robert Rivest
      Date:       2024-02-28
      Reason:     PD-1142 - Add clause to filter out disabled images
  
      Modified By: James Coles
      Date:       2024-06-04
      Reason:     PD-1392 - Image order
  
      Modified By: James Coles
      Date:       2024-06-27
      Reason:     PD-1628 - Lineup Title implementation
  
      Modified By: Sarath Sontam
      Date:       2024-07-15
      Reason:     PD-1936 - Copy lineup distribution new columns
  
      Modified By: James Coles
      Date:       2024-11-20
      Reason:     PD-2844 - Added a new table to store workplace levels
  */


  DECLARE new_workplaceIDs varchar(1000);
  DECLARE old_workplaceIDs varchar(1000);
  SET @lineup = lineup_id;

  -- Lineup form header
  INSERT INTO LineupFormHeader (Site, Shift, ContactInfo, SafetyTopic, WorkplaceImpacts, CommunicationNotes, JobNumber, Crew, ClientRep, Supervisor, LineupDate, lfh_aco_id, lfh_created_by_per_id, lfh_enable, lfh_created_date, lfh_title)
    SELECT
      Site,
      Shift,
      ContactInfo,
      SafetyTopic,
      WorkplaceImpacts,
      CommunicationNotes,
      JobNumber,
      Crew,
      ClientRep,
      Supervisor,
      LineupDate,
      lfh_aco_id,
      lfh_created_by_per_id,
      lfh_enable,
      NOW(),
      lfh_title
    FROM LineupFormHeader
    WHERE ID = @lineup;

  SET @new_lineup = (SELECT
      LAST_INSERT_ID());
  SELECT
    @new_lineup;

  -- Lineup Workplaces
  INSERT INTO LineupWorkplaces (LineupWorkplaces.LineupID, WorkplaceLevel, WorkplaceLineup, WorkplaceName, lwp_created_by_per_id, lwp_enable, lwp_created_date)
    SELECT
      @new_lineup,
      WorkplaceLevel,
      WorkplaceLineup,
      WorkplaceName,
      lwp_created_by_per_id,
      lwp_enable,
      NOW()
    FROM LineupWorkplaces lw
    WHERE lw.LineupID = @lineup;

  -- Lineup distribution.
  INSERT INTO lineup_distribution (lid_lineup_id, lid_per_id, lid_edl_id, lid_dig_id, lid_email, lid_created_date, lid_created_by_per_id, lid_enable)
    SELECT
      @new_lineup,
      ld.lid_per_id,
      ld.lid_edl_id,
      ld.lid_dig_id,
      ld.lid_email,
      NOW(),
      per_id,
      1
    FROM lineup_distribution ld
    WHERE lid_lineup_id = @lineup
    AND ld.lid_enable = 1;

  SET new_workplaceIDs = (SELECT
      GROUP_CONCAT(ID)
    FROM LineupWorkplaces
    WHERE LineupID = @new_lineup);
  SET old_workplaceIDs = (SELECT
      GROUP_CONCAT(ID)
    FROM LineupWorkplaces lw
    WHERE lw.LineupID = lineup_id);

  WHILE new_workplaceIDs != '' DO

    SET @new_wpid = SUBSTRING_INDEX (new_workplaceIDs, ',', 1);
    SET @old_wpid = SUBSTRING_INDEX (old_workplaceIDs, ',', 1);

    -- Add workplace levels with the new workplace id.
    INSERT INTO lineup_workplace_level (lwl_lwp_id, lwl_rld_level_id, lwl_created_by_per_id, lwl_created_date, lwl_modified_by_per_id, lwl_modified_date, lwl_enable, lwl_enote)
      SELECT
        @new_wpid,
        lwl_rld_level_id,
        lwl_created_by_per_id,
        lwl_created_date,
        lwl_modified_by_per_id,
        lwl_modified_date,
        lwl_enable,
        lwl_enote
      FROM lineup_workplace_level lwl
      WHERE lwl_lwp_id = @old_wpid
      AND lwl.lwl_enable = 1;

    -- insert into lineup workers
    INSERT INTO LineupWorkers (LineupID, WorkplaceID, WorkerAlone, WorkerName, lwo_created_by_per_id, lwo_created_date, lwo_enable)
      SELECT
        @new_lineup,
        @new_wpid,
        lw.WorkerAlone,
        lw.WorkerName,
        per_id,
        NOW(),
        lw.lwo_enable
      FROM LineupWorkers lw
      WHERE lineup_id = @lineup
      AND lw.WorkplaceID = @old_wpid;

    -- Lineup JRA Steps.
    INSERT INTO rmm_jra_lineup_steps (rmm_jls_workplace_id, rmm_jls_step_id, rmm_jls_created_date, rmm_jls_enable, rmm_jls_created_by_per_id, rmm_jls_lineup_id)
      SELECT
        @new_wpid,
        rmm_jls_step_id,
        NOW(),
        rmm_jls_enable,
        per_id,
        @new_lineup
      FROM rmm_jra_lineup_steps rjls
      WHERE rjls.rmm_jls_workplace_id = @old_wpid
      AND lineup_id = @lineup;

    SET @new_workers = (SELECT
        GROUP_CONCAT(WorkerID)
      FROM LineupWorkers lw
      WHERE lw.LineupID = @new_lineup);
    SET @old_workers = (SELECT
        GROUP_CONCAT(WorkerID)
      FROM LineupWorkers lw
      WHERE lw.LineupID = @lineup);


    WHILE @new_workers != '' DO

      SET @new_worker_id = (SUBSTRING_INDEX (@new_workers, ',', 1));
      SET @old_worker_id = (SUBSTRING_INDEX (@old_workers, ',', 1));

      -- Lineup Equipment.
      INSERT INTO LineupEquipment (WorkplaceID, WorkerID, LineupID, EquipmentLocation, EquipmentNumber, EquipmentType, leq_created_date, leq_created_by_per_id, leq_enable)
        SELECT
          @new_wpid,
          @new_worker_id,
          @new_lineup,
          EquipmentLocation,
          EquipmentNumber,
          EquipmentType,
          NOW(),
          per_id,
          1
        FROM LineupEquipment le
        WHERE le.LineupID = @lineup
        AND le.WorkerID = @old_worker_id
        AND le.WorkplaceID = @old_wpid;


      -- Lineup Workers PPE.
      INSERT INTO LineupWorkersPPE (WorkerID, PPEID, LineupID, WorkplaceID, lpp_created_by_per_id, lpp_created_date, lpp_enable)
        SELECT
          @new_worker_id,
          lwp.PPEID,
          @new_lineup,
          @new_wpid,
          per_id,
          NOW(),
          1
        FROM LineupWorkersPPE lwp
        WHERE lineup_id = @lineup
        AND lwp.WorkplaceID = @old_wpid
        AND lwp.WorkerID = @old_worker_id;

      IF LOCATE(',', @new_workers) > 0 THEN
        SET @new_workers = SUBSTRING(@new_workers, LOCATE(',', @new_workers) + 1);
        SET @old_workers = SUBSTRING(@old_workers, LOCATE(',', @old_workers) + 1);

      ELSE
        SET @new_workers = '';
        SET @old_workers = '';

      END IF;

    END WHILE;

    -- Insert into lineup JRA.
    INSERT INTO lineup_jra (ljr_lwp_id, ljr_jra_id, ljr_created_date, ljr_created_by_per_id, ljr_enable)
      SELECT
        @new_wpid,
        ljr_jra_id,
        NOW(),
        per_id,
        1
      FROM lineup_jra lj
      WHERE lj.ljr_lwp_id = @old_wpid;

    -- Lineup Image.
    INSERT INTO lineup_image (lim_lwp_id, lim_filename, lim_created_date, lim_created_by_per_id, lim_enable, lim_attachment_index)
      SELECT
        @new_wpid,
        li.lim_filename,
        NOW(),
        per_id,
        1,
        li.lim_attachment_index
      FROM lineup_image li
      WHERE li.lim_lwp_id = @old_wpid
      AND li.lim_enable = 1;

    -- Setup for the next loop.
    IF LOCATE(',', new_workplaceIDs) > 0 THEN
      SET new_workplaceIDs = SUBSTRING(new_workplaceIDs, LOCATE(',', new_workplaceIDs) + 1);
      SET old_workplaceIDs = SUBSTRING(old_workplaceIDs, LOCATE(',', old_workplaceIDs) + 1);

    ELSE
      SET new_workplaceIDs = '';
      SET old_workplaceIDs = '';
    END IF;

  END WHILE;

  SET new_lineup_id = @new_lineup;
  SELECT
    new_lineup_id;



END
$$

DELIMITER ;

--
-- Drop procedure `api_lineup_details`
--
DROP PROCEDURE IF EXISTS api_lineup_details;

DELIMITER $$

--
-- Create procedure `api_lineup_details`
--
CREATE PROCEDURE IF NOT EXISTS api_lineup_details (IN submission_header_id int, IN start_date datetime, IN end_date datetime, IN date_type int, IN language_id int)
BEGIN
  /*
     Created by:    Vinh Lam
     Created Date:  2024-07-03
     Reason    :    Client API- Get details data for Lineup.

     Modified by:    Vinh Lam
     Created Date:  2024-07-23
     Reason    :    PD-2140 - Update group by for worker name.

     Modified by:    Vinh Lam
     Created Date:  2024-07-24
     Reason    :    PD-2140 - Update join condition for worker field.

     Modified by:    Vinh Lam
     Modified Date:  2024-01-08
     Reason    :    PD-3296 - Update workplace level, add workplace level id.
     
  */

  DECLARE use_id boolean DEFAULT FALSE;
  DECLARE header_date int(11) DEFAULT 1;
  DECLARE submission_date int(11) DEFAULT 2;
  DECLARE creation_date int(11) DEFAULT 3;
  DECLARE yes_label varchar(50);
  DECLARE no_label varchar(50);
  SET yes_label = get_translation(1379, language_id, 1);
  SET no_label = get_translation(1380, language_id, 1);

  IF submission_header_id IS NOT NULL THEN
    SET use_id = TRUE;
  END IF;

  IF TIME(end_date) = TIME(0) THEN
    SET end_date = CAST(DATE_ADD(end_date, INTERVAL 1 DAY) AS datetime);
  END IF;

  IF start_date IS NULL THEN
    SET start_date = '1900-01-01';
  END IF;

  IF end_date IS NULL THEN
    SET end_date = '2999-12-31';
  END IF;

  WITH translation
  AS
  (SELECT
      language_translation.ltr_text,
      ref_list_detail.rld_id,
      ref_list_detail.rld_code
    FROM language_translation
      INNER JOIN ref_list_detail
        ON language_translation.ltr_tag = ref_list_detail.rld_name
        AND language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
    WHERE language_translation.ltr_lng_id = language_id
    AND language_translation.ltr_enable = 1)

  SELECT
    sh.ID AS submission_header_id,
    sh.HeaderDate AS header_date,
    sh.FormSubmissionDate AS submission_date,
    sh.FormCreationDate AS creation_date,
    sh.she_modified_date AS modified_date,
    GROUP_CONCAT(lwl.lwl_rld_level_id ORDER BY lwl.lwl_rld_level_id SEPARATOR ', ') AS workplace_level_id,
    GROUP_CONCAT(area.ltr_text ORDER BY lwl.lwl_rld_level_id SEPARATOR ', ') AS workplace_level,
    lw.WorkplaceName AS workplace_name,
    lwr.WorkerName AS worker_id,
    CONCAT(w.per_last_name, ', ', w.per_first_name) AS worker,
    CASE WHEN lwr.WorkerAlone = 1 THEN yes_label WHEN lwr.WorkerAlone = 0 THEN no_label ELSE lwr.WorkerAlone END AS work_alone,
    rppe.ltr_text AS special_ppe,
    le.EquipmentNumber AS equipment_type_id,
    CONCAT(le.EquipmentNumber, '- ', lt.ltr_text) AS equipment_type,
    le.EquipmentLocation AS equipment_location,
    lw.WorkplaceLineup AS details
  FROM LineupFormHeader lfh
    LEFT JOIN SubmissionHeader sh
      ON lfh.SubmissionHeaderID = sh.ID
    LEFT JOIN LineupWorkplaces lw
      ON lfh.ID = lw.LineupID
      AND lw.lwp_enable = 1
    LEFT JOIN LineupWorkers lwr
      ON lw.ID = lwr.WorkplaceID
    LEFT JOIN LineupWorkersPPE lwppe
      ON lw.ID = lwppe.WorkplaceID
      AND lwr.WorkerID = lwppe.WorkerID
    LEFT JOIN LineupEquipment le
      ON lwr.WorkerID = le.WorkerID
    LEFT JOIN v_employee created
      ON lfh.lfh_created_by_per_id = created.per_id
    LEFT JOIN v_employee updated
      ON lfh.lfh_modified_by_per_id = updated.per_id
    LEFT JOIN v_employee supervisor
      ON lfh.Supervisor = supervisor.per_id
    LEFT JOIN v_employee employeedet
      ON lfh.SubmittedBy = employeedet.per_id
    LEFT JOIN preop_equipment equipment
      ON le.EquipmentType = equipment.poe_id
    LEFT JOIN person w
      ON lwr.WorkerName = w.per_id
    LEFT JOIN lineup_workplace_level lwl
      ON lwl.lwl_lwp_id = lw.ID
      AND lwl.lwl_enable = 1
    LEFT JOIN translation area
      ON area.rld_id = lwl.lwl_rld_level_id
    LEFT JOIN ref_special_ppe rppe
      ON lwppe.PPEID = rppe.rld_id
      AND rppe.lng_id = language_id
    LEFT JOIN language_translation lt
      ON equipment.poe_equip_description = lt.ltr_tag
      AND lt.ltr_lng_id = language_id
      AND lt.ltr_enable = 1
      AND lt.ltr_tag_type = equipment.poe_tag_type
  WHERE CASE WHEN use_id = TRUE THEN sh.ID = submission_header_id ELSE CASE WHEN date_type = header_date THEN sh.FormCreationDate BETWEEN start_date AND end_date WHEN date_type = submission_date THEN sh.FormSubmissionDate BETWEEN start_date AND end_date WHEN date_type = creation_date THEN sh.HeaderDate BETWEEN start_date AND end_date END END
  AND sh.she_enable = 1
  AND (sh.IsArchived = 0
  OR sh.IsArchived IS NULL)
  AND lfh.lfh_enable = 1
  GROUP BY sh.ID,
           lw.WorkplaceLevel,
           lw.WorkplaceName,
           lwr.WorkerName,
           lwppe.PPEID,
           lwr.WorkerID,
           le.EquipmentNumber,
           le.EquipmentType,
           le.EquipmentLocation;

END
$$

DELIMITER ;

--
-- Drop function `get_min_header_date`
--
DROP FUNCTION IF EXISTS get_min_header_date;

DELIMITER $$

--
-- Create function `get_min_header_date`
--
CREATE FUNCTION IF NOT EXISTS get_min_header_date (incident_ID int)
RETURNS date
BEGIN
  DECLARE min_date_1 date;
  DECLARE min_date_2 date;
  DECLARE min_date_3 date;
  DECLARE min_date date;
  DECLARE submission_id text;







  SET min_date_1 = (SELECT
      sh.HeaderDate
    FROM SubmissionHeader sh
      INNER JOIN IncidentSubmissions incs
        ON sh.ID = incs.SubmissionHeaderID
    WHERE incs.IncidentID = incident_ID
    AND sh.FormDescriptionID IN (1237, 1308, 1312, 1314, 1322, 1324, 1328, 1333, 1337, 1338)
    ORDER BY sh.HeaderDate ASC LIMIT 1);



  SET min_date_2 = (SELECT
      sh.HeaderDate
    FROM SubmissionHeader sh
      INNER JOIN IncidentSubmissions incs
        ON sh.ID = incs.SubmissionHeaderID
    WHERE incs.IncidentID = incident_ID
    AND sh.FormDescriptionID IN (1329, 1220, 1309, 1310, 1321, 1323, 1325, 1327, 1329)
    ORDER BY sh.HeaderDate ASC LIMIT 1);




  SET min_date_3 = (SELECT
      sh.HeaderDate
    FROM SubmissionHeader sh
      INNER JOIN IncidentSubmissions incs
        ON sh.ID = incs.SubmissionHeaderID
    WHERE incs.IncidentID = incident_ID
    ORDER BY sh.HeaderDate ASC LIMIT 1);

  SET min_date_1 = IFNULL(min_date_1, '2099-12-31');
  SET min_date_2 = IFNULL(min_date_2, '2099-12-31');
  SET min_date_3 = IFNULL(min_date_3, '2099-12-31');



  SET min_date = LEAST(min_date_1, min_date_2, min_date_3);


  RETURN min_date;
END
$$

DELIMITER ;

--
-- Drop procedure `sp_AssignSubmissionsToIncident`
--
DROP PROCEDURE IF EXISTS sp_AssignSubmissionsToIncident;

DELIMITER $$

--
-- Create procedure `sp_AssignSubmissionsToIncident`
--
CREATE PROCEDURE IF NOT EXISTS sp_AssignSubmissionsToIncident (IN Incident_ID int, IN Submission_ID int)
BEGIN

  /*
      Modified by: James Coles
      Modified Date: 2025-01-15
      Reason:  Populate the min header date in the incidents table.
  
  */

  DECLARE comp_date date DEFAULT NULL;
  DECLARE min_date date DEFAULT NULL;
  DECLARE rowcount int;
  DECLARE `_rollback` bool DEFAULT 0;  -- We will use this variable to track if an error occurred during the transaction
  DECLARE CONTINUE HANDLER FOR SQLEXCEPTION SET `_rollback` = 1;  -- if an error occurs, the bool will be set to true

  START TRANSACTION;

    INSERT INTO IncidentSubmissions (IncidentID, SubmissionHeaderID)
      VALUES (Incident_ID, Submission_ID);

    SET min_date = (SELECT
        sh.headerdate
      FROM SubmissionHeader sh
      WHERE sh.ID = Submission_ID);
    SET comp_date = (SELECT
        inc_minimum_incident_date
      FROM Incidents i
      WHERE ID = Incident_ID);

    SELECT
      min_date min,
      comp_date comp;
    IF min_date < comp_date
      OR ISNULL(comp_date) THEN
      UPDATE Incidents i
      SET i.inc_minimum_incident_date = min_date
      WHERE i.ID = Incident_ID;
    END IF;

    IF `_rollback` = 1 THEN
      ROLLBACK;
    ELSE
      COMMIT;
    END IF;


END
$$

DELIMITER ;

--
-- Drop procedure `get_incident_actions_by_employee_id`
--
DROP PROCEDURE IF EXISTS get_incident_actions_by_employee_id;

DELIMITER $$

--
-- Create procedure `get_incident_actions_by_employee_id`
--
CREATE PROCEDURE IF NOT EXISTS get_incident_actions_by_employee_id (IN per_id int, IN lang varchar(2))
BEGIN

  /*
    Created By: Robert Rivest
    Created Date: 2019-10-01
    Purpose: To retrieve the The Open incidents for a user in Mobile
  
    Modified Date: 2019-06-16
    Modified By: Robert Rivest
    Purpose:  Corrected SP to Work with Maria DB

    Modified Date: 2019-09-22
    Modified By: Robert Rivest
    Reason:  Changed  SubmissionHAP.action_status != "COMPLETE" instead of = null

    Modified Date: 2021-02-18
    Modified By: James Coles
    Purpose: SOF-6243 - Return hazard type, hazard description for more context.

    Modified Date: 2021-02-24
    Modified By: Wu Liao
    Purpose: SOF-6372 - APP IMM Add General Action.

    Modified Date: 2021-04-08
    Modified By: Vishnu Prakash
    Purpose: added the validation 'sha_enable' as true

    Modified Date: 2021-04-09
    Modified By: Robert Rivest
    Purpose: SOF-7280 - Mobile - add filter to exlude completed actions

    Modified Date: 2021-05-25
    Modified By: Sarath Sontam
    Purpose: SOF-7280 - Add subqueries to get translated value for site, site level, form_name and hazard_type
             Add two new variables 'INCOMPLETE' and 'COMPLETE' using hardcoded tag value. 

    Modified Date: 2021-07-08
    Modified By: Vishnu Prakash
    Modification: SOF-8178 - Modified for tag revamp

    Modified Date: 2021-09-16
    Modified By: Robert Rivest
    Modification: SOF-9010 - Modified for correct filter for complete and incomplete in other languages

    Modified   : March 16th, 2022
    Modified by: James Coles
    Reason     : SOF-10397 - Validate parameters.
  
    Modified   : 2023-05-04
    Modified by: Robert Rivest
    Reason     : SOF-14169 - add a new Join to include the submission_general_action_person and submission_hazard_action_person tables
  
    Modified   : 2023-09-05
    Modified by: Vishnu Prakash
    Reason     : SOF-14746 - added new column for translation and tag; New columns for action type

    Modified by: Suman Marlapudi
    Date       : 2023-11-10
    Reason     : SOF-14025 - Replace the deprecated SELECT INTO clause with variables.
    
    Modified by: Sarath Sontam
    Date       : 2025-01-28
    Reason     : PD-3400 - Filter language translation with ltr_tag_type =1 to get translated form name.  

  */

  DECLARE INCOMPLETE varchar(50);
  DECLARE COMPLETE varchar(50);
  DECLARE lang_id int;
  DECLARE users int;

  DECLARE general_translation varchar(50);
  DECLARE hazard_translation varchar(50);


  SET users = (SELECT
      COUNT(1)
    FROM person
    WHERE person.per_id = per_id);

  IF users > 0 THEN
    SET lang_id = (SELECT
        language.lng_id
      FROM language
      WHERE lng_name = lang);

    SET INCOMPLETE = get_translation(5028, lang_id, 1);
    SET COMPLETE = get_translation(2045, lang_id, 1);

    -- general action
    SET @general_translation = get_translation(1039, lang_id, 1);
    -- hazard action
    SET @hazard_translation = get_translation(1999, lang_id, 1);


    SELECT
      SubmissionHAP.ID,
      @hazard_translation AS type,
      1999 AS action_type_tag,
      SubmissionHAP.recommended_action action,
      SubmissionHAP.action_by_who assigned_to,
      SubmissionHAP.action_by_when,
      SubmissionHAP.action_completed_date,
      v_employee.per_full_name AS created_by,
      CASE WHEN SubmissionHAP.action_status LIKE 'INCOMPLETE' OR
          COALESCE(SubmissionHAP.action_status, '') = '' THEN INCOMPLETE WHEN SubmissionHAP.action_status LIKE 'COMPLETE' THEN COMPLETE END AS status,
      SubmissionHAP.SubmissionHeaderID,
      (SELECT
          ltr_text
        FROM language_translation
        WHERE ltr_tag = FormDescription.FormName
        AND ltr_tag_type = 1 -- FormName is always tag_type 1
        AND ltr_lng_id = lang_id) AS originated_from,
      SubmissionHeader.FormSubmissionDate submission_date,
      CASE WHEN SubmissionHAP.action_status LIKE 'INCOMPLETE' OR
          COALESCE(SubmissionHAP.action_status, '') = '' THEN action_by_when WHEN SubmissionHAP.action_status LIKE 'COMPLETE' THEN action_completed_date END AS action_contextual_date,
      SubmissionHeader.SubmissionID,
      (SELECT
          language_translation.ltr_text
        FROM language_translation
          JOIN ref_list_detail
            ON language_translation.ltr_tag = ref_list_detail.rld_name
            AND language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
        WHERE ltr_lng_id = lang_id
        AND rld_id = SubmissionHeader.Site) AS Site,
      (SELECT
          language_translation.ltr_text
        FROM language_translation
          JOIN ref_list_detail
            ON language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
            AND language_translation.ltr_tag = ref_list_detail.rld_name
          JOIN language
            ON language.lng_id = language_translation.ltr_lng_id
        WHERE ltr_lng_id = lang_id
        AND rld_id = SubmissionHeader.SiteLevel) AS SiteLevel,
      SubmissionHeader.Workplace,
      v_employee.email,
      (SELECT
          language_translation.ltr_text
        FROM language_translation
          JOIN ref_list_detail
            ON language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
            AND language_translation.ltr_tag = ref_list_detail.rld_name
        WHERE ltr_lng_id = lang_id
        AND rld_id = SubmissionHAP.hazard_type) AS hazard_type,
      SubmissionHAP.hazard_description,
      get_translation_from_ref_list_id(SubmissionHAP.action_type, 'ref_action_type', lang_id) AS action_type
    FROM SubmissionHAP
      INNER JOIN submission_hazard_action_person
        ON SubmissionHAP.ID = submission_hazard_action_person.hap_sha_id
      JOIN SubmissionHeader
        ON SubmissionHAP.SubmissionHeaderID = SubmissionHeader.ID
      JOIN FormDescription
        ON SubmissionHeader.FormDescriptionID = FormDescription.ID
      LEFT JOIN v_employee
        ON SubmissionHeader.SubmittedBy_SupervisorID = v_employee.per_id
    WHERE (SubmissionHeader.IsArchived IS NULL
    OR SubmissionHeader.IsArchived = 0)
    AND UPPER(SubmissionHAP.action_status) != 'COMPLETE'
    AND SubmissionHAP.sha_enable = TRUE
    AND SubmissionHAP.ID IN (SELECT
        id
      FROM SubmissionHAP
      WHERE SubmissionHeaderID IN (SELECT
          SubmissionHeaderID
        FROM IncidentSubmissions))
    AND submission_hazard_action_person.hap_per_id = per_id

    UNION ALL

    SELECT
      submission_general_action.sga_id AS ID,
      @general_translation AS type,
      1039 AS action_type_tag,
      submission_general_action.sga_recommended_action action,
      submission_general_action.sga_action_by_who_per_id assigned_to,
      submission_general_action.sga_action_by_when AS action_by_when,
      submission_general_action.sga_completed_action_date AS action_completed_date,
      s.per_full_name AS created_by,
      CASE WHEN submission_general_action.sga_action_is_complete = 0 OR
          COALESCE(submission_general_action.sga_action_is_complete, '') = '' THEN INCOMPLETE WHEN submission_general_action.sga_action_is_complete = 1 THEN COMPLETE END AS status,
      sga_submission_header_id AS SubmissionHeaderID,
      (SELECT
          ltr_text
        FROM language_translation
        WHERE ltr_tag = FormDescription.FormName
        AND ltr_tag_type = 1 -- FormName is always tag_type 1  
        AND ltr_lng_id = lang_id) AS originated_from,
      SubmissionHeader.FormSubmissionDate submission_date,
      CASE WHEN submission_general_action.sga_action_is_complete = 0 OR
          COALESCE(submission_general_action.sga_action_is_complete, '') = '' THEN submission_general_action.sga_action_by_when WHEN submission_general_action.sga_action_is_complete = 1 THEN submission_general_action.sga_completed_action_date END AS action_contextual_date,
      SubmissionHeader.SubmissionID,
      (SELECT
          language_translation.ltr_text
        FROM language_translation
          JOIN ref_list_detail
            ON language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
            AND language_translation.ltr_tag = ref_list_detail.rld_name
        WHERE ltr_lng_id = lang_id
        AND rld_id = SubmissionHeader.Site) AS Site,
      (SELECT
          language_translation.ltr_text
        FROM language_translation
          JOIN ref_list_detail
            ON language_translation.ltr_tag_type = ref_list_detail.rld_tag_type
            AND language_translation.ltr_tag = ref_list_detail.rld_name
        WHERE ltr_lng_id = lang_id
        AND rld_id = SubmissionHeader.SiteLevel) AS SiteLevel,
      SubmissionHeader.Workplace,
      s.email,
      NULL AS hazard_type,
      NULL AS hazard_description,
      get_translation_from_ref_list_id(submission_general_action.sga_action_type_rld_id, 'ref_general_action', lang_id) AS action_type
    FROM submission_general_action
      INNER JOIN submission_general_action_person
        ON submission_general_action.sga_id = submission_general_action_person.gap_sga_id
      JOIN SubmissionHeader
        ON submission_general_action.sga_submission_header_id = SubmissionHeader.ID
      JOIN FormDescription
        ON SubmissionHeader.FormDescriptionID = FormDescription.ID
      LEFT JOIN v_employee s
        ON SubmissionHeader.SubmittedBy_SupervisorID = s.per_id
    WHERE submission_general_action.sga_recommended_action <> ''
    AND submission_general_action_person.gap_per_id <> ''
    AND (SubmissionHeader.IsArchived IS NULL
    OR SubmissionHeader.IsArchived = 0)
    AND submission_general_action.sga_action_is_complete = 0
    AND submission_general_action.sga_id IN (SELECT
        sga_id
      FROM submission_general_action
      WHERE sga_submission_header_id IN (SELECT
          SubmissionHeaderID
        FROM IncidentSubmissions))
    AND submission_general_action_person.gap_per_id = per_id;
  END IF;
END
$$

DELIMITER ;

--
-- Drop procedure `rpt_pra_hap`
--
DROP PROCEDURE IF EXISTS rpt_pra_hap;

DELIMITER $$

--
-- Create procedure `rpt_pra_hap`
--
CREATE PROCEDURE IF NOT EXISTS rpt_pra_hap (IN formSubmissionId int, IN language_id int)
BEGIN

  /* 

   Created by : Jaganjot Kaur
   Created On : 16th June 2021
   Purpose : Details for hazard actions for PRA

   Modified by : Brandon McKee
   Modified date : 2021-08-19
   Purpose : Corrected the subqueries to ref_list_detail to tie to the correct tag type

   Modified by : Jazmyn Zarichney 
   Modified date : 2022-01-18
   Purpose : Replacing strings with tags (SOF-10161)

   Modified By: Jazmyn Zarichney
   Modified Date: 2022-05-06
   Description: Adding enable check on language translations (SOF-11119)
   
   Modified By: Jazmyn Zarichney
   Modified Date: 2022-09-08
   Description: Updating the labels to use the language function (SOF-12027)

   Modified By: Pragati
   Modified Date: 2023-01-11
   Description: SOF-13279 - Updated SP to get one row from a subquery
   
   Modified By: Pragati Das
   Modified Date: 2023-03-31
   Description: SOF-13374 - Updated the SP with the AMA functionality 

   Modified By: Pragati Das
   Modified Date: 2023-07-17
   Description: SOF-14663 - Added case statement to get the HAP with 
  only immediate actions and distibution label.

   Modified By: Naveen Kumar Vadlamudi
   Modified Date: 2024-12-20
   Description: PD-2834 Distribution - Store per_id Instead of Email - Reports Changes
 
   */

  DECLARE hazard_action_label text;
  DECLARE hazard_type_label text;
  DECLARE hazard_identification_label text;
  DECLARE hazard_description_label text;
  DECLARE potential_loss_identification_label text;
  DECLARE potential_loss_label text;
  DECLARE actions_identification_immediate_label text;
  DECLARE was_immediate_action_required_performed_label text;
  DECLARE action_taken_label text;
  DECLARE action_type_label text;
  DECLARE further_action_required_label text;
  DECLARE actions_identification_followup_label text;
  DECLARE recommendation_label text;
  DECLARE by_who_label text;
  DECLARE by_when_label text;
  DECLARE action_status_label text;
  DECLARE action_completed_by_who_label text;
  DECLARE action_completed_by_label text;
  DECLARE completion_report_label text;
  DECLARE no_images_label text;
  DECLARE initial_images_label text;
  DECLARE followup_images_label text;
  DECLARE images_label text;
  DECLARE report_distribution_label text;

  SET hazard_action_label = get_translation(1999, language_id, 1);
  SET hazard_type_label = get_translation(514, language_id, 1);
  SET hazard_identification_label = get_translation(510, language_id, 1);
  SET hazard_description_label = get_translation(509, language_id, 1);
  SET potential_loss_identification_label = get_translation(2177, language_id, 1);
  SET potential_loss_label = get_translation(1144, language_id, 1);
  SET actions_identification_immediate_label = get_translation(1911, language_id, 1);
  SET was_immediate_action_required_performed_label = get_translation(889, language_id, 1);
  SET action_taken_label = get_translation(15, language_id, 1);
  SET action_type_label = get_translation(17, language_id, 1);
  SET further_action_required_label = get_translation(589, language_id, 1);
  SET actions_identification_followup_label = get_translation(1912, language_id, 1);
  SET recommendation_label = get_translation(1915, language_id, 1);
  SET by_who_label = get_translation(71, language_id, 1);
  SET by_when_label = get_translation(70, language_id, 1);
  SET action_status_label = get_translation(14, language_id, 1);
  SET action_completed_by_who_label = get_translation(89, language_id, 1);
  SET action_completed_by_label = get_translation(91, language_id, 1);
  SET completion_report_label = get_translation(1913, language_id, 1);
  SET no_images_label = get_translation(2075, language_id, 1);
  SET initial_images_label = get_translation(1914, language_id, 1);
  SET followup_images_label = get_translation(1917, language_id, 1);
  SET images_label = get_translation(1918, language_id, 1);
  SET report_distribution_label = get_translation(166, language_id, 1);


  WITH distribution_cte
  AS
  (SELECT
      SubmissionHeaderID,
      GROUP_CONCAT(DISTINCT CASE WHEN value LIKE 'account-%' THEN CONCAT(p1.per_last_name, IFNULL(p.per_middle_name, ' '), p1.per_first_name) WHEN value LIKE 'external-%' THEN CONCAT(e.edl_last_name, ' ', e.edl_first_name) WHEN value LIKE 'group-%' THEN CASE WHEN CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) IS NULL THEN CONCAT(edl.edl_first_name, ' ', edl.edl_last_name) ELSE CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) END ELSE value END SEPARATOR '; ') AS Distributors
    FROM SubmissionDetails_Explode
      JOIN SubmissionDetails
        ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
      JOIN FormFieldDescription
        ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
      LEFT JOIN person p1
        ON SUBSTRING_INDEX (value, '-', -1) = p1.per_id
        AND value LIKE 'account-%'
      LEFT JOIN external_distribution_list e
        ON SUBSTRING_INDEX (value, '-', -1) = e.edl_id
        AND value LIKE 'external-%'
      LEFT JOIN distribution_group_email dge
        ON SUBSTRING_INDEX (value, '-', -1) = dge.dge_dig_id
        AND dge.dge_enable = 1
        AND SubmissionDetails_Explode.value LIKE 'group-%'
      LEFT JOIN person AS p
        ON p.per_id = dge.dge_per_id
      LEFT JOIN external_distribution_list edl
        ON edl.edl_id = dge.dge_edl_id
    WHERE FormFieldDescription.fieldKey = 'Report_Distribution1'
    GROUP BY SubmissionHeaderID)

  SELECT
    SubmissionHAP.ID,
    SubmissionHAP.action_by_when AS followup_action_by_date,
    get_translation_from_ref_list_id(SubmissionHAP.immediate_action_type, 'ref_action_type', language_id) AS immediate_action_type,
    get_translation_from_ref_list_id(SubmissionHAP.action_type, 'ref_action_type', language_id) AS followup_action_type,
    SubmissionHAP.hazard_description AS HAP_description,
    SubmissionHAP.immediate_action_required_and_performed AS immediate_action_required_and_performed_flag,
    CASE WHEN SubmissionHAP.immediate_action_required_and_performed = 1 THEN (get_translation(1379, language_id, 1)) ELSE (get_translation(1380, language_id, 1)) END AS was_immediate_action_required_and_performed,
    SubmissionHAP.further_action_required AS further_action_required_flag,
    CASE WHEN SubmissionHAP.further_action_required = 1 THEN (get_translation(1379, language_id, 1)) ELSE (get_translation(1380, language_id, 1)) END AS was_further_action_required,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_tag_type = 1
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          MAX(ltr_tag)
        FROM language_translation
        WHERE ltr_text = action_status)) AS hazard_status,
    get_translation_from_ref_list_id(SubmissionHAP.hazard_identification, 'ref_hazard_identification', language_id) AS hazard_identification,
    get_translation_from_ref_list_id(SubmissionHAP.hazard_type, 'ref_hazard_type', language_id) AS hazard_type,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          rld_name
        FROM ref_list_detail
        WHERE rld_id = SubmissionHAP.potential_risk
        AND rld_tag_type = ltr_tag_type)) AS potential_risk,

    SubmissionHAP.recommended_action AS followup_recommended_action,
    SubmissionHAP.immediate_action_taken AS immediate_action_taken,

    IF(SubmissionHAP.sha_is_group_action IS NOT NULL,
    GROUP_CONCAT(by_who.per_full_name SEPARATOR '; '),
    by_who.per_full_name) AS by_who,
    distribution_cte.Distributors AS distribution_list,
    SubmissionHAP.sha_is_group_action,
    hazard_action_label AS hazard_action_label,
    hazard_type_label AS hazard_type_label,
    hazard_identification_label AS hazard_identification_label,
    hazard_description_label AS hazard_description_label,
    potential_loss_identification_label AS potential_loss_identification_label,
    potential_loss_label AS potential_loss_label,
    actions_identification_immediate_label AS actions_identification_immediate_label,
    was_immediate_action_required_performed_label AS was_immediate_action_required_performed_label,
    action_taken_label AS action_taken_label,
    action_type_label AS action_type_label,
    further_action_required_label AS further_action_required_label,
    actions_identification_followup_label AS actions_identification_followup_label,
    recommendation_label AS recommendation_label,
    by_who_label AS by_who_label,
    by_when_label AS by_when_label,
    action_status_label AS action_status_label,
    action_completed_by_who_label AS action_completed_by_who_label,
    action_completed_by_label AS action_completed_by_label,
    completion_report_label AS completion_report_label,
    no_images_label AS no_images_label,
    initial_images_label AS initial_images_label,
    followup_images_label AS followup_images_label,
    images_label AS images_label,
    report_distribution_label AS report_distribution_label
  FROM rmm_pra_hazard_action
    INNER JOIN SubmissionHAP
      ON rmm_pra_hazard_action.rmm_pha_sha_id = SubmissionHAP.ID
    LEFT JOIN submission_hazard_action_person
      ON SubmissionHAP.ID = submission_hazard_action_person.hap_sha_id
    LEFT JOIN v_employee by_who
      ON submission_hazard_action_person.hap_per_id = by_who.per_id
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.id = SubmissionHAP.SubmissionHeaderID
    LEFT JOIN SubmissionDetails
      ON SubmissionHeader.id = SubmissionDetails.SubmissionHeaderID
    LEFT JOIN distribution_cte
      ON distribution_cte.SubmissionHeaderID = SubmissionDetails.SubmissionHeaderID
  WHERE rmm_pra_hazard_action.rmm_pha_pra_id = formSubmissionId
  AND SubmissionHAP.sha_enable = 1
  AND CASE WHEN immediate_action_required_and_performed = 1 AND
      further_action_required = 0 THEN 1 = 1 ELSE submission_hazard_action_person.hap_enable = 1 END
  GROUP BY submission_hazard_action_person.hap_sha_id;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_pra_general_actions`
--
DROP PROCEDURE IF EXISTS rpt_pra_general_actions;

DELIMITER $$

--
-- Create procedure `rpt_pra_general_actions`
--
CREATE PROCEDURE IF NOT EXISTS rpt_pra_general_actions (IN formSubmissionId int, IN language_id int)
BEGIN

  /* 

   Created by : Jaganjot Kaur
   Created On : 16th June 2021
   Purpose : Details for General Actions for PRA

   Modified by : Brandon McKee
   Modified date : 2021-08-19
   Purpose : Corrected the subqueries to ref_list_detail to tie to the correct tag type

   Modified by : Jazmyn Zarichney
   Modified date : 2022-01-18
   Purpose : Replacing strings with tags (SOF-10161)

   Modified By: Jazmyn Zarichney
   Modified Date: 2022-05-16
   Description: Adding enable check on language translations (SOF-11119)
   
   Modified By: Jazmyn Zarichney
   Modified Date: 2022-09-08
   Description: Updating the labels to use the language function (SOF-12027)
     
  Modified By: Pragati Das
  Modified Date: 2023-03-31
  Description: SOF-13374 - Updated the SP with the AMA functionality 
 
  Modified By: Pragati Das
  Modified Date: 2023-03-31
  Description: SOF-13374 - Updated the SP with the AMA functionality 

  Modified By: Naveen Kumar Vadlamudi
  Modified Date: 2024-12-20
  Description: PD-2834 Distribution - Store per_id Instead of Email - Reports Changes

   */

  DECLARE action_identification_label text;
  DECLARE general_action_label text;
  DECLARE action_type_label text;
  DECLARE by_who_label text;
  DECLARE by_when_label text;
  DECLARE recommended_action_label text;
  DECLARE action_completed_label text;
  DECLARE action_completed_by_label text;
  DECLARE action_completed_by_when_label text;
  DECLARE completed_action_taken_label text;
  DECLARE completed_action_type_label text;
  DECLARE job_number_label text;
  DECLARE date_label text;
  DECLARE site_label text;
  DECLARE supervisor_label text;
  DECLARE level_label text;
  DECLARE workplace_label text;
  DECLARE no_images_label text;
  DECLARE initial_images_label text;
  DECLARE followup_images_label text;
  DECLARE images_label text;
  DECLARE report_distribution_label text;

  SET action_identification_label = get_translation(2078, language_id, 1);
  SET general_action_label = get_translation(1039, language_id, 1);
  SET action_type_label = get_translation(17, language_id, 1);
  SET by_who_label = get_translation(71, language_id, 1);
  SET by_when_label = get_translation(70, language_id, 1);
  SET recommended_action_label = get_translation(773, language_id, 1);
  SET action_completed_label = get_translation(2026, language_id, 1);
  SET action_completed_by_label = get_translation(89, language_id, 1);
  SET action_completed_by_when_label = get_translation(91, language_id, 1);
  SET completed_action_taken_label = get_translation(15, language_id, 1);
  SET completed_action_type_label = get_translation(17, language_id, 1);
  SET job_number_label = get_translation(617, language_id, 1);
  SET date_label = get_translation(124, language_id, 1);
  SET site_label = get_translation(828, language_id, 1);
  SET supervisor_label = get_translation(844, language_id, 1);
  SET level_label = get_translation(8305, language_id, 1);
  SET workplace_label = get_translation(959, language_id, 1);
  SET no_images_label = get_translation(2075, language_id, 1);
  SET initial_images_label = get_translation(1914, language_id, 1);
  SET followup_images_label = get_translation(1917, language_id, 1);
  SET images_label = get_translation(1918, language_id, 1);
  SET report_distribution_label = get_translation(777, language_id, 1);



  WITH distribution_cte
  AS
  (SELECT
      SubmissionHeaderID,
      GROUP_CONCAT(DISTINCT CASE WHEN value LIKE 'account-%' THEN CONCAT(p1.per_last_name, IFNULL(p.per_middle_name, ' '), p1.per_first_name) WHEN value LIKE 'external-%' THEN CONCAT(e.edl_last_name, ' ', e.edl_first_name) WHEN value LIKE 'group-%' THEN CASE WHEN CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) IS NULL THEN CONCAT(edl.edl_first_name, ' ', edl.edl_last_name) ELSE CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) END ELSE value END SEPARATOR '; ') AS Distributors
    FROM SubmissionDetails_Explode
      JOIN SubmissionDetails
        ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
      JOIN FormFieldDescription
        ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
      LEFT JOIN person p1
        ON SUBSTRING_INDEX (value, '-', -1) = p1.per_id
        AND value LIKE 'account-%'
      LEFT JOIN external_distribution_list e
        ON SUBSTRING_INDEX (value, '-', -1) = e.edl_id
        AND value LIKE 'external-%'
      LEFT JOIN distribution_group_email dge
        ON SUBSTRING_INDEX (value, '-', -1) = dge.dge_dig_id
        AND dge.dge_enable = 1
        AND SubmissionDetails_Explode.value LIKE 'group-%'
      LEFT JOIN person AS p
        ON p.per_id = dge.dge_per_id
      LEFT JOIN external_distribution_list edl
        ON edl.edl_id = dge.dge_edl_id
    WHERE FormFieldDescription.fieldKey = 'Report_Distribution1'
    GROUP BY SubmissionHeaderID)

  SELECT
    submission_general_action.sga_submission_header_id,
    submission_general_action.sga_id,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          rld_name
        FROM ref_list_detail
        WHERE rld_id = submission_general_action.sga_action_type_rld_id
        AND rld_tag_type = ltr_tag_type)) AS action_type,
    IF(submission_general_action.sga_is_group_action = 1,
    GROUP_CONCAT(by_who.per_full_name SEPARATOR '; '),
    by_who.per_full_name) AS by_who,
    distribution_cte.Distributors AS distribution_list,
    submission_general_action.sga_action_by_when,
    submission_general_action.sga_recommended_action,
    submission_general_action.sga_action_is_complete,
    submission_general_action.sga_created_date,
    action_identification_label AS action_identification_label,
    general_action_label AS general_action_label,
    action_type_label AS action_type_label,
    by_who_label AS by_who_label,
    by_when_label AS by_when_label,
    recommended_action_label AS recommended_action_label,
    action_completed_label AS action_completed_label,
    action_completed_by_label AS action_completed_by_label,
    action_completed_by_when_label AS action_completed_by_when_label,
    completed_action_taken_label AS completed_action_taken_label,
    completed_action_type_label AS completed_action_type_label,
    job_number_label AS job_number_label,
    date_label AS date_label,
    site_label AS site_label,
    supervisor_label AS supervisor_label,
    level_label AS level_label,
    workplace_label AS workplace_label,
    no_images_label AS no_images_label,
    initial_images_label AS initial_images_label,
    followup_images_label AS followup_images_label,
    images_label AS images_label,
    report_distribution_label AS report_distribution_label
  FROM rmm_pra_general_action
    LEFT JOIN submission_general_action
      ON rmm_pra_general_action.rmm_pga_sga_id = submission_general_action.sga_id
    INNER JOIN submission_general_action_person
      ON submission_general_action.sga_id = submission_general_action_person.gap_sga_id
    INNER JOIN v_employee by_who
      ON submission_general_action_person.gap_per_id = by_who.per_id
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.id = submission_general_action.sga_submission_header_id
    LEFT JOIN SubmissionDetails
      ON SubmissionHeader.id = SubmissionDetails.SubmissionHeaderID
    LEFT JOIN v_employee supervisor
      ON SubmissionHeader.Supervisor = supervisor.per_id
    LEFT JOIN distribution_cte
      ON distribution_cte.SubmissionHeaderID = SubmissionDetails.SubmissionHeaderID
  WHERE rmm_pra_general_action.rmm_pga_pra_id = formSubmissionId
  AND submission_general_action.sga_enable = 1
  AND submission_general_action_person.gap_enable = 1
  GROUP BY submission_general_action_person.gap_sga_id;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_ora_hap`
--
DROP PROCEDURE IF EXISTS rpt_ora_hap;

DELIMITER $$

--
-- Create procedure `rpt_ora_hap`
--
CREATE PROCEDURE IF NOT EXISTS rpt_ora_hap (IN formSubmissionId int, IN language_id int)
BEGIN

  /* 

   Created by : Jaganjot Kaur
   Created On : 16th June 2021
   Purpose : Details for hazard actions for ORA

   Modified by : Brandon McKee
   Modified date : 2021-08-19
   Purpose : Corrected the subqueries to ref_list_detail to tie to the correct tag type

   Modified by : Jazmyn Zarichney
   Modified date : 2022-01-13
   Purpose : Replacing strings with tags SOF-10161

   Modified By: Jazmyn Zarichney
   Modified Date: 2022-05-18
   Description: Adding enable check on language translations (SOF-11119)

   Modified By: Pragati Das
   Modified Date: 2022-08-16
   Description: Updated the position with correct tag type  (SOF-11465)
   
   Modified By: Jazmyn Zarichney
   Modified Date: 2022-09-07
   Description: Updating the labels to use the language function (SOF-12027)
   
   Modified By: Pragati
   Modified Date: 2023-01-11
   Description: SOF-13279 - Updated SP to get one row from a subquery
  
   Modified By: Pragati Das
   Modified Date: 2023-03-31
   Description: SOF-13374 - Updated the SP with the AMA functionality 

   Modified By: Pragati Das
   Modified Date: 2023-07-17
   Description: SOF-14663 - Added case statement to get the HAP with 
    only immediate actions and distibution label.
 
   Modified By: Naveen Kumar Vadlamudi
   Modified Date: 2024-12-20
   Description: PD-2834 Distribution - Store per_id Instead of Email - Reports Changes

  */

  DECLARE hazard_action_label text;
  DECLARE hazard_type_label text;
  DECLARE hazard_identification_label text;
  DECLARE hazard_description_label text;
  DECLARE potential_loss_identification_label text;
  DECLARE potential_loss_label text;
  DECLARE actions_identification_immediate_label text;
  DECLARE was_immediate_action_required_performed_label text;
  DECLARE action_taken_label text;
  DECLARE action_type_label text;
  DECLARE further_action_required_label text;
  DECLARE actions_identification_followup_label text;
  DECLARE recommendation_label text;
  DECLARE by_who_label text;
  DECLARE by_when_label text;
  DECLARE action_status_label text;
  DECLARE action_completed_by_who_label text;
  DECLARE action_completed_by_label text;
  DECLARE completion_report_label text;
  DECLARE no_images_label text;
  DECLARE initial_images_label text;
  DECLARE followup_images_label text;
  DECLARE images_label text;
  DECLARE report_distribution_label text;

  SET hazard_action_label = get_translation(1999, language_id, 1);
  SET hazard_type_label = get_translation(514, language_id, 1);
  SET hazard_identification_label = get_translation(510, language_id, 1);
  SET hazard_description_label = get_translation(509, language_id, 1);
  SET potential_loss_identification_label = get_translation(2177, language_id, 1);
  SET potential_loss_label = get_translation(1144, language_id, 1);
  SET actions_identification_immediate_label = get_translation(1911, language_id, 1);
  SET was_immediate_action_required_performed_label = get_translation(889, language_id, 1);
  SET action_taken_label = get_translation(15, language_id, 1);
  SET action_type_label = get_translation(17, language_id, 1);
  SET further_action_required_label = get_translation(589, language_id, 1);
  SET actions_identification_followup_label = get_translation(1912, language_id, 1);
  SET recommendation_label = get_translation(1915, language_id, 1);
  SET by_who_label = get_translation(71, language_id, 1);
  SET by_when_label = get_translation(70, language_id, 1);
  SET action_status_label = get_translation(14, language_id, 1);
  SET action_completed_by_who_label = get_translation(89, language_id, 1);
  SET action_completed_by_label = get_translation(91, language_id, 1);
  SET completion_report_label = get_translation(1913, language_id, 1);
  SET no_images_label = get_translation(2075, language_id, 1);
  SET initial_images_label = get_translation(1914, language_id, 1);
  SET followup_images_label = get_translation(1917, language_id, 1);
  SET images_label = get_translation(1918, language_id, 1);
  SET report_distribution_label = get_translation(166, language_id, 1);

  WITH distribution_cte
  AS
  (SELECT
      SubmissionHeaderID,
      GROUP_CONCAT(DISTINCT CASE WHEN value LIKE 'account-%' THEN CONCAT(p1.per_last_name, IFNULL(p.per_middle_name, ' '), p1.per_first_name) WHEN value LIKE 'external-%' THEN CONCAT(e.edl_last_name, ' ', e.edl_first_name) WHEN value LIKE 'group-%' THEN CASE WHEN CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) IS NULL THEN CONCAT(edl.edl_first_name, ' ', edl.edl_last_name) ELSE CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) END ELSE value END SEPARATOR '; ') AS Distributors
    FROM SubmissionDetails_Explode
      JOIN SubmissionDetails
        ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
      JOIN FormFieldDescription
        ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
      LEFT JOIN person p1
        ON SUBSTRING_INDEX (value, '-', -1) = p1.per_id
        AND value LIKE 'account-%'
      LEFT JOIN external_distribution_list e
        ON SUBSTRING_INDEX (value, '-', -1) = e.edl_id
        AND value LIKE 'external-%'
      LEFT JOIN distribution_group_email dge
        ON SUBSTRING_INDEX (value, '-', -1) = dge.dge_dig_id
        AND dge.dge_enable = 1
        AND SubmissionDetails_Explode.value LIKE 'group-%'
      LEFT JOIN person AS p
        ON p.per_id = dge.dge_per_id
      LEFT JOIN external_distribution_list edl
        ON edl.edl_id = dge.dge_edl_id
    WHERE FormFieldDescription.fieldKey = 'Report_Distribution1'
    GROUP BY SubmissionHeaderID)


  SELECT
    SubmissionHAP.ID,
    SubmissionHAP.action_by_when AS followup_action_by_date,
    get_translation_from_ref_list_id(SubmissionHAP.immediate_action_type, 'ref_action_type', language_id) AS immediate_action_type,
    get_translation_from_ref_list_id(SubmissionHAP.action_type, 'ref_action_type', language_id) AS followup_action_type,
    SubmissionHAP.hazard_description AS HAP_description,
    SubmissionHAP.immediate_action_required_and_performed AS immediate_action_required_and_performed_flag,
    CASE WHEN SubmissionHAP.immediate_action_required_and_performed = 1 THEN (get_translation(1379, language_id, 1)) ELSE (get_translation(1380, language_id, 1)) END AS was_immediate_action_required_and_performed,
    SubmissionHAP.further_action_required AS further_action_required_flag,
    CASE WHEN SubmissionHAP.further_action_required = 1 THEN (get_translation(1379, language_id, 1)) ELSE (get_translation(1380, language_id, 1)) END AS was_further_action_required,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_tag_type = 1
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          MAX(ltr_tag)
        FROM language_translation
        WHERE ltr_text = action_status)) AS hazard_status,
    get_translation_from_ref_list_id(SubmissionHAP.hazard_identification, 'ref_hazard_identification', language_id) AS hazard_identification,
    get_translation_from_ref_list_id(SubmissionHAP.hazard_type, 'ref_hazard_type', language_id) AS hazard_type,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          rld_name
        FROM ref_list_detail
        WHERE rld_id = SubmissionHAP.potential_risk
        AND rld_tag_type = ltr_tag_type)) AS potential_risk,

    SubmissionHAP.recommended_action AS followup_recommended_action,
    SubmissionHAP.immediate_action_taken AS immediate_action_taken,

    IF(SubmissionHAP.sha_is_group_action IS NOT NULL,
    GROUP_CONCAT(by_who.per_full_name SEPARATOR '; '),
    by_who.per_full_name) AS by_who,
    distribution_cte.Distributors AS distribution_list,
    SubmissionHAP.sha_is_group_action,
    hazard_action_label AS hazard_action_label,
    hazard_type_label AS hazard_type_label,
    hazard_identification_label AS hazard_identification_label,
    hazard_description_label AS hazard_description_label,
    potential_loss_identification_label AS potential_loss_identification_label,
    potential_loss_label AS potential_loss_label,
    actions_identification_immediate_label AS actions_identification_immediate_label,
    was_immediate_action_required_performed_label AS was_immediate_action_required_performed_label,
    action_taken_label AS action_taken_label,
    action_type_label AS action_type_label,
    further_action_required_label AS further_action_required_label,
    actions_identification_followup_label AS actions_identification_followup_label,
    recommendation_label AS recommendation_label,
    by_who_label AS by_who_label,
    by_when_label AS by_when_label,
    action_status_label AS action_status_label,
    action_completed_by_who_label AS action_completed_by_who_label,
    action_completed_by_label AS action_completed_by_label,
    completion_report_label AS completion_report_label,
    no_images_label AS no_images_label,
    initial_images_label AS initial_images_label,
    followup_images_label AS followup_images_label,
    images_label AS images_label,
    report_distribution_label AS report_distribution_label
  FROM rmm_ora_hazard_action
    INNER JOIN SubmissionHAP
      ON rmm_ora_hazard_action.rmm_oha_sha_id = SubmissionHAP.ID
    LEFT JOIN submission_hazard_action_person
      ON SubmissionHAP.ID = submission_hazard_action_person.hap_sha_id
    LEFT JOIN v_employee by_who
      ON submission_hazard_action_person.hap_per_id = by_who.per_id
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.id = SubmissionHAP.SubmissionHeaderID
    LEFT JOIN SubmissionDetails
      ON SubmissionHeader.id = SubmissionDetails.SubmissionHeaderID
    LEFT JOIN distribution_cte
      ON distribution_cte.SubmissionHeaderID = SubmissionDetails.SubmissionHeaderID
  WHERE rmm_ora_hazard_action.rmm_oha_ora_id = formSubmissionId
  AND SubmissionHAP.sha_enable = 1
  AND CASE WHEN immediate_action_required_and_performed = 1 AND
      further_action_required = 0 THEN 1 = 1 ELSE submission_hazard_action_person.hap_enable = 1 END
  GROUP BY submission_hazard_action_person.hap_sha_id;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_ora_general_actions`
--
DROP PROCEDURE IF EXISTS rpt_ora_general_actions;

DELIMITER $$

--
-- Create procedure `rpt_ora_general_actions`
--
CREATE PROCEDURE IF NOT EXISTS rpt_ora_general_actions (IN formSubmissionId int, IN language_id int)
BEGIN

  /* 

     Created by : Jaganjot Kaur
     Created On : 16th June 2021
     Purpose : Details for General Actions for ORA
  
     Modified by : Brandon McKee
     Modified date : 2021-08-19
     Purpose : Corrected the subqueries to ref_list_detail to tie to the correct tag type
  
     Modified by : Jazmyn Zarichney
     Modified date : 2022-01-13
     Purpose : Replacing string with tags SOF-10161
  
     Modified By: Jazmyn Zarichney
     Modified Date: 2022-05-18
     Description: Adding enable check on language translations (SOF-11119)
     
     Modified By: Jazmyn Zarichney
     Modified Date: 2022-09-07
     Description: Updating the labels to use the language function (SOF-12027)
  
      
     Modified By: Pragati Das
     Modified Date: 2023-03-31
     Description: SOF-13374 - Updated the SP with the AMA functionality 
  
     Modified By: Naveen Kumar Vadlamudi
     Modified Date: 2024-12-20
     Description: PD-2834 Distribution - Store per_id Instead of Email - Reports Changes
  */
  DECLARE action_identification_label text;
  DECLARE general_action_label text;
  DECLARE action_type_label text;
  DECLARE by_who_label text;
  DECLARE by_when_label text;
  DECLARE recommended_action_label text;
  DECLARE action_completed_label text;
  DECLARE action_completed_by_label text;
  DECLARE action_completed_by_when_label text;
  DECLARE completed_action_taken_label text;
  DECLARE completed_action_type_label text;
  DECLARE job_number_label text;
  DECLARE date_label text;
  DECLARE site_label text;
  DECLARE supervisor_label text;
  DECLARE level_label text;
  DECLARE workplace_label text;
  DECLARE no_images_label text;
  DECLARE initial_images_label text;
  DECLARE followup_images_label text;
  DECLARE images_label text;
  DECLARE report_distribution_label text;

  SET action_identification_label = get_translation(2078, language_id, 1);
  SET general_action_label = get_translation(1039, language_id, 1);
  SET action_type_label = get_translation(17, language_id, 1);
  SET by_who_label = get_translation(71, language_id, 1);
  SET by_when_label = get_translation(70, language_id, 1);
  SET recommended_action_label = get_translation(773, language_id, 1);
  SET action_completed_label = get_translation(2026, language_id, 1);
  SET action_completed_by_label = get_translation(89, language_id, 1);
  SET action_completed_by_when_label = get_translation(91, language_id, 1);
  SET completed_action_taken_label = get_translation(2072, language_id, 1);
  SET completed_action_type_label = get_translation(2073, language_id, 1);
  SET job_number_label = get_translation(617, language_id, 1);
  SET date_label = get_translation(124, language_id, 1);
  SET site_label = get_translation(828, language_id, 1);
  SET supervisor_label = get_translation(844, language_id, 1);
  SET level_label = get_translation(8305, language_id, 1);
  SET workplace_label = get_translation(959, language_id, 1);
  SET no_images_label = get_translation(2075, language_id, 1);
  SET initial_images_label = get_translation(1914, language_id, 1);
  SET followup_images_label = get_translation(1917, language_id, 1);
  SET images_label = get_translation(1918, language_id, 1);
  SET report_distribution_label = get_translation(777, language_id, 1);


  WITH distribution_cte
  AS
  (SELECT
      SubmissionHeaderID,
      GROUP_CONCAT(DISTINCT CASE WHEN value LIKE 'account-%' THEN CONCAT(p1.per_last_name, IFNULL(p.per_middle_name, ' '), p1.per_first_name) WHEN value LIKE 'external-%' THEN CONCAT(e.edl_last_name, ' ', e.edl_first_name) WHEN value LIKE 'group-%' THEN CASE WHEN CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) IS NULL THEN CONCAT(edl.edl_first_name, ' ', edl.edl_last_name) ELSE CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) END ELSE value END SEPARATOR '; ') AS Distributors
    FROM SubmissionDetails_Explode
      JOIN SubmissionDetails
        ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
      JOIN FormFieldDescription
        ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
      LEFT JOIN person p1
        ON SUBSTRING_INDEX (value, '-', -1) = p1.per_id
        AND value LIKE 'account-%'
      LEFT JOIN external_distribution_list e
        ON SUBSTRING_INDEX (value, '-', -1) = e.edl_id
        AND value LIKE 'external-%'
      LEFT JOIN distribution_group_email dge
        ON SUBSTRING_INDEX (value, '-', -1) = dge.dge_dig_id
        AND dge.dge_enable = 1
        AND SubmissionDetails_Explode.value LIKE 'group-%'
      LEFT JOIN person AS p
        ON p.per_id = dge.dge_per_id
      LEFT JOIN external_distribution_list edl
        ON edl.edl_id = dge.dge_edl_id
    WHERE FormFieldDescription.fieldKey = 'Report_Distribution1'
    GROUP BY SubmissionHeaderID)

  SELECT
    submission_general_action.sga_submission_header_id,
    submission_general_action.sga_id,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          rld_name
        FROM ref_list_detail
        WHERE rld_id = submission_general_action.sga_action_type_rld_id
        AND rld_tag_type = ltr_tag_type)) AS action_type,
    IF(submission_general_action.sga_is_group_action = 1,
    GROUP_CONCAT(by_who.per_full_name SEPARATOR '; '),
    by_who.per_full_name) AS by_who,
    distribution_cte.Distributors AS distribution_list,
    submission_general_action.sga_action_by_when,
    submission_general_action.sga_recommended_action,
    submission_general_action.sga_action_is_complete,
    submission_general_action.sga_created_date,
    action_identification_label AS action_identification_label,
    general_action_label AS general_action_label,
    action_type_label AS action_type_label,
    by_who_label AS by_who_label,
    by_when_label AS by_when_label,
    recommended_action_label AS recommended_action_label,
    action_completed_label AS action_completed_label,
    action_completed_by_label AS action_completed_by_label,
    action_completed_by_when_label AS action_completed_by_when_label,
    completed_action_taken_label AS completed_action_taken_label,
    completed_action_type_label AS completed_action_type_label,
    job_number_label AS job_number_label,
    date_label AS date_label,
    site_label AS site_label,
    supervisor_label AS supervisor_label,
    level_label AS level_label,
    workplace_label AS workplace_label,
    no_images_label AS no_images_label,
    initial_images_label AS initial_images_label,
    followup_images_label AS followup_images_label,
    images_label AS images_label,
    report_distribution_label AS report_distribution_label
  FROM rmm_ora_general_action
    LEFT JOIN submission_general_action
      ON rmm_ora_general_action.rmm_oga_sga_id = submission_general_action.sga_id
    INNER JOIN submission_general_action_person
      ON submission_general_action.sga_id = submission_general_action_person.gap_sga_id
    INNER JOIN v_employee by_who
      ON submission_general_action_person.gap_per_id = by_who.per_id
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.id = submission_general_action.sga_submission_header_id
    LEFT JOIN SubmissionDetails
      ON SubmissionHeader.id = SubmissionDetails.SubmissionHeaderID
    LEFT JOIN v_employee supervisor
      ON SubmissionHeader.Supervisor = supervisor.per_id
    LEFT JOIN distribution_cte
      ON distribution_cte.SubmissionHeaderID = SubmissionDetails.SubmissionHeaderID
  WHERE rmm_ora_general_action.rmm_oga_ora_id = formSubmissionId
  AND submission_general_action.sga_enable = 1
  AND submission_general_action_person.gap_enable = 1
  GROUP BY submission_general_action_person.gap_sga_id;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_jra_hap`
--
DROP PROCEDURE IF EXISTS rpt_jra_hap;

DELIMITER $$

--
-- Create procedure `rpt_jra_hap`
--
CREATE PROCEDURE IF NOT EXISTS rpt_jra_hap (IN formSubmissionId int, IN language_id int)
BEGIN

  /* 

   Created by : Jaganjot Kaur
   Created On : 16th June 2021
   Purpose : Details for hazard actions for JRA

   Modified by : Brandon McKee
   Modified date : 2021-08-19
   Purpose : Corrected the subqueries to ref_list_detail to tie to the correct tag type

   Modified by : Jaganjot Kaur
   Modified date : 2021-09-03
   Purpose : Group concat returns a blank row when there is no data; adding a group by null to avoid that

   Modified By : Jaganjot Kaur
   Modified On : 8th Nov 2021
   Purpose : Adding the GROUP BY clause because we have added a GROUP concat

   Modified By : Jazmyn Zarichney
   Modified On : 2022-01-26
   Purpose : Replacing strings with language tags (SOF-10161)
   
   Modified By: Jazmyn Zarichney
   Modified Date: 2022-05-18
   Description: Adding enable check on language translations (SOF-11119)
   
   Modified By: Jazmyn Zarichney
   Modified Date: 2022-09-07
   Description: Updating the labels to use the language function (SOF-12027)
   
   Modified By: Pragati Das
   Modified Date: 2023-03-31
   Description: SOF-13374 - Updated the SP with the AMA functionality 

   Modified By: Pragati Das / Vishnu
   Modified Date: 2023-07-06
   Description: SOF-14655 - While dev testing, In JRA report, Hazard action with Immediate is not showing data in report.
 
   Modified By: Pragati Das
   Modified Date: 2023-08-03
   Description: SOF-14663 - Added distribution label

   Modified By: Naveen Kumar Vadlamudi
   Modified Date: 2024-12-20
   Description: PD-2834 Distribution - Store per_id Instead of Email - Reports Changes
 
 */

  DECLARE hazard_action_label text;
  DECLARE hazard_type_label text;
  DECLARE hazard_identification_label text;
  DECLARE hazard_description_label text;
  DECLARE potential_loss_identification_label text;
  DECLARE potential_loss_label text;
  DECLARE actions_identification_immediate_label text;
  DECLARE was_immediate_action_required_performed_label text;
  DECLARE action_taken_label text;
  DECLARE action_type_label text;
  DECLARE further_action_required_label text;
  DECLARE actions_identification_followup_label text;
  DECLARE recommendation_label text;
  DECLARE by_who_label text;
  DECLARE by_when_label text;
  DECLARE action_status_label text;
  DECLARE action_completed_by_who_label text;
  DECLARE action_completed_by_label text;
  DECLARE completion_report_label text;
  DECLARE no_images_label text;
  DECLARE initial_images_label text;
  DECLARE followup_images_label text;
  DECLARE images_label text;
  DECLARE report_distribution_label text;

  SET hazard_action_label = get_translation(1999, language_id, 1);
  SET hazard_type_label = get_translation(514, language_id, 1);
  SET hazard_identification_label = get_translation(510, language_id, 1);
  SET hazard_description_label = get_translation(509, language_id, 1);
  SET potential_loss_identification_label = get_translation(2177, language_id, 1);
  SET potential_loss_label = get_translation(1144, language_id, 1);
  SET actions_identification_immediate_label = get_translation(1911, language_id, 1);
  SET was_immediate_action_required_performed_label = get_translation(889, language_id, 1);
  SET action_taken_label = get_translation(15, language_id, 1);
  SET action_type_label = get_translation(17, language_id, 1);
  SET further_action_required_label = get_translation(589, language_id, 1);
  SET actions_identification_followup_label = get_translation(1912, language_id, 1);
  SET recommendation_label = get_translation(1915, language_id, 1);
  SET by_who_label = get_translation(71, language_id, 1);
  SET by_when_label = get_translation(70, language_id, 1);
  SET action_status_label = get_translation(14, language_id, 1);
  SET action_completed_by_who_label = get_translation(89, language_id, 1);
  SET action_completed_by_label = get_translation(91, language_id, 1);
  SET completion_report_label = get_translation(1913, language_id, 1);
  SET no_images_label = get_translation(2075, language_id, 1);
  SET initial_images_label = get_translation(1914, language_id, 1);
  SET followup_images_label = get_translation(1917, language_id, 1);
  SET images_label = get_translation(1918, language_id, 1);
  SET report_distribution_label = get_translation(166, language_id, 1);

  WITH distribution_cte
  AS
  (SELECT
      SubmissionHeaderID,
      GROUP_CONCAT(DISTINCT CASE WHEN value LIKE 'account-%' THEN CONCAT(p1.per_last_name, IFNULL(p.per_middle_name, ' '), p1.per_first_name) WHEN value LIKE 'external-%' THEN CONCAT(e.edl_last_name, ' ', e.edl_first_name) WHEN value LIKE 'group-%' THEN CASE WHEN CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) IS NULL THEN CONCAT(edl.edl_first_name, ' ', edl.edl_last_name) ELSE CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) END ELSE value END SEPARATOR '; ') AS Distributors
    FROM SubmissionDetails_Explode
      JOIN SubmissionDetails
        ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
      JOIN FormFieldDescription
        ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
      LEFT JOIN person p1
        ON SUBSTRING_INDEX (value, '-', -1) = p1.per_id
        AND value LIKE 'account-%'
      LEFT JOIN external_distribution_list e
        ON SUBSTRING_INDEX (value, '-', -1) = e.edl_id
        AND value LIKE 'external-%'
      LEFT JOIN distribution_group_email dge
        ON SUBSTRING_INDEX (value, '-', -1) = dge.dge_dig_id
        AND dge.dge_enable = 1
        AND SubmissionDetails_Explode.value LIKE 'group-%'
      LEFT JOIN person AS p
        ON p.per_id = dge.dge_per_id
      LEFT JOIN external_distribution_list edl
        ON edl.edl_id = dge.dge_edl_id
    WHERE FormFieldDescription.fieldKey = 'Report_Distribution1'
    GROUP BY SubmissionHeaderID)

  SELECT
    SubmissionHAP.ID,
    SubmissionHAP.action_by_when AS followup_action_by_date,
    get_translation_from_ref_list_id(SubmissionHAP.immediate_action_type, 'ref_action_type', language_id) AS immediate_action_type,
    get_translation_from_ref_list_id(SubmissionHAP.action_type, 'ref_action_type', language_id) AS followup_action_type,
    SubmissionHAP.hazard_description AS HAP_description,
    SubmissionHAP.immediate_action_required_and_performed AS immediate_action_required_and_performed_flag,
    CASE WHEN SubmissionHAP.immediate_action_required_and_performed = 1 THEN (get_translation(1379, language_id, 1)) ELSE (get_translation(1380, language_id, 1)) END AS was_immediate_action_required_and_performed,
    SubmissionHAP.further_action_required AS further_action_required_flag,
    CASE WHEN SubmissionHAP.further_action_required = 1 THEN (get_translation(1379, language_id, 1)) ELSE (get_translation(1380, language_id, 1)) END AS was_further_action_required,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_tag_type = 1
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          MAX(ltr_tag)
        FROM language_translation
        WHERE ltr_text = action_status)) AS hazard_status,
    get_translation_from_ref_list_id(SubmissionHAP.hazard_identification, 'ref_hazard_identification', language_id) AS hazard_identification,
    get_translation_from_ref_list_id(SubmissionHAP.hazard_type, 'ref_hazard_type', language_id) AS hazard_type,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          rld_name
        FROM ref_list_detail
        WHERE rld_id = SubmissionHAP.potential_risk
        AND rld_tag_type = ltr_tag_type)) AS potential_risk,

    SubmissionHAP.recommended_action AS followup_recommended_action,
    SubmissionHAP.immediate_action_taken AS immediate_action_taken,

    IF(SubmissionHAP.sha_is_group_action IS NOT NULL,
    GROUP_CONCAT(by_who.per_full_name SEPARATOR '; '),
    by_who.per_full_name) AS by_who,
    distribution_cte.Distributors AS distribution_list,
    SubmissionHAP.sha_is_group_action,
    hazard_action_label AS hazard_action_label,
    hazard_type_label AS hazard_type_label,
    hazard_identification_label AS hazard_identification_label,
    hazard_description_label AS hazard_description_label,
    potential_loss_identification_label AS potential_loss_identification_label,
    potential_loss_label AS potential_loss_label,
    actions_identification_immediate_label AS actions_identification_immediate_label,
    was_immediate_action_required_performed_label AS was_immediate_action_required_performed_label,
    action_taken_label AS action_taken_label,
    action_type_label AS action_type_label,
    further_action_required_label AS further_action_required_label,
    actions_identification_followup_label AS actions_identification_followup_label,
    recommendation_label AS recommendation_label,
    by_who_label AS by_who_label,
    by_when_label AS by_when_label,
    action_status_label AS action_status_label,
    action_completed_by_who_label AS action_completed_by_who_label,
    action_completed_by_label AS action_completed_by_label,
    completion_report_label AS completion_report_label,
    no_images_label AS no_images_label,
    initial_images_label AS initial_images_label,
    followup_images_label AS followup_images_label,
    images_label AS images_label,
    report_distribution_label AS report_distribution_label
  FROM rmm_jra_hazard_action
    INNER JOIN SubmissionHAP
      ON rmm_jra_hazard_action.rmm_jha_sha_id = SubmissionHAP.ID
    LEFT JOIN submission_hazard_action_person
      ON SubmissionHAP.ID = submission_hazard_action_person.hap_sha_id
    LEFT JOIN v_employee by_who
      ON submission_hazard_action_person.hap_per_id = by_who.per_id
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.id = SubmissionHAP.SubmissionHeaderID
    LEFT JOIN SubmissionDetails
      ON SubmissionHeader.id = SubmissionDetails.SubmissionHeaderID
    LEFT JOIN distribution_cte
      ON distribution_cte.SubmissionHeaderID = SubmissionDetails.SubmissionHeaderID
  WHERE rmm_jra_hazard_action.rmm_jha_jra_id = formSubmissionId
  AND SubmissionHAP.sha_enable = 1
  AND CASE WHEN immediate_action_required_and_performed = 1 AND
      further_action_required = 0 THEN 1 = 1 ELSE submission_hazard_action_person.hap_enable = 1 END
  GROUP BY submission_hazard_action_person.hap_sha_id;


END
$$

DELIMITER ;

--
-- Drop procedure `rpt_jra_general_actions`
--
DROP PROCEDURE IF EXISTS rpt_jra_general_actions;

DELIMITER $$

--
-- Create procedure `rpt_jra_general_actions`
--
CREATE PROCEDURE IF NOT EXISTS rpt_jra_general_actions (IN formSubmissionId int, IN language_id int)
BEGIN

  /* 

   Created by : Jaganjot Kaur
   Created On : 16th June 2021
   Purpose : Details for General Actions for JRA

   Modified by : Brandon McKee
   Modified date : 2021-08-19
   Purpose : Corrected the subqueries to ref_list_detail, making sure they tie to the correct tag type
   
   Modified by: Jazmyn Zarichney
   Modified date : 2022-01-26
   Purpose: Replacing strings with langauge tags (SOF-10161)
   
   Modified By: Jazmyn Zarichney
   Modified Date: 2022-05-18
   Description: Adding enable check on language translations (SOF-11119)
   
   Modified By: Jazmyn Zarichney
   Modified Date: 2022-09-07
   Description: Updating the labels to use the language function (SOF-12027)
       
  Modified By: Pragati Das
  Modified Date: 2023-03-31
  Description: SOF-13374 - Updated the SP with the AMA functionality 

  Modified By: Naveen Kumar Vadlamudi
  Modified Date: 2024-12-20
  Description: PD-2834 Distribution - Store per_id Instead of Email - Reports Changes
 
   */

  DECLARE action_identification_label text;
  DECLARE general_action_label text;
  DECLARE action_type_label text;
  DECLARE by_who_label text;
  DECLARE by_when_label text;
  DECLARE recommended_action_label text;
  DECLARE action_completed_label text;
  DECLARE action_completed_by_label text;
  DECLARE action_completed_by_when_label text;
  DECLARE completed_action_taken_label text;
  DECLARE completed_action_type_label text;
  DECLARE job_number_label text;
  DECLARE date_label text;
  DECLARE site_label text;
  DECLARE supervisor_label text;
  DECLARE level_label text;
  DECLARE workplace_label text;
  DECLARE no_images_label text;
  DECLARE initial_images_label text;
  DECLARE followup_images_label text;
  DECLARE images_label text;
  DECLARE report_distribution_label text;

  SET action_identification_label = get_translation(2078, language_id, 1);
  SET general_action_label = get_translation(1039, language_id, 1);
  SET action_type_label = get_translation(17, language_id, 1);
  SET by_who_label = get_translation(71, language_id, 1);
  SET by_when_label = get_translation(70, language_id, 1);
  SET recommended_action_label = get_translation(773, language_id, 1);
  SET action_completed_label = get_translation(2026, language_id, 1);
  SET action_completed_by_label = get_translation(89, language_id, 1);
  SET action_completed_by_when_label = get_translation(91, language_id, 1);
  SET completed_action_taken_label = get_translation(15, language_id, 1);
  SET completed_action_type_label = get_translation(17, language_id, 1);
  SET job_number_label = get_translation(617, language_id, 1);
  SET date_label = get_translation(124, language_id, 1);
  SET site_label = get_translation(828, language_id, 1);
  SET supervisor_label = get_translation(844, language_id, 1);
  SET level_label = get_translation(8305, language_id, 1);
  SET workplace_label = get_translation(959, language_id, 1);
  SET no_images_label = get_translation(2075, language_id, 1);
  SET initial_images_label = get_translation(1914, language_id, 1);
  SET followup_images_label = get_translation(1917, language_id, 1);
  SET images_label = get_translation(1918, language_id, 1);
  SET report_distribution_label = get_translation(777, language_id, 1);

  WITH distribution_cte
  AS
  (SELECT
      SubmissionHeaderID,
      GROUP_CONCAT(DISTINCT CASE WHEN value LIKE 'account-%' THEN CONCAT(p1.per_last_name, IFNULL(p.per_middle_name, ' '), p1.per_first_name) WHEN value LIKE 'external-%' THEN CONCAT(e.edl_last_name, ' ', e.edl_first_name) WHEN value LIKE 'group-%' THEN CASE WHEN CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) IS NULL THEN CONCAT(edl.edl_first_name, ' ', edl.edl_last_name) ELSE CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) END ELSE value END SEPARATOR '; ') AS Distributors
    FROM SubmissionDetails_Explode
      JOIN SubmissionDetails
        ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
      JOIN FormFieldDescription
        ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
      LEFT JOIN person p1
        ON SUBSTRING_INDEX (value, '-', -1) = p1.per_id
        AND value LIKE 'account-%'
      LEFT JOIN external_distribution_list e
        ON SUBSTRING_INDEX (value, '-', -1) = e.edl_id
        AND value LIKE 'external-%'
      LEFT JOIN distribution_group_email dge
        ON SUBSTRING_INDEX (value, '-', -1) = dge.dge_dig_id
        AND dge.dge_enable = 1
        AND SubmissionDetails_Explode.value LIKE 'group-%'
      LEFT JOIN person AS p
        ON p.per_id = dge.dge_per_id
      LEFT JOIN external_distribution_list edl
        ON edl.edl_id = dge.dge_edl_id
    WHERE FormFieldDescription.fieldKey = 'Report_Distribution1'
    GROUP BY SubmissionHeaderID)

  SELECT
    submission_general_action.sga_submission_header_id,
    submission_general_action.sga_id,

    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          rld_name
        FROM ref_list_detail
        WHERE rld_id = submission_general_action.sga_action_type_rld_id
        AND rld_tag_type = ltr_tag_type)) AS action_type,
    IF(submission_general_action.sga_is_group_action = 1,
    GROUP_CONCAT(by_who.per_full_name SEPARATOR '; '),
    by_who.per_full_name) AS by_who,
    distribution_cte.Distributors AS distribution_list,
    submission_general_action.sga_action_by_when,
    submission_general_action.sga_recommended_action,
    submission_general_action.sga_action_is_complete,
    submission_general_action.sga_created_date,
    action_identification_label AS action_identification_label,
    general_action_label AS general_action_label,
    action_type_label AS action_type_label,
    by_who_label AS by_who_label,
    by_when_label AS by_when_label,
    recommended_action_label AS recommended_action_label,
    action_completed_label AS action_completed_label,
    action_completed_by_label AS action_completed_by_label,
    action_completed_by_when_label AS action_completed_by_when_label,
    completed_action_taken_label AS completed_action_taken_label,
    completed_action_type_label AS completed_action_type_label,
    job_number_label AS job_number_label,
    date_label AS date_label,
    site_label AS site_label,
    supervisor_label AS supervisor_label,
    level_label AS level_label,
    workplace_label AS workplace_label,
    no_images_label AS no_images_label,
    initial_images_label AS initial_images_label,
    followup_images_label AS followup_images_label,
    images_label AS images_label,
    report_distribution_label AS report_distribution_label

  FROM rmm_jra_general_action
    LEFT JOIN submission_general_action
      ON rmm_jra_general_action.rmm_jga_sga_id = submission_general_action.sga_id
    INNER JOIN submission_general_action_person
      ON submission_general_action.sga_id = submission_general_action_person.gap_sga_id
    INNER JOIN v_employee by_who
      ON submission_general_action_person.gap_per_id = by_who.per_id
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.id = submission_general_action.sga_submission_header_id
    LEFT JOIN SubmissionDetails
      ON SubmissionHeader.id = SubmissionDetails.SubmissionHeaderID
    LEFT JOIN v_employee supervisor
      ON SubmissionHeader.Supervisor = supervisor.per_id
    LEFT JOIN distribution_cte
      ON distribution_cte.SubmissionHeaderID = SubmissionDetails.SubmissionHeaderID
  WHERE rmm_jra_general_action.rmm_jga_jra_id = formSubmissionId
  AND submission_general_action.sga_enable = 1
  AND submission_general_action_person.gap_enable = 1
  GROUP BY submission_general_action_person.gap_sga_id;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_injury_summary`
--
DROP PROCEDURE IF EXISTS rpt_injury_summary;

DELIMITER $$

--
-- Create procedure `rpt_injury_summary`
--
CREATE PROCEDURE IF NOT EXISTS rpt_injury_summary (IN site_ids text, IN start_date date, IN end_date date, IN lang int, IN job_ids text, IN incident_type_ids text)
BEGIN
  /*
  
     Created By: Naveen / Pragati Das
     Creation Date: 2024-09-24
     Description: PD-2579 - Created new SP for Injury Summary report

     Modified By: Naveen
     Modified Date: 2024-11-28
     Description: PD-2579 - Created new SP for Injury Summary report

    Modified By: James Coles / Pragati Das
    Modified Date: 2025-01-16
    Description:  PD-3209 - Use the column from the incidents table to get the minimum incident date.
     
  */

  DECLARE count_label text;
  DECLARE none_label text;
  SET none_label = get_translation(1075, lang, 1);
  SET count_label = get_translation(2047, lang, 1);


  WITH incident_type_cte
  AS
  (SELECT
      rld_id,
      ltr_text
    FROM ref_preliminary_incident_type
    WHERE FIND_IN_SET(rld_id, incident_type_ids)
    AND lng_id = lang),

  main_injury_data
  AS
  (SELECT
      -- data -- 
      main_inc.ID,
      main_inc.IncidentNumber,
      main_inc.inc_minimum_incident_date AS CreationDate,
      CASE WHEN (SELECT
              rld_enable
            FROM ref_list_detail
            WHERE ref_list_detail.rld_id = SubmissionHeader.Site) = 1 THEN get_translation_from_ref_list_id(SubmissionHeader.Site,
            'ref_site', lang) ELSE get_translation_from_ref_list_id(SubmissionHeader.Site, 'ref_site', lang) END AS Site, #Site
      (SELECT
          rld_enable
        FROM ref_list_detail
        WHERE ref_list_detail.rld_id = SubmissionHeader.Site) AS site_enable_status,
      (SELECT
          rld_code
        FROM ref_list_detail
        WHERE rld_id = SubmissionHeader.JobNumber) AS JobNumber,
      (SELECT
          rld_enable
        FROM ref_list_detail
        WHERE rld_id = SubmissionHeader.JobNumber) AS job_status,
      (SELECT
          value
        FROM IncidentSubmissions inc
          INNER JOIN SubmissionDetails sd
            ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
          INNER JOIN SubmissionDetails_Explode e
            ON e.SubmissionDetailID = sd.ID
          INNER JOIN FormFieldDescription ff
            ON e.FormFieldDescriptionID = ff.ID
          LEFT OUTER JOIN FormDescription fd
            ON ff.FormDescriptionID = fd.ID
        WHERE fd.ID = 1338
        AND ff.fieldKey = 'incident_short_description'
        AND IncidentID = main_inc.ID
        LIMIT 1) AS DESCRIPTION,
      count_label AS count_label,
      (SELECT
          value
        FROM IncidentSubmissions inc
          INNER JOIN SubmissionDetails sd
            ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
          INNER JOIN SubmissionDetails_Explode e
            ON e.SubmissionDetailID = sd.ID
          INNER JOIN FormFieldDescription ff
            ON e.FormFieldDescriptionID = ff.ID
          LEFT OUTER JOIN FormDescription fd
            ON ff.FormDescriptionID = fd.ID
        WHERE fd.ID = 1338
        AND ff.fieldKey = 'name_of_injury_person'
        AND IncidentID = main_inc.ID LIMIT 1) AS person_injured,

      CASE WHEN (SELECT
              COUNT(*)
            FROM RootCauseAnalysis
            WHERE RootCauseAnalysis.IncidentID = main_inc.ID
            AND RootCauseAnalysis.rca_aco_id IS NULL
            AND RootCauseAnalysis.ActualIncidentTypeDetailID IS NOT NULL) > 0 THEN (SELECT
                ltr_text
              FROM RootCauseAnalysis rca
                INNER JOIN ref_list_detail pt
                  ON rca.ActualIncidentTypeDetailID = pt.rld_id
                INNER JOIN language_translation lt
                  ON lt.ltr_tag = pt.rld_name
                  AND lt.ltr_tag_type = pt.rld_tag_type
              WHERE IncidentID = main_inc.ID
              AND rca.ActualIncidentTypeDetailID IS NOT NULL
              AND rca.rca_aco_id IS NULL
              AND ltr_lng_id = lang
              ORDER BY rca.ID DESC
              LIMIT 1) ELSE IF((SELECT
              COUNT(*)
            FROM IncidentSubmissions inc
              INNER JOIN SubmissionHeader
                ON inc.SubmissionHeaderID = SubmissionHeader.ID
              INNER JOIN FormDescription fd
                ON SubmissionHeader.FormDescriptionID = fd.ID
            WHERE fd.FormName = 1003
            AND IncidentID = main_inc.ID), (SELECT
              GROUP_CONCAT(DISTINCT get_actual_incident_type_detail_reverse_translation(value, lang))
            FROM IncidentSubmissions inc
              INNER JOIN SubmissionDetails sd
                ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
              INNER JOIN SubmissionDetails_Explode e
                ON e.SubmissionDetailID = sd.ID
              INNER JOIN FormFieldDescription ff
                ON e.FormFieldDescriptionID = ff.ID
              LEFT OUTER JOIN FormDescription fd
                ON ff.FormDescriptionID = fd.ID
            WHERE fd.ID = 1338
            AND ff.fieldKey = 'Incident_Type_Detail'
            AND IncidentID = main_inc.ID
            AND sd.ID = (SELECT
                MIN(sd.ID)
              FROM IncidentSubmissions inc
                INNER JOIN SubmissionDetails sd
                  ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
                INNER JOIN SubmissionDetails_Explode e
                  ON e.SubmissionDetailID = sd.ID
                INNER JOIN FormFieldDescription ff
                  ON e.FormFieldDescriptionID = ff.ID
                LEFT OUTER JOIN FormDescription fd
                  ON ff.FormDescriptionID = fd.ID
              WHERE IncidentID = main_inc.ID
              AND ff.fieldKey = 'Incident_Type_Detail')), get_translation(1075, lang, 1)) END AS incident_type_detail_value,

      (SELECT
          value
        FROM IncidentSubmissions inc
          INNER JOIN SubmissionDetails sd
            ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
          INNER JOIN SubmissionDetails_Explode e
            ON e.SubmissionDetailID = sd.ID
          INNER JOIN FormFieldDescription ff
            ON e.FormFieldDescriptionID = ff.ID
          LEFT OUTER JOIN FormDescription fd
            ON ff.FormDescriptionID = fd.ID
        WHERE fd.ID = 1338
        AND ff.fieldKey = 'incident_shift'
        AND IncidentID = main_inc.ID
        LIMIT 1) AS incident_shift,

      (SELECT
          value
        FROM IncidentSubmissions inc
          INNER JOIN SubmissionDetails sd
            ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
          INNER JOIN SubmissionDetails_Explode e
            ON e.SubmissionDetailID = sd.ID
          INNER JOIN FormFieldDescription ff
            ON e.FormFieldDescriptionID = ff.ID
          LEFT OUTER JOIN FormDescription fd
            ON ff.FormDescriptionID = fd.ID
        WHERE fd.ID = 1338
        AND ff.fieldKey = 'day_of_rotation'
        AND IncidentID = main_inc.ID
        LIMIT 1) AS day_of_rotation


    FROM Incidents main_inc
      LEFT JOIN v_incident_signoff_status
        ON main_inc.ID = v_incident_signoff_status.incident_id
      LEFT JOIN IncidentSubmissions
        ON IncidentSubmissions.IncidentID = main_inc.ID
      LEFT JOIN SubmissionHeader
        ON SubmissionHeader.ID = IncidentSubmissions.SubmissionHeaderID

    WHERE ((FIND_IN_SET(SubmissionHeader.JobNumber, job_ids) > 0)
    OR (SubmissionHeader.JobNumber IS NOT NULL
    AND job_ids IS NULL))
    AND ((FIND_IN_SET(SubmissionHeader.Site, site_ids) > 0)
    OR (SubmissionHeader.Site IS NOT NULL
    AND site_ids IS NULL))
    AND main_inc.inc_aco_id IS NULL
    AND get_min_header_date(main_inc.ID)
    BETWEEN start_date AND end_date
    GROUP BY main_inc.ID,
             main_inc.IncidentNumber),


  pre_filtering
  AS
  (SELECT
      *
    FROM (SELECT
        *,
        DENSE_RANK() OVER (PARTITION BY IncidentID ORDER BY ID DESC) AS drank
      FROM RootCauseAnalysis
      WHERE RootCauseAnalysis.IncidentID IN (SELECT
          ID
        FROM main_injury_data)
      AND RootCauseAnalysis.rca_aco_id IS NULL
      AND RootCauseAnalysis.ActualTypeID IS NOT NULL) AS res
    WHERE res.drank = 1),


  get_rca_data
  AS
  (SELECT
      ltr_text,
      IncidentID,
      rca.ActualTypeID AS ActualTypeID
    FROM (SELECT
        *
      FROM pre_filtering) rca
      INNER JOIN ref_list_detail pt
        ON rca.ActualTypeID = pt.rld_id
      INNER JOIN language_translation lt
        ON lt.ltr_tag = pt.rld_name
        AND lt.ltr_tag_type = pt.rld_tag_type
        AND lt.ltr_lng_id = lang),


  get_incident_data
  AS
  (SELECT
      *
    FROM get_rca_data
    UNION ALL
    SELECT
      *
    FROM (SELECT
        IFNULL(get_preliminary_incident_type_reverse_translation(value, lang), none_label) AS ltr_text,    -- tag 1075 - 'None'
        IncidentID,
        incident_type_cte.rld_id AS ActualTypeID
      FROM IncidentSubmissions inc
        INNER JOIN SubmissionDetails sd
          ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
        INNER JOIN SubmissionDetails_Explode e
          ON e.SubmissionDetailID = sd.ID
        INNER JOIN FormFieldDescription ff
          ON e.FormFieldDescriptionID = ff.ID
        LEFT OUTER JOIN FormDescription fd
          ON ff.FormDescriptionID = fd.ID
        INNER JOIN incident_type_cte
          ON incident_type_cte.ltr_text = e.value
      WHERE fd.ID = 1338
      AND ff.fieldKey = 'incident_type'
      AND (inc.IncidentID, sd.ID) IN (SELECT
          inc.IncidentID,
          MIN(sd.ID)
        FROM IncidentSubmissions inc
          INNER JOIN SubmissionDetails sd
            ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
          INNER JOIN SubmissionDetails_Explode e
            ON e.SubmissionDetailID = sd.ID
          INNER JOIN FormFieldDescription ff
            ON e.FormFieldDescriptionID = ff.ID
          LEFT OUTER JOIN FormDescription fd
            ON ff.FormDescriptionID = fd.ID
        WHERE ff.fieldKey = 'incident_type'
        AND inc.IncidentID IN (SELECT
            ID
          FROM main_injury_data)
        GROUP BY inc.IncidentID)) AS incident_result
    WHERE incident_result.IncidentID NOT IN (SELECT
        IncidentID
      FROM get_rca_data))



  SELECT
    mid.*,
    gid.ltr_text AS incident_type
  FROM main_injury_data AS mid
    LEFT JOIN get_incident_data AS gid
      ON mid.ID = gid.IncidentID
  WHERE gid.ActualTypeID IN (SELECT
      rld_id
    FROM incident_type_cte);



END
$$

DELIMITER ;

--
-- Drop procedure `rpt_incident_summary`
--
DROP PROCEDURE IF EXISTS rpt_incident_summary;

DELIMITER $$

--
-- Create procedure `rpt_incident_summary`
--
CREATE PROCEDURE IF NOT EXISTS rpt_incident_summary (IN site_ids text, IN start_date date, IN end_date date, IN lang int, IN job_ids text)
BEGIN
  /*
  
     Created By: Sarath Sontam
     Creation Date: 03 August 2021
     Description: Incident Summary for reports
     
     Change History
     Modified by : Sarath Sontam
     Modified on: 09 Sept 2021
     Reason: Modify queries to get count of Incident_statement, Preliminary_Incident, Preliminary_Investigation and Hazard_actions.
  
     Change History
     Modified by : Pragati Das
     Modified on: 24 Sept 2021
     Reason: Modified the SP to get boolean values for signoffs.

     Modified by : Jaganjot Kaur
     Modified on: 25 Nov 2021
     Reason: Added Job filter and label with TRIFR update

     Modified by : Pragati Das
     Modified on: 07 Jan 2022
     Reason: SOF-10154 - To update the incident information from the Incident Analysis and 
     if not found use the information from the Preliminary Incident Report. 

     Modified By: Jaganjot Kaur
     Modified Date: 14th Jan 2022
     Description: Incident Summary sign off numbers

     
     Modified By: Pragati Das
     Modified Date: 21th Jan 2022
     Description: Added enable = 1 for Incident Summary sign off numbers

     Modified By: Pragati Das
     Modified Date: 23rd March 2022
     Description: Applied optional filters 

     Modified By: Pragati Das/Vishnu 
     Modified Date: 18th April 2022
     Description: SOF-10965 Incident Summary Report - Days Open and Complete Status Not Reporting (numdays and SignedOffDate)

     Modified By: Pragati /Sarath 
     Modified Date: 03th May 2022
     Description: SOF-11169 Wesdome - Report - Incident Summary 
                  SOF-11098 Testmintomine - Incident Summary Report - 500 error
                  Added a subquery to fetch ltr_tag_type for RCA_Type
   
     Modified By: Jazmyn Zarichney
     Modified Date: 2022-05-18
     Description: Adding enable check on language translations (SOF-11119)
   
     Modified by: Jazmyn Zarichney 
     Modified date: 2022-07-14
     Purpose: Updating tag type and alias name for Incident Class (SOF-11690)
   
     Modified By: Jazmyn Zarichney
     Modified Date: 2022-09-07
     Description: Updating the labels to use the language function (SOF-12027)
   
     Modified By: Jazmyn Zarichney
     Modified Date: 2022-09-23
     Description: Adding site_enable_status and job_status (SOF-11458)

     Modified By: Sarath Sontam
     Modified Date: 2022-10-22
     Description: SOF-12611 - Get RCA_TYPE from incident_analysis if there is an rca for an Incident or get it from preliminary_investigation

     Modified By: Sarath Sontam
     Modified Date: 2022-10-24
     Description: SOF-12611 - check if incident's incidnet analysis has ActualTypeID for incidnet_type and IncidentTypeID for event_type.

     Modified By: Sarath Sontam
     Modified Date: 2022-10-25
     Description: SOF-12611 - check count of rca for an incident when ActulaTypeID and IncidentTypeID is not null

     Modified By: Pragati Das
     Modified Date: 2022-11-09
     Description: SOF-12737 - Added where clause for the job status column
     
     Modified By: Pragati Das
     Modified Date: 2023-04-13
     Description: SOF-13966 - Updated the WHERE clasue to convert date time to date
     
     Modified By: Pragati Das
     Modified Date: 2023-04-24
     Description: SOF-13966 - Updated the SP to display modified date for inactive sites
     
     Modified By: Pragati Das
     Modified Date: 2023-05-03
     Description: SOF-13967 - Updated the SP to filter the incidents with as per 
                  the first preliminary incident site value

     Modified By: Pragati Das
     Modified Date: 2023-08-21
     Description: SOF-14785 - Updated the SP with 2 new columns for 
                  new pie charts in Incident Summary report

     Modified By: James Coles/Suman Marlapudi/ Pragati Das
     Modified Date: 2023-08-21
     Description: SOF-15148 - Incident Summary - 
                  Show Incidents with Preliminary Investigation
    
     Modified By: Pragati Das
     Modified Date: 2023-10-24
     Description: SOF-13978 - Incident Summary - Removed the modified date from Site column

     Modified By: Sarath Sontam
     Modified Date: 2024-02-27
     Description: PD-339 - ignore archived Incidents - add condition inc_aco_id is null
     
     Modified By: Pragati Das
     Modified Date: 2024-03-06
     Description: PD-957 - Added potential loss column to display the pie chart
     
     Modified By: Pragati Das
     Modified Date: 2024-05-03
     Description: PD-1413 - Updated the SP with the reverse translation function

     Modified by : Sarath Sontam
     Modified on : 2024-05-15
     Change      : PD-1680 - Filter out archived RootCauseAnalysis/IncidentAnalysis (1.6)

     Modified by : Gowtham Ravindran
     Modified on : 2024-06-04
     Change      : PD-1680 - Changed the hard coded lang value to the input parameter lang value when we retrieve Incident Class

     Modified by : Gowtham Ravindran
     Modified on : 2024-08-27
     Change      : PD-2591 - Excluding archived Incident analysis
     
     Modified by : Pragati Das
     Modified on : 2024-09-25
     Change      : PD-2579 - Added additional fields

     Modified by: Shane Robinson, Naveen Kumar Vadlamudi
     Modified on: 2024-10-08
     Change: PD-2580 - Injury/Incident Summary Adjusted previously added fields for efficiency

     Modified By: James Coles / Pragati Das
     Modified Date: 2025-01-16
     Description:  PD-3209 - Use the column from the incidents table to get the minimum incident date.
 */

  DECLARE rowcount int;
  DECLARE rowcount1 int;
  DECLARE DELIMITTER varchar(20);
  DECLARE status_yes varchar(20);
  DECLARE status_no varchar(20);

  DECLARE incident_label text;
  DECLARE summary_label text;
  DECLARE created_label text;
  DECLARE completed_label text;
  DECLARE site_label text;
  DECLARE job_label text;
  DECLARE description_label text;
  DECLARE incident_class_label text;
  DECLARE rca_type_label text;
  DECLARE mgr_label text;
  DECLARE saf_label text;
  DECLARE jhsc_label text;
  DECLARE complete_label text;
  DECLARE days_label text;
  DECLARE type_label text;
  DECLARE forms_label text;
  DECLARE rca_label text;
  DECLARE ha_label text;
  DECLARE ga_label text;
  DECLARE pir_label text;
  DECLARE pinv_label text;
  DECLARE stmt_label text;
  DECLARE signoffs_label text;
  DECLARE yes_label text;
  DECLARE no_label text;
  DECLARE count_label text;

  SET incident_label = get_translation(1170, lang, 1);
  SET summary_label = get_translation(1311, lang, 1);
  SET created_label = get_translation(2035, lang, 1);
  SET completed_label = get_translation(1108, lang, 1);
  SET site_label = get_translation(828, lang, 1);
  SET job_label = get_translation(617, lang, 1);
  SET description_label = get_translation(143, lang, 1);
  SET incident_class_label = get_translation(9168, lang, 1);
  SET rca_type_label = get_translation(2048, lang, 1);
  SET mgr_label = get_translation(2043, lang, 1);
  SET saf_label = get_translation(2044, lang, 1);
  SET jhsc_label = get_translation(1724, lang, 1);
  SET complete_label = get_translation(2045, lang, 1);
  SET days_label = get_translation(1095, lang, 1);
  SET type_label = get_translation(1054, lang, 1);
  SET forms_label = get_translation(2036, lang, 1);
  SET rca_label = get_translation(2037, lang, 1);
  SET ha_label = get_translation(5664, lang, 1);
  SET ga_label = get_translation(2037, lang, 1);
  SET pir_label = get_translation(2039, lang, 1);
  SET pinv_label = get_translation(2040, lang, 1);
  SET stmt_label = get_translation(2037, lang, 1);
  SET signoffs_label = get_translation(2042, lang, 1);
  SET yes_label = get_translation(1379, lang, 1);
  SET no_label = get_translation(1380, lang, 1);
  SET count_label = get_translation(2047, lang, 1);

  SET status_yes := '';
  SET status_yes = get_translation(1379, lang, 1);


  SET status_no := '';
  SET status_no = get_translation(1380, lang, 1);

  SELECT
    -- labels --
    (SELECT
        lng_name
      FROM language
      WHERE lng_id = lang) AS language_code,
    incident_label AS incident_label,
    summary_label AS summary_label,
    created_label AS created_label,
    completed_label AS completed_label,
    site_label AS site_label,
    job_label AS job_label,
    description_label AS description_label,
    incident_class_label AS incident_class_label,
    rca_type_label AS rca_type_label,
    mgr_label AS mgr_label,
    saf_label AS saf_label,
    jhsc_label AS jhsc_label,
    complete_label AS complete_label,
    days_label AS days_label,
    type_label AS type_label,
    forms_label AS forms_label,
    rca_label AS rca_label,
    ha_label AS ha_label,
    ga_label AS ga_label,
    pir_label AS pir_label,
    pinv_label AS pinv_label,
    stmt_label AS stmt_label,
    signoffs_label AS signoffs_label,
    yes_label AS yes_label,
    no_label AS no_label,
    count_label AS count_label,
    -- data -- 
    main_inc.ID,
    main_inc.IncidentNumber,
    CASE WHEN v_incident_signoff_status.inc_is_quick_signoff = 1 THEN 1 ELSE (SELECT
            COUNT(*)
          FROM Incidents
            INNER JOIN incident_signoffs
              ON incident_signoffs.iso_incident_id = Incidents.ID
          WHERE Incidents.IncidentNumber = main_inc.IncidentNumber
          AND incident_signoffs.iso_enable = 1) END AS totalSignoff,
    CASE WHEN v_incident_signoff_status.inc_is_quick_signoff = 1 THEN 1 ELSE (SELECT
            SUM(CASE WHEN incident_signoffs.iso_per_id IS NOT NULL THEN 1 ELSE 0 END)
          FROM Incidents
            INNER JOIN incident_signoffs
              ON incident_signoffs.iso_incident_id = Incidents.ID
          WHERE Incidents.IncidentNumber = main_inc.IncidentNumber
          AND incident_signoffs.iso_enable = 1) END AS signedOffs,
    main_inc.inc_minimum_incident_date AS CreationDate,
    CASE WHEN (SELECT
            rld_enable
          FROM ref_list_detail
          WHERE ref_list_detail.rld_id = SubmissionHeader.Site) = 1 THEN get_translation_from_ref_list_id(SubmissionHeader.Site, 'ref_site', lang) ELSE get_translation_from_ref_list_id(SubmissionHeader.Site, 'ref_site', lang) END AS Site,
    (SELECT
        rld_enable
      FROM ref_list_detail
      WHERE ref_list_detail.rld_id = SubmissionHeader.Site) AS site_enable_status,
    (SELECT
        rld_code
      FROM ref_list_detail
      WHERE rld_id = SubmissionHeader.JobNumber) AS JobNumber,
    (SELECT
        rld_enable
      FROM ref_list_detail
      WHERE rld_id = SubmissionHeader.JobNumber) AS job_status,
    (SELECT
        value
      FROM IncidentSubmissions inc
        INNER JOIN SubmissionDetails sd
          ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
        INNER JOIN SubmissionDetails_Explode e
          ON e.SubmissionDetailID = sd.ID
        INNER JOIN FormFieldDescription ff
          ON e.FormFieldDescriptionID = ff.ID
        LEFT OUTER JOIN FormDescription fd
          ON ff.FormDescriptionID = fd.ID
      WHERE fd.FormName = 1003
      AND ff.fieldKey = 'incident_short_description'
      AND IncidentID = main_inc.ID
      LIMIT 1) AS DESCRIPTION,

    CASE WHEN (SELECT
            COUNT(*)
          FROM RootCauseAnalysis
          WHERE RootCauseAnalysis.IncidentID = main_inc.ID
          AND RootCauseAnalysis.rca_aco_id IS NULL
          AND RootCauseAnalysis.ActualTypeID IS NOT NULL) > 0 THEN (SELECT
              ltr_text
            FROM RootCauseAnalysis rca
              INNER JOIN v_ref_header_detail_list pt
                ON rca.ActualTypeID = pt.rld_id
              INNER JOIN language_translation lt
                ON lt.ltr_tag = pt.rld_name
                AND lt.ltr_tag_type = pt.rld_tag_type
            WHERE IncidentID = main_inc.ID
            AND rca.ActualTypeID IS NOT NULL
            AND rca.rca_aco_id IS NULL
            AND ltr_lng_id = lang
            ORDER BY rca.ID DESC
            LIMIT 1) ELSE (SELECT
            IFNULL(get_preliminary_incident_type_reverse_translation(value, lang), get_translation(1075, lang, 1)) AS value    -- tag 1075 - 'None'
          FROM IncidentSubmissions inc
            INNER JOIN SubmissionDetails sd
              ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
            INNER JOIN SubmissionDetails_Explode e
              ON e.SubmissionDetailID = sd.ID
            INNER JOIN FormFieldDescription ff
              ON e.FormFieldDescriptionID = ff.ID
            LEFT OUTER JOIN FormDescription fd
              ON ff.FormDescriptionID = fd.ID
          WHERE fd.ID = 1338
          AND ff.fieldKey = 'incident_type'
          AND IncidentID = main_inc.ID
          AND sd.ID = (SELECT
              MIN(sd.ID)
            FROM IncidentSubmissions inc
              INNER JOIN SubmissionDetails sd
                ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
              INNER JOIN SubmissionDetails_Explode e
                ON e.SubmissionDetailID = sd.ID
              INNER JOIN FormFieldDescription ff
                ON e.FormFieldDescriptionID = ff.ID
              LEFT OUTER JOIN FormDescription fd
                ON ff.FormDescriptionID = fd.ID
            WHERE IncidentID = main_inc.ID
            AND ff.fieldKey = 'incident_type')) END AS incidenttype,
    CASE WHEN (SELECT
            COUNT(*)
          FROM RootCauseAnalysis
          WHERE RootCauseAnalysis.IncidentID = main_inc.ID
          AND RootCauseAnalysis.rca_aco_id IS NULL
          AND RootCauseAnalysis.ActualTypeID IS NOT NULL) > 0 THEN (SELECT
              ltr_text
            FROM RootCauseAnalysis rca
              INNER JOIN v_ref_header_detail_list pt
                ON rca.PotentialLossID = pt.rld_id
              INNER JOIN language_translation lt
                ON lt.ltr_tag = pt.rld_name
                AND lt.ltr_tag_type = pt.rld_tag_type
            WHERE IncidentID = main_inc.ID
            AND rca.PotentialLossID IS NOT NULL
            AND rca.rca_aco_id IS NULL
            AND ltr_lng_id = lang
            ORDER BY rca.ID DESC
            LIMIT 1) ELSE get_translation(1075, lang, 1) END AS potential_loss,
    CASE WHEN (SELECT
            COUNT(*)
          FROM RootCauseAnalysis
          WHERE RootCauseAnalysis.IncidentID = main_inc.ID
          AND RootCauseAnalysis.rca_aco_id IS NULL
          AND RootCauseAnalysis.ActualIncidentTypeDetailID IS NOT NULL) > 0 THEN (SELECT
              ltr_text
            FROM RootCauseAnalysis rca
              INNER JOIN v_ref_header_detail_list pt
                ON rca.ActualIncidentTypeDetailID = pt.rld_id
              INNER JOIN language_translation lt
                ON lt.ltr_tag = pt.rld_name
                AND lt.ltr_tag_type = pt.rld_tag_type
            WHERE IncidentID = main_inc.ID
            AND rca.ActualIncidentTypeDetailID IS NOT NULL
            AND rca.rca_aco_id IS NULL
            AND ltr_lng_id = lang
            ORDER BY rca.ID DESC
            LIMIT 1) ELSE IF((SELECT
            COUNT(*)
          FROM IncidentSubmissions inc
            INNER JOIN SubmissionHeader
              ON inc.SubmissionHeaderID = SubmissionHeader.ID
            INNER JOIN FormDescription fd
              ON SubmissionHeader.FormDescriptionID = fd.ID
          WHERE fd.FormName = 1003
          AND IncidentID = main_inc.ID), (SELECT
            GROUP_CONCAT(DISTINCT get_actual_incident_type_detail_reverse_translation(value, lang))
          FROM IncidentSubmissions inc
            INNER JOIN SubmissionDetails sd
              ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
            INNER JOIN SubmissionDetails_Explode e
              ON e.SubmissionDetailID = sd.ID
            INNER JOIN FormFieldDescription ff
              ON e.FormFieldDescriptionID = ff.ID
            LEFT OUTER JOIN FormDescription fd
              ON ff.FormDescriptionID = fd.ID
          WHERE fd.ID = 1338
          AND ff.fieldKey = 'Incident_Type_Detail'
          AND IncidentID = main_inc.ID
          AND sd.ID = (SELECT
              MIN(sd.ID)
            FROM IncidentSubmissions inc
              INNER JOIN SubmissionDetails sd
                ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
              INNER JOIN SubmissionDetails_Explode e
                ON e.SubmissionDetailID = sd.ID
              INNER JOIN FormFieldDescription ff
                ON e.FormFieldDescriptionID = ff.ID
              LEFT OUTER JOIN FormDescription fd
                ON ff.FormDescriptionID = fd.ID
            WHERE IncidentID = main_inc.ID
            AND ff.fieldKey = 'Incident_Type_Detail')), get_translation(1075, lang, 1)) END AS incident_type_detail_value,
    IF((SELECT
        COUNT(*)
      FROM IncidentSubmissions inc
        INNER JOIN SubmissionHeader
          ON inc.SubmissionHeaderID = SubmissionHeader.ID
        INNER JOIN FormDescription fd
          ON SubmissionHeader.FormDescriptionID = fd.ID
      WHERE fd.FormName = 1003
      AND IncidentID = main_inc.ID), (SELECT
        GROUP_CONCAT(DISTINCT get_preliminary_incident_type_category_reverse_translation(value, lang))

      FROM IncidentSubmissions inc
        INNER JOIN SubmissionDetails sd
          ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
        INNER JOIN SubmissionDetails_Explode e
          ON e.SubmissionDetailID = sd.ID
        INNER JOIN FormFieldDescription ff
          ON e.FormFieldDescriptionID = ff.ID
        LEFT OUTER JOIN FormDescription fd
          ON ff.FormDescriptionID = fd.ID
      WHERE fd.ID = 1338
      AND ff.fieldKey = 'Incident_Type_Category'
      AND IncidentID = main_inc.ID
      AND sd.ID = (SELECT
          MIN(sd.ID)
        FROM IncidentSubmissions inc
          INNER JOIN SubmissionDetails sd
            ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
          INNER JOIN SubmissionDetails_Explode e
            ON e.SubmissionDetailID = sd.ID
          INNER JOIN FormFieldDescription ff
            ON e.FormFieldDescriptionID = ff.ID
          LEFT OUTER JOIN FormDescription fd
            ON ff.FormDescriptionID = fd.ID
        WHERE IncidentID = main_inc.ID
        AND ff.fieldKey = 'Incident_Type_Category')), get_translation(1075, lang, 1)) AS incident_type_category_value,
    CASE WHEN (SELECT
            COUNT(*)
          FROM RootCauseAnalysis
          WHERE RootCauseAnalysis.IncidentID = main_inc.ID
          AND RootCauseAnalysis.rca_aco_id IS NULL
          AND RootCauseAnalysis.IncidentTypeID IS NOT NULL) > 0 THEN (SELECT
              ltr_text
            FROM RootCauseAnalysis rca
              INNER JOIN v_ref_header_detail_list pt
                ON rca.IncidentTypeID = pt.rld_id
              INNER JOIN language_translation lt
                ON lt.ltr_tag = pt.rld_name
                AND lt.ltr_tag_type = pt.rld_tag_type
            WHERE IncidentID = main_inc.ID
            AND rca.IncidentTypeID IS NOT NULL
            AND rca.rca_aco_id IS NULL
            AND ltr_lng_id = lang
            ORDER BY rca.ID DESC
            LIMIT 1) ELSE (SELECT
            get_incident_type_reverse_translation(value, lang) AS value
          FROM IncidentSubmissions inc
            INNER JOIN SubmissionDetails sd
              ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
            INNER JOIN SubmissionDetails_Explode e
              ON e.SubmissionDetailID = sd.ID
            INNER JOIN FormFieldDescription ff
              ON e.FormFieldDescriptionID = ff.ID
            LEFT OUTER JOIN FormDescription fd
              ON ff.FormDescriptionID = fd.ID
          WHERE fd.ID = 1329
          AND ff.fieldKey = 'event_type'
          AND IncidentID = main_inc.ID
          ORDER BY inc.SubmissionHeaderID
          LIMIT 1) END AS RCATYPE,
    (SELECT
        COUNT(*)
      FROM RootCauseAnalysis
      WHERE RootCauseAnalysis.IncidentID = main_inc.ID
      AND RootCauseAnalysis.rca_aco_id IS NULL) AS rootcausecount,
    (SELECT
        FORMAT((SUM(immediate_action_required_and_performed) + SUM(further_action_required)), 0) AS haz
      FROM SubmissionHAP
        JOIN IncidentSubmissions
          ON IncidentSubmissions.SubmissionHeaderID = SubmissionHAP.SubmissionHeaderID
      WHERE IncidentSubmissions.IncidentID = main_inc.ID) AS hazardreports,
    (SELECT
        COUNT(*)
      FROM submission_general_action
        JOIN IncidentSubmissions
          ON IncidentSubmissions.SubmissionHeaderID = submission_general_action.sga_submission_header_id
      WHERE IncidentSubmissions.IncidentID = main_inc.ID) AS GeneralActions,
    (SELECT
        COUNT(*)
      FROM IncidentSubmissions inc
        INNER JOIN SubmissionHeader
          ON inc.SubmissionHeaderID = SubmissionHeader.ID
        INNER JOIN FormDescription fd
          ON SubmissionHeader.FormDescriptionID = fd.ID
      WHERE fd.FormName = 1003
      AND IncidentID = main_inc.ID) AS 'PRELIMINARY INCIDENT',
    (SELECT
        COUNT(*)
      FROM IncidentSubmissions inc
        INNER JOIN SubmissionHeader
          ON inc.SubmissionHeaderID = SubmissionHeader.ID
        INNER JOIN FormDescription fd
          ON SubmissionHeader.FormDescriptionID = fd.ID
      WHERE fd.FormName = 1002
      AND IncidentID = main_inc.ID) AS 'PRELIMINARY INVESTIGATION',
    (SELECT
        COUNT(*)
      FROM IncidentSubmissions inc
        INNER JOIN SubmissionHeader
          ON inc.SubmissionHeaderID = SubmissionHeader.ID
        INNER JOIN FormDescription fd
          ON SubmissionHeader.FormDescriptionID = fd.ID
      WHERE fd.FormName = 1004
      AND IncidentID = main_inc.ID) AS 'INCIDENT STATEMENT',
    (SELECT
        COUNT(1)
      FROM RootCauseAnalysis_BasicCause
        INNER JOIN RootCauseAnalysis
          ON RootCauseAnalysis.ID = RootCauseAnalysis_BasicCause.RootCauseAnalysisID
      WHERE RootCauseAnalysis.IncidentID = main_inc.ID
      AND RootCauseAnalysis.rca_aco_id IS NULL) AS RCAB,
    (SELECT
        COUNT(1)
      FROM RootCauseAnalysis_ImmediateCause
        INNER JOIN RootCauseAnalysis
          ON RootCauseAnalysis.ID = RootCauseAnalysis_ImmediateCause.RootCauseAnalysisID
      WHERE RootCauseAnalysis.IncidentID = main_inc.ID
      AND RootCauseAnalysis.rca_aco_id IS NULL) AS RCAI,

    IFNULL(CASE WHEN
        (DATEDIFF((CASE WHEN v_incident_signoff_status.inc_is_quick_signoff = 0 THEN (SELECT
                  iso_signoff_datetime
                FROM incident_signoffs
                WHERE iso_incident_id = main_inc.ID
                AND iso_enable = 1
                ORDER BY iso_signoff_datetime DESC LIMIT 1) ELSE (SELECT
                iqn_created_date
              FROM incident_quick_signoff_note
              WHERE iqn_incident_id = main_inc.ID
              AND iqn_enable = TRUE
              ORDER BY iqn_created_date DESC LIMIT 1) END), main_inc.CreationDate)) = 0 THEN 1 ELSE (DATEDIFF((CASE WHEN v_incident_signoff_status.inc_is_quick_signoff = 0 THEN (SELECT
                  iso_signoff_datetime
                FROM incident_signoffs
                WHERE iso_incident_id = main_inc.ID
                AND iso_enable = 1
                ORDER BY iso_signoff_datetime DESC LIMIT 1) ELSE (SELECT
                iqn_created_date
              FROM incident_quick_signoff_note
              WHERE iqn_incident_id = main_inc.ID
              AND iqn_enable = TRUE
              ORDER BY iqn_created_date DESC LIMIT 1) END), main_inc.CreationDate)) END, DATEDIFF(CURDATE(), main_inc.CreationDate)) AS numdays,


    (CASE WHEN v_incident_signoff_status.inc_is_quick_signoff = 0 THEN (SELECT
              iso_signoff_datetime
            FROM incident_signoffs
            WHERE iso_incident_id = main_inc.ID
            AND iso_enable = 1
            ORDER BY iso_signoff_datetime DESC LIMIT 1) ELSE (SELECT
            iqn_created_date
          FROM incident_quick_signoff_note
          WHERE iqn_incident_id = main_inc.ID
          AND iqn_enable = TRUE
          ORDER BY iqn_created_date DESC LIMIT 1) END
    ) AS SignedOffDate,

    DATEDIFF(CURRENT_DATE(),
    DATE((CASE WHEN v_incident_signoff_status.inc_is_quick_signoff = 0 THEN (SELECT
              iso_signoff_datetime
            FROM incident_signoffs
            WHERE iso_incident_id = main_inc.ID
            AND iso_enable = 1
            ORDER BY iso_signoff_datetime DESC LIMIT 1) ELSE (SELECT
            iqn_created_date
          FROM incident_quick_signoff_note
          WHERE iqn_incident_id = main_inc.ID
          AND iqn_enable = TRUE
          ORDER BY iqn_created_date DESC LIMIT 1) END
    ))) AS DaysCompleted,


    (SELECT
        value
      FROM IncidentSubmissions inc
        INNER JOIN SubmissionDetails sd
          ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
        INNER JOIN SubmissionDetails_Explode e
          ON e.SubmissionDetailID = sd.ID
        INNER JOIN FormFieldDescription ff
          ON e.FormFieldDescriptionID = ff.ID
        LEFT OUTER JOIN FormDescription fd
          ON ff.FormDescriptionID = fd.ID
      WHERE IncidentID = main_inc.ID
      AND fd.ID = 1338
      AND ff.fieldKey = 'day_of_rotation' LIMIT 1) AS dayOfRotation,
    (SELECT
        value
      FROM IncidentSubmissions inc
        INNER JOIN SubmissionDetails sd
          ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
        INNER JOIN SubmissionDetails_Explode e
          ON e.SubmissionDetailID = sd.ID
        INNER JOIN FormFieldDescription ff
          ON e.FormFieldDescriptionID = ff.ID
        LEFT OUTER JOIN FormDescription fd
          ON ff.FormDescriptionID = fd.ID
      WHERE IncidentID = main_inc.ID
      AND fd.ID = 1338
      AND ff.fieldKey = 'incident_shift' LIMIT 1) AS incidentShift,
    (SELECT
        value
      FROM IncidentSubmissions inc
        INNER JOIN SubmissionDetails sd
          ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
        INNER JOIN SubmissionDetails_Explode e
          ON e.SubmissionDetailID = sd.ID
        INNER JOIN FormFieldDescription ff
          ON e.FormFieldDescriptionID = ff.ID
        LEFT OUTER JOIN FormDescription fd
          ON ff.FormDescriptionID = fd.ID
      WHERE IncidentID = main_inc.ID
      AND fd.ID = 1338
      AND ff.fieldKey = 'incident_time' LIMIT 1) AS incidentTime,
    (SELECT
        value
      FROM IncidentSubmissions inc
        INNER JOIN SubmissionDetails sd
          ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
        INNER JOIN SubmissionDetails_Explode e
          ON e.SubmissionDetailID = sd.ID
        INNER JOIN FormFieldDescription ff
          ON e.FormFieldDescriptionID = ff.ID
        LEFT OUTER JOIN FormDescription fd
          ON ff.FormDescriptionID = fd.ID
      WHERE IncidentID = main_inc.ID
      AND fd.ID = 1338
      AND ff.fieldKey = 'shift_schedule' LIMIT 1) AS shiftschedule,


    CASE WHEN (SELECT
            value
          FROM IncidentSubmissions inc
            INNER JOIN SubmissionDetails sd
              ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
            INNER JOIN SubmissionDetails_Explode e
              ON e.SubmissionDetailID = sd.ID
            INNER JOIN FormFieldDescription ff
              ON e.FormFieldDescriptionID = ff.ID
            LEFT OUTER JOIN FormDescription fd
              ON ff.FormDescriptionID = fd.ID
          WHERE IncidentID = main_inc.ID
          AND fd.ID = 1329
          AND ff.fieldKey = 'investigator_1' LIMIT 1) IS NOT NULL THEN yes_label ELSE no_label END AS jhsc_involved,

    v_employee.per_full_name AS incident_created_by,
    DATE(main_inc.CreationDate) AS incCreationDate,
    get_translated_day_of_week(DATE(main_inc.CreationDate), lang) AS dow

  FROM Incidents main_inc
    LEFT JOIN v_incident_signoff_status
      ON main_inc.ID = v_incident_signoff_status.incident_id
    LEFT JOIN IncidentSubmissions
      ON IncidentSubmissions.IncidentID = main_inc.ID
    LEFT JOIN v_employee
      ON main_inc.CreatedBy = v_employee.per_id
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.ID = IncidentSubmissions.SubmissionHeaderID
  WHERE ((FIND_IN_SET(SubmissionHeader.JobNumber, job_ids) > 0)
  OR (SubmissionHeader.JobNumber IS NOT NULL
  AND job_ids IS NULL))
  AND ((FIND_IN_SET(SubmissionHeader.Site, site_ids) > 0)
  OR (SubmissionHeader.Site IS NOT NULL
  AND site_ids IS NULL))
  AND main_inc.inc_aco_id IS NULL
  AND get_min_header_date(main_inc.ID)
  BETWEEN start_date AND end_date
  GROUP BY main_inc.ID,
           main_inc.IncidentNumber;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_get_lesson_learned_hazard_actions_by_id`
--
DROP PROCEDURE IF EXISTS rpt_get_lesson_learned_hazard_actions_by_id;

DELIMITER $$

--
-- Create procedure `rpt_get_lesson_learned_hazard_actions_by_id`
--
CREATE PROCEDURE IF NOT EXISTS rpt_get_lesson_learned_hazard_actions_by_id (IN llm_id int, IN language_id int)
BEGIN

  /*
  Created By: Jaganjot Kaur
  Creation Date: 4th June 2021
  Description: Get details for hazard action list by llm_id
 
  Modified by : Brandon McKee
  Modified date : 2021-08-19
  Purpose :  Corrected the subqueries to ref_list_detail to tie to the correct tag type
   
  Modified by : Jazmyn Zarichney
  Modified date : 2022-01-24
  Purpose : Replacing strings with language tags (SOF-10161)
 
  Modified by: Pragati 
  Modified date: 05th May 2022
  Purpose: SOF-11117 - Add ENABLE Check on Language Translations

  Modified By: Jazmyn Zarichney
  Modified Date: 2022-08-16
  Description: Updating hard coded ltr_tag_types (SOF-11465)
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-09-02
  Description: Updating the labels to use the language function (SOF-12027)

   Modified By: Pragati Das
   Modified Date: 2023-03-31
   Description: SOF-13374 - Updated the SP with the AMA functionality 

   Modified By: Pragati Das
   Modified Date: 2023-08-04
   Description: SOF-14663 - Updated the SP with distribution label 

   Modified By: Pragati Das
   Modified Date: 2023-08-08
   Description: SOF-14663 - Updated the SP with case statement

    Modified By: Naveen Kumar Vadlamudi
    Modified Date: 2024-12-20
    Description: PD-2834 Distribution - Store per_id Instead of Email - Reports Changes

*/


  DECLARE hazard_action_label text;
  DECLARE hazard_type_label text;
  DECLARE hazard_identification_label text;
  DECLARE hazard_description_label text;
  DECLARE potential_loss_identification_label text;
  DECLARE potential_loss_label text;
  DECLARE actions_identification_immediate_label text;
  DECLARE was_immediate_action_required_performed_label text;
  DECLARE action_taken_label text;
  DECLARE action_type_label text;
  DECLARE further_action_required_label text;
  DECLARE actions_identification_followup_label text;
  DECLARE recommendation_label text;
  DECLARE by_who_label text;
  DECLARE by_when_label text;
  DECLARE action_status_label text;
  DECLARE action_completed_by_who_label text;
  DECLARE action_completed_by_label text;
  DECLARE completion_report_label text;
  DECLARE no_images_label text;
  DECLARE initial_images_label text;
  DECLARE followup_images_label text;
  DECLARE images_label text;
  DECLARE report_distribution_label text;


  SET hazard_action_label = get_translation(1999, language_id, 1);
  SET hazard_type_label = get_translation(514, language_id, 1);
  SET hazard_identification_label = get_translation(510, language_id, 1);
  SET hazard_description_label = get_translation(509, language_id, 1);
  SET potential_loss_identification_label = get_translation(2177, language_id, 1);
  SET potential_loss_label = get_translation(1144, language_id, 1);
  SET actions_identification_immediate_label = get_translation(1911, language_id, 1);
  SET was_immediate_action_required_performed_label = get_translation(889, language_id, 1);
  SET action_taken_label = get_translation(15, language_id, 1);
  SET action_type_label = get_translation(17, language_id, 1);
  SET further_action_required_label = get_translation(589, language_id, 1);
  SET actions_identification_followup_label = get_translation(1912, language_id, 1);
  SET recommendation_label = get_translation(1915, language_id, 1);
  SET by_who_label = get_translation(71, language_id, 1);
  SET by_when_label = get_translation(70, language_id, 1);
  SET action_status_label = get_translation(14, language_id, 1);
  SET action_completed_by_who_label = get_translation(89, language_id, 1);
  SET action_completed_by_label = get_translation(91, language_id, 1);
  SET completion_report_label = get_translation(1913, language_id, 1);
  SET no_images_label = get_translation(2075, language_id, 1);
  SET initial_images_label = get_translation(1914, language_id, 1);
  SET followup_images_label = get_translation(1917, language_id, 1);
  SET images_label = get_translation(1918, language_id, 1);
  SET report_distribution_label = get_translation(166, language_id, 1);

  WITH distribution_cte
  AS
  (SELECT
      SubmissionHeaderID,
      GROUP_CONCAT(DISTINCT CASE WHEN value LIKE 'account-%' THEN CONCAT(p1.per_last_name, IFNULL(p.per_middle_name, ' '), p1.per_first_name) WHEN value LIKE 'external-%' THEN CONCAT(e.edl_last_name, ' ', e.edl_first_name) WHEN value LIKE 'group-%' THEN CASE WHEN CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) IS NULL THEN CONCAT(edl.edl_first_name, ' ', edl.edl_last_name) ELSE CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) END ELSE value END SEPARATOR '; ') AS Distributors
    FROM SubmissionDetails_Explode
      JOIN SubmissionDetails
        ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
      JOIN FormFieldDescription
        ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
      LEFT JOIN person p1
        ON SUBSTRING_INDEX (value, '-', -1) = p1.per_id
        AND value LIKE 'account-%'
      LEFT JOIN external_distribution_list e
        ON SUBSTRING_INDEX (value, '-', -1) = e.edl_id
        AND value LIKE 'external-%'
      LEFT JOIN distribution_group_email dge
        ON SUBSTRING_INDEX (value, '-', -1) = dge.dge_dig_id
        AND dge.dge_enable = 1
        AND SubmissionDetails_Explode.value LIKE 'group-%'
      LEFT JOIN person AS p
        ON p.per_id = dge.dge_per_id
      LEFT JOIN external_distribution_list edl
        ON edl.edl_id = dge.dge_edl_id
    WHERE FormFieldDescription.fieldKey = 'Report_Distribution1'
    GROUP BY SubmissionHeaderID)

  SELECT
    SubmissionHAP.ID,
    SubmissionHAP.action_by_when AS followup_action_by_date,
    get_translation_from_ref_list_id(SubmissionHAP.immediate_action_type, 'ref_action_type', language_id) AS immediate_action_type,
    get_translation_from_ref_list_id(SubmissionHAP.action_type, 'ref_action_type', language_id) AS followup_action_type,
    SubmissionHAP.hazard_description AS HAP_description,
    SubmissionHAP.immediate_action_required_and_performed AS immediate_action_required_and_performed_flag,
    CASE WHEN SubmissionHAP.immediate_action_required_and_performed = 1 THEN (get_translation(1379, language_id, 1)) ELSE (get_translation(1380, language_id, 1)) END AS was_immediate_action_required_and_performed,
    SubmissionHAP.further_action_required AS further_action_required_flag,
    CASE WHEN SubmissionHAP.further_action_required = 1 THEN (get_translation(1379, language_id, 1)) ELSE (get_translation(1380, language_id, 1)) END AS was_further_action_required,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_tag_type = 1
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          MAX(ltr_tag)
        FROM language_translation
        WHERE ltr_text = action_status)) AS hazard_status,
    get_translation_from_ref_list_id(SubmissionHAP.hazard_identification, 'ref_hazard_identification', language_id) AS hazard_identification,
    get_translation_from_ref_list_id(SubmissionHAP.hazard_type, 'ref_hazard_type', language_id) AS hazard_type,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          rld_name
        FROM ref_list_detail
        WHERE rld_id = SubmissionHAP.potential_risk
        AND rld_tag_type = ltr_tag_type)) AS potential_risk,

    SubmissionHAP.recommended_action AS followup_recommended_action,
    SubmissionHAP.immediate_action_taken AS immediate_action_taken,

    IF(SubmissionHAP.sha_is_group_action IS NOT NULL,
    GROUP_CONCAT(by_who.per_full_name SEPARATOR '; '),
    by_who.per_full_name) AS by_who,
    distribution_cte.Distributors AS distribution_list,
    SubmissionHAP.sha_is_group_action,
    hazard_action_label AS hazard_action_label,
    hazard_type_label AS hazard_type_label,
    hazard_identification_label AS hazard_identification_label,
    hazard_description_label AS hazard_description_label,
    potential_loss_identification_label AS potential_loss_identification_label,
    potential_loss_label AS potential_loss_label,
    actions_identification_immediate_label AS actions_identification_immediate_label,
    was_immediate_action_required_performed_label AS was_immediate_action_required_performed_label,
    action_taken_label AS action_taken_label,
    action_type_label AS action_type_label,
    further_action_required_label AS further_action_required_label,
    actions_identification_followup_label AS actions_identification_followup_label,
    recommendation_label AS recommendation_label,
    by_who_label AS by_who_label,
    by_when_label AS by_when_label,
    action_status_label AS action_status_label,
    action_completed_by_who_label AS action_completed_by_who_label,
    action_completed_by_label AS action_completed_by_label,
    completion_report_label AS completion_report_label,
    no_images_label AS no_images_label,
    initial_images_label AS initial_images_label,
    followup_images_label AS followup_images_label,
    images_label AS images_label,
    report_distribution_label AS report_distribution_label
  FROM lesson_learned_hazard_action
    INNER JOIN SubmissionHAP
      ON lesson_learned_hazard_action.llh_sha_id = SubmissionHAP.ID
    LEFT JOIN submission_hazard_action_person
      ON SubmissionHAP.ID = submission_hazard_action_person.hap_sha_id
    LEFT JOIN v_employee by_who
      ON submission_hazard_action_person.hap_per_id = by_who.per_id
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.id = SubmissionHAP.SubmissionHeaderID
    LEFT JOIN SubmissionDetails
      ON SubmissionHeader.id = SubmissionDetails.SubmissionHeaderID
    LEFT JOIN distribution_cte
      ON distribution_cte.SubmissionHeaderID = SubmissionDetails.SubmissionHeaderID

  WHERE lesson_learned_hazard_action.llh_llm_id = llm_id
  AND SubmissionHAP.sha_enable = 1
  AND CASE WHEN immediate_action_required_and_performed = 1 AND
      further_action_required = 0 THEN 1 = 1 ELSE submission_hazard_action_person.hap_enable = 1 END
  GROUP BY submission_hazard_action_person.hap_sha_id;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_get_lesson_learned_general_actions_by_id`
--
DROP PROCEDURE IF EXISTS rpt_get_lesson_learned_general_actions_by_id;

DELIMITER $$

--
-- Create procedure `rpt_get_lesson_learned_general_actions_by_id`
--
CREATE PROCEDURE IF NOT EXISTS rpt_get_lesson_learned_general_actions_by_id (IN llm_id int, IN language_id int)
BEGIN

  /*
  Created By: Jaganjot Kaur
  Creation Date: 4th June 2021
  Description: Get details for general action list by llm_id

  Modified By: Brandon McKee
  Modified Date: 2021-08-19
  Description: Corrected the subqueries to ref_list_detail to tie to the correct tag type
  
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-01-24
  Description: Replacing strings with language tags (SOF-10161)

  Modified by: Pragati 
  Modified date: 05th May 2022
  Purpose: SOF-11117 - Add ENABLE Check on Language Translations
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-08-30
  Description: Updating the labels to use the language function (SOF-12027)

  Modified By: Pragati Das
  Modified Date: 2023-03-31
  Description: SOF-13374 - Updated the SP with the AMA functionality 

  Modified By: Naveen Kumar Vadlamudi
  Modified Date: 2024-12-20
  Description: PD-2834 Distribution - Store per_id Instead of Email - Reports Changes

*/

  DECLARE action_identification_label text;
  DECLARE general_action_label text;
  DECLARE action_type_label text;
  DECLARE by_who_label text;
  DECLARE by_when_label text;
  DECLARE recommended_action_label text;
  DECLARE action_completed_label text;
  DECLARE action_completed_by_label text;
  DECLARE action_completed_by_when_label text;
  DECLARE completed_action_taken_label text;
  DECLARE completed_action_type_label text;
  DECLARE job_number_label text;
  DECLARE date_label text;
  DECLARE site_label text;
  DECLARE supervisor_label text;
  DECLARE level_label text;
  DECLARE workplace_label text;
  DECLARE no_images_label text;
  DECLARE initial_images_label text;
  DECLARE followup_images_label text;
  DECLARE images_label text;
  DECLARE report_distribution_label text;

  SET action_identification_label = get_translation(2078, language_id, 1);
  SET general_action_label = get_translation(1039, language_id, 1);
  SET action_type_label = get_translation(17, language_id, 1);
  SET by_who_label = get_translation(71, language_id, 1);
  SET by_when_label = get_translation(70, language_id, 1);
  SET recommended_action_label = get_translation(773, language_id, 1);
  SET action_completed_label = get_translation(2026, language_id, 1);
  SET action_completed_by_label = get_translation(89, language_id, 1);
  SET action_completed_by_when_label = get_translation(91, language_id, 1);
  SET completed_action_taken_label = get_translation(2072, language_id, 1);
  SET completed_action_type_label = get_translation(2073, language_id, 1);
  SET job_number_label = get_translation(617, language_id, 1);
  SET date_label = get_translation(124, language_id, 1);
  SET site_label = get_translation(828, language_id, 1);
  SET supervisor_label = get_translation(844, language_id, 1);
  SET level_label = get_translation(8305, language_id, 1);
  SET workplace_label = get_translation(959, language_id, 1);
  SET no_images_label = get_translation(2075, language_id, 1);
  SET initial_images_label = get_translation(1914, language_id, 1);
  SET followup_images_label = get_translation(1917, language_id, 1);
  SET images_label = get_translation(1918, language_id, 1);
  SET report_distribution_label = get_translation(777, language_id, 1);

  WITH distribution_cte
  AS
  (SELECT
      SubmissionHeaderID,
      GROUP_CONCAT(DISTINCT CASE WHEN value LIKE 'account-%' THEN CONCAT(p1.per_last_name, IFNULL(p.per_middle_name, ' '), p1.per_first_name) WHEN value LIKE 'external-%' THEN CONCAT(e.edl_last_name, ' ', e.edl_first_name) WHEN value LIKE 'group-%' THEN CASE WHEN CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) IS NULL THEN CONCAT(edl.edl_first_name, ' ', edl.edl_last_name) ELSE CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) END ELSE value END SEPARATOR '; ') AS Distributors
    FROM SubmissionDetails_Explode
      JOIN SubmissionDetails
        ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
      JOIN FormFieldDescription
        ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
      LEFT JOIN person p1
        ON SUBSTRING_INDEX (value, '-', -1) = p1.per_id
        AND value LIKE 'account-%'
      LEFT JOIN external_distribution_list e
        ON SUBSTRING_INDEX (value, '-', -1) = e.edl_id
        AND value LIKE 'external-%'
      LEFT JOIN distribution_group_email dge
        ON SUBSTRING_INDEX (value, '-', -1) = dge.dge_dig_id
        AND dge.dge_enable = 1
        AND SubmissionDetails_Explode.value LIKE 'group-%'
      LEFT JOIN person AS p
        ON p.per_id = dge.dge_per_id
      LEFT JOIN external_distribution_list edl
        ON edl.edl_id = dge.dge_edl_id
    WHERE FormFieldDescription.fieldKey = 'Report_Distribution1'
    GROUP BY SubmissionHeaderID)

  SELECT
    submission_general_action.sga_submission_header_id,
    submission_general_action.sga_id,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          rld_name
        FROM ref_list_detail
        WHERE rld_id = submission_general_action.sga_action_type_rld_id
        AND rld_tag_type = ltr_tag_type)) AS action_type,
    IF(submission_general_action.sga_is_group_action = 1,
    GROUP_CONCAT(by_who.per_full_name SEPARATOR '; '),
    by_who.per_full_name) AS by_who,
    distribution_cte.Distributors AS distribution_list,
    submission_general_action.sga_action_by_when,
    submission_general_action.sga_recommended_action,
    submission_general_action.sga_action_is_complete,
    submission_general_action.sga_created_date,
    action_identification_label AS action_identification_label,
    general_action_label AS general_action_label,
    action_type_label AS action_type_label,
    by_who_label AS by_who_label,
    by_when_label AS by_when_label,
    recommended_action_label AS recommended_action_label,
    action_completed_label AS action_completed_label,
    action_completed_by_label AS action_completed_by_label,
    action_completed_by_when_label AS action_completed_by_when_label,
    completed_action_taken_label AS completed_action_taken_label,
    completed_action_type_label AS completed_action_type_label,
    job_number_label AS job_number_label,
    date_label AS date_label,
    site_label AS site_label,
    supervisor_label AS supervisor_label,
    level_label AS level_label,
    workplace_label AS workplace_label,
    no_images_label AS no_images_label,
    initial_images_label AS initial_images_label,
    followup_images_label AS followup_images_label,
    images_label AS images_label,
    report_distribution_label AS report_distribution_label
  FROM lesson_learned_general_action
    LEFT JOIN submission_general_action
      ON lesson_learned_general_action.llg_sga_id = submission_general_action.sga_id
    INNER JOIN submission_general_action_person
      ON submission_general_action.sga_id = submission_general_action_person.gap_sga_id
    INNER JOIN v_employee by_who
      ON submission_general_action_person.gap_per_id = by_who.per_id
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.id = submission_general_action.sga_submission_header_id
    LEFT JOIN SubmissionDetails
      ON SubmissionHeader.id = SubmissionDetails.SubmissionHeaderID
    LEFT JOIN distribution_cte
      ON distribution_cte.SubmissionHeaderID = SubmissionDetails.SubmissionHeaderID
    LEFT JOIN v_employee supervisor
      ON SubmissionHeader.supervisor = supervisor.per_id
  WHERE lesson_learned_general_action.llg_llm_id = llm_id
  AND submission_general_action.sga_enable = 1
  AND submission_general_action_person.gap_enable = 1
  GROUP BY submission_general_action_person.gap_sga_id;


END
$$

DELIMITER ;

--
-- Drop procedure `rpt_get_decision_log_hazard_actions`
--
DROP PROCEDURE IF EXISTS rpt_get_decision_log_hazard_actions;

DELIMITER $$

--
-- Create procedure `rpt_get_decision_log_hazard_actions`
--
CREATE PROCEDURE IF NOT EXISTS rpt_get_decision_log_hazard_actions (IN ID int, IN language_id int)
BEGIN

  /* 

   Created by : Jaganjot Kaur
   Created On : 24th June 2021
   Purpose : Details for hazard actions for decision log report

   Modified by : Brandon McKee
   Modified date: 2021-08-19
   Purpose : Corrected the subqueries to ref_list_detail to tie to the correct tag type

   Modified by : Robert Rivest
   Modified date: 2021-08-24
   Purpose : Added a field for Report Distribution 

   Modified by : Pragati Das
   Modified date : 2022-01-20
   purpose : SOF-10162 Replace Strings w/ Tags for Translations in Reporting

   
   Modified by: Pragati 
   Modified date: 18th May 2022
   Purpose: SOF-11117 - Add ENABLE Check on Language Translations

   Modified By: Jazmyn Zarichney
   Modified Date: 2022-08-16
   Description: Updating hard coded ltr_tag_types (SOF-11465)
   
   Modified By: Jazmyn Zarichney
   Modified Date: 2022-08-30
   Description: Updating the labels to use the language function (SOF-12027)
   
   Modified By: Pragati
   Modified Date: 2022-11-04
   Description: SOF-12740 - Updated the tag for followup_images_label to 1917
  
   Modified By: Pragati Das
   Modified Date: 2023-03-31
   Description: SOF-13374 - Updated the SP with the AMA functionality 
   
   Modified By: Pragati Das
   Modified Date: 2023-07-17
   Description: SOF-14663 - Added case statement to get the HAP with 
    only immediate actions and distibution label.
  
    Modified By: Naveen Kumar Vadlamudi
    Modified Date: 2024-12-20
    Description: PD-2834 Distribution - Store per_id Instead of Email - Reports Changes

   */

  DECLARE hazard_action_label text;
  DECLARE hazard_type_label text;
  DECLARE hazard_identification_label text;
  DECLARE hazard_description_label text;
  DECLARE potential_loss_identification_label text;
  DECLARE potential_loss_label text;
  DECLARE actions_identification_immediate_label text;
  DECLARE was_immediate_action_required_performed_label text;
  DECLARE action_taken_label text;
  DECLARE action_type_label text;
  DECLARE further_action_required_label text;
  DECLARE actions_identification_followup_label text;
  DECLARE recommendation_label text;
  DECLARE by_who_label text;
  DECLARE by_when_label text;
  DECLARE action_status_label text;
  DECLARE action_completed_by_who_label text;
  DECLARE action_completed_by_label text;
  DECLARE completion_report_label text;
  DECLARE no_images_label text;
  DECLARE initial_images_label text;
  DECLARE followup_images_label text;
  DECLARE images_label text;
  DECLARE report_distribution_label text;


  SET hazard_action_label = get_translation(1999, language_id, 1);
  SET hazard_type_label = get_translation(514, language_id, 1);
  SET hazard_identification_label = get_translation(510, language_id, 1);
  SET hazard_description_label = get_translation(509, language_id, 1);
  SET potential_loss_identification_label = get_translation(2177, language_id, 1);
  SET potential_loss_label = get_translation(1144, language_id, 1);
  SET actions_identification_immediate_label = get_translation(1911, language_id, 1);
  SET was_immediate_action_required_performed_label = get_translation(889, language_id, 1);
  SET action_taken_label = get_translation(15, language_id, 1);
  SET action_type_label = get_translation(17, language_id, 1);
  SET further_action_required_label = get_translation(589, language_id, 1);
  SET actions_identification_followup_label = get_translation(1912, language_id, 1);
  SET recommendation_label = get_translation(1915, language_id, 1);
  SET by_who_label = get_translation(71, language_id, 1);
  SET by_when_label = get_translation(70, language_id, 1);
  SET action_status_label = get_translation(14, language_id, 1);
  SET action_completed_by_who_label = get_translation(89, language_id, 1);
  SET action_completed_by_label = get_translation(91, language_id, 1);
  SET completion_report_label = get_translation(1913, language_id, 1);
  SET no_images_label = get_translation(2075, language_id, 1);
  SET initial_images_label = get_translation(1914, language_id, 1);
  SET followup_images_label = get_translation(1917, language_id, 1);
  SET images_label = get_translation(1918, language_id, 1);
  SET report_distribution_label = get_translation(166, language_id, 1);

  WITH distribution_cte
  AS
  (SELECT
      SubmissionHeaderID,
      GROUP_CONCAT(DISTINCT CASE WHEN value LIKE 'account-%' THEN CONCAT(p1.per_last_name, IFNULL(p.per_middle_name, ' '), p1.per_first_name) WHEN value LIKE 'external-%' THEN CONCAT(e.edl_last_name, ' ', e.edl_first_name) WHEN value LIKE 'group-%' THEN CASE WHEN CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) IS NULL THEN CONCAT(edl.edl_first_name, ' ', edl.edl_last_name) ELSE CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) END ELSE value END SEPARATOR '; ') AS Distributors
    FROM SubmissionDetails_Explode
      JOIN SubmissionDetails
        ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
      JOIN FormFieldDescription
        ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
      LEFT JOIN person p1
        ON SUBSTRING_INDEX (value, '-', -1) = p1.per_id
        AND value LIKE 'account-%'
      LEFT JOIN external_distribution_list e
        ON SUBSTRING_INDEX (value, '-', -1) = e.edl_id
        AND value LIKE 'external-%'
      LEFT JOIN distribution_group_email dge
        ON SUBSTRING_INDEX (value, '-', -1) = dge.dge_dig_id
        AND dge.dge_enable = 1
        AND SubmissionDetails_Explode.value LIKE 'group-%'
      LEFT JOIN person AS p
        ON p.per_id = dge.dge_per_id
      LEFT JOIN external_distribution_list edl
        ON edl.edl_id = dge.dge_edl_id
    WHERE FormFieldDescription.fieldKey = 'Report_Distribution1'
    GROUP BY SubmissionHeaderID)

  SELECT
    SubmissionHAP.ID,
    SubmissionHAP.action_by_when AS followup_action_by_date,
    get_translation_from_ref_list_id(SubmissionHAP.immediate_action_type, 'ref_action_type', language_id) AS immediate_action_type,
    get_translation_from_ref_list_id(SubmissionHAP.action_type, 'ref_action_type', language_id) AS followup_action_type,
    SubmissionHAP.hazard_description AS HAP_description,
    SubmissionHAP.immediate_action_required_and_performed AS immediate_action_required_and_performed_flag,
    CASE WHEN SubmissionHAP.immediate_action_required_and_performed = 1 THEN (get_translation(1379, language_id, 1)) ELSE (get_translation(1380, language_id, 1)) END AS was_immediate_action_required_and_performed,
    SubmissionHAP.further_action_required AS further_action_required_flag,
    CASE WHEN SubmissionHAP.further_action_required = 1 THEN (get_translation(1379, language_id, 1)) ELSE (get_translation(1380, language_id, 1)) END AS was_further_action_required,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_tag_type = 1
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          MAX(ltr_tag)
        FROM language_translation
        WHERE ltr_text = action_status)) AS hazard_status,
    get_translation_from_ref_list_id(SubmissionHAP.hazard_identification, 'ref_hazard_identification', language_id) AS hazard_identification,
    get_translation_from_ref_list_id(SubmissionHAP.hazard_type, 'ref_hazard_type', language_id) AS hazard_type,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          rld_name
        FROM ref_list_detail
        WHERE rld_id = SubmissionHAP.potential_risk
        AND rld_tag_type = ltr_tag_type)) AS potential_risk,

    SubmissionHAP.recommended_action AS followup_recommended_action,
    SubmissionHAP.immediate_action_taken AS immediate_action_taken,

    IF(SubmissionHAP.sha_is_group_action IS NOT NULL,
    GROUP_CONCAT(DISTINCT by_who.per_full_name SEPARATOR '; '),
    by_who.per_full_name) AS by_who,
    distribution_cte.Distributors AS distribution_list,
    SubmissionHAP.sha_is_group_action,
    hazard_action_label AS hazard_action_label,
    hazard_type_label AS hazard_type_label,
    hazard_identification_label AS hazard_identification_label,
    hazard_description_label AS hazard_description_label,
    potential_loss_identification_label AS potential_loss_identification_label,
    potential_loss_label AS potential_loss_label,
    actions_identification_immediate_label AS actions_identification_immediate_label,
    was_immediate_action_required_performed_label AS was_immediate_action_required_performed_label,
    action_taken_label AS action_taken_label,
    action_type_label AS action_type_label,
    further_action_required_label AS further_action_required_label,
    actions_identification_followup_label AS actions_identification_followup_label,
    recommendation_label AS recommendation_label,
    by_who_label AS by_who_label,
    by_when_label AS by_when_label,
    action_status_label AS action_status_label,
    action_completed_by_who_label AS action_completed_by_who_label,
    action_completed_by_label AS action_completed_by_label,
    completion_report_label AS completion_report_label,
    no_images_label AS no_images_label,
    initial_images_label AS initial_images_label,
    followup_images_label AS followup_images_label,
    images_label AS images_label,
    report_distribution_label AS report_distribution_label
  FROM decision_log_hazard_action
    INNER JOIN SubmissionHAP
      ON decision_log_hazard_action.dlh_sha_id = SubmissionHAP.ID
    LEFT JOIN submission_hazard_action_person
      ON SubmissionHAP.ID = submission_hazard_action_person.hap_sha_id
    LEFT JOIN v_employee by_who
      ON submission_hazard_action_person.hap_per_id = by_who.per_id
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.id = SubmissionHAP.SubmissionHeaderID
    LEFT JOIN SubmissionDetails
      ON SubmissionHeader.id = SubmissionDetails.SubmissionHeaderID
    LEFT JOIN distribution_cte
      ON distribution_cte.SubmissionHeaderID = SubmissionDetails.SubmissionHeaderID
  WHERE decision_log_hazard_action.dlh_dlm_id = ID
  AND SubmissionHAP.sha_enable = 1
  AND CASE WHEN immediate_action_required_and_performed = 1 AND
      further_action_required = 0 THEN 1 = 1 ELSE submission_hazard_action_person.hap_enable = 1 END
  GROUP BY submission_hazard_action_person.hap_sha_id;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_get_decision_log_general_actions_by_id`
--
DROP PROCEDURE IF EXISTS rpt_get_decision_log_general_actions_by_id;

DELIMITER $$

--
-- Create procedure `rpt_get_decision_log_general_actions_by_id`
--
CREATE PROCEDURE IF NOT EXISTS rpt_get_decision_log_general_actions_by_id (IN decision_log_id int, IN language_id int)
BEGIN

  /* 

  Created by : Jaganjot Kaur
  Created On : 4th June 2021
  Purpose : Getting decision log General Action details

   Modified by : Brandon McKee
   Modified date: 2021-08-19
   Purpose : Corrected the subquery calls to ref_list_detail, making sure they tie to the correct tag type
   
   Modified by : Robert Rivest
   Modified date: 2021-08-24
   Purpose : Added a field for Report Distribution 

   Modified by : Pragati Das
   Modified date : 2022-01-19
   purpose : SOF-10162 Replace Strings w/ Tags for Translations in Reporting

   Modified by: Pragati 
   Modified date: 18th May 2022
   Purpose: SOF-11117 - Add ENABLE Check on Language Translations
   
   Modified By: Jazmyn Zarichney
   Modified Date: 2022-08-29
   Description: Updating the labels to use the language function (SOF-12027)

   Modified By: Pragati
   Modified Date: 2022-11-04
   Description: SOF-12740 - Updated the tag for followup_images_label to 1917
  
   Modified By: Pragati Das
   Modified Date: 2023-03-31
   Description: SOF-13374 - Updated the SP with the AMA functionality 

   Modified By: Naveen Kumar Vadlamudi
   Modified Date: 2024-12-20
   Description: PD-2834 Distribution - Store per_id Instead of Email - Reports Changes
 
   */

  DECLARE action_identification_label text;
  DECLARE general_action_label text;
  DECLARE action_type_label text;
  DECLARE by_who_label text;
  DECLARE by_when_label text;
  DECLARE recommended_action_label text;
  DECLARE action_completed_label text;
  DECLARE action_completed_by_label text;
  DECLARE action_completed_by_when_label text;
  DECLARE completed_action_taken_label text;
  DECLARE completed_action_type_label text;
  DECLARE job_number_label text;
  DECLARE date_label text;
  DECLARE site_label text;
  DECLARE supervisor_label text;
  DECLARE level_label text;
  DECLARE workplace_label text;
  DECLARE no_images_label text;
  DECLARE initial_images_label text;
  DECLARE followup_images_label text;
  DECLARE images_label text;
  DECLARE report_distribution_label text;

  SET action_identification_label = get_translation(2078, language_id, 1);
  SET general_action_label = get_translation(1039, language_id, 1);
  SET action_type_label = get_translation(17, language_id, 1);
  SET by_who_label = get_translation(71, language_id, 1);
  SET by_when_label = get_translation(70, language_id, 1);
  SET recommended_action_label = get_translation(773, language_id, 1);
  SET action_completed_label = get_translation(2026, language_id, 1);
  SET action_completed_by_label = get_translation(89, language_id, 1);
  SET action_completed_by_when_label = get_translation(91, language_id, 1);
  SET completed_action_taken_label = get_translation(15, language_id, 1);
  SET completed_action_type_label = get_translation(17, language_id, 1);
  SET job_number_label = get_translation(617, language_id, 1);
  SET date_label = get_translation(124, language_id, 1);
  SET site_label = get_translation(828, language_id, 1);
  SET supervisor_label = get_translation(844, language_id, 1);
  SET level_label = get_translation(8305, language_id, 1);
  SET workplace_label = get_translation(959, language_id, 1);
  SET no_images_label = get_translation(2075, language_id, 1);
  SET initial_images_label = get_translation(1914, language_id, 1);
  SET followup_images_label = get_translation(1917, language_id, 1);
  SET images_label = get_translation(1918, language_id, 1);
  SET report_distribution_label = get_translation(777, language_id, 1);

  WITH distribution_cte
  AS
  (SELECT
      SubmissionHeaderID,
      GROUP_CONCAT(DISTINCT CASE WHEN value LIKE 'account-%' THEN CONCAT(p1.per_last_name, IFNULL(p.per_middle_name, ' '), p1.per_first_name) WHEN value LIKE 'external-%' THEN CONCAT(e.edl_last_name, ' ', e.edl_first_name) WHEN value LIKE 'group-%' THEN CASE WHEN CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) IS NULL THEN CONCAT(edl.edl_first_name, ' ', edl.edl_last_name) ELSE CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) END ELSE value END SEPARATOR '; ') AS Distributors
    FROM SubmissionDetails_Explode
      JOIN SubmissionDetails
        ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
      JOIN FormFieldDescription
        ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
      LEFT JOIN person p1
        ON SUBSTRING_INDEX (value, '-', -1) = p1.per_id
        AND value LIKE 'account-%'
      LEFT JOIN external_distribution_list e
        ON SUBSTRING_INDEX (value, '-', -1) = e.edl_id
        AND value LIKE 'external-%'
      LEFT JOIN distribution_group_email dge
        ON SUBSTRING_INDEX (value, '-', -1) = dge.dge_dig_id
        AND dge.dge_enable = 1
        AND SubmissionDetails_Explode.value LIKE 'group-%'
      LEFT JOIN person AS p
        ON p.per_id = dge.dge_per_id
      LEFT JOIN external_distribution_list edl
        ON edl.edl_id = dge.dge_edl_id
    WHERE FormFieldDescription.fieldKey = 'Report_Distribution1'
    GROUP BY SubmissionHeaderID)

  SELECT
    submission_general_action.sga_submission_header_id,
    submission_general_action.sga_id,

    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          rld_name
        FROM ref_list_detail
        WHERE rld_id = submission_general_action.sga_action_type_rld_id
        AND rld_tag_type = ltr_tag_type)) AS action_type,
    IF(submission_general_action.sga_is_group_action = 1,
    GROUP_CONCAT(by_who.per_full_name SEPARATOR '; '),
    by_who.per_full_name) AS by_who,
    distribution_cte.Distributors AS distribution_list,
    submission_general_action.sga_action_by_when,
    submission_general_action.sga_recommended_action,
    submission_general_action.sga_action_is_complete,
    submission_general_action.sga_created_date,
    action_identification_label AS action_identification_label,
    general_action_label AS general_action_label,
    action_type_label AS action_type_label,
    by_who_label AS by_who_label,
    by_when_label AS by_when_label,
    recommended_action_label AS recommended_action_label,
    action_completed_label AS action_completed_label,
    action_completed_by_label AS action_completed_by_label,
    action_completed_by_when_label AS action_completed_by_when_label,
    completed_action_taken_label AS completed_action_taken_label,
    completed_action_type_label AS completed_action_type_label,
    job_number_label AS job_number_label,
    date_label AS date_label,
    site_label AS site_label,
    supervisor_label AS supervisor_label,
    level_label AS level_label,
    workplace_label AS workplace_label,
    no_images_label AS no_images_label,
    initial_images_label AS initial_images_label,
    followup_images_label AS followup_images_label,
    images_label AS images_label,
    report_distribution_label AS report_distribution_label
  FROM decision_log_general_action
    LEFT JOIN submission_general_action
      ON decision_log_general_action.dlg_sga_id = submission_general_action.sga_id
    INNER JOIN submission_general_action_person
      ON submission_general_action.sga_id = submission_general_action_person.gap_sga_id
    INNER JOIN v_employee by_who
      ON submission_general_action_person.gap_per_id = by_who.per_id
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.id = submission_general_action.sga_submission_header_id
    LEFT JOIN SubmissionDetails
      ON SubmissionHeader.id = SubmissionDetails.SubmissionHeaderID
    LEFT JOIN distribution_cte
      ON distribution_cte.SubmissionHeaderID = SubmissionDetails.SubmissionHeaderID
    LEFT JOIN v_employee supervisor
      ON SubmissionHeader.supervisor = supervisor.per_id
  WHERE decision_log_general_action.dlg_dlm_id = decision_log_id
  AND submission_general_action.sga_enable = 1
  AND submission_general_action_person.gap_enable = 1
  GROUP BY submission_general_action_person.gap_sga_id;
END
$$

DELIMITER ;

--
-- Drop procedure `rpt_form_details_distribution`
--
DROP PROCEDURE IF EXISTS rpt_form_details_distribution;

DELIMITER $$

--
-- Create procedure `rpt_form_details_distribution`
--
CREATE PROCEDURE IF NOT EXISTS rpt_form_details_distribution (IN submission_id int, IN language_id int)
BEGIN



  /*
  Created By: Jaganjot Kaur
  Creation Date: 10th June 2021
  Description: Records for the get distribution details list
  
  Modifed Date: 13 Jan 2022
  Modified By:  Pragati Das
  Comment: SOF-10162 Replace Strings w/ Tags for Translations in Reporting  

  Change History
  
  Modifed Date: 2022-04-12
  Modified By: Brandon McKee
  Comment: SOF-10961 bug fix
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-05-18
  Description: Adding enable check on language translations (SOF-11119)

  Modified By: Pragati Das
  Modified Date: 2022-06-09
  Description: Removed "\" from string (SOF-11384)
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-08-29
  Description: Updating the labels to use the language function (SOF-12027)

  Modified By: Shane Robinson
  Modified Date: 2024-05-30
  Description: Removing the user email from the distributors information (PD-1940)

  Modified By: Naveen Kumar Vadlamudi
  Modified Date: 2024-12-18
  Description: PD-2834 Distribution - Store per_id Instead of Email - Reports Changes

  */

  SELECT
    SubmissionHeaderID,
    GROUP_CONCAT(DISTINCT CASE WHEN value LIKE 'account-%' THEN CONCAT(p1.per_last_name, IFNULL(p.per_middle_name, ' '), p1.per_first_name) WHEN value LIKE 'external-%' THEN CONCAT(e.edl_last_name, ' ', e.edl_first_name) WHEN value LIKE 'group-%' THEN CASE WHEN CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) IS NULL THEN CONCAT(edl.edl_first_name, ' ', edl.edl_last_name) ELSE CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) END ELSE value END SEPARATOR '; ') AS Distributors
  FROM SubmissionDetails_Explode
    JOIN SubmissionDetails
      ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
    JOIN FormFieldDescription
      ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
    LEFT JOIN person p1
      ON SUBSTRING_INDEX (value, '-', -1) = p1.per_id
      AND value LIKE 'account-%'
    LEFT JOIN external_distribution_list e
      ON SUBSTRING_INDEX (value, '-', -1) = e.edl_id
      AND value LIKE 'external-%'
    LEFT JOIN distribution_group_email dge
      ON SUBSTRING_INDEX (value, '-', -1) = dge.dge_dig_id
      AND dge.dge_enable = 1
      AND SubmissionDetails_Explode.value LIKE 'group-%'
    LEFT JOIN person AS p
      ON p.per_id = dge.dge_per_id
    LEFT JOIN external_distribution_list edl
      ON edl.edl_id = dge.dge_edl_id
  WHERE SubmissionHeaderID = submission_id
  AND FormFieldDescription.fieldKey = 'Report_Distribution1'
  GROUP BY SubmissionHeaderID;


END
$$

DELIMITER ;

--
-- Drop procedure `rpt_bowtie_hap`
--
DROP PROCEDURE IF EXISTS rpt_bowtie_hap;

DELIMITER $$

--
-- Create procedure `rpt_bowtie_hap`
--
CREATE PROCEDURE IF NOT EXISTS rpt_bowtie_hap (IN SubmissionId int, IN language_id int)
BEGIN

  /* 
  
    Created by : Pragati Das
    Created On : 25th October 2021
    Purpose : Details for hazard actions for Bowtie

    Modified By : Jaganjot Kaur
    Modified On : 8th Nov 2021
    Purpose : Adding the GROUP BY clause because we have added a GROUP concat

    Modified by : Pragati Das
    Modified date : 2022-01-18
    purpose : SOF-10162 Replace Strings w/ Tags for Translations in Reporting
    
    Modified By: Jazmyn Zarichney
    Modified Date: 2022-05-18
    Description: Adding enable check on language translations (SOF-11119)

    Modified By: Jazmyn Zarichney
    Modified Date: 2022-08-16
    Description: Updating hard coded ltr_tag_types (SOF-11465)
   
    Modified By: Jazmyn Zarichney
    Modified Date: 2022-08-26
    Description: Updating the labels to use the language function (SOF-12027)
  
    Modified By: Pragati
    Modified Date: 2022-11-04
    Description: SOF-12740 - Updated the tag for followup_images_label to 1917
  
    Modified By: Pragati
    Modified Date: 2023-01-11
    Description: SOF-13279 - Updated SP to get one row from a subquery
  
    Modified By: Pragati Das
    Modified Date: 2023-03-31
    Description: SOF-13374 - Updated the SP with the AMA functionality 
 
    Modified By: Pragati Das
    Modified Date: 2023-07-14
    Description: SOF-14663 - Added case statement to get the HAP with 
    only immediate actions and distibution label.

    
    Modified By: Naveen Kumar Vadlamudi
    Modified Date: 2024-12-20
    Description: PD-2834 Distribution - Store per_id Instead of Email - Reports Changes
  */

  DECLARE hazard_action_label text;
  DECLARE hazard_type_label text;
  DECLARE hazard_identification_label text;
  DECLARE hazard_description_label text;
  DECLARE potential_loss_identification_label text;
  DECLARE potential_loss_label text;
  DECLARE actions_identification_immediate_label text;
  DECLARE was_immediate_action_required_performed_label text;
  DECLARE action_taken_label text;
  DECLARE action_type_label text;
  DECLARE further_action_required_label text;
  DECLARE actions_identification_followup_label text;
  DECLARE recommendation_label text;
  DECLARE by_who_label text;
  DECLARE by_when_label text;
  DECLARE action_status_label text;
  DECLARE action_completed_by_who_label text;
  DECLARE action_completed_by_label text;
  DECLARE completion_report_label text;
  DECLARE no_images_label text;
  DECLARE initial_images_label text;
  DECLARE followup_images_label text;
  DECLARE images_label text;
  DECLARE report_distribution_label text;

  SET hazard_action_label = get_translation(1999, language_id, 1);
  SET hazard_type_label = get_translation(514, language_id, 1);
  SET hazard_identification_label = get_translation(510, language_id, 1);
  SET hazard_description_label = get_translation(509, language_id, 1);
  SET potential_loss_identification_label = get_translation(2177, language_id, 1);
  SET potential_loss_label = get_translation(1144, language_id, 1);
  SET actions_identification_immediate_label = get_translation(1911, language_id, 1);
  SET was_immediate_action_required_performed_label = get_translation(889, language_id, 1);
  SET action_taken_label = get_translation(15, language_id, 1);
  SET action_type_label = get_translation(17, language_id, 1);
  SET further_action_required_label = get_translation(589, language_id, 1);
  SET actions_identification_followup_label = get_translation(1912, language_id, 1);
  SET recommendation_label = get_translation(1915, language_id, 1);
  SET by_who_label = get_translation(71, language_id, 1);
  SET by_when_label = get_translation(70, language_id, 1);
  SET action_status_label = get_translation(14, language_id, 1);
  SET action_completed_by_who_label = get_translation(89, language_id, 1);
  SET action_completed_by_label = get_translation(91, language_id, 1);
  SET completion_report_label = get_translation(1913, language_id, 1);
  SET no_images_label = get_translation(2075, language_id, 1);
  SET initial_images_label = get_translation(1914, language_id, 1);
  SET followup_images_label = get_translation(1917, language_id, 1);
  SET images_label = get_translation(1918, language_id, 1);
  SET report_distribution_label = get_translation(166, language_id, 1);

  WITH distribution_cte
  AS
  (SELECT
      SubmissionHeaderID,
      GROUP_CONCAT(DISTINCT CASE WHEN value LIKE 'account-%' THEN CONCAT(p1.per_last_name, IFNULL(p.per_middle_name, ' '), p1.per_first_name) WHEN value LIKE 'external-%' THEN CONCAT(e.edl_last_name, ' ', e.edl_first_name) WHEN value LIKE 'group-%' THEN CASE WHEN CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) IS NULL THEN CONCAT(edl.edl_first_name, ' ', edl.edl_last_name) ELSE CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) END ELSE value END SEPARATOR '; ') AS Distributors
    FROM SubmissionDetails_Explode
      JOIN SubmissionDetails
        ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
      JOIN FormFieldDescription
        ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
      LEFT JOIN person p1
        ON SUBSTRING_INDEX (value, '-', -1) = p1.per_id
        AND value LIKE 'account-%'
      LEFT JOIN external_distribution_list e
        ON SUBSTRING_INDEX (value, '-', -1) = e.edl_id
        AND value LIKE 'external-%'
      LEFT JOIN distribution_group_email dge
        ON SUBSTRING_INDEX (value, '-', -1) = dge.dge_dig_id
        AND dge.dge_enable = 1
        AND SubmissionDetails_Explode.value LIKE 'group-%'
      LEFT JOIN person AS p
        ON p.per_id = dge.dge_per_id
      LEFT JOIN external_distribution_list edl
        ON edl.edl_id = dge.dge_edl_id
    WHERE FormFieldDescription.fieldKey = 'Report_Distribution1'
    GROUP BY SubmissionHeaderID)

  SELECT
    SubmissionHAP.ID,
    SubmissionHAP.action_by_when AS followup_action_by_date,
    get_translation_from_ref_list_id(SubmissionHAP.immediate_action_type, 'ref_action_type', language_id) AS immediate_action_type,
    get_translation_from_ref_list_id(SubmissionHAP.action_type, 'ref_action_type', language_id) AS followup_action_type,
    SubmissionHAP.hazard_description AS HAP_description,
    SubmissionHAP.immediate_action_required_and_performed AS immediate_action_required_and_performed_flag,
    CASE WHEN SubmissionHAP.immediate_action_required_and_performed = 1 THEN (get_translation(1379, language_id, 1)) ELSE (get_translation(1380, language_id, 1)) END AS was_immediate_action_required_and_performed,
    SubmissionHAP.further_action_required AS further_action_required_flag,
    CASE WHEN SubmissionHAP.further_action_required = 1 THEN (get_translation(1379, language_id, 1)) ELSE (get_translation(1380, language_id, 1)) END AS was_further_action_required,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_tag_type = 1
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          MAX(ltr_tag)
        FROM language_translation
        WHERE ltr_text = action_status)) AS hazard_status,
    get_translation_from_ref_list_id(SubmissionHAP.hazard_identification, 'ref_hazard_identification', language_id) AS hazard_identification,
    get_translation_from_ref_list_id(SubmissionHAP.hazard_type, 'ref_hazard_type', language_id) AS hazard_type,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          rld_name
        FROM ref_list_detail
        WHERE rld_id = SubmissionHAP.potential_risk
        AND rld_tag_type = ltr_tag_type)) AS potential_risk,

    SubmissionHAP.recommended_action AS followup_recommended_action,
    SubmissionHAP.immediate_action_taken AS immediate_action_taken,

    IF(SubmissionHAP.sha_is_group_action IS NOT NULL,
    GROUP_CONCAT(by_who.per_full_name SEPARATOR '; '),
    by_who.per_full_name) AS by_who,
    distribution_cte.Distributors AS distribution_list,
    SubmissionHAP.sha_is_group_action,
    hazard_action_label AS hazard_action_label,
    hazard_type_label AS hazard_type_label,
    hazard_identification_label AS hazard_identification_label,
    hazard_description_label AS hazard_description_label,
    potential_loss_identification_label AS potential_loss_identification_label,
    potential_loss_label AS potential_loss_label,
    actions_identification_immediate_label AS actions_identification_immediate_label,
    was_immediate_action_required_performed_label AS was_immediate_action_required_performed_label,
    action_taken_label AS action_taken_label,
    action_type_label AS action_type_label,
    further_action_required_label AS further_action_required_label,
    actions_identification_followup_label AS actions_identification_followup_label,
    recommendation_label AS recommendation_label,
    by_who_label AS by_who_label,
    by_when_label AS by_when_label,
    action_status_label AS action_status_label,
    action_completed_by_who_label AS action_completed_by_who_label,
    action_completed_by_label AS action_completed_by_label,
    completion_report_label AS completion_report_label,
    no_images_label AS no_images_label,
    initial_images_label AS initial_images_label,
    followup_images_label AS followup_images_label,
    images_label AS images_label,
    report_distribution_label AS report_distribution_label
  FROM rmm_bowtie_hazard_action
    INNER JOIN SubmissionHAP
      ON rmm_bowtie_hazard_action.rmm_bha_sha_id = SubmissionHAP.ID
    LEFT JOIN submission_hazard_action_person
      ON SubmissionHAP.ID = submission_hazard_action_person.hap_sha_id
    LEFT JOIN v_employee by_who
      ON submission_hazard_action_person.hap_per_id = by_who.per_id
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.id = SubmissionHAP.SubmissionHeaderID
    LEFT JOIN SubmissionDetails
      ON SubmissionHeader.id = SubmissionDetails.SubmissionHeaderID
    LEFT JOIN distribution_cte
      ON distribution_cte.SubmissionHeaderID = SubmissionDetails.SubmissionHeaderID
  WHERE rmm_bowtie_hazard_action.rmm_bha_bow_id = SubmissionId
  AND SubmissionHAP.sha_enable = 1
  AND CASE WHEN immediate_action_required_and_performed = 1 AND
      further_action_required = 0 THEN 1 = 1 ELSE submission_hazard_action_person.hap_enable = 1 END
  GROUP BY submission_hazard_action_person.hap_sha_id;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_bowtie_general_actions_by_sga_id`
--
DROP PROCEDURE IF EXISTS rpt_bowtie_general_actions_by_sga_id;

DELIMITER $$

--
-- Create procedure `rpt_bowtie_general_actions_by_sga_id`
--
CREATE PROCEDURE IF NOT EXISTS rpt_bowtie_general_actions_by_sga_id (IN formSubmissionId int, IN language_id int)
BEGIN

  /*
  Creation Date: 14th Jan 2021
  Created By: Jaganjot Kaur
  Description: General actions for bowtie

  Modified by : Pragati Das
  Modified date: 21st October 2021
  Purpose : Updated the SP to get data for Bowtie with language translations

  Modified by : Pragati Das
  Modified date: 05th Nov 2021
  Purpose : Updated the SP with action_type for consistency with the GA component
 
  Modified by : Pragati Das
  Modified date : 2022-01-17
  purpose : SOF-10162 Replace Strings w/ Tags for Translations in Reporting 
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-05-18
  Description: Adding enable check on language translations (SOF-11119)
   
  Modified By: Jazmyn Zarichney
  Modified Date: 2022-08-26
  Description: Updating the labels to use the language function (SOF-12027)

  Modified By: Pragati
  Modified Date: 2022-11-04
  Description: SOF-12740 - Updated the tag for followup_images_label to 1917
  
  Modified By: Pragati Das
  Modified Date: 2023-03-31
  Description: SOF-13374 - Updated the SP with the AMA functionality 

  Modified By: Naveen Kumar Vadlamudi
  Modified Date: 2024-12-20
  Description: PD-2834 Distribution - Store per_id Instead of Email - Reports Changes
 
*/


  DECLARE action_identification_label text;
  DECLARE general_action_label text;
  DECLARE action_type_label text;
  DECLARE by_who_label text;
  DECLARE by_when_label text;
  DECLARE recommended_action_label text;
  DECLARE action_completed_label text;
  DECLARE action_completed_by_label text;
  DECLARE action_completed_by_when_label text;
  DECLARE completed_action_taken_label text;
  DECLARE completed_action_type_label text;
  DECLARE job_number_label text;
  DECLARE date_label text;
  DECLARE site_label text;
  DECLARE supervisor_label text;
  DECLARE level_label text;
  DECLARE workplace_label text;
  DECLARE no_images_label text;
  DECLARE initial_images_label text;
  DECLARE followup_images_label text;
  DECLARE images_label text;
  DECLARE report_distribution_label text;

  SET action_identification_label = get_translation(2078, language_id, 1);
  SET general_action_label = get_translation(1039, language_id, 1);
  SET action_type_label = get_translation(17, language_id, 1);
  SET by_who_label = get_translation(71, language_id, 1);
  SET by_when_label = get_translation(70, language_id, 1);
  SET recommended_action_label = get_translation(773, language_id, 1);
  SET action_completed_label = get_translation(2026, language_id, 1);
  SET action_completed_by_label = get_translation(89, language_id, 1);
  SET action_completed_by_when_label = get_translation(91, language_id, 1);
  SET completed_action_taken_label = get_translation(15, language_id, 1);
  SET completed_action_type_label = get_translation(17, language_id, 1);
  SET job_number_label = get_translation(617, language_id, 1);
  SET date_label = get_translation(124, language_id, 1);
  SET site_label = get_translation(828, language_id, 1);
  SET supervisor_label = get_translation(844, language_id, 1);
  SET level_label = get_translation(8305, language_id, 1);
  SET workplace_label = get_translation(959, language_id, 1);
  SET no_images_label = get_translation(2075, language_id, 1);
  SET initial_images_label = get_translation(1914, language_id, 1);
  SET followup_images_label = get_translation(1917, language_id, 1);
  SET images_label = get_translation(1918, language_id, 1);
  SET report_distribution_label = get_translation(777, language_id, 1);


  WITH distribution_cte
  AS
  (SELECT
      SubmissionHeaderID,
      GROUP_CONCAT(DISTINCT CASE WHEN value LIKE 'account-%' THEN CONCAT(p1.per_last_name, IFNULL(p.per_middle_name, ' '), p1.per_first_name) WHEN value LIKE 'external-%' THEN CONCAT(e.edl_last_name, ' ', e.edl_first_name) WHEN value LIKE 'group-%' THEN CASE WHEN CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) IS NULL THEN CONCAT(edl.edl_first_name, ' ', edl.edl_last_name) ELSE CONCAT(p.per_last_name, IFNULL(p.per_middle_name, ' '), p.per_first_name) END ELSE value END SEPARATOR '; ') AS Distributors
    FROM SubmissionDetails_Explode
      JOIN SubmissionDetails
        ON SubmissionDetails.ID = SubmissionDetails_Explode.SubmissionDetailID
      JOIN FormFieldDescription
        ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
      LEFT JOIN person p1
        ON SUBSTRING_INDEX (value, '-', -1) = p1.per_id
        AND value LIKE 'account-%'
      LEFT JOIN external_distribution_list e
        ON SUBSTRING_INDEX (value, '-', -1) = e.edl_id
        AND value LIKE 'external-%'
      LEFT JOIN distribution_group_email dge
        ON SUBSTRING_INDEX (value, '-', -1) = dge.dge_dig_id
        AND dge.dge_enable = 1
        AND SubmissionDetails_Explode.value LIKE 'group-%'
      LEFT JOIN person AS p
        ON p.per_id = dge.dge_per_id
      LEFT JOIN external_distribution_list edl
        ON edl.edl_id = dge.dge_edl_id
    WHERE FormFieldDescription.fieldKey = 'Report_Distribution1'
    GROUP BY SubmissionHeaderID)

  SELECT
    submission_general_action.sga_submission_header_id,
    submission_general_action.sga_id,
    (SELECT
        language_translation.ltr_text
      FROM language_translation
      WHERE ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag = (SELECT
          rld_name
        FROM ref_list_detail
        WHERE rld_id = submission_general_action.sga_action_type_rld_id
        AND rld_tag_type = ltr_tag_type)) AS action_type,
    IF(submission_general_action.sga_is_group_action = 1,
    GROUP_CONCAT(by_who.per_full_name SEPARATOR '; '),
    by_who.per_full_name) AS by_who,
    distribution_cte.Distributors AS distribution_list,
    submission_general_action.sga_action_by_when,
    submission_general_action.sga_recommended_action,
    submission_general_action.sga_action_is_complete,
    submission_general_action.sga_created_date,
    action_identification_label AS action_identification_label,
    general_action_label AS general_action_label,
    action_type_label AS action_type_label,
    by_who_label AS by_who_label,
    by_when_label AS by_when_label,
    recommended_action_label AS recommended_action_label,
    action_completed_label AS action_completed_label,
    action_completed_by_label AS action_completed_by_label,
    action_completed_by_when_label AS action_completed_by_when_label,
    completed_action_taken_label AS completed_action_taken_label,
    completed_action_type_label AS completed_action_type_label,
    job_number_label AS job_number_label,
    date_label AS date_label,
    site_label AS site_label,
    supervisor_label AS supervisor_label,
    level_label AS level_label,
    workplace_label AS workplace_label,
    no_images_label AS no_images_label,
    initial_images_label AS initial_images_label,
    followup_images_label AS followup_images_label,
    images_label AS images_label,
    report_distribution_label AS report_distribution_label
  FROM rmm_bowtie_general_action
    LEFT JOIN submission_general_action
      ON rmm_bowtie_general_action.rmm_bga_sga_id = submission_general_action.sga_id
    INNER JOIN submission_general_action_person
      ON submission_general_action.sga_id = submission_general_action_person.gap_sga_id
    INNER JOIN v_employee by_who
      ON submission_general_action_person.gap_per_id = by_who.per_id
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.id = submission_general_action.sga_submission_header_id
    LEFT JOIN SubmissionDetails
      ON SubmissionHeader.id = SubmissionDetails.SubmissionHeaderID
    LEFT JOIN v_employee supervisor
      ON SubmissionHeader.supervisor = supervisor.per_id
    LEFT JOIN distribution_cte
      ON distribution_cte.SubmissionHeaderID = SubmissionDetails.SubmissionHeaderID

  WHERE rmm_bowtie_general_action.rmm_bga_bow_id = formSubmissionId
  AND submission_general_action.sga_enable = 1
  AND submission_general_action_person.gap_enable = 1
  GROUP BY submission_general_action_person.gap_sga_id;

END
$$

DELIMITER ;

--
-- Drop procedure `get_trifr_trir_analytics_data`
--
DROP PROCEDURE IF EXISTS get_trifr_trir_analytics_data;

DELIMITER $$

--
-- Create procedure `get_trifr_trir_analytics_data`
--
CREATE PROCEDURE IF NOT EXISTS get_trifr_trir_analytics_data (IN start_date varchar(255), IN end_date varchar(255), IN lang int)
BEGIN
  /* 
        Created by: Gowtham Ravindran
        Modified on: 2022-09-12
        Reason: SOF-12175 - TRIFR UPDATES
    
        Modified By: Sarath Sontam
        Modified On: 2022-10-25
        Reason: SOF-12611 - count rca for an incident only when ActualTypeID and IncidentTypeID is not NULL
  
        Modified by : Gowtham Ravindran
        Modified on : 2024-01-25
        Change      : PD-339 - Changed submitted date to header date to calculate Open days
  
        Modified by : Gowtham Ravindran/ Sarath Sontam
        Modified on : 2024-02-27
        Change      : PD-339 - Modify the SP to pull the data as in reports.

        Modified by : Sarath Sontam
        Modified on : 2024-05-15
        Change      : PD-1680 - Filter out archived RootCauseAnalysis/IncidentAnalysis (1.6)

        Modified By  :   Gowtham Ravindran
        Modified on :    2024-06-01      
        Reason      :    PD-1820 - Retrieve reverse translation for incident_type and incident_class

        Modified By  :   Gowtham Ravindran
        Modified on :    2024-06-23     
        Reason      :    PD-2591 - Retrieve reverse translation for incident_type and incident_class

        Modified By  :   Gowtham Ravindran
        Modified on :    2024-08-27  
        Reason      :    PD-2591 - Excluding Archived Incident Analysis
        
        Modified By :   Naveen Kumar Vadlamudi, Pragati Das 
        Modified on :   2024-09-27
        Reason      :   Added LIMIT 1 to the incident type column alias in the ELSE part of the case statement.

        Modified By : James Coles / Pragati Das
        Modified on : 2025-01-16
        Reason      :  PD-3209 - Use the column from the incidents table to get the minimum incident date.


    */
  SELECT
    main_inc.ID,
    main_inc.IncidentNumber,
    main_inc.inc_minimum_incident_date AS header_date,
    SubmissionHeader.Site,
    IFNULL(get_preliminary_incident_type_reverse_translation(CASE WHEN (SELECT
            COUNT(*)
          FROM RootCauseAnalysis
          WHERE RootCauseAnalysis.IncidentID = main_inc.ID
          AND RootCauseAnalysis.rca_aco_id IS NULL
          AND RootCauseAnalysis.ActualTypeID IS NOT NULL) > 0 THEN (SELECT
              ltr_text
            FROM RootCauseAnalysis rca
              INNER JOIN v_ref_header_detail_list pt
                ON rca.ActualTypeID = pt.rld_id
              INNER JOIN language_translation lt
                ON lt.ltr_tag = pt.rld_name
                AND lt.ltr_tag_type = pt.rld_tag_type
            WHERE IncidentID = main_inc.ID
            AND rca.ActualTypeID IS NOT NULL
            AND rca.rca_aco_id IS NULL
            AND ltr_lng_id = lang
            ORDER BY rca.ID DESC
            LIMIT 1) ELSE (SELECT
            value
          FROM IncidentSubmissions inc
            INNER JOIN SubmissionDetails sd
              ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
            INNER JOIN SubmissionDetails_Explode e
              ON e.SubmissionDetailID = sd.ID
            INNER JOIN FormFieldDescription ff
              ON e.FormFieldDescriptionID = ff.ID
            LEFT OUTER JOIN FormDescription fd
              ON ff.FormDescriptionID = fd.ID
          WHERE fd.ID = 1338
          AND ff.fieldKey = 'incident_type'
          AND IncidentID = main_inc.ID
          AND sd.ID = (SELECT
              MIN(sd.ID)
            FROM IncidentSubmissions inc
              INNER JOIN SubmissionDetails sd
                ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
              INNER JOIN SubmissionDetails_Explode e
                ON e.SubmissionDetailID = sd.ID
              INNER JOIN FormFieldDescription ff
                ON e.FormFieldDescriptionID = ff.ID
              LEFT OUTER JOIN FormDescription fd
                ON ff.FormDescriptionID = fd.ID
            WHERE IncidentID = main_inc.ID
            AND ff.fieldKey = 'incident_type') LIMIT 1) END, lang), NULL) AS incident_type,
    IFNULL(get_incident_type_reverse_translation(CASE WHEN (SELECT
            COUNT(*)
          FROM RootCauseAnalysis
          WHERE RootCauseAnalysis.IncidentID = main_inc.ID
          AND RootCauseAnalysis.rca_aco_id IS NULL
          AND RootCauseAnalysis.IncidentTypeID IS NOT NULL) > 0 THEN (SELECT
              ltr_text
            FROM RootCauseAnalysis rca
              INNER JOIN v_ref_header_detail_list pt
                ON rca.IncidentTypeID = pt.rld_id
              INNER JOIN language_translation lt
                ON lt.ltr_tag = pt.rld_name
                AND lt.ltr_tag_type = pt.rld_tag_type
            WHERE IncidentID = main_inc.ID
            AND rca.IncidentTypeID IS NOT NULL
            AND rca.rca_aco_id IS NULL
            AND ltr_lng_id = lang
            ORDER BY rca.ID DESC
            LIMIT 1) ELSE (SELECT
            value
          FROM IncidentSubmissions inc
            INNER JOIN SubmissionDetails sd
              ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
            INNER JOIN SubmissionDetails_Explode e
              ON e.SubmissionDetailID = sd.ID
            INNER JOIN FormFieldDescription ff
              ON e.FormFieldDescriptionID = ff.ID
            LEFT OUTER JOIN FormDescription fd
              ON ff.FormDescriptionID = fd.ID
          WHERE fd.ID = 1329
          AND ff.fieldKey = 'event_type'
          AND IncidentID = main_inc.ID
          ORDER BY inc.SubmissionHeaderID
          LIMIT 1) END, lang), NULL) AS incident_class
  FROM Incidents main_inc
    LEFT JOIN v_incident_signoff_status
      ON main_inc.ID = v_incident_signoff_status.incident_id
    LEFT JOIN IncidentSubmissions
      ON IncidentSubmissions.IncidentID = main_inc.ID
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.ID = IncidentSubmissions.SubmissionHeaderID
  WHERE main_inc.inc_aco_id IS NULL
  AND IF(start_date IS NOT NULL
  AND end_date IS NOT NULL, get_min_header_date(main_inc.ID) BETWEEN start_date AND end_date, 1 = 1)

  GROUP BY main_inc.ID,
           main_inc.IncidentNumber;
END
$$

DELIMITER ;

--
-- Drop procedure `api_safety_executive`
--
DROP PROCEDURE IF EXISTS api_safety_executive;

DELIMITER $$

--
-- Create procedure `api_safety_executive`
--
CREATE PROCEDURE IF NOT EXISTS api_safety_executive (IN site_ids text, IN start_date date, IN lang int, IN job_ids text)
BEGIN

  /*
  
     Created By: Suman, James, Vinh, Pragati
     Creation Date: 2023-11-30
     Description: Safety Executive Summary Report data

     Modified by:   James Coles, Vinh Lam
     Modified Date: 2024-03-06
     Reason:        We are not considering signed off incidents now.

     Modified By: James Coles / Pragati Das
     Modified Date: 2025-01-16
     Description:  PD-3209 - Use the column from the incidents table to get the minimum incident date.


     */
  DECLARE end_date date;

  SET end_date = LAST_DAY(start_date);

  SELECT
    -- labels --
    main_inc.ID AS IncidentID,
    main_inc.IncidentNumber,
    (SELECT
        GROUP_CONCAT((get_translation_from_ref_list_id(sh.Site, 'ref_site', lang)), ', ', ((SELECT
              rld_code
            FROM ref_list_detail
            WHERE rld_id = sh.JobNumber)), ', ',
        ((get_translation_from_ref_list_id(sh.SiteLevel, 'ref_level', lang))), ', ', sh.Workplace)
      FROM IncidentSubmissions inc
        INNER JOIN SubmissionHeader sh
          ON inc.SubmissionHeaderID = sh.ID
      WHERE IncidentID = main_inc.ID
      AND sh.ID = (SELECT
          MIN(sh.ID)
        FROM IncidentSubmissions inc
          INNER JOIN SubmissionHeader sh
            ON inc.SubmissionHeaderID = sh.ID
        WHERE IncidentID = main_inc.ID)) AS location,
    get_translation_from_ref_list_id(SubmissionHeader.Site, 'ref_site', lang) AS Site,
    get_translation_from_ref_list_id(SubmissionHeader.JobNumber, 'ref_job', lang) AS JobNumber,

    CASE WHEN (SELECT
            COUNT(*)
          FROM RootCauseAnalysis
          WHERE RootCauseAnalysis.IncidentID = main_inc.ID
          AND RootCauseAnalysis.ActualTypeID IS NOT NULL) > 0 THEN (SELECT
              ltr_text
            FROM RootCauseAnalysis rca
              INNER JOIN v_ref_header_detail_list pt
                ON rca.ActualTypeID = pt.rld_id
              INNER JOIN language_translation lt
                ON lt.ltr_tag = pt.rld_name
                AND lt.ltr_tag_type = pt.rld_tag_type
            WHERE IncidentID = main_inc.ID
            AND rca.ActualTypeID IS NOT NULL
            AND ltr_lng_id = lang
            ORDER BY rca.ID DESC
            LIMIT 1) ELSE (SELECT
            value
          FROM IncidentSubmissions inc
            INNER JOIN SubmissionDetails sd
              ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
            INNER JOIN SubmissionDetails_Explode e
              ON e.SubmissionDetailID = sd.ID
            INNER JOIN FormFieldDescription ff
              ON e.FormFieldDescriptionID = ff.ID
            LEFT OUTER JOIN FormDescription fd
              ON ff.FormDescriptionID = fd.ID
          WHERE fd.ID = 1338
          AND ff.fieldKey = 'incident_type'
          AND IncidentID = main_inc.ID
          AND sd.ID = (SELECT
              MIN(sd.ID)
            FROM IncidentSubmissions inc
              INNER JOIN SubmissionDetails sd
                ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
              INNER JOIN SubmissionDetails_Explode e
                ON e.SubmissionDetailID = sd.ID
              INNER JOIN FormFieldDescription ff
                ON e.FormFieldDescriptionID = ff.ID
              LEFT OUTER JOIN FormDescription fd
                ON ff.FormDescriptionID = fd.ID
            WHERE IncidentID = main_inc.ID
            AND ff.fieldKey = 'incident_type')) END AS incidenttype,
    CASE WHEN (SELECT
            COUNT(*)
          FROM RootCauseAnalysis
          WHERE RootCauseAnalysis.IncidentID = main_inc.ID
          AND RootCauseAnalysis.IncidentTypeID IS NOT NULL) > 0 THEN (SELECT
              ltr_text
            FROM RootCauseAnalysis rca
              INNER JOIN v_ref_header_detail_list pt
                ON rca.IncidentTypeID = pt.rld_id
              INNER JOIN language_translation lt
                ON lt.ltr_tag = pt.rld_name
                AND lt.ltr_tag_type = pt.rld_tag_type
            WHERE IncidentID = main_inc.ID
            AND rca.IncidentTypeID IS NOT NULL
            AND ltr_lng_id = lang
            ORDER BY rca.ID DESC
            LIMIT 1) ELSE (SELECT
            value
          FROM IncidentSubmissions inc
            INNER JOIN SubmissionDetails sd
              ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
            INNER JOIN SubmissionDetails_Explode e
              ON e.SubmissionDetailID = sd.ID
            INNER JOIN FormFieldDescription ff
              ON e.FormFieldDescriptionID = ff.ID
            LEFT OUTER JOIN FormDescription fd
              ON ff.FormDescriptionID = fd.ID
          WHERE fd.ID = 1329
          AND ff.fieldKey = 'event_type'
          AND IncidentID = main_inc.ID
          ORDER BY inc.SubmissionHeaderID
          LIMIT 1) END AS RCATYPE,
    main_inc.inc_minimum_incident_date AS header_date,
    (SELECT
        value
      FROM IncidentSubmissions inc
        INNER JOIN SubmissionDetails sd
          ON inc.SubmissionHeaderID = sd.SubmissionHeaderID
        INNER JOIN SubmissionDetails_Explode e
          ON e.SubmissionDetailID = sd.ID
        INNER JOIN FormFieldDescription ff
          ON e.FormFieldDescriptionID = ff.ID
        LEFT OUTER JOIN FormDescription fd
          ON ff.FormDescriptionID = fd.ID
      WHERE fd.FormName = 1003
      AND ff.fieldKey = 'incident_short_description'
      AND IncidentID = main_inc.ID
      LIMIT 1) AS DESCRIPTION
  FROM Incidents main_inc
    LEFT JOIN v_incident_signoff_status
      ON main_inc.ID = v_incident_signoff_status.incident_id
    LEFT JOIN IncidentSubmissions
      ON IncidentSubmissions.IncidentID = main_inc.ID
    LEFT JOIN SubmissionHeader
      ON SubmissionHeader.ID = IncidentSubmissions.SubmissionHeaderID
  WHERE ((FIND_IN_SET(SubmissionHeader.JobNumber, job_ids) > 0)
  OR (SubmissionHeader.JobNumber IS NOT NULL
  AND job_ids IS NULL))
  AND ((FIND_IN_SET(SubmissionHeader.Site, site_ids) > 0)
  OR (SubmissionHeader.Site IS NOT NULL
  AND site_ids IS NULL))
  AND get_min_header_date(main_inc.ID)
  BETWEEN start_date AND end_date
  GROUP BY main_inc.ID,
           main_inc.IncidentNumber;
END
$$

DELIMITER ;

--
-- Drop procedure `api_safety_dashboard`
--
DROP PROCEDURE IF EXISTS api_safety_dashboard;

DELIMITER $$

--
-- Create procedure `api_safety_dashboard`
--
CREATE PROCEDURE IF NOT EXISTS api_safety_dashboard (IN start_date date)
BEGIN


  /*
     Created By:    James Coles and Vinh Lam
     Created Date:
     Reason:        CNPIAT monthly report.

     Modified By:   James Coles and Vinh Lam
     Modified Date: 2024-03-06
     Reason:        Fixing incident counts, monthly and ytd, using the function get_min_header_date.
  
     Modified By: James Coles / Pragati Das
     Modified Date: 2025-01-16
     Description:  PD-3209 - Use the column from the incidents table to get the minimum incident date.
    

  */

  DECLARE start_of_year date;
  DECLARE end_date date;

  SET start_of_year = DATE(CONCAT(YEAR(start_date), '-01-01'));
  SET end_date = (SELECT
      LAST_DAY(start_date));

  -- 1 incident detail information.
  CALL api_safety_executive(NULL, start_date, 1, NULL);

  -- 2 Work hours matrix.
  SELECT
    whl_hours_worked,
    ltrs.ltr_text site,
    ltrj.ltr_text job,
    whl_level_of_detail,
    whl_start_date,
    whl_end_date
  FROM work_hours_log
    LEFT JOIN ref_list_detail rldj
      ON work_hours_log.whl_job_id = rldj.rld_id
    LEFT JOIN language_translation ltrj
      ON ltrj.ltr_tag = rldj.rld_name
      AND ltrj.ltr_lng_id = 1
      AND ltrj.ltr_tag_type = rldj.rld_tag_type
    LEFT JOIN ref_list_detail rlds
      ON work_hours_log.whl_site_id = rlds.rld_id
    LEFT JOIN language_translation ltrs
      ON ltrs.ltr_tag = rlds.rld_name
      AND ltrs.ltr_lng_id = 1
      AND ltrs.ltr_tag_type = rlds.rld_tag_type
  WHERE YEAR(whl_start_date) = YEAR(start_date)
  OR YEAR(whl_end_date) = YEAR(end_date)
  AND whl_enable = 1;

  -- 3 Detail setting.
  SELECT
    sys_setting_value
  FROM system_settings AS level_of_detail
  WHERE sys_setting_name = 'level of detail';

  -- 4 Positive recognition count
  SELECT
    COUNT(1) AS positive_recognition_count,
    get_translation_from_ref_list_id(sh.Site, 'ref_site', 1) Site,
    get_translation_from_ref_list_id(sh.JobNumber, 'ref_job', 1) JobNumber
  FROM SubmissionPositiveRecognition AS positive_recognition_count_ytd
    INNER JOIN SubmissionHeader sh
      ON positive_recognition_count_ytd.SubmissionHeaderID = sh.ID
  WHERE sh.FormSubmissionDate BETWEEN start_date AND end_date
  GROUP BY sh.Site,
           sh.JobNumber;


  -- 5 Positive recognition count YTD.
  SELECT
    COUNT(1) AS positive_recognition_count_ytd,
    get_translation_from_ref_list_id(sh.Site, 'ref_site', 1) Site,
    get_translation_from_ref_list_id(sh.JobNumber, 'ref_job', 1) JobNumber
  FROM SubmissionPositiveRecognition AS positive_recognition_count_ytd
    INNER JOIN SubmissionHeader sh
      ON positive_recognition_count_ytd.SubmissionHeaderID = sh.ID
  WHERE sh.FormSubmissionDate BETWEEN start_of_year AND end_date
  GROUP BY sh.Site,
           sh.JobNumber;


  -- 6 ORA for the month
  SELECT
    COUNT(1) ORA_count
  FROM rmm_ora
  WHERE rmm_ora_date BETWEEN start_date AND end_date
  AND rmm_ora_enable = 1; -- count ORA  

  -- 7 PRA for the month
  SELECT
    COUNT(1) PRA_count
  FROM rmm_pra
  WHERE rmm_pra_date BETWEEN start_date AND end_date
  AND rmm_pra_enable = 1;

  -- 8 JRA for the month
  SELECT
    COUNT(1) JRA_count
  FROM rmm_jra
  WHERE rmm_jra_date BETWEEN start_date AND end_date
  AND rmm_jra_enable = 1;

  -- 9 Bow for the month
  SELECT
    COUNT(1) BOW_count
  FROM rmm_bowtie
  WHERE rmm_bow_date BETWEEN start_date AND end_date
  AND rmm_bow_enable = 1;

  -- 10 lineup for the month
  SELECT
    COUNT(1) lineup_count
  FROM LineupFormHeader lfh
  WHERE lfh.LineupDate BETWEEN start_date AND end_date
  AND lfh.lfh_enable = 1;

  -- 11 Safety meeting for the month
  SELECT
    COUNT(1) safety_meeting_count
  FROM SubmissionHeader sh
  WHERE sh.FormDescriptionID = 1339
  AND sh.FormSubmissionDate BETWEEN start_date AND end_date;
  -- AND sh.she_enable = 1

  -- 12 ORA for the year  
  SELECT
    COUNT(1) ORA_count_ytd
  FROM rmm_ora
  WHERE rmm_ora_date BETWEEN start_of_year AND end_date
  AND rmm_ora_enable = 1;

  -- 13 PRA for the year  
  SELECT
    COUNT(1) PRA_count_ytd
  FROM rmm_pra
  WHERE rmm_pra_date BETWEEN start_of_year AND end_date
  AND rmm_pra_enable = 1;

  -- 14 JRA for the year  
  SELECT
    COUNT(1) JRA_count_ytd
  FROM rmm_jra
  WHERE rmm_jra_date BETWEEN start_of_year AND end_date
  AND rmm_jra_enable = 1;

  -- 15 Bow for the year  
  SELECT
    COUNT(1) BOW_count_ytd
  FROM rmm_bowtie
  WHERE rmm_bow_date BETWEEN start_of_year AND end_date
  AND rmm_bow_enable = 1;

  -- 16 Lineup for the year  
  SELECT
    COUNT(1) lineup_count_ytd
  FROM LineupFormHeader lfh
  WHERE lfh.LineupDate BETWEEN start_of_year AND end_date
  AND lfh.lfh_enable = 1;

  -- 17 Safety meeting for the year  
  SELECT
    COUNT(1) safety_meeting_count_ytd
  FROM SubmissionHeader sh
  WHERE sh.FormDescriptionID = 1339
  AND sh.FormSubmissionDate BETWEEN start_of_year AND end_date;
  -- AND sh.she_enable = 1

  -- 18 Training counts for completed training this month.
  SELECT
    ltr_text,
    COUNT(1)
  FROM employee_training training_count
    INNER JOIN ref_list_detail rld
      ON training_count.etr_training_code_id = rld.rld_id
    INNER JOIN language_translation
      ON ltr_tag = rld_name
      AND ltr_tag_type = rld.rld_tag_type
      AND ltr_lng_id = 1
  WHERE etr_completion_date BETWEEN start_date AND end_date
  GROUP BY etr_training_code_id;

  -- 19 Year to date training totals for training this month.
  SELECT
    ltr_text,
    COUNT(1) training_ytd
  FROM employee_training training_count_ytd
    INNER JOIN ref_list_detail rld
      ON training_count_ytd.etr_training_code_id = rld.rld_id
    INNER JOIN language_translation
      ON ltr_tag = rld_name
      AND ltr_tag_type = rld.rld_tag_type
      AND ltr_lng_id = 1
  WHERE etr_completion_date BETWEEN start_of_year AND end_date
  AND training_count_ytd.etr_training_code_id IN (SELECT
      tc.etr_training_code_id
    FROM employee_training tc
      INNER JOIN ref_list_detail rld
        ON tc.etr_training_code_id = rld.rld_id
      INNER JOIN language_translation
        ON ltr_tag = rld_name
        AND ltr_tag_type = rld.rld_tag_type
        AND ltr_lng_id = 1
    WHERE etr_completion_date BETWEEN start_date AND end_date
    GROUP BY etr_training_code_id)
  GROUP BY ltr_text;

  -- 20 PPE Count for the month
  SELECT
    COUNT(1) ppe_audit_count
  FROM SubmissionHeader sh
  WHERE sh.FormDescriptionID = 1291
  AND sh.FormSubmissionDate BETWEEN start_date AND end_date;
  -- AND sh.she_enable = 1 
  -- PPE count YTD

  -- 21 PPE Count for the year 
  SELECT
    COUNT(1) ppe_audit_ytd
  FROM SubmissionHeader sh
  WHERE sh.FormDescriptionID = 1291
  AND sh.FormSubmissionDate BETWEEN start_of_year AND end_date;
  -- AND sh.she_enable = 1 

  -- 22 Incident Count for the month
  SELECT
    COUNT(1) incident_count
  FROM Incidents
  WHERE Incidents.inc_minimum_incident_date BETWEEN start_date AND end_date;

  -- 23 Incident Count for the year to date.
  SELECT
    COUNT(1) incident_count_ytd
  FROM Incidents
  WHERE Incidents.inc_minimum_incident_date BETWEEN start_of_year AND end_date;

  -- 24 Hazard count for the month
  SELECT
    COUNT(1) AS hazard_count,
    get_translation_from_ref_list_id(Site, 'ref_site', 1) Site,
    get_translation_from_ref_list_id(sh1.JobNumber, 'ref_job', 1) JobNumber
  FROM submission_hazard_action_completion shac
    INNER JOIN SubmissionHAP sh
      ON shac.hac_sha_id = sh.ID
    INNER JOIN SubmissionHeader sh1
      ON sh.SubmissionHeaderID = sh1.ID
  WHERE hac_completed_action_date BETWEEN start_date AND end_date
  AND hac_enable = 1
  GROUP BY sh1.Site,
           sh1.JobNumber;

  -- 25 Hazard count YTD
  SELECT
    COUNT(1) AS hazard_count_ytd,
    get_translation_from_ref_list_id(Site, 'ref_site', 1) Site,
    get_translation_from_ref_list_id(sh1.JobNumber, 'ref_job', 1) JobNumber
  FROM submission_hazard_action_completion shac
    INNER JOIN SubmissionHAP sh
      ON shac.hac_sha_id = sh.ID
    INNER JOIN SubmissionHeader sh1
      ON sh.SubmissionHeaderID = sh1.ID
  WHERE hac_completed_action_date BETWEEN start_of_year AND end_date
  AND hac_enable = 1
  GROUP BY sh1.Site,
           sh1.JobNumber;

  -- 26 Target by site and job for the month
  CALL api_target_site_job(start_date, end_date);

  -- 27 Target by site and job for the year
  CALL api_target_site_job(start_of_year, end_date);


  -- 28 closed incidents this month.
  SELECT
    COUNT(1) closed_incidents
  FROM Incidents
  WHERE (is_incident_signed_off(Incidents.ID, start_date, end_date) = 1);


  -- 29 closed incidents this year.
  SELECT
    COUNT(1) closed_incidents
  FROM Incidents
  WHERE (is_incident_signed_off(Incidents.ID, start_of_year, end_date) = 1);

  -- 30 Trailing indicators for the month
  CALL api_safety_trailing_indicators(start_date, end_date);

  -- 31 Trailing indicators for the year
  CALL api_safety_trailing_indicators(start_of_year, end_date);

END
$$

DELIMITER ;

--
-- Create column `poq_additional_detail_required` on table `preop_question`
--
ALTER TABLE preop_question
ADD COLUMN IF NOT EXISTS poq_additional_detail_required tinyint(4) DEFAULT NULL;

--
-- Create column `poq_additional_detail_description` on table `preop_question`
--
ALTER TABLE preop_question
ADD COLUMN IF NOT EXISTS poq_additional_detail_description int(11) DEFAULT NULL;

--
-- Change columns order on table `preop_question`
--
ALTER TABLE preop_question
MODIFY poq_additional_detail_required tinyint(4) DEFAULT NULL AFTER poq_decimal_precision;
ALTER TABLE preop_question
MODIFY poq_additional_detail_description int(11) DEFAULT NULL AFTER poq_additional_detail_required;

--
-- Create table `preop_context_image`
--
CREATE TABLE IF NOT EXISTS preop_context_image (
  pci_id int(11) NOT NULL AUTO_INCREMENT,
  pci_poq_id int(11) DEFAULT NULL,
  pci_lng_id int(11) NOT NULL,
  pci_image varchar(400) DEFAULT NULL,
  pci_actual_image tinyint(4) DEFAULT NULL,
  pci_created_date datetime DEFAULT NULL,
  pci_created_by_per_id int(11) DEFAULT NULL,
  pci_modified_date datetime DEFAULT NULL,
  pci_modified_by_per_id int(11) DEFAULT NULL,
  pci_enable tinyint(1) DEFAULT NULL,
  pci_enote varchar(400) DEFAULT NULL,
  PRIMARY KEY (pci_id)
)
ENGINE = INNODB,
CHARACTER SET utf8mb3,
COLLATE utf8mb3_general_ci;

--
-- Create foreign key
--
ALTER TABLE preop_context_image
ADD CONSTRAINT FK_preop_context_image_pci_created_by_per_id FOREIGN KEY IF NOT EXISTS (pci_created_by_per_id)
REFERENCES person (per_id) ON DELETE NO ACTION;

--
-- Create foreign key
--
ALTER TABLE preop_context_image
ADD CONSTRAINT FK_preop_context_image_pci_lng_id FOREIGN KEY IF NOT EXISTS (pci_lng_id)
REFERENCES language (lng_id) ON DELETE NO ACTION;

--
-- Create foreign key
--
ALTER TABLE preop_context_image
ADD CONSTRAINT FK_preop_context_image_pci_modified_by_per_id FOREIGN KEY IF NOT EXISTS (pci_modified_by_per_id)
REFERENCES person (per_id) ON DELETE NO ACTION;

--
-- Create foreign key
--
ALTER TABLE preop_context_image
ADD CONSTRAINT FK_preop_context_image_pci_poq_id FOREIGN KEY IF NOT EXISTS (pci_poq_id)
REFERENCES preop_question (poq_id) ON DELETE NO ACTION;

--
-- Drop procedure `rpt_pre_op_questions_by_submission`
--
DROP PROCEDURE IF EXISTS rpt_pre_op_questions_by_submission;

DELIMITER $$

--
-- Create procedure `rpt_pre_op_questions_by_submission`
--
CREATE PROCEDURE IF NOT EXISTS rpt_pre_op_questions_by_submission (IN ID int, IN location varchar(225), IN language_id int)
BEGIN

  /*
   Creation Date: 3rd June 2021
   Created By: Jaganjot Kaur
   Description: Fetching pre op question details
   
   Change history
   
   Updated on: 2022-01-17
   Updated by: Jazmyn Zarichney
   Description: Replacing strings with tags (SOF-10161)
   
   Updated on: 2022-01-18
   Updated by: Jazmyn Zarichney
   Description: Updating the pre_op_label to the correct ltr_tag
   
   Modified By: Jazmyn Zarichney
   Modified Date: 2022-05-04
   Description: Adding enable check on language translations (SOF-11119) 
   
   Modified By: Jazmyn Zarichney
   Modified Date: 2022-09-08
   Description: Updating the labels to use the language function (SOF-12027) 

   Modified By: Robert Rivest
   Modified Date: 2022-10-06
   Description: SOF-11879 - corrected CAST of inner join

   Modified By: Robert Rivest
   Modified Date: 2023-02-17
   Description: SOF-13505 - Changed Query to use new table names and fieldnames
  
   Modified By: Pragati Das
   Modified Date: 2023-06-13
   Description: SOF-14372 - Added a column in the select statement preop_question.poq_pct_id,
               psh_pet_id and poq_id

   Modified By: Vishnu Prakash
   Modified Date: 2024-05-15
   Description: PD-452 - Equipment Pre-Ops - Report - Submission Reports - Pre-Op

   Modified By: Pragati Das
   Modified Date: 2024-05-21
   Description: PD-452 - Equipment Pre-Ops - Report - Fixed the variable name and added yes and no label

   Modified By: Vishnu Prakash
   Modified Date: 2024-06-02
   Description: PD-452 - Added extra condition for additional comments

   Modified By: Vishnu Prakash
   Modified Date: 2024-07-03
   Description: PD-2232 - Report - Pre-Op - Image Field Shown Twice

    Modified By: Pragati Das / Vishnu Prakash
   Modified Date: 2024-12-30
   Description: PD-2623 - Added equipment context

   Modified By: Naveen Kumar Vadlamudi
   Modified Date: 2024-01-21
   Description: PD-3058 - Added case when statement for getting image into value column.

   Modified By: Vishnu Prakash
   Modified Date: 2024-02-18
   Description: PD-3058 - include the image upload url
  
  */

  DECLARE ok_value text;
  DECLARE defective_value text;
  DECLARE yes_value text;
  DECLARE no_value text;
  DECLARE pre_op_label text;
  DECLARE questions_label text;
  DECLARE post_op_label text;
  DECLARE signature_label text;
  DECLARE superisor_signature_label text;
  DECLARE pet_id varchar(11);

  SET ok_value = get_translation(1405, language_id, 1);
  SET defective_value = get_translation(1440, language_id, 1);
  SET yes_value = get_translation(1379, language_id, 1);
  SET no_value = get_translation(1380, language_id, 1);
  SET pre_op_label = get_translation(995, language_id, 1);
  SET questions_label = get_translation(1955, language_id, 1);
  SET post_op_label = get_translation(8352, language_id, 1);
  SET signature_label = get_translation(823, language_id, 1);
  SET superisor_signature_label = get_translation(850, language_id, 1);
  SET pet_id = (SELECT
      psh_pet_id
    FROM preop_submission_header
    WHERE preop_submission_header.psh_submissionheader_id = ID);

  WITH additional_info_rs
  AS
  (SELECT
      preop_submission_value.*,
      CASE WHEN psv_preop_question_identifier LIKE BINARY '%galleryid\_%' THEN SUBSTRING_INDEX (SUBSTRING_INDEX (psv_preop_question_identifier, '|', 2), '|', -1) ELSE SUBSTRING_INDEX (psv_preop_question_identifier, '_', 1) END AS questionIdentifier
    FROM preop_submission_value
    WHERE psv_psh_id = (SELECT
        psh_id
      FROM preop_submission_header
      WHERE psh_submissionheader_id = ID)
    AND (psv_preop_question_identifier LIKE '%additional_info'
    OR psv_preop_question_identifier LIKE BINARY '%galleryid\_%'
    )),
  pic_area_signature_rs
  AS
  (SELECT
      uniqueRecords.questionIdentifier,
      GROUP_CONCAT(uniqueRecords.psv_value) AS psv_value
    FROM (SELECT
        questionIdentifier,
        JSON_OBJECTAGG(image_and_signs.keyColumn, image_and_signs.valueColumn) AS psv_value
      FROM (SELECT
          psv_preop_question_identifier,
          CASE WHEN (BINARY psv_preop_question_identifier LIKE '%_signature_img_time%') THEN SUBSTRING_INDEX (psv_preop_question_identifier, '_signature_img_time', 1) WHEN (BINARY psv_preop_question_identifier LIKE '%_signature%') THEN SUBSTRING_INDEX (psv_preop_question_identifier, '_signature', 1) WHEN (BINARY psv_preop_question_identifier LIKE '%_sign_comment%') THEN SUBSTRING_INDEX (psv_preop_question_identifier, '_sign_comment', 1) ELSE TRIM(SUBSTRING_INDEX (psv_preop_question_identifier, '|', 1)) END AS imageUnique,
          unique_records.questionIdentifier,
          CASE WHEN (BINARY psv_preop_question_identifier LIKE '%_comment%') THEN 'comment' WHEN (BINARY psv_preop_question_identifier LIKE '%_signature_img_time%' OR
              (STR_TO_DATE(filter_tbl.psv_value, '%Y-%m-%d %H:%i:%s') IS NOT NULL)) THEN 'timestamp' ELSE 'image' END AS keyColumn,
          CASE WHEN (BINARY psv_preop_question_identifier LIKE '%_comment%') OR
              (BINARY psv_preop_question_identifier LIKE '%_signature_img_time%' OR
              (STR_TO_DATE(filter_tbl.psv_value, '%Y-%m-%d %H:%i:%s') IS NOT NULL)) THEN filter_tbl.psv_value ELSE CONCAT(location, filter_tbl.psv_value) END AS valueColumn

        FROM (SELECT
            psv_preop_question_identifier,
            psv_value
          FROM preop_submission_value
          WHERE psv_psh_id = (SELECT
              psh_id
            FROM preop_submission_header
            WHERE psh_submissionheader_id = ID)
          UNION
          SELECT
            poa_element_name AS psv_preop_question_identifier,
            poa_image_timestamp AS psv_value
          FROM preop_attachments
          WHERE poa_psh_id = (SELECT
              psh_id
            FROM preop_submission_header
            WHERE psh_submissionheader_id = ID)
          AND poa_element_name LIKE BINARY '%galleryid\_%') AS filter_tbl
          INNER JOIN (SELECT DISTINCT
              CASE WHEN (psv_preop_question_identifier LIKE '%_signature%' OR
                  psv_preop_question_identifier LIKE '%_comment' AND
                  (psv_preop_question_identifier NOT LIKE '%|_comment')) THEN SUBSTRING_INDEX (psv_preop_question_identifier, '_', 1) ELSE SUBSTRING_INDEX (SUBSTRING_INDEX (psv_preop_question_identifier, '|', 2), '|', -1) END AS questionIdentifier
            FROM preop_submission_value
            WHERE psv_psh_id = (SELECT
                psh_id
              FROM preop_submission_header
              WHERE psh_submissionheader_id = ID)
            AND (psv_preop_question_identifier LIKE '%_signature'
            OR psv_preop_question_identifier LIKE '%\_comment%'
            )) AS unique_records
            ON filter_tbl.psv_preop_question_identifier LIKE CONCAT('%', unique_records.questionIdentifier, '%')
        WHERE psv_preop_question_identifier NOT LIKE ('%_vector_employee%')
        AND psv_preop_question_identifier NOT LIKE ('%_vector_sign')) AS image_and_signs
      GROUP BY image_and_signs.imageUnique) AS uniqueRecords
    GROUP BY uniqueRecords.questionIdentifier)



  SELECT
    NULL AS image_comments,
    CASE WHEN preop_question.poq_pct_id = 11 THEN CONCAT(location, '/preop_equipment/', preop_context_image.pci_image) ELSE preop_submission_value.psv_value END AS Answer,
    preop_submission_header.psh_submissionheader_id,
    language_translation.ltr_text AS PreOpQuestion,
    preop_question.poq_pct_id,
    preop_submission_header.psh_pet_id,
    preop_question.poq_id,
    ok_value AS ok_value,
    defective_value AS defective_value,
    yes_value AS yes_value,
    no_value AS no_value,
    pre_op_label AS pre_op_label,
    questions_label AS questions_label,
    post_op_label AS post_op_label,
    signature_label AS signature_label,
    superisor_signature_label AS superisor_signature_label,
    CASE WHEN LENGTH(TRIM(additional_info_rs.psv_value)) > 0 THEN preop_additional_info_label.ltr_text ELSE '' END AS additional_info_item,
    additional_info_rs.psv_value AS additional_info_value,
    preop_question.poq_additional_detail_required,
    get_translation(preop_question.poq_additional_detail_description, language_id, 2) AS poq_additional_detail_description

  FROM preop_submission_header
    INNER JOIN preop_submission_value
      ON preop_submission_header.psh_id = preop_submission_value.psv_psh_id
    INNER JOIN preop_question
      ON CAST(preop_submission_value.psv_preop_question_identifier AS char) = CAST(preop_question.poq_preop_identifier AS char)
    LEFT JOIN language_translation
      ON language_translation.ltr_tag = preop_question.poq_preop_question
    LEFT JOIN language_translation AS preop_additional_info_label
      ON preop_additional_info_label.ltr_tag = preop_question.poq_additional_info_label
      AND (preop_additional_info_label.ltr_lng_id = language_id)
      AND (preop_additional_info_label.ltr_tag_type = preop_question.poq_tag_type)
    LEFT JOIN additional_info_rs
      ON CAST(additional_info_rs.questionIdentifier AS char) = CAST(preop_question.poq_preop_identifier AS char)
    LEFT JOIN preop_context_image
      ON preop_context_image.pci_poq_id = preop_question.poq_id
      AND preop_context_image.pci_lng_id = language_id
  WHERE (preop_submission_header.psh_submissionheader_id = ID)
  AND (language_translation.ltr_lng_id = language_id)
  AND (language_translation.ltr_tag_type = preop_question.poq_tag_type)


  UNION
  SELECT
    pic_area_signature_rs.psv_value AS image_comments,
    '' AS Answer,
    '' AS psh_submissionheader_id,
    language_translation.ltr_text AS PreOpQuestion,
    preop_question.poq_pct_id,
    pet_id AS psh_pet_id,
    preop_question.poq_id,
    ok_value AS ok_value,
    defective_value AS defective_value,
    yes_value AS yes_value,
    no_value AS no_value,
    pre_op_label AS pre_op_label,
    questions_label AS questions_label,
    post_op_label AS post_op_label,
    signature_label AS signature_label,
    superisor_signature_label AS superisor_signature_label,
    '' AS additional_info_item,
    '' AS additional_info_value,
    '' AS poq_additional_detail_required,
    '' AS poq_additional_detail_description
  FROM pic_area_signature_rs
    INNER JOIN preop_question
      ON CAST(preop_question.poq_preop_identifier AS char) = CAST(pic_area_signature_rs.questionIdentifier AS char)
    LEFT JOIN language_translation
      ON language_translation.ltr_tag = preop_question.poq_preop_question
      AND language_translation.ltr_lng_id = language_id
      AND language_translation.ltr_tag_type = preop_question.poq_tag_type

  UNION

  SELECT
    JSON_OBJECT('timestamp', psv_created_date, 'image', CONCAT(location, additional_info_rs.psv_value)) AS image_comments,
    '' AS Answer,
    '' AS psh_submissionheader_id,
    language_translation.ltr_text AS PreOpQuestion,
    preop_question.poq_pct_id,
    pet_id AS psh_pet_id,
    preop_question.poq_id,
    ok_value AS ok_value,
    defective_value AS defective_value,
    yes_value AS yes_value,
    no_value AS no_value,
    pre_op_label AS pre_op_label,
    questions_label AS questions_label,
    post_op_label AS post_op_label,
    signature_label AS signature_label,
    superisor_signature_label AS superisor_signature_label,
    '' AS additional_info_item,
    '' AS additional_info_value,
    '' AS poq_additional_detail_required,
    '' AS poq_additional_detail_description

  FROM additional_info_rs
    INNER JOIN preop_question
      ON preop_question.poq_preop_identifier = additional_info_rs.questionIdentifier
    LEFT JOIN language_translation
      ON language_translation.ltr_tag = preop_question.poq_preop_question
      AND language_translation.ltr_lng_id = language_id
      AND language_translation.ltr_tag_type = preop_question.poq_tag_type
  WHERE preop_question.poq_pct_id = 5;
END
$$

DELIMITER ;

--
-- Drop procedure `get_preop_questions`
--
DROP PROCEDURE IF EXISTS get_preop_questions;

DELIMITER $$

--
-- Create procedure `get_preop_questions`
--
CREATE PROCEDURE IF NOT EXISTS get_preop_questions (IN lang varchar(11))
BEGIN
  /*
  Modified Date: 2021-05-17
  Modified By: Zach Ross
  Modification: SOF-7734 - Modified to join PreOpQuestion i18n translations

  Modified Date: 2021-05-26
  Modified By: Zach Ross
  Modification: SOF-7734 - Modified to concat ltr_tag_type onto tag

  Modified Date: 2021-07-07
  Modified By: Zach Ross
  Modification: SOF-8178 - Modified for tag revamp

  Modified Date: 2021-08-23
  Modified By: Vishnu Prakash
  Modification: SOF-8480 - Preop checkpoint comments-Modify the preop in mobile

  Modified   : 2023-02-15
  Modified by: Robert Rivest
  Reason     : SOF-13504 - Changed to work with new field names and DB Names

  Modified by: Suman Marlapudi
  Date       : 2023-11-30
  Reason     : SOF-14025 - Replace the deprecated SELECT INTO clause with variables.

  Modified by: Vishnu Prakash
  Date       : 2024-05-01
  Reason     : PD-445 - Added new field for the equipment changes

  Modified by: James coles
  Date       : 2024-10-01
  Reason     : PD-2903 - Rename poq_questionmode_id to poq_must_pass_inspection

  Modified by: Vishnu Prakash
  Date       : 2025-01-07
  Reason     : PD-2623 - implemented the preop context feature

  */

  DECLARE lang_id int;
  SET lang_id = (SELECT
      language.lng_id
    FROM language
    WHERE lng_name = lang);

  SELECT
    poq_id,
    poq_preop_identifier,
    poq_must_pass_inspection,
    language_translation.ltr_text AS poq_preop_question,
    poq_sort_order,
    poq_pct_id,
    lang_additional.ltr_text AS poq_additional_info_label,
    poq_additional_info_required,
    poq_additional_info_option,
    poq_decimal_precision,
    CASE WHEN poq_must_pass_inspection = 2 THEN TRUE ELSE FALSE END AS must_pass_inspection,
    preop_question.poq_additional_detail_required,
    preop_question.poq_additional_detail_description,
    lang_additional_details.ltr_text AS additional_detail_description_label,
    preop_context_image.pci_image
  FROM preop_question
    LEFT JOIN language_translation
      ON poq_preop_question = language_translation.ltr_tag
      AND poq_tag_type = language_translation.ltr_tag_type
      AND language_translation.ltr_lng_id = lang_id
    LEFT JOIN language_translation AS lang_additional
      ON poq_additional_info_label = lang_additional.ltr_tag
      AND poq_tag_type = lang_additional.ltr_tag_type
      AND lang_additional.ltr_lng_id = lang_id
    LEFT JOIN preop_context_image
      ON preop_context_image.pci_poq_id = preop_question.poq_id
      AND preop_context_image.pci_lng_id = lang_id
    LEFT JOIN language_translation AS lang_additional_details
      ON lang_additional_details.ltr_tag = poq_additional_detail_description
      AND lang_additional_details.ltr_tag_type = poq_tag_type
      AND lang_additional_details.ltr_lng_id = lang_id
  WHERE preop_question.poq_enable = 1;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_archived_equipment_preop`
--
DROP PROCEDURE IF EXISTS rpt_archived_equipment_preop;

DELIMITER $$

--
-- Create procedure `rpt_archived_equipment_preop`
--
CREATE PROCEDURE IF NOT EXISTS rpt_archived_equipment_preop (IN start_date date, IN end_date date, IN lang int)
BEGIN

  /*
 Created By: Pragati Das
 Created Date: 2023-08-17
 Purpose: SOF-13836 - Archived Non Submissions report( Pre-Op Equipment Type)
 
 Created By: Pragati Das
 Created Date: 2023-08-29
 Purpose: SOF-13836 - Added DATE function to get data for today
  
 Modified By: Vishnu Prakash
 Modified Date: 2023-10-16
 Purpose: SOF-14837- Archive - Context - Reporting - Update Archived Submissions and Archived Item
 
 Modified By: Pragati Das
 Modified Date: 2023-10-26
 Purpose: SOF-14837- Archive - Context - Added position and context column in the select statement
 
 Modified By: Naveen Kumar Vadlamudi 
 Modified Date: 2024-12-05
 Purpose: Report - Archived Items - Data and Date Updates
  */
  SELECT
    pet.pet_id AS equipment_preops_equipment_type,
    pet.pet_equipment_identifier AS equipment_preops_ID,
    archived_context.aco_created_date AS equipment_preops_archived_date,
    archived_by.per_full_name AS equipment_preops_archived_by,
    DATE(pet.pet_created_date) AS equipment_preops_created_date,
    created_by.per_full_name AS equipment_preops_created_by,
    get_translation_from_ref_list_id(pesj.psj_rld_site_id, 'ref_site', lang) AS equipment_preops_site,
    get_translation_from_ref_list_id(pesj.psj_rld_job_id, 'ref_job', lang) AS equipment_preops_department,
    get_translation_from_ref_list_id(archived_context.aco_rld_position_id, 'ref_position', lang) AS equipment_preops_archived_position,
    archived_context.aco_context AS equipment_preops_context
  FROM preop_equipment_type pet
    INNER JOIN preop_equipment_question peq
      ON pet.pet_id = peq.peq_pet_id
    LEFT JOIN archived_context
      ON archived_context.aco_id = peq.peq_aco_id

    INNER JOIN preop_equipment_site_job pesj
      ON pet.pet_id = pesj.psj_pet_id
    LEFT JOIN v_employee archived_by
      ON archived_context.aco_created_by_per_id = archived_by.per_id
    LEFT JOIN v_employee created_by
      ON pet.pet_created_by_per_id = created_by.per_id
  WHERE pet.pet_enable = 0
  AND DATE(archived_context.aco_created_date) BETWEEN start_date AND end_date
  GROUP BY pet.pet_equipment_identifier
  ;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_all_archived_submissions`
--
DROP PROCEDURE IF EXISTS rpt_all_archived_submissions;

DELIMITER $$

--
-- Create procedure `rpt_all_archived_submissions`
--
CREATE PROCEDURE IF NOT EXISTS rpt_all_archived_submissions (IN start_date date, IN end_date date, IN language_id int, IN modules text)
BEGIN
  /*
  Created by : Sarath Sontam
  Date        : 2024-01-04
  Reason      : PD-430 - include rpt_archived_incidents SP, to get archived incidents
   
  Modified by : Naveen Kumar Vadlamudi
  Date        : 2024-12-12
  Reason      : PD - 2869 Report - Archived Items - Data and Date Updates

  */
  SET @all = ISNULL(modules);


  IF @all = TRUE THEN
    CALL rpt_archived_bowtie(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('bowtie_risk_assessment', modules)) > 0 THEN
    CALL rpt_archived_bowtie(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_custom_forms(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('custom_forms', modules)) > 0 THEN
    CALL rpt_archived_custom_forms(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_custom_lists(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('custom_lists', modules)) > 0 THEN
    CALL rpt_archived_custom_lists(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_decision_log(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('decision_log', modules)) > 0 THEN
    CALL rpt_archived_decision_log(start_date, end_date, language_id);
  END IF;


  IF @all = TRUE THEN
    CALL rpt_archived_distribution_contacts(start_date, end_date, language_id);

  ELSEIF (FIND_IN_SET('distribution_contacts', modules)) > 0 THEN
    CALL rpt_archived_distribution_contacts(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_distribution_groups(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('distribution_groups', modules)) > 0 THEN
    CALL rpt_archived_distribution_groups(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_documents(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('documents', modules)) > 0 THEN
    CALL rpt_archived_documents(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_equipment_preop(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('equipment_preops', modules)) > 0 THEN
    CALL rpt_archived_equipment_preop(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_hours_log(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('hours_log', modules)) > 0 THEN
    CALL rpt_archived_hours_log(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_incident_analysis(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('incident_analysis', modules)) > 0 THEN
    CALL rpt_archived_incident_analysis(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_jra(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('job_risk_assessment', modules)) > 0 THEN
    CALL rpt_archived_jra(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_lessons_learned(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('lessons_learned', modules)) > 0 THEN
    CALL rpt_archived_lessons_learned(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_lockout_tagout(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('lockout_tagout', modules)) > 0 THEN
    CALL rpt_archived_lockout_tagout(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_ora(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('organization_risk_assessment', modules)) > 0 THEN
    CALL rpt_archived_ora(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_pra(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('projectprocess_risk_assessment', modules)) > 0 THEN
    CALL rpt_archived_pra(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_roles(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('roles', modules)) > 0 THEN
    CALL rpt_archived_roles(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_targets(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('targets', modules)) > 0 THEN
    CALL rpt_archived_targets(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_training_records(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('training_record', modules)) > 0 THEN
    CALL rpt_archived_training_records(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_incidents(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('incidents', modules)) > 0 THEN
    CALL rpt_archived_incidents(start_date, end_date, language_id);
  END IF;

  IF @all = TRUE THEN
    CALL rpt_archived_useful_links(start_date, end_date, language_id);
  ELSEIF (FIND_IN_SET('useful_links', modules)) > 0 THEN
    CALL rpt_archived_useful_links(start_date, end_date, language_id);
  END IF;

END
$$

DELIMITER ;

--
-- Drop procedure `get_all_site_job_equipment_list`
--
DROP PROCEDURE IF EXISTS get_all_site_job_equipment_list;

DELIMITER $$

--
-- Create procedure `get_all_site_job_equipment_list`
--
CREATE PROCEDURE IF NOT EXISTS get_all_site_job_equipment_list (IN lang_name varchar(2))
BEGIN

  /*
     Created by: Robert Rivest
     Modified on: 2023-03-15
     Reason: SOF-10407 - Procedure to get a list of equipment with the associated sites/jobs

     Modified by: Robert Rivest
     Modified on: 2023-03-15
     Reason: SOF-14042 - Changed logic to match one used in App

     Modified by: Robert Rivest
     Modified on: 2023-04-21
     Reason: SOF-14054 - Changed sort of equipment

     Modified by: Suman Marlapudi
     Date       : 2023-11-13
     Reason     : SOF-14025 - Replace the deprecated SELECT INTO clause with variables.

     Modified by: Vishnu Prakash
     Date       : 2024-11-14
     Reason     : PD-840 - Equipment-Pre-Op---Active-In-Active-Option
     
     Modified by: Vishnu Prakash
     Date       : 2025-01-28
     Reason     : PD-3270 - Equipment-Pre-Op-Turn off mandatory pictures
  */

  DECLARE lang int;
  SET lang = (SELECT
      lng_id
    FROM language
    WHERE language.lng_name = lang_name);

  SELECT
    pet.pet_id,
    pet.pet_poe_id,
    pesj.psj_rld_site_id,
    pesj.psj_rld_job_id,
    pet.pet_equipment_identifier,
    get_translation(pe.poe_equip_description, lang, pe.poe_tag_type) AS pet_equipment_name,
    pet.pet_start_photos_required,
    pet.pet_end_photos_required
  FROM preop_equipment_type pet
    LEFT JOIN preop_equipment_question peq
      ON pet.pet_id = peq.peq_pet_id
    LEFT JOIN preop_equipment_site_job pesj
      ON pet.pet_id = pesj.psj_pet_id
      AND pesj.psj_enable = 1
    INNER JOIN preop_equipment pe
      ON pet.pet_poe_id = pe.poe_id
  WHERE pet.pet_enable = 1
  AND peq.peq_pet_id IS NOT NULL
  AND peq_enable = 1
  AND pet_is_active = 1
  GROUP BY pet.pet_id
  ORDER BY pet.pet_equipment_identifier, get_translation(pe.poe_equip_description, lang, pe.poe_tag_type);

END
$$

DELIMITER ;

--
-- Alter column `int_emp_employee_number` on table `integration_training`
--
ALTER TABLE integration_training
CHANGE COLUMN IF EXISTS int_emp_employee_number int_emp_employee_number varchar(255) DEFAULT NULL;

--
-- Create column `int_email` on table `integration_training`
--
ALTER TABLE integration_training
ADD COLUMN IF NOT EXISTS int_email varchar(255) DEFAULT NULL;

DELIMITER $$

--
-- Create procedure `int_training_integration_check`
--
CREATE PROCEDURE IF NOT EXISTS int_training_integration_check ()
BEGIN

  /*
    Created By: Naveen Kumar Vadlamudi 
    Purpose: Validating bulk training records import.
    Created Date: 2025-02-03 
   */


  DECLARE loaded_count int DEFAULT 0;
  DECLARE integrated_count int DEFAULT 0;

  SELECT
    SUM(training_count) INTO loaded_count
  FROM (SELECT
      COUNT(1) AS training_count
    FROM integration_training
      INNER JOIN ref_list_detail rld
        ON rld.rld_code = int_training_code
    GROUP BY int_training_type_name,
             int_training_code,
             int_emp_employee_number
    HAVING COUNT(1) = 1) AS loaded_data;


  SELECT
    SUM(employee_count.c) INTO integrated_count
  FROM (SELECT
      COUNT(1) c
    FROM employee_training ee
      INNER JOIN employee e
        ON e.emp_id = ee.etr_emp_id
    GROUP BY ee.etr_training_status_id,
             etr_training_code_id,
             e.emp_employee_number
    HAVING COUNT(1) = 1) AS employee_count;

  IF (loaded_count = integrated_count
    AND (loaded_count != 0
    AND integrated_count != 0)) THEN
    SELECT
      "Training records Import Successful, and the counts are successfully matching.";
  END IF;


END
$$

DELIMITER ;

--
-- Drop procedure `int_process_training_institutions`
--
DROP PROCEDURE IF EXISTS int_process_training_institutions;

DELIMITER $$

--
-- Create procedure `int_process_training_institutions`
--
CREATE PROCEDURE IF NOT EXISTS int_process_training_institutions ()
BEGIN

  /* Declare needed variables here */
  DECLARE int_records_count int DEFAULT 0;
  DECLARE int_institution_translation_id int DEFAULT 0;
  DECLARE int_current_tag int DEFAULT 0;
  DECLARE current_record int DEFAULT 0;
  DECLARE int_training_institution_code,
          int_training_institution_description,
          int_training_institution_name text DEFAULT '';
  DECLARE record_exists tinyint DEFAULT TRUE;
  DECLARE records_found int DEFAULT 0;
  DECLARE institution_tag int DEFAULT 0;
  DECLARE tag_count int DEFAULT 0;
  /* Retrieve the number of integration records, and loop through them */
  SELECT
    COUNT(*)
  FROM integration_training INTO int_records_count;
  SET current_record = 0;
  WHILE current_record < int_records_count DO


    /* Reset needed variables to their default value, as some may have been set to values during previous iterations of this looping procedure */
    SET record_exists = 0;
    SET records_found = 0;
    SET institution_tag = 0;
    SET int_training_institution_code = '';
    SET int_training_institution_name = '';
    SET int_training_institution_description = '';


    /* Based on the current record, populate the current training code, code and number of records found based on that site - any more than 0 indicates the site already exists! */
    SELECT
      integration_training.int_training_institution_code,
      integration_training.int_training_institution_name,
      integration_training.int_training_institution_description INTO int_training_institution_code, int_training_institution_name, int_training_institution_description
    FROM integration_training LIMIT current_record, 1;

    IF LENGTH(TRIM(int_training_institution_name)) > 0 THEN

      SELECT
        ltr_tag INTO institution_tag
      FROM language_translation
        INNER JOIN ref_list_detail rld
          ON rld.rld_name = ltr_tag
          AND rld.rld_rlh_id = 52
      WHERE ltr_text = int_training_institution_name
      AND ltr_lng_id = 1
      AND ltr_enable = 1
      AND ltr_tag_type = 2
      AND ltr_translated = 1
      LIMIT 1;

      SELECT
        COUNT(*) INTO records_found
      FROM ref_list_detail
      WHERE rld_name = institution_tag
      AND rld_enable = 1
      AND rld_rlh_id IN (SELECT
          rlh_id
        FROM ref_list_header
        WHERE rlh_name = 'ref_training_institution');

    ELSE
      SET records_found = 1;
    END IF;

    IF ISNULL(institution_tag)
      OR institution_tag = 0 THEN
      SET records_found = 0;
    END IF;


    IF records_found > 0 THEN
      SET record_exists = 1;
    ELSE
      SET record_exists = 0;
    END IF;

    /* If the record does not exist, go ahead and insert it into the ref list detail table */
    IF record_exists = 0
      AND LENGTH(TRIM(int_training_institution_name)) > 0 THEN

      SET int_current_tag = (SELECT
          MAX(ltr_tag) + 1
        FROM language_translation
        WHERE ltr_tag_type = 2);

      SET int_institution_translation_id = int_current_tag;

      -- insert the english translation record for the training name
      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (1, int_current_tag, int_training_institution_name, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint: Training Institution', 1);

      -- Apply the used tag to the french and spanish entries
      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (2, int_current_tag, int_training_institution_name, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint: Training Institution', 0);

      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (3, int_current_tag, int_training_institution_name, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint: Training Institution', 0);

      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (4, int_current_tag, int_training_institution_name, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint: Training Institution', 0);


      INSERT INTO ref_list_detail (rld_rlh_id,
      rld_code,
      rld_name,
      rld_description,
      rld_tag_type,
      rld_parent_detail_rld_id,
      rld_created_date,
      rld_created_by_per_id,
      rld_enable,
      rld_enote)
        SELECT
          (SELECT
              rlh_id
            FROM ref_list_header
            WHERE rlh_name = 'ref_training_institution' LIMIT 1),
          int_training_institution_code,
          int_current_tag,
          int_training_institution_description,
          2,
          NULL,
          NOW(),
          1,
          1,
          'Inserted via integration - int_process_training_institutions()';
    END IF;


    /* Iterate the counter, to point to the next record */
    SET current_record = current_record + 1;
  END WHILE;
END
$$

DELIMITER ;

--
-- Drop index `IDX_integration_training_temp_int_emp_employee_number` from table `integration_training_temp`
--
ALTER TABLE integration_training_temp
DROP INDEX IF EXISTS IDX_integration_training_temp_int_emp_employee_number;

--
-- Alter column `int_emp_employee_number` on table `integration_training_temp`
--
ALTER TABLE integration_training_temp
CHANGE COLUMN IF EXISTS int_emp_employee_number int_emp_employee_number varchar(255) DEFAULT NULL;

--
-- Create column `int_email` on table `integration_training_temp`
--
ALTER TABLE integration_training_temp
ADD COLUMN IF NOT EXISTS int_email varchar(255) DEFAULT NULL;

--
-- Create index `IDX_integration_training_temp_int_emp_employee_number` on table `integration_training_temp`
--
ALTER TABLE integration_training_temp
ADD INDEX IF NOT EXISTS IDX_integration_training_temp_int_emp_employee_number (int_emp_employee_number);

--
-- Change permissions on `integration_training_temp`
--

DELIMITER $$

--
-- Create procedure `int_process_training_by_email`
--
CREATE PROCEDURE IF NOT EXISTS int_process_training_by_email ()
BEGIN


  DECLARE int_records_count int DEFAULT 0;
  DECLARE current_record int DEFAULT 0;
  DECLARE per_enable tinyint DEFAULT 0;

  DECLARE etr_emp_id,
          emp_id,
          etr_training_type_id,
          training_type_id,
          etr_training_institution_id,
          training_institution_id,
          etr_training_code_id,
          training_code_id,
          int_id,
          is_integrated,
          new_etr_id int DEFAULT 0;

  DECLARE int_email,
          int_training_type_code,
          int_training_institution_code,
          int_training_institution_name,
          int_training_institution_description,
          is_retired_flag,
          int_url,
          int_training_code,
          institution_code text DEFAULT '';

  DECLARE int_etr_completion_date,
          int_etr_expiry_date,
          existing_completion_date date DEFAULT NULL;

  DECLARE records_found int DEFAULT 0;

  DECLARE complete int(11);
  DECLARE retired int(11);

  DECLARE support_account int(11) DEFAULT get_support_account();

  SET complete = (SELECT
      rld_id
    FROM ref_list_detail
    WHERE rld_name = 2045
    AND rld_rlh_id = 90
    AND rld_enable = 1); -- rld_id for - complete
  SET retired = (SELECT
      rld_id
    FROM ref_list_detail
    WHERE rld_name = 1442
    AND rld_rlh_id = 90
    AND rld_enable = 1  -- rld_id for - retired

  );

  DELETE
    FROM integration_training_temp;
    -- ALTER TABLE integration_training_temp AUTO_INCREMENT = 1;

    SELECT
      COUNT(*)
    FROM integration_training INTO int_records_count;
    SET current_record = 0;
    WHILE current_record < int_records_count DO

      SET records_found = 0;
      SET etr_emp_id = 0;
      SET emp_id = 0;
      SET etr_training_type_id = 0;
      SET etr_training_institution_id = 0;
      SET etr_training_code_id = 0;
      SET training_type_id = 0;
      SET training_institution_id = 0;
      SET training_code_id = 0;
      SET int_etr_completion_date = NULL;
      SET int_etr_expiry_date = NULL;
      SET int_email = '';
      SET int_id = 0;
      SET is_integrated = 0;
      SET is_retired_flag = '';
      SET int_url = '';
      SET institution_code = '';

      SELECT
        integration_training.int_id,
        integration_training.int_email,
        integration_training.int_training_type_code,
        integration_training.int_training_institution_code,
        integration_training.int_training_institution_name,
        integration_training.int_training_institution_description,
        integration_training.int_training_code,
        integration_training.int_etr_completion_date,
        integration_training.int_etr_expiry_date,
        integration_training.int_record_is_integrated,
        integration_training.int_retired_flag,
        integration_training.int_training_certificate_link INTO int_id
      , int_email
      , int_training_type_code
      , int_training_institution_code
      , int_training_institution_name
      , int_training_institution_description
      , int_training_code
      , int_etr_completion_date
      , int_etr_expiry_date
      , is_integrated
      , is_retired_flag
      , int_url
      FROM integration_training LIMIT current_record, 1;

      -- select ltr_tag FROM language_translation where ltr_text = int_training_institution_name;

      SELECT
        rld_id INTO institution_code
      FROM ref_list_detail
      WHERE rld_name = (SELECT
          ltr_tag
        FROM language_translation
        WHERE ltr_text = int_training_institution_name
        AND ltr_tag_type = 2
        AND ltr_lng_id = 1 LIMIT 1)
      AND rld_rlh_id = 52
      AND rld_enable = 1 LIMIT 1;

      IF institution_code = 0 THEN
        SET institution_code = NULL;
      END IF;

      # We are going to fetch the mail from the employee using email address from auth user sofvie.
      SELECT
        e.emp_id INTO etr_emp_id
      FROM auth_user_sofvie aus
        INNER JOIN employee AS e
          ON e.emp_per_id = aus.user_per_id
      WHERE TRIM(aus.email) = TRIM(int_email)
      AND int_email != '' LIMIT 1;

      SELECT
        ref_list_detail.rld_id INTO training_code_id
      FROM ref_list_detail
        LEFT OUTER JOIN ref_list_header
          ON ref_list_detail.rld_rlh_id = ref_list_header.rlh_id
      WHERE ref_list_detail.rld_code = int_training_code
      AND ref_list_header.rlh_name = 'ref_training_code' LIMIT 1;

      SELECT
        ref_list_detail.rld_id INTO training_type_id
      FROM ref_list_detail
        LEFT OUTER JOIN ref_list_header
          ON ref_list_detail.rld_rlh_id = ref_list_header.rlh_id
      WHERE LOWER(TRIM(ref_list_detail.rld_code)) = LOWER(TRIM(int_training_type_code))
      AND ref_list_header.rlh_name = 'ref_training_type' LIMIT 1;

      SELECT
        COUNT(etr_id),
        etr_completion_date INTO records_found,
      existing_completion_date
      FROM employee_training
      WHERE employee_training.etr_training_type_id = training_type_id
      AND employee_training.etr_training_code_id = training_code_id
      AND employee_training.etr_emp_id = etr_emp_id
      AND int_email != ''
      AND employee_training.etr_enable <> 0;

      # Added an extra condition to check if the incoming completion date is greater than the existing record in the table.
      IF (records_found > 0
        AND is_integrated = 0) THEN
        IF (existing_completion_date <= int_etr_completion_date) THEN
          UPDATE employee_training
          SET etr_completion_date = int_etr_completion_date,
              etr_expiry_date = int_etr_expiry_date,
              etr_modified_date = NOW(),
              etr_modified_by_per_id = get_support_account(),
              etr_no_expiry_date = CASE WHEN int_etr_expiry_date IS NULL THEN 1 ELSE 0 END,
              etr_training_status_id = CASE WHEN TRIM(is_retired_flag) = 'Y' THEN retired ELSE complete END,
              etr_enote = CONCAT('Modified via integration - int_process_training()\n', etr_enote)

          WHERE employee_training.etr_training_code_id = training_code_id
          AND employee_training.etr_training_type_id = training_type_id
          AND employee_training.etr_emp_id = etr_emp_id;
        END IF;
      END IF;


      IF (etr_emp_id > 0
        AND records_found = 0
        AND training_code_id != 0
        AND training_type_id != 0
        AND int_etr_completion_date IS NOT NULL
        AND etr_emp_id IS NOT NULL) THEN

        INSERT INTO employee_training (employee_training.etr_emp_id
        , employee_training.etr_training_type_id
        , employee_training.etr_training_institution_id
        , employee_training.etr_training_code_id
        , employee_training.etr_completion_date
        , employee_training.etr_expiry_date
        , employee_training.etr_no_expiry_date
        , employee_training.etr_created_date
        , employee_training.etr_created_by_per_id
        , employee_training.etr_enable
        , employee_training.etr_enote
        , employee_training.etr_external_source
        , employee_training.etr_is_integrated
        , employee_training.etr_training_status_id)
          VALUES (etr_emp_id, training_type_id, institution_code, training_code_id, int_etr_completion_date, int_etr_expiry_date, (CASE WHEN int_etr_expiry_date IS NULL THEN 1 ELSE 0 END), NOW(), get_support_account(), 1, 'Inserted via integration - int_process_training()\n', 1, 1, (CASE WHEN TRIM(is_retired_flag) = 'Y' THEN retired ELSE complete END));

        SET new_etr_id = (SELECT
            LAST_INSERT_ID());
        IF LENGTH(TRIM(int_url)) > 0 THEN
          INSERT INTO employee_training_attachment (eta_etr_id, eta_attachment_type, eta_attachment_name, eta_created_date, eta_created_by_per_id, eta_enable, eta_enote)
            VALUES (new_etr_id, 2, int_url, NOW(), support_account, 1, 'Added training URL by integration');

        END IF;


      END IF;


      UPDATE integration_training
      SET int_record_is_integrated = 1,
          int_date_integrated = NOW()
      WHERE integration_training.int_id = int_id
      AND int_record_is_integrated != 1;


      SET current_record = current_record + 1;
    END WHILE;

    END
    $$

DELIMITER ;

--
-- Drop procedure `int_process_training`
--
DROP PROCEDURE IF EXISTS int_process_training;

DELIMITER $$

--
-- Create procedure `int_process_training`
--
CREATE PROCEDURE IF NOT EXISTS int_process_training ()
BEGIN


  DECLARE int_records_count int DEFAULT 0;
  DECLARE current_record int DEFAULT 0;
  DECLARE per_enable tinyint DEFAULT 0;

  DECLARE etr_emp_id,
          emp_id,
          etr_training_type_id,
          training_type_id,
          etr_training_institution_id,
          training_institution_id,
          etr_training_code_id,
          training_code_id,
          int_id,
          is_integrated,
          new_etr_id int DEFAULT 0;

  DECLARE int_emp_employee_number,
          int_training_type_code,
          int_training_institution_code,
          int_training_institution_name,
          int_training_institution_description,
          is_retired_flag,
          int_url,
          int_training_code,
          institution_code text DEFAULT '';

  DECLARE int_etr_completion_date,
          int_etr_expiry_date,
          existing_completion_date date DEFAULT NULL;

  DECLARE records_found int DEFAULT 0;

  DECLARE complete int(11);
  DECLARE retired int(11);

  DECLARE support_account int(11) DEFAULT get_support_account();

  SET complete = (SELECT
      rld_id
    FROM ref_list_detail
    WHERE rld_name = 2045
    AND rld_rlh_id = 90
    AND rld_enable = 1); -- rld_id for - complete
  SET retired = (SELECT
      rld_id
    FROM ref_list_detail
    WHERE rld_name = 1442
    AND rld_rlh_id = 90
    AND rld_enable = 1  -- rld_id for - retired

  );

  DELETE
    FROM integration_training_temp;
    -- ALTER TABLE integration_training_temp AUTO_INCREMENT = 1;

    SELECT
      COUNT(*)
    FROM integration_training INTO int_records_count;
    SET current_record = 0;
    WHILE current_record < int_records_count DO

      SET records_found = 0;
      SET etr_emp_id = 0;
      SET emp_id = 0;
      SET etr_training_type_id = 0;
      SET etr_training_institution_id = 0;
      SET etr_training_code_id = 0;
      SET training_type_id = 0;
      SET training_institution_id = 0;
      SET training_code_id = 0;
      SET int_etr_completion_date = NULL;
      SET int_etr_expiry_date = NULL;
      SET int_emp_employee_number = 0;
      SET int_id = 0;
      SET is_integrated = 0;
      SET is_retired_flag = '';
      SET int_url = '';
      SET institution_code = '';

      SELECT
        integration_training.int_id,
        integration_training.int_emp_employee_number,
        integration_training.int_training_type_code,
        integration_training.int_training_institution_code,
        integration_training.int_training_institution_name,
        integration_training.int_training_institution_description,
        integration_training.int_training_code,
        integration_training.int_etr_completion_date,
        integration_training.int_etr_expiry_date,
        integration_training.int_record_is_integrated,
        integration_training.int_retired_flag,
        integration_training.int_training_certificate_link INTO int_id
      , int_emp_employee_number
      , int_training_type_code
      , int_training_institution_code
      , int_training_institution_name
      , int_training_institution_description
      , int_training_code
      , int_etr_completion_date
      , int_etr_expiry_date
      , is_integrated
      , is_retired_flag
      , int_url
      FROM integration_training LIMIT current_record, 1;

      -- select ltr_tag FROM language_translation where ltr_text = int_training_institution_name;

      SELECT
        rld_id INTO institution_code
      FROM ref_list_detail
      WHERE rld_name = (SELECT
          ltr_tag
        FROM language_translation
        WHERE ltr_text = int_training_institution_name
        AND ltr_tag_type = 2
        AND ltr_lng_id = 1 LIMIT 1)
      AND rld_rlh_id = 52
      AND rld_enable = 1 LIMIT 1;

      IF institution_code = 0 THEN
        SET institution_code = NULL;
      END IF;

      SELECT
        employee.emp_id INTO etr_emp_id
      FROM employee
      WHERE TRIM(employee.emp_employee_number) = TRIM(int_emp_employee_number)
      AND int_emp_employee_number != '' LIMIT 1;

      SELECT
        ref_list_detail.rld_id INTO training_code_id
      FROM ref_list_detail
        LEFT OUTER JOIN ref_list_header
          ON ref_list_detail.rld_rlh_id = ref_list_header.rlh_id
      WHERE ref_list_detail.rld_code = int_training_code
      AND ref_list_header.rlh_name = 'ref_training_code' LIMIT 1;

      SELECT
        ref_list_detail.rld_id INTO training_type_id
      FROM ref_list_detail
        LEFT OUTER JOIN ref_list_header
          ON ref_list_detail.rld_rlh_id = ref_list_header.rlh_id
      WHERE LOWER(TRIM(ref_list_detail.rld_code)) = LOWER(TRIM(int_training_type_code))
      AND ref_list_header.rlh_name = 'ref_training_type' LIMIT 1;

      SELECT
        COUNT(etr_id),
        etr_completion_date INTO records_found,
      existing_completion_date
      FROM employee_training
      WHERE employee_training.etr_training_type_id = training_type_id
      AND employee_training.etr_training_code_id = training_code_id
      AND employee_training.etr_emp_id = etr_emp_id
      AND int_emp_employee_number != ''
      AND employee_training.etr_enable <> 0;

      # Added an extra condition to check if the incoming completion date is greater than the existing record in the table.
      IF (records_found > 0
        AND is_integrated = 0) THEN
        IF (existing_completion_date <= int_etr_completion_date) THEN
          UPDATE employee_training
          SET etr_completion_date = int_etr_completion_date,
              etr_expiry_date = int_etr_expiry_date,
              etr_modified_date = NOW(),
              etr_modified_by_per_id = get_support_account(),
              etr_no_expiry_date = CASE WHEN int_etr_expiry_date IS NULL THEN 1 ELSE 0 END,
              etr_training_status_id = CASE WHEN TRIM(is_retired_flag) = 'Y' THEN retired ELSE complete END,
              etr_enote = CONCAT('Modified via integration - int_process_training()\n', etr_enote)

          WHERE employee_training.etr_training_code_id = training_code_id
          AND employee_training.etr_training_type_id = training_type_id
          AND employee_training.etr_emp_id = etr_emp_id;
        END IF;
      END IF;


      IF (etr_emp_id > 0
        AND records_found = 0
        AND training_code_id != 0
        AND training_type_id != 0
        AND int_etr_completion_date IS NOT NULL
        AND etr_emp_id IS NOT NULL) THEN

        INSERT INTO employee_training (employee_training.etr_emp_id
        , employee_training.etr_training_type_id
        , employee_training.etr_training_institution_id
        , employee_training.etr_training_code_id
        , employee_training.etr_completion_date
        , employee_training.etr_expiry_date
        , employee_training.etr_no_expiry_date
        , employee_training.etr_created_date
        , employee_training.etr_created_by_per_id
        , employee_training.etr_enable
        , employee_training.etr_enote
        , employee_training.etr_external_source
        , employee_training.etr_is_integrated
        , employee_training.etr_training_status_id)
          VALUES (etr_emp_id, training_type_id, institution_code, training_code_id, int_etr_completion_date, int_etr_expiry_date, (CASE WHEN int_etr_expiry_date IS NULL THEN 1 ELSE 0 END), NOW(), get_support_account(), 1, 'Inserted via integration - int_process_training()\n', 1, 1, (CASE WHEN TRIM(is_retired_flag) = 'Y' THEN retired ELSE complete END));

        SET new_etr_id = (SELECT
            LAST_INSERT_ID());
        IF LENGTH(TRIM(int_url)) > 0 THEN
          INSERT INTO employee_training_attachment (eta_etr_id, eta_attachment_type, eta_attachment_name, eta_created_date, eta_created_by_per_id, eta_enable, eta_enote)
            VALUES (new_etr_id, 2, int_url, NOW(), support_account, 1, 'Added training URL by integration');

        END IF;


      END IF;


      UPDATE integration_training
      SET int_record_is_integrated = 1,
          int_date_integrated = NOW()
      WHERE integration_training.int_id = int_id
      AND int_record_is_integrated != 1;


      SET current_record = current_record + 1;
    END WHILE;

    END
    $$

DELIMITER ;

--
-- Drop procedure `int_add_integration_training_records_by_email`
--
DROP PROCEDURE IF EXISTS int_add_integration_training_records_by_email;

DELIMITER $$

--
-- Create procedure `int_add_integration_training_records_by_email`
--
CREATE PROCEDURE IF NOT EXISTS int_add_integration_training_records_by_email ()
BEGIN





  DECLARE int_records_count int DEFAULT 0;
  DECLARE current_record int DEFAULT 0;
  DECLARE record_exists tinyint DEFAULT TRUE;
  DECLARE records_found int DEFAULT 0;
  DECLARE per_enable tinyint DEFAULT 0;
  DECLARE temp_per_enable tinyint DEFAULT 0;

  DECLARE int_emp_email,
          int_training_type_code,
          int_training_type_name,
          int_training_type_description,
          int_training_institution_code,
          int_training_institution_name,
          int_training_institution_description,
          int_training_code,
          int_training_name,
          int_training_description,
          int_etr_completion_date,
          int_etr_expiry_date,
          int_etr_external_source,
          temp_email,
          temp_int_training_type_code,
          temp_int_training_type_name,
          temp_int_training_type_description,
          temp_int_training_institution_code,
          temp_int_training_institution_name,
          temp_int_training_institution_description,
          temp_int_training_code,
          temp_int_training_name,
          temp_int_training_description,
          temp_int_etr_completion_date,
          temp_int_etr_expiry_date,
          temp_int_etr_external_source text DEFAULT '';

  SET GLOBAL net_read_timeout = 120;


  SELECT
    COUNT(*)
  FROM integration_training_temp INTO int_records_count;
  SET current_record = 0;

  WHILE current_record < int_records_count DO



    SET
    int_emp_email = '',
    int_training_type_code = '',
    int_training_type_name = '',
    int_training_type_description = '',
    int_training_institution_code = '',
    int_training_institution_name = '',
    int_training_institution_description = '',
    int_training_code = '',
    int_training_name = '',
    int_training_description = '',
    int_etr_completion_date = NULL,
    int_etr_expiry_date = NULL,
    temp_email = '',
    temp_int_training_type_code = '',
    temp_int_training_type_name = '',
    temp_int_training_type_description = '',
    temp_int_training_institution_code = '',
    temp_int_training_institution_name = '',
    temp_int_training_institution_description = '',
    temp_int_training_code = '',
    temp_int_training_name = '',
    temp_int_training_description = '',
    temp_int_etr_completion_date = NULL,
    temp_int_etr_expiry_date = NULL,
    records_found = 0,
    record_exists = 1;



    SELECT
      integration_training_temp.int_email,
      integration_training_temp.int_training_type_code,
      integration_training_temp.int_training_type_name,
      integration_training_temp.int_training_type_description,
      integration_training_temp.int_training_institution_code,
      integration_training_temp.int_training_institution_name,
      integration_training_temp.int_training_institution_description,
      integration_training_temp.int_training_code,
      integration_training_temp.int_training_name,
      integration_training_temp.int_training_description,
      integration_training_temp.int_etr_completion_date,
      integration_training_temp.int_etr_expiry_date INTO temp_email,
    temp_int_training_type_code,
    temp_int_training_type_name,
    temp_int_training_type_description,
    temp_int_training_institution_code,
    temp_int_training_institution_name,
    temp_int_training_institution_description,
    temp_int_training_code,
    temp_int_training_name,
    temp_int_training_description,
    temp_int_etr_completion_date,
    temp_int_etr_expiry_date

    FROM integration_training_temp LIMIT current_record, 1;




    SELECT
      COUNT(*) INTO records_found
    FROM integration_training
    WHERE TRIM(integration_training.int_email) = TRIM(temp_email)
    AND TRIM(integration_training.int_training_type_code) = TRIM(temp_int_training_type_code)
    AND TRIM(integration_training.int_training_code) = TRIM(temp_int_training_code)
    AND DATE(integration_training.int_etr_completion_date) = DATE(temp_int_etr_completion_date);



    IF records_found > 0 THEN
      SET record_exists = 1;
    ELSE
      SET record_exists = 0;
    END IF;

    IF records_found = 0
      AND temp_int_etr_completion_date IS NOT NULL THEN


      INSERT INTO integration_training (int_record_is_integrated,
      int_date_integrated,
      int_email,
      int_training_type_code,
      int_training_type_name,
      int_training_type_description,
      int_training_institution_code,
      int_training_institution_name,
      int_training_institution_description,
      int_training_code,
      int_training_name,
      int_training_description,
      int_etr_completion_date,
      int_etr_expiry_date)
        VALUES (0, CURRENT_TIMESTAMP(), temp_email, temp_int_training_type_code, temp_int_training_type_name, temp_int_training_type_description, temp_int_training_institution_code, temp_int_training_institution_name, temp_int_training_institution_description, temp_int_training_code, temp_int_training_name, temp_int_training_description, temp_int_etr_completion_date, temp_int_etr_expiry_date);
    END IF;



    SET current_record = current_record + 1;
  END WHILE;

END
$$

DELIMITER ;

--
-- Drop procedure `int_process_sites`
--
DROP PROCEDURE IF EXISTS int_process_sites;

DELIMITER $$

--
-- Create procedure `int_process_sites`
--
CREATE PROCEDURE IF NOT EXISTS int_process_sites ()
BEGIN

  /* Declare needed variables here */
  DECLARE int_records_count int DEFAULT 0;
  DECLARE current_record int DEFAULT 0;
  DECLARE current_int_site text DEFAULT '';
  DECLARE ref_list_detail_site_code text DEFAULT '';
  DECLARE current_int_site_code text DEFAULT '';
  DECLARE current_int_site_description text DEFAULT '';
  DECLARE record_exists tinyint DEFAULT TRUE;
  DECLARE records_found int DEFAULT 0;
  DECLARE site_exists_tag int DEFAULT 0;
  DECLARE site_tag_type int DEFAULT 0;
  DECLARE site_tag int DEFAULT 0;

  /* Retrieve the number of integration records, and loop through them */
  SELECT
    COUNT(*)
  FROM integration_person INTO int_records_count;

  SET current_record = 0;
  WHILE current_record < int_records_count DO

    /* Reset needed variables to their default value, as some may have been set to values during previous iterations of this looping procedure */
    SET record_exists = 0;
    SET records_found = 0;
    SET current_int_site = '';
    SET ref_list_detail_site_code = '';
    SET current_int_site_code = '';
    SET site_exists_tag = NULL;
    SET site_tag_type = NULL;

    /* Based on the current record, populate the current site, code, description and number of records found based on that site - any more than 0 indicates the site already exists! */
    SELECT
      integration_person.int_site_name INTO current_int_site
    FROM integration_person LIMIT current_record, 1;

    SELECT
      integration_person.int_site_code INTO current_int_site_code
    FROM integration_person LIMIT current_record, 1;

    SELECT
      integration_person.int_site_description INTO current_int_site_description
    FROM integration_person LIMIT current_record, 1;


    IF LENGTH(TRIM(current_int_site)) > 0 THEN
      SELECT
        ltr_tag,
        ltr_tag_type INTO site_exists_tag, site_tag_type
      FROM language_translation
      WHERE ltr_text = current_int_site
      AND ltr_enable = 1
      AND ltr_translated = 1
      AND ltr_tag_type = 2
      GROUP BY ltr_tag,
               ltr_tag_type LIMIT 1;
      -- SELECT site_exists_tag AS tag,site_tag_type AS tagtype, current_int_site AS currents;
      -- SELECT 1, position_exists_tag;
      IF NOT ISNULL(site_exists_tag)
        AND site_exists_tag > 0 THEN
        SET records_found = 1;
      -- SELECT rld_name INTO position_exists_tag FROM ref_list_detail WHERE rld_name = ltr_tag AND rlh_id =(SELECT rlh_id FROM ref_list_header WHERE rlh_name = 'ref_position');
      ELSEIF ISNULL(site_exists_tag)
        OR site_exists_tag = 0 THEN
        -- insert into language_translation;
        SET records_found = 0;
      ELSE
        SET records_found = 0;
      END IF;
    ELSE
      SET records_found = 1; -- dont insert into the database.
    END IF;


    --       SELECT
    --          COUNT(*),
    --          ref_list_detail.rld_code INTO records_found, ref_list_detail_site_code
    --       FROM ref_list_detail
    --       WHERE rld_code = current_int_site_code
    --       AND rld_enable = 1
    --       AND rld_rlh_id IN (SELECT
    --             rlh_id
    --          FROM ref_list_header
    --          WHERE rlh_name = 'ref_site');

    /* Set the record_exists variable accordingly to identify if further processing is required */
    IF records_found > 0 THEN
      SET record_exists = 1;
    ELSE
      SET record_exists = 0;
    END IF;

    /* If the current site is null, set it back to it's default */
    IF current_int_site IS NULL THEN
      SET current_int_site = '';
    END IF;

    SELECT
      MAX(ltr_tag) + 1 INTO site_tag
    FROM language_translation
    WHERE ltr_tag_type = 2;
    IF ISNULL(site_tag) THEN
      SET site_tag = 1;
    END IF;


    /* If the record does not exist, go ahead and insert it into the ref list detail table */
    IF (record_exists = 0
      AND current_int_site != '') THEN


      # Add English translation record for Site name
      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (1, site_tag, current_int_site, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint', 1);

      # Add French translation record for Site name
      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (2, site_tag, current_int_site, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint', 0);

      # Add Spanish translation record for Site name
      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (3, site_tag, current_int_site, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint', 0);

      # Add Portuguese translation record for Site name
      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (4, site_tag, current_int_site, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint', 0);


      --          # Add English translation record for Site description
      --          INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
      --             VALUES (1, site_description_tag, current_int_site_description, 2, CURRENT_TIMESTAMP(), NULL, 1, NULL, 1, 'Created via Integration from ViewPoint', 1);

      --          # Add French translation record for Site description
      --          INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
      --             VALUES (2, site_description_tag, current_int_site_description, 2, CURRENT_TIMESTAMP(), NULL, 1, NULL, 1, 'Created via Integration from ViewPoint', 0);

      --          # Add Spanish translation record for Site description
      --          INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
      --             VALUES (3, site_description_tag, current_int_site_description, 2, CURRENT_TIMESTAMP(), NULL, 1, NULL, 1, 'Created via Integration from ViewPoint', 0);



      INSERT INTO ref_list_detail (rld_rlh_id,
      rld_code,
      rld_name,
      --          rld_parent_header_rlh_id,
      rld_parent_detail_rld_id,
      rld_created_date,
      rld_created_by_per_id,
      rld_enable,
      rld_enote,
      rld_tag_type)
        SELECT
          (SELECT
              rlh_id
            FROM ref_list_header
            WHERE rlh_name = 'ref_site' LIMIT 1),
          current_int_site_code,
          site_tag,

          --                NULL,
          NULL,
          NOW(),
          get_support_account(),
          1,
          'Inserted via integration - int_process_sites()\n',
          2;
    END IF;

    -- Update the rld_name with site_tag.
    IF (record_exists = 1
      AND current_int_site_code != ref_list_detail_site_code) THEN -- In this case, we must update if the record exists but the code is changed
      UPDATE ref_list_detail
      SET ref_list_detail.rld_code = current_int_site_code,
          ref_list_detail.rld_modified_date = CURRENT_TIMESTAMP(),
          ref_list_detail.rld_modified_by_per_id = get_support_account(),
          ref_list_detail.rld_enote = LEFT(CONCAT('Modified via integration - int_process_sites()', ref_list_detail.rld_enote), 255)
      WHERE ref_list_detail.rld_name = site_tag;
    END IF;

    /* Iterate the counter, to point to the next record */
    SET current_record = current_record + 1;
  END WHILE;
END
$$

DELIMITER ;

--
-- Drop procedure `int_process_positions`
--
DROP PROCEDURE IF EXISTS int_process_positions;

DELIMITER $$

--
-- Create procedure `int_process_positions`
--
CREATE PROCEDURE IF NOT EXISTS int_process_positions ()
BEGIN

  /* Declare needed variables here */
  DECLARE int_records_count int DEFAULT 0;
  DECLARE current_record int DEFAULT 0;
  DECLARE current_int_position text DEFAULT '';
  DECLARE current_int_position_code text DEFAULT '';
  DECLARE current_int_position_description text DEFAULT '';
  DECLARE record_exists tinyint DEFAULT TRUE;
  DECLARE records_found int DEFAULT 0;
  DECLARE position_tag int DEFAULT 0;
  DECLARE position_exists_tag int DEFAULT NULL;
  DECLARE position_tag_type int DEFAULT 0;
  DECLARE position_rld_id int DEFAULT NULL;

  /* Retrieve the number of integration records, and loop through them */
  SELECT
    COUNT(*)
  FROM integration_person INTO int_records_count;

  SET current_record = 0;
  WHILE current_record < int_records_count DO
    -- SELECT current_record, int_records_count;
    /* Reset needed variables to their default value, as some may have been set to values during previous iterations of this looping procedure */
    SET record_exists = 0;
    SET records_found = 0;
    SET current_int_position = '';
    SET position_exists_tag = NULL;
    SET position_tag_type = NULL;

    /* Based on the current record, populate the current position, code, description and number of records found based on that site - any more than 0 indicates the position already exists! */
    SELECT
      integration_person.int_position_name INTO current_int_position
    FROM integration_person LIMIT current_record, 1;
    -- SELECT current_int_position;
    SELECT
      integration_person.int_position_code INTO current_int_position_code
    FROM integration_person LIMIT current_record, 1;

    SELECT
      integration_person.int_position_description INTO current_int_position_description
    FROM integration_person LIMIT current_record, 1;


    -- 1: in the case where the translation is not in the database: done
    -- 1A: Add the translation to the database. done
    -- 2: Check to see if it is in the ref_list_detail and if not not done
    -- 2a: Add a record to ref_list_detail with that tag in the rld_name field.  not done


    IF LENGTH(TRIM(current_int_position)) > 0 THEN


      SELECT
        ltr_tag,
        ltr_tag_type INTO position_exists_tag, position_tag_type
      FROM language_translation
      WHERE ltr_text = current_int_position
      AND ltr_enable = 1
      AND ltr_translated = 1
      AND ltr_tag_type = 2
      GROUP BY ltr_tag,
               ltr_tag_type LIMIT 1;

      -- SELECT 1, position_exists_tag;
      IF NOT ISNULL(position_exists_tag)
        AND position_exists_tag > 0 THEN
        SET records_found = 1;
      -- SELECT rld_name INTO position_exists_tag FROM ref_list_detail WHERE rld_name = ltr_tag AND rlh_id =(SELECT rlh_id FROM ref_list_header WHERE rlh_name = 'ref_position');
      ELSEIF ISNULL(position_exists_tag)
        OR position_exists_tag = 0 THEN
        -- insert into language_translation;
        SET records_found = 0;
      ELSE
        SET records_found = 0;
      END IF;
    ELSE
      SET records_found = 1; -- dont insert into the database.
    END IF;

    --     SELECT
    --       COUNT(*) INTO records_found
    --     FROM ref_list_detail
    --     WHERE rld_name = current_int_position_code
    --     AND rld_enable = 1
    --     AND rld_rlh_id IN (SELECT
    --         rlh_id
    --       FROM ref_list_header
    --       WHERE rlh_name = 'ref_position');

    /* Set the record_exists variable accordingly to identify if further processing is required */
    IF records_found > 0 THEN
      SET record_exists = 1;
    ELSE
      SET record_exists = 0;
    END IF;

    /* If the current position is null, set it back to it's default */
    IF current_int_position IS NULL THEN
      SET current_int_position = '';
    END IF;

    /* If the record does not exist, go ahead and insert it into the ref list detail table */
    IF (record_exists = 0
      AND current_int_position != '') THEN


      SELECT
        MAX(ltr_tag) + 1 INTO position_tag
      FROM language_translation
      WHERE ltr_tag_type = 2;

      IF ISNULL(position_tag) THEN
        SET position_tag = 1;
      END IF;

      # Add English translation record for position
      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (1, position_tag, current_int_position, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint', 1);

      # Add French translation record for position
      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (2, position_tag, current_int_position, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint', 0);

      # Add Spanish translation record for position
      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (3, position_tag, current_int_position, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint', 0);

      # Add Portuguese translation record for position
      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (4, position_tag, current_int_position, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint', 0);

      INSERT INTO ref_list_detail (rld_rlh_id,
      rld_code,
      rld_name,
      --       rld_parent_header_rlh_id,
      rld_parent_detail_rld_id,
      rld_created_date,
      rld_created_by_per_id,
      rld_enable,
      rld_enote,
      rld_tag_type)
        SELECT
          (SELECT
              rlh_id
            FROM ref_list_header
            WHERE rlh_name = 'ref_position' LIMIT 1),
          current_int_position_code,
          position_tag,
          --           NULL,
          NULL,
          NOW(),
          get_support_account(),
          1,
          NULL,
          2;
    END IF;

    /* Iterate the counter, to point to the next record */
    SET current_record = current_record + 1;

  END WHILE;
END
$$

DELIMITER ;

--
-- Drop procedure `int_process_phone`
--
DROP PROCEDURE IF EXISTS int_process_phone;

DELIMITER $$

--
-- Create procedure `int_process_phone`
--
CREATE PROCEDURE IF NOT EXISTS int_process_phone ()
BEGIN


  DECLARE int_records_count int DEFAULT 0;
  DECLARE current_record int DEFAULT 0;
  DECLARE found_per_id int DEFAULT 0;
  DECLARE int_add_pty_id int DEFAULT NULL;

  DECLARE employee_number,
          pho_number,
          int_pho_number
          text DEFAULT '';

  DECLARE record_exists tinyint DEFAULT TRUE;
  DECLARE records_found int DEFAULT 0;


  SELECT
    COUNT(*)
  FROM integration_person INTO int_records_count;
  SET current_record = 0;
  WHILE current_record < int_records_count DO


    SET record_exists = 0;
    SET records_found = 0;
    SET found_per_id = 0;
    SET int_add_pty_id = NULL;
    SET employee_number = '';
    SET pho_number = NULL;
    SET int_pho_number = NULL;



    SELECT
      integration_person.int_emp_employee_number,
      integration_person.int_add_mobile_phone INTO employee_number
    , int_pho_number
    FROM integration_person
    LIMIT current_record, 1;


    SELECT
      address_phone_type.pty_id INTO int_add_pty_id
    FROM address_phone_type
    WHERE address_phone_type.pty_code = 'M' LIMIT 1;


    SELECT
      address_phone.pho_number INTO pho_number
    FROM address_phone
      LEFT JOIN person
        ON address_phone.pho_per_id = person.per_id
      LEFT OUTER JOIN employee
        ON person.per_id = employee.emp_per_id
    WHERE employee.emp_employee_number = employee_number LIMIT 1;


    SELECT
      MAX(person.per_id) INTO found_per_id
    FROM person
      LEFT JOIN employee
        ON person.per_id = employee.emp_per_id
    WHERE employee.emp_employee_number = employee_number LIMIT 1;



    IF pho_number IS NOT NULL THEN
      SET record_exists = 1;
    ELSE
      SET record_exists = 0;
    END IF;


    IF employee_number IS NULL THEN
      SET employee_number = '';
    END IF;


    IF record_exists = 1 THEN

      UPDATE address_phone
      SET address_phone.pho_number = int_pho_number

      WHERE address_phone.pho_per_id IN (SELECT
          per_id
        FROM person
          LEFT OUTER JOIN employee
            ON person.per_id = employee.emp_per_id
        WHERE employee.emp_employee_number = employee_number);
    END IF;


    IF (record_exists = 0
      AND found_per_id != 0
      AND pho_number != '') THEN

      INSERT INTO address_phone (pho_per_id
      , pho_pty_id
      , pho_number
      , pho_is_primary
      , pho_created_date
      , pho_created_by_per_id
      , pho_enable
      , pho_enote)
        VALUES (found_per_id, int_add_pty_id, pho_number, 1, NOW(), get_support_account(), 1, '');
    END IF;


    SET current_record = current_record + 1;
  END WHILE;

END
$$

DELIMITER ;

--
-- Drop procedure `int_process_personal_emergency_contact`
--
DROP PROCEDURE IF EXISTS int_process_personal_emergency_contact;

DELIMITER $$

--
-- Create procedure `int_process_personal_emergency_contact`
--
CREATE PROCEDURE IF NOT EXISTS int_process_personal_emergency_contact ()
BEGIN


  DECLARE int_records_count int DEFAULT 0;
  DECLARE current_record int DEFAULT 0;
  DECLARE found_per_id int DEFAULT 0;


  DECLARE employee_number,
          pec_first_name,
          pec_last_name,
          pec_relationship,
          pec_home_phone,
          pec_work_phone,
          pec_mobile_phone,
          pec_email,
          int_employee_number,
          int_pec_first_name,
          int_pec_last_name,
          int_pec_relationship,
          int_pec_home_phone,
          int_pec_work_phone,
          int_pec_mobile_phone,
          int_pec_email

          text DEFAULT '';

  DECLARE record_exists tinyint DEFAULT TRUE;
  DECLARE records_found int DEFAULT 0;


  SELECT
    COUNT(*)
  FROM integration_person INTO int_records_count;
  SET current_record = 0;
  WHILE current_record < int_records_count DO


    SET employee_number = '';
    SET pec_first_name = '';
    SET pec_last_name = '';
    SET pec_relationship = '';
    SET pec_home_phone = '';
    SET pec_work_phone = '';
    SET pec_mobile_phone = '';
    SET pec_email = '';
    SET int_employee_number = '';
    SET int_pec_first_name = '';
    SET int_pec_last_name = '';
    SET int_pec_relationship = '';
    SET int_pec_home_phone = '';
    SET int_pec_work_phone = '';
    SET int_pec_mobile_phone = '';
    SET int_pec_email = '';
    SET found_per_id = 0;



    SELECT
      integration_person.int_emp_employee_number,
      integration_person.int_pec_first_name,
      integration_person.int_pec_last_name,
      integration_person.int_pec_relationship,
      integration_person.int_pec_home_phone,
      integration_person.int_pec_work_phone,
      integration_person.int_pec_mobile_phone,
      integration_person.int_pec_email INTO int_employee_number
    , int_pec_first_name
    , int_pec_last_name
    , int_pec_relationship
    , int_pec_home_phone
    , int_pec_work_phone
    , int_pec_mobile_phone
    , int_pec_email
    FROM integration_person LIMIT current_record, 1;


    SELECT
      employee.emp_employee_number,
      person_emergency_contact.pec_first_name,
      person_emergency_contact.pec_last_name,
      person_emergency_contact.pec_relationship,
      person_emergency_contact.pec_home_phone,
      person_emergency_contact.pec_work_phone,
      person_emergency_contact.pec_mobile_phone,
      person_emergency_contact.pec_email INTO employee_number
    , pec_first_name
    , pec_last_name
    , pec_relationship
    , pec_home_phone
    , pec_work_phone
    , pec_mobile_phone
    , pec_email

    FROM person_emergency_contact
      LEFT OUTER JOIN person
        ON person_emergency_contact.pec_per_id = person.per_id
      LEFT OUTER JOIN employee
        ON person.per_id = employee.emp_per_id
    WHERE employee.emp_employee_number = int_employee_number
    ORDER BY person.per_id DESC LIMIT 1;


    SELECT
      MAX(person.per_id) INTO found_per_id
    FROM person
      LEFT JOIN employee
        ON person.per_id = employee.emp_per_id
    WHERE employee.emp_employee_number = int_employee_number LIMIT 1;


    SELECT
      COUNT(person_emergency_contact.pec_per_id) INTO records_found
    FROM person_emergency_contact
      LEFT OUTER JOIN person
        ON person_emergency_contact.pec_per_id = person.per_id
      LEFT OUTER JOIN employee
        ON employee.emp_per_id = person.per_id
    WHERE employee.emp_employee_number = int_employee_number;


    IF records_found > 0 THEN
      SET record_exists = 1;
    ELSE
      SET record_exists = 0;
    END IF;


    IF employee_number IS NULL THEN
      SET employee_number = '';
    END IF;


    IF record_exists = 1 THEN

      UPDATE person_emergency_contact
      SET person_emergency_contact.pec_first_name = int_pec_first_name,
          person_emergency_contact.pec_last_name = int_pec_last_name,
          person_emergency_contact.pec_relationship = int_pec_relationship,
          person_emergency_contact.pec_home_phone = int_pec_home_phone,
          person_emergency_contact.pec_work_phone = int_pec_work_phone,
          person_emergency_contact.pec_mobile_phone = int_pec_mobile_phone,
          person_emergency_contact.pec_email = int_pec_email,
          person_emergency_contact.pec_modified_date = CURRENT_TIMESTAMP(),
          person_emergency_contact.pec_modified_by_per_id = get_support_account(),
          person_emergency_contact.pec_enote = CONCAT('Modified via integration - int_process_person_emergency_contact()\n', person_emergency_contact.pec_enote)
      WHERE person_emergency_contact.pec_per_id IN (SELECT
          per_id
        FROM person
          LEFT OUTER JOIN employee
            ON person.per_id = employee.emp_per_id
        WHERE employee.emp_employee_number = employee_number);
    END IF;

    SET @recs = CONCAT(int_pec_first_name, int_pec_last_name, int_pec_relationship, int_pec_home_phone, int_pec_work_phone, int_pec_mobile_phone, int_pec_email);

    IF (record_exists = 0
      AND found_per_id != 0
      AND int_pec_relationship != 'Self'
      AND LENGTH(@recs) > 0) THEN
      INSERT INTO person_emergency_contact (pec_per_id
      , pec_first_name
      , pec_last_name
      , pec_relationship
      , pec_home_phone
      , pec_work_phone
      , pec_mobile_phone
      , pec_email
      , pec_created_date
      , pec_created_by_per_id
      , pec_enable
      , pec_enote)
        VALUES (found_per_id, int_pec_first_name, int_pec_last_name, int_pec_relationship, int_pec_home_phone, int_pec_work_phone, int_pec_mobile_phone, int_pec_email, NOW(), get_support_account(), 1, 'Inserted via integration - int_process_personal_emergency_contact()\n');
    END IF;


    SET current_record = current_record + 1;
  END WHILE;
END
$$

DELIMITER ;

--
-- Drop procedure `int_process_jobs`
--
DROP PROCEDURE IF EXISTS int_process_jobs;

DELIMITER $$

--
-- Create procedure `int_process_jobs`
--
CREATE PROCEDURE IF NOT EXISTS int_process_jobs ()
BEGIN

  /* Declare needed variables here */
  DECLARE int_records_count int DEFAULT 0;
  DECLARE current_record int DEFAULT 0;
  DECLARE current_int_job text DEFAULT '';
  DECLARE current_int_job_code text DEFAULT '';
  DECLARE current_int_job_description text DEFAULT '';
  DECLARE current_int_site text DEFAULT '';
  DECLARE current_int_site_tag text DEFAULT '';
  DECLARE current_int_site_rldid int DEFAULT NULL;
  DECLARE record_exists tinyint DEFAULT TRUE;
  DECLARE records_found int DEFAULT 0;

  DECLARE job_tag int DEFAULT 0;
  -- DECLARE job_description_tag int DEFAULT 0;

  /* Retrieve the number of integration records, and loop through them */
  SELECT
    COUNT(*)
  FROM integration_person INTO int_records_count;
  SET current_record = 0;
  WHILE current_record < int_records_count DO

    /* Reset needed variables to their default value, as some may have been set to values during previous iterations of this looping procedure */
    SET record_exists = 0;
    SET records_found = 0;
    SET current_int_job = '';
    SET current_int_site = '';
    SET current_int_site_tag = 0;
    /* Based on the current record, populate the current job  */
    SELECT
      integration_person.int_job_name INTO current_int_job
    FROM integration_person LIMIT current_record, 1;

    /* Based on the current record, populate the current job  */
    SELECT
      integration_person.int_job_code INTO current_int_job_code
    FROM integration_person LIMIT current_record, 1;

    /* Based on the current record, populate the current site */
    SELECT
      integration_person.int_site_name INTO current_int_site
    FROM integration_person LIMIT current_record, 1;

    SELECT
      ltr_tag INTO current_int_site_tag
    FROM language_translation
    WHERE ltr_text = current_int_site
    AND ltr_tag_type = 2
    AND ltr_translated = 1 LIMIT 1;
    SELECT
      rld_id INTO current_int_site_rldid
    FROM ref_list_detail
    WHERE rld_name = current_int_site_tag;


    /* Based on the current record, populate the current job description */
    SELECT
      integration_person.int_job_description INTO current_int_job_description
    FROM integration_person LIMIT current_record, 1;

    /* Get the number of records found based on that job - any more than 0 indicates the job already exists! */
    SELECT
      COUNT(*) INTO records_found
    FROM ref_list_detail
    WHERE rld_code = current_int_job_code
    --     AND rld_enable = 1
    AND rld_rlh_id IN (SELECT
        rlh_id
      FROM ref_list_header
      WHERE rlh_name = 'ref_job');

    /* Set the record_exists variable accordingly to identify if further processing is required */
    IF records_found > 0 THEN
      SET record_exists = 1;
    ELSE
      SET record_exists = 0;
    END IF;

    /* If the current site is null, set it back to it's default */
    IF current_int_job IS NULL THEN
      SET current_int_job = '';
    END IF;

    /* If the record does not exist, go ahead and insert it into the ref list detail table */
    IF (record_exists = 0
      AND current_int_job != '') THEN

      SELECT
        MAX(ltr_tag) + 1 INTO job_tag
      FROM language_translation
      WHERE ltr_tag_type = 2;

      IF ISNULL(job_tag) THEN
        SET job_tag = 1;
      END IF;

      -- SET job_description_tag = job_tag + 1;



      # Add English translation record for Job name
      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (1, job_tag, current_int_job, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint: int_process_jobs()', 1);

      # Add French translation record for Job name
      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (2, job_tag, current_int_job, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint: int_process_jobs()', 0);

      # Add Spanish translation record for Job name
      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (3, job_tag, current_int_job, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint: int_process_jobs()', 0);

      # Add Portuguese translation record for Job name
      INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
        VALUES (4, job_tag, current_int_job, 2, CURRENT_TIMESTAMP(), NULL, get_support_account(), NULL, 1, 'Created via Integration from ViewPoint: int_process_jobs()', 0);


      --          # Add English translation record for Job Description
      --          INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
      --             VALUES (1, job_description_tag, current_int_job_description, 2, CURRENT_TIMESTAMP(), NULL, 1, NULL, 1, 'Created via Integration from ViewPoint', 1);
      -- 
      --          # Add French translation record for Job Description
      --          INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
      --             VALUES (2, job_description_tag, current_int_job_description, 2, CURRENT_TIMESTAMP(), NULL, 1, NULL, 1, 'Created via Integration from ViewPoint', 0);
      -- 
      --          # Add Spanish translation record for Job Description
      --          INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
      --             VALUES (3, job_description_tag, current_int_job_description, 2, CURRENT_TIMESTAMP(), NULL, 1, NULL, 1, 'Created via Integration from ViewPoint', 0);


      INSERT INTO ref_list_detail (rld_rlh_id,
      rld_code,
      rld_name,
      -- rld_description,
      -- rld_parent_header_rlh_id,
      rld_parent_detail_rld_id,
      rld_created_date,
      rld_created_by_per_id,
      rld_enable,
      rld_enote,
      rld_tag_type)
        SELECT
          (SELECT
              rlh_id
            FROM ref_list_header
            WHERE rlh_name = 'ref_job' LIMIT 1),
          current_int_job_code,
          job_tag,
          -- job_description_tag,
          --                (SELECT
          --                      ref_list_header.rlh_id
          --                   FROM ref_list_header
          --                   WHERE ref_list_header.rlh_name = 'ref_site' LIMIT 1),
          --                (SELECT
          --                      ref_list_detail.rld_id
          --                   FROM ref_list_detail
          --                      LEFT JOIN ref_list_detail `parent_detail`
          --                         ON ref_list_detail.rld_parent_detail_rld_id = `parent_detail`.rld_id
          --                   WHERE ref_list_detail.rld_name = current_int_site LIMIT 1),
          current_int_site_rldid,
          NOW(),
          get_support_account(),
          1,
          'Inserted via integration - int_process_jobs()\n',
          2;
    END IF;

    /* Iterate the counter, to point to the next record */
    SET current_record = current_record + 1;

  END WHILE;

END
$$

DELIMITER ;

--
-- Drop procedure `int_process_employee_sites`
--
DROP PROCEDURE IF EXISTS int_process_employee_sites;

DELIMITER $$

--
-- Create procedure `int_process_employee_sites`
--
CREATE PROCEDURE IF NOT EXISTS int_process_employee_sites ()
BEGIN


  /* Declare needed variables here */
  DECLARE int_records_count,
          records_not_inserted int DEFAULT 0;
  DECLARE site_missing_count int DEFAULT 0;
  DECLARE current_record int DEFAULT 0;
  DECLARE emp_enable,
          int_enable tinyint DEFAULT 0;
  DECLARE emp_site_id,
          emp_id int DEFAULT 0;
  DECLARE int_site_id int DEFAULT 0;

  DECLARE emp_enote,
          int_enote,
          -- int_site_code,
          int_site_name,
          int_employee_number text DEFAULT '';
  DECLARE site_exists_tag,
          site_tag_type,
          site_tag int DEFAULT NULL;

  DECLARE record_exists tinyint DEFAULT TRUE;
  DECLARE records_found int DEFAULT 0;


  /* Retrieve the number of integration records, and loop through them */
  SELECT
    COUNT(*)
  FROM integration_person INTO int_records_count;
  SET current_record = 0;
  WHILE current_record < int_records_count DO


    /* Reset needed variables to their default value, as some may have been set to values during previous iterations of this looping procedure */
    SET record_exists = 0;
    SET records_found = 0;
    SET emp_site_id = 0;
    SET emp_id = 0;
    SET int_site_id = 0;
    -- SET int_site_code = '';
    SET int_site_name = '';
    SET emp_enote = '';
    SET int_enote = '';
    SET int_employee_number = '';
    SET emp_enable = 0;
    SET int_enable = 0;


    /* Based on the current record, populate the needed person data */
    SELECT
      integration_person.int_emp_employee_number,
      integration_person.int_enable,
      integration_person.int_site_name INTO int_employee_number
    , int_enable
    , int_site_name
    FROM integration_person LIMIT current_record, 1;



    IF LENGTH(TRIM(int_site_name)) THEN

      SELECT
        ltr_tag,
        ltr_tag_type INTO site_exists_tag, site_tag_type
      FROM language_translation
      WHERE ltr_text = int_site_name
      AND ltr_enable = 1
      AND ltr_translated = 1
      AND ltr_tag_type = 2
      GROUP BY ltr_tag,
               ltr_tag_type LIMIT 1;

      IF NOT ISNULL(site_exists_tag)
        AND site_exists_tag > 0 THEN
        SET records_found = 1;
      -- SELECT rld_name INTO position_exists_tag FROM ref_list_detail WHERE rld_name = ltr_tag AND rlh_id =(SELECT rlh_id FROM ref_list_header WHERE rlh_name = 'ref_position');
      ELSEIF ISNULL(site_exists_tag)
        OR site_exists_tag = 0 THEN
        -- insert into language_translation;
        SET records_found = 0;
      ELSE
        SET records_found = 0;
      END IF;
    ELSE
      SET records_found = 1; -- dont insert into the database.

    END IF;


    /* Fetch the site id */
    SELECT
      ref_list_detail.rld_id INTO int_site_id
    FROM ref_list_detail
      LEFT OUTER JOIN ref_list_header
        ON ref_list_detail.rld_rlh_id = ref_list_header.rlh_id
    WHERE ref_list_detail.rld_name = site_exists_tag
    AND ref_list_header.rlh_name = 'ref_site' LIMIT 1;
    -- 

    --     /* Fetch the employee ID */
    SELECT
      employee.emp_id INTO emp_id
    FROM employee
    WHERE employee.emp_employee_number = int_employee_number;

    -- 
    --     /* Count the matching records in the employee_job table - any more than 0 indicates the employee record already exists! */
    SELECT
      COUNT(employee.emp_id) INTO records_found
    FROM employee_site
      LEFT OUTER JOIN employee
        ON employee.emp_id = employee_site.esi_emp_id
    WHERE employee.emp_employee_number = int_employee_number;


    /* Set the record_exists variable accordingly to identify if further processing is required */
    IF records_found > 0 THEN
      SET record_exists = 1;
    ELSE
      SET record_exists = 0;
    END IF;


    /* If the current employee number is null, set it back to it's default */
    IF int_employee_number IS NULL THEN
      SET int_employee_number = '';
    END IF;


    /* If the record exists but does not match, let's update it - requested by Technica to remove this (SSU-1646) */
    --     IF (record_exists = 1
    --       AND int_site_id > 0) THEN
    -- 
    --       UPDATE employee_site
    --       SET employee_site.esi_sit_id = int_site_id
    --       WHERE employee_site.esi_emp_id IN (SELECT
    --           employee.emp_id
    --         FROM employee
    --         WHERE employee.emp_employee_number = int_employee_number);
    --     END IF;


    /* If the record does not exist and the site exists, let's insert a new employee site record */
    IF (record_exists = 0
      AND int_site_id > 0
      AND emp_id > 0) THEN

      INSERT INTO employee_site (esi_emp_id
      , esi_sit_id
      , esi_created_date
      , esi_created_by_per_id
      , esi_enote
      , esi_enable)
        VALUES (emp_id -- ejo_emp_id - INT(11) NOT NULL
        , int_site_id -- ejo_job_id - INT(11)
        , NOW() -- ejo_created_date - DATETIME
        , get_support_account(), 'Inserted via integration - int_process_employee_sites()\n', 1 -- ejo_enable - TINYINT
        );
    END IF;


    /* Iterate the counter, to point to the next record */
    SET current_record = current_record + 1;
  END WHILE;


END
$$

DELIMITER ;

--
-- Drop procedure `int_process_employee_jobs`
--
DROP PROCEDURE IF EXISTS int_process_employee_jobs;

DELIMITER $$

--
-- Create procedure `int_process_employee_jobs`
--
CREATE PROCEDURE IF NOT EXISTS int_process_employee_jobs ()
BEGIN



  DECLARE int_records_count,
          records_not_inserted int DEFAULT 0;
  DECLARE job_missing_count,
          position_missing_count int DEFAULT 0;
  DECLARE current_record int DEFAULT 0;
  DECLARE emp_enable,
          int_enable tinyint DEFAULT 0;
  DECLARE emp_job_id,
          emp_id int DEFAULT 0;
  DECLARE int_job_id int DEFAULT 0;

  DECLARE emp_enote,
          int_enote,
          int_job_name,
          int_job_code,
          int_employee_number text DEFAULT '';

  DECLARE record_exists tinyint DEFAULT TRUE;
  DECLARE records_found int DEFAULT 0;



  SELECT
    COUNT(*)
  FROM integration_person INTO int_records_count;
  SET current_record = 0;
  WHILE current_record < int_records_count DO



    SET record_exists = 0;
    SET records_found = 0;
    SET emp_job_id = 0;
    SET emp_id = 0;
    SET int_job_id = 0;
    SET int_job_name = '';
    SET int_job_code = '';
    SET emp_enote = '';
    SET int_enote = '';
    SET int_employee_number = '';
    SET emp_enable = 0;
    SET int_enable = 0;



    SELECT
      integration_person.int_emp_employee_number,
      integration_person.int_enable,
      integration_person.int_job_name,
      integration_person.int_job_code INTO int_employee_number
    , int_enable
    , int_job_name
    , int_job_code
    FROM integration_person LIMIT current_record, 1;



    SELECT
      ref_list_detail.rld_id INTO int_job_id
    FROM ref_list_detail
      LEFT OUTER JOIN ref_list_header
        ON ref_list_detail.rld_rlh_id = ref_list_header.rlh_id
    WHERE ref_list_detail.rld_code = int_job_code
    AND ref_list_header.rlh_name = 'ref_job' LIMIT 1;



    SELECT
      employee.emp_id INTO emp_id
    FROM employee
    WHERE employee.emp_employee_number = int_employee_number;



    SELECT
      COUNT(employee.emp_id) INTO records_found
    FROM employee_job
      LEFT OUTER JOIN employee
        ON employee.emp_id = employee_job.ejo_emp_id
    WHERE employee.emp_employee_number = int_employee_number;



    IF records_found > 0 THEN
      SET record_exists = 1;
    ELSE
      SET record_exists = 0;
    END IF;



    IF int_employee_number IS NULL THEN
      SET int_employee_number = '';
    END IF;
















    IF (record_exists = 0
      AND int_job_id > 0
      AND emp_id > 0) THEN

      INSERT INTO employee_job (ejo_emp_id
      , ejo_job_id
      , ejo_created_date
      , ejo_created_by_per_id
      , ejo_enable
      , ejo_enote)
        VALUES (emp_id, int_job_id, NOW(), get_support_account(), 1, 'Inserted via integration - int_process_employee_jobs()\n');
    END IF;



    SET current_record = current_record + 1;
  END WHILE;


END
$$

DELIMITER ;

--
-- Drop procedure `int_process_person`
--
DROP PROCEDURE IF EXISTS int_process_person;

DELIMITER $$

--
-- Create procedure `int_process_person`
--
CREATE PROCEDURE IF NOT EXISTS int_process_person ()
BEGIN

  DECLARE int_records_count int DEFAULT 0;
  DECLARE current_record int DEFAULT 0;
  DECLARE per_enable,
          int_enable tinyint DEFAULT 0;
  DECLARE per_dob,
          int_dob date;

  DECLARE employee_number,
          per_first_name,
          per_middle_name,
          per_last_name,
          per_gender,
          per_created_date,
          per_created_by_per_id,
          per_modified_date,
          per_modified_by_per_id,
          per_enote,
          int_first_name,
          int_middle_name,
          int_last_name,
          int_gender,
          int_email,
          int_norcat_id

          text DEFAULT '';

  DECLARE record_exists tinyint DEFAULT TRUE;
  DECLARE records_found,
          int_id,
          per_id,
          user_id,
          email_count int DEFAULT 0;

  DECLARE gender_tag int DEFAULT 0;

  DELETE
    FROM integration_person_temp;
    ALTER TABLE integration_person_temp AUTO_INCREMENT = 1;

    SELECT
      COUNT(*)
    FROM integration_person INTO int_records_count;
    SET current_record = 0;
    WHILE current_record < int_records_count DO

      SET record_exists = 0;
      SET records_found = 0;
      SET employee_number = '';
      SET per_first_name = '';
      SET per_middle_name = '';
      SET per_last_name = '';
      SET per_dob = NULL;
      SET per_gender = '';
      SET per_enable = 0;
      SET per_enote = '';
      SET int_first_name = '';
      SET int_middle_name = NULL;
      SET int_last_name = '';
      SET int_dob = NULL;
      SET int_gender = '';
      SET int_enable = 0;
      SET int_id = 0;
      SET per_id = 0;
      SET user_id = 0;
      SET email_count = 0;
      SET int_email = NULL;
      SET int_norcat_id = NULL;



      SELECT
        integration_person.int_emp_employee_number,
        integration_person.int_id,
        integration_person.int_per_first_name,
        integration_person.int_per_middle_name,
        integration_person.int_per_last_name,
        integration_person.int_per_dob,
        integration_person.int_per_gender,
        integration_person.int_enable,
        integration_person.int_email,
        integration_person.int_norcat_id INTO employee_number
      , int_id
      , int_first_name
      , int_middle_name
      , int_last_name
      , int_dob
      , int_gender
      , int_enable
      , int_email
      , int_norcat_id
      FROM integration_person LIMIT current_record, 1;

      SELECT
        person.per_id,
        person.per_first_name,
        person.per_middle_name,
        person.per_last_name,
        person.per_dob,
        person.per_gender,
        person.per_enable INTO per_id,
      per_first_name,
      per_middle_name,
      per_last_name,
      per_dob,
      per_gender,
      per_enable

      FROM person
        LEFT OUTER JOIN employee
          ON person.per_id = employee.emp_per_id
      WHERE employee.emp_employee_number = employee_number
      ORDER BY person.per_id DESC LIMIT 1;

      IF per_id > 0 THEN
        SET record_exists = 1;
      ELSE
        SET record_exists = 0;
      END IF;

      IF employee_number IS NULL THEN
        SET employee_number = '';
      END IF;

      IF LOWER(int_gender) = 'male' THEN
        SET gender_tag = 6454;
      ELSEIF LOWER(int_gender) = 'female' THEN
        SET gender_tag = 8610;
      END IF;

      IF LENGTH(int_middle_name) = 0 THEN
        SET int_middle_name = NULL;
      END IF;

      IF record_exists = 1 THEN

        UPDATE person
        SET person.per_first_name = int_first_name,
            person.per_middle_name = int_middle_name,
            person.per_last_name = int_last_name,
            person.per_dob = int_dob,
            person.per_gender = gender_tag,
            person.per_norcat_id = int_norcat_id,
            person.per_enote = CONCAT('Modified via integration - int_process_person()\n', person.per_enote)
        WHERE person.per_id = per_id;
      END IF;

      SELECT
        COUNT(auth_user_sofvie.email) INTO email_count
      FROM auth_user_sofvie
      WHERE auth_user_sofvie.email = int_email;

      IF email_count > 0 THEN
        SET int_email = NULL;
      END IF;

      IF record_exists = 0 THEN



        INSERT INTO person (per_first_name
        , per_middle_name
        , per_last_name
        , per_dob
        , per_sin
        , per_gender
        , per_created_date
        , per_created_by_per_id
        , per_enable
        , per_enote
        , per_integration_unique_id
        , per_norcat_id)
          VALUES (int_first_name, int_middle_name, int_last_name, int_dob, NULL, gender_tag, NOW(), get_support_account(), 0, 'Inserted via integration - int_process_person()\n', employee_number, int_norcat_id);



        SELECT
          LAST_INSERT_ID() INTO per_id;

        IF record_exists = 0 THEN

          INSERT INTO auth_user_sofvie (user_per_id
          , password
          , last_login
          , is_superuser
          , first_name
          , last_name
          , is_staff
          , is_active
          , date_joined
          , username
          , email
          , user_login_count
          , password_modified_date
          , reset_token
          , activation_key
          , user_receive_signup_email
          , user_can_login
          , created_date
          , created_by_per_id
          , activation_type
          , user_enote)
            VALUES (per_id, '', NULL, 0, '', '', 0, 0, NOW(), '', int_email, 0, NULL, NULL, NULL, 0, 0, NOW(), get_support_account(), 'later', 'Inserted via integration - int_process_person()\n');

          SELECT
            LAST_INSERT_ID() INTO user_id;



          INSERT INTO auth_user_role_sofvie (aur_user_id
          , aur_aro_id
          , aur_created_date
          , aur_created_by_per_id
          , aur_enable
          , aur_enote)
            VALUES (user_id, 1, NOW(), get_support_account(), 1, 'Inserted via integration - int_process_person()\n');

          INSERT INTO user_profile (upr_per_id
          , upr_language
          , upr_theme_app
          , upr_theme_mobile
          , upr_site_id
          , upr_job_id
          , upr_level_id
          , upr_supervisor_per_id
          , upr_created_by_per_id
          , upr_created_date
          , upr_modified_date
          , upr_modified_by_per_id
          , upr_enable
          , upr_enote)
            VALUES (per_id, 'en', 'light', 'light', NULL, NULL, NULL, NULL, get_support_account(), CURRENT_TIMESTAMP(), NULL, NULL, 1, 'Inserted via integration - int_process_person()\n');
        END IF;
      END IF;



      UPDATE integration_person
      SET int_record_is_integrated = 1
      WHERE integration_person.int_id = int_id;



      SET current_record = current_record + 1;
    END WHILE;

    END
    $$

DELIMITER ;

--
-- Drop view `supervisor_targets_weekly`
--
DROP VIEW IF EXISTS supervisor_targets_weekly CASCADE;

--
-- Create view `supervisor_targets_weekly`
--
CREATE VIEW IF NOT EXISTS supervisor_targets_weekly
AS
SELECT
  `SupervisorTargets`.`sta_per_id` AS `SupervisorID`,
  `SupervisorTargets`.`FDFormID` AS `FDFormID`,
  `DimDate`.`YearCalendar` AS `YearCalendar`,
  `DimDate`.`WeekNumberOfYear` AS `WeekNumberOfYear`,
  `SupervisorTargets`.`Target` AS `Target`,
  COUNT(`submission_header_form_description`.`ID`) AS `ActualCount`,
  `SupervisorTargets`.`EffectiveOn` AS `EffectiveOn`,
  COALESCE(`SupervisorTargets`.`EffectiveEnd`, CAST('December 31, 2050' AS date)) AS `EffectiveEnd`
FROM ((`SupervisorTargets`
  JOIN `DimDate`)
  LEFT JOIN `submission_header_form_description`
    ON (`SupervisorTargets`.`sta_per_id` = `submission_header_form_description`.`SubmittedBy_SupervisorID`
    AND `DimDate`.`date` = `submission_header_form_description`.`FormSubmissionDate`
    AND `SupervisorTargets`.`FDFormID` = `submission_header_form_description`.`FormID`))
WHERE `SupervisorTargets`.`FrequencyID` = 7
GROUP BY `SupervisorTargets`.`sta_per_id`,
         `SupervisorTargets`.`FDFormID`,
         `DimDate`.`YearCalendar`,
         `DimDate`.`WeekNumberOfYear`,
         `SupervisorTargets`.`Target`,
         `SupervisorTargets`.`EffectiveOn`,
         `SupervisorTargets`.`EffectiveEnd`;

--
-- Drop view `supervisor_targets_quarterly`
--
DROP VIEW IF EXISTS supervisor_targets_quarterly CASCADE;

--
-- Create view `supervisor_targets_quarterly`
--
CREATE VIEW IF NOT EXISTS supervisor_targets_quarterly
AS
SELECT
  `SupervisorTargets`.`sta_per_id` AS `SupervisorID`,
  `SupervisorTargets`.`FDFormID` AS `FDFormID`,
  `DimDate`.`YearCalendar` AS `YearCalendar`,
  `DimDate`.`QuarterNumberCalendar` AS `QuarterNumberCalendar`,
  `SupervisorTargets`.`Target` AS `Target`,
  COUNT(`submission_header_form_description`.`ID`) AS `ActualCount`,
  `SupervisorTargets`.`EffectiveOn` AS `EffectiveOn`,
  COALESCE(`SupervisorTargets`.`EffectiveEnd`, CAST('December 31, 2050' AS date)) AS `EffectiveEnd`
FROM ((`SupervisorTargets`
  JOIN `DimDate`)
  LEFT JOIN `submission_header_form_description`
    ON (`SupervisorTargets`.`sta_per_id` = `submission_header_form_description`.`SubmittedBy_SupervisorID`
    AND `DimDate`.`date` = `submission_header_form_description`.`FormSubmissionDate`
    AND `SupervisorTargets`.`FDFormID` = `submission_header_form_description`.`FormID`))
WHERE `SupervisorTargets`.`FrequencyID` = 90
AND `SupervisorTargets`.`sta_enable` = 1
GROUP BY `SupervisorTargets`.`sta_per_id`,
         `SupervisorTargets`.`FDFormID`,
         `DimDate`.`YearCalendar`,
         `DimDate`.`QuarterNumberCalendar`,
         `SupervisorTargets`.`Target`,
         `SupervisorTargets`.`EffectiveOn`,
         `SupervisorTargets`.`EffectiveEnd`;

--
-- Drop view `supervisor_targets_monthly`
--
DROP VIEW IF EXISTS supervisor_targets_monthly CASCADE;

--
-- Create view `supervisor_targets_monthly`
--
CREATE VIEW IF NOT EXISTS supervisor_targets_monthly
AS
SELECT
  `SupervisorTargets`.`sta_per_id` AS `SupervisorID`,
  `SupervisorTargets`.`FDFormID` AS `FDFormID`,
  `DimDate`.`YearCalendar` AS `YearCalendar`,
  `DimDate`.`MonthNumberOfYear` AS `MonthNumberOfYear`,
  `SupervisorTargets`.`Target` AS `Target`,
  COUNT(`submission_header_form_description`.`ID`) AS `ActualCount`,
  `SupervisorTargets`.`EffectiveOn` AS `EffectiveOn`
FROM ((`SupervisorTargets`
  JOIN `DimDate`)
  LEFT JOIN `submission_header_form_description`
    ON (`SupervisorTargets`.`sta_per_id` = `submission_header_form_description`.`SubmittedBy_SupervisorID`
    AND `DimDate`.`date` = `submission_header_form_description`.`FormSubmissionDate`
    AND `SupervisorTargets`.`FDFormID` = `submission_header_form_description`.`FormID`))
WHERE `SupervisorTargets`.`FrequencyID` = 30
AND `SupervisorTargets`.`sta_enable` = 1
GROUP BY `SupervisorTargets`.`sta_per_id`,
         `SupervisorTargets`.`FDFormID`,
         `DimDate`.`YearCalendar`,
         `DimDate`.`MonthNumberOfYear`,
         `SupervisorTargets`.`Target`,
         `SupervisorTargets`.`EffectiveOn`;

--
-- Drop view `supervisor_targets_daily`
--
DROP VIEW IF EXISTS supervisor_targets_daily CASCADE;

--
-- Create view `supervisor_targets_daily`
--
CREATE VIEW IF NOT EXISTS supervisor_targets_daily
AS
SELECT
  `SupervisorTargets`.`sta_per_id` AS `SupervisorID`,
  `SupervisorTargets`.`FDFormID` AS `FDFormID`,
  `DimDate`.`Date` AS `Date`,
  `SupervisorTargets`.`Target` AS `Target`,
  COUNT(`submission_header_form_description`.`ID`) AS `ActualCount`,
  `SupervisorTargets`.`EffectiveOn` AS `EffectiveOn`,
  COALESCE(`SupervisorTargets`.`EffectiveEnd`, CAST('December 31, 2050' AS date)) AS `EffectiveEnd`
FROM ((`SupervisorTargets`
  JOIN `DimDate`)
  LEFT JOIN `submission_header_form_description`
    ON (`SupervisorTargets`.`sta_per_id` = `submission_header_form_description`.`SubmittedBy_SupervisorID`
    AND `DimDate`.`Date` = `submission_header_form_description`.`FormSubmissionDate`
    AND `SupervisorTargets`.`FDFormID` = `submission_header_form_description`.`FormID`))
WHERE `SupervisorTargets`.`FrequencyID` = 1
GROUP BY `SupervisorTargets`.`sta_per_id`,
         `SupervisorTargets`.`FDFormID`,
         `DimDate`.`Date`,
         `SupervisorTargets`.`Target`,
         `SupervisorTargets`.`EffectiveOn`,
         `SupervisorTargets`.`EffectiveEnd`;

--
-- Drop view `supervisor_targets_biannually`
--
DROP VIEW IF EXISTS supervisor_targets_biannually CASCADE;

--
-- Create view `supervisor_targets_biannually`
--
CREATE VIEW IF NOT EXISTS supervisor_targets_biannually
AS
SELECT
  `SupervisorTargets`.`sta_per_id` AS `SupervisorID`,
  `SupervisorTargets`.`FDFormID` AS `FDFormID`,
  `DimDate`.`YearCalendar` AS `YearCalendar`,
  `DimDate`.`HalfNumberCalendar` AS `HalfNumberCalendar`,
  `SupervisorTargets`.`Target` AS `Target`,
  COUNT(`submission_header_form_description`.`ID`) AS `ActualCount`,
  `SupervisorTargets`.`EffectiveOn` AS `EffectiveOn`,
  COALESCE(`SupervisorTargets`.`EffectiveEnd`, CAST('December 31, 2050' AS date)) AS `EffectiveEnd`
FROM ((`SupervisorTargets`
  JOIN `DimDate`)
  LEFT JOIN `submission_header_form_description`
    ON (`SupervisorTargets`.`sta_per_id` = `submission_header_form_description`.`SubmittedBy_SupervisorID`
    AND `DimDate`.`date` = `submission_header_form_description`.`FormSubmissionDate`
    AND `SupervisorTargets`.`FDFormID` = `submission_header_form_description`.`FormID`))
WHERE `SupervisorTargets`.`FrequencyID` = 182
AND `SupervisorTargets`.`sta_enable` = 1
GROUP BY `SupervisorTargets`.`sta_per_id`,
         `SupervisorTargets`.`FDFormID`,
         `DimDate`.`YearCalendar`,
         `DimDate`.`HalfNumberCalendar`,
         `SupervisorTargets`.`Target`,
         `SupervisorTargets`.`EffectiveOn`,
         `SupervisorTargets`.`EffectiveEnd`;

--
-- Drop view `supervisor_targets_annually`
--
DROP VIEW IF EXISTS supervisor_targets_annually CASCADE;

--
-- Create view `supervisor_targets_annually`
--
CREATE VIEW IF NOT EXISTS supervisor_targets_annually
AS
SELECT
  `SupervisorTargets`.`sta_per_id` AS `SupervisorID`,
  `SupervisorTargets`.`FDFormID` AS `FDFormID`,
  `DimDate`.`YearCalendar` AS `YearCalendar`,
  `SupervisorTargets`.`Target` AS `Target`,
  COUNT(`submission_header_form_description`.`ID`) AS `ActualCount`,
  `SupervisorTargets`.`EffectiveOn` AS `EffectiveOn`,
  COALESCE(`SupervisorTargets`.`EffectiveEnd`, CAST('December 31, 2050' AS date)) AS `EffectiveEnd`
FROM ((`SupervisorTargets`
  JOIN `DimDate`)
  LEFT JOIN `submission_header_form_description`
    ON (`SupervisorTargets`.`sta_per_id` = `submission_header_form_description`.`SubmittedBy_SupervisorID`
    AND `DimDate`.`date` = `submission_header_form_description`.`FormSubmissionDate`
    AND `SupervisorTargets`.`FDFormID` = `submission_header_form_description`.`FormID`))
WHERE `SupervisorTargets`.`FrequencyID` = 365
AND `SupervisorTargets`.`sta_enable` = 1
GROUP BY `SupervisorTargets`.`sta_per_id`,
         `SupervisorTargets`.`FDFormID`,
         `DimDate`.`YearCalendar`,
         `SupervisorTargets`.`Target`,
         `SupervisorTargets`.`EffectiveOn`,
         `SupervisorTargets`.`EffectiveEnd`;

--
-- Drop procedure `int_process_all`
--
DROP PROCEDURE IF EXISTS int_process_all;

DELIMITER $$

--
-- Create procedure `int_process_all`
--
CREATE PROCEDURE IF NOT EXISTS int_process_all ()
BEGIN

  DECLARE integration_type tinyint;   -- Possible values 1 - employee number and 2 - email
  DECLARE integration_employee tinyint;  -- 0 means FALSE and 1 means TRUE
  DECLARE integration_training tinyint;   -- 0 means FALSE and 1 means TRUE
  DECLARE continue_flag tinyint;          -- 0 means FALSE and 1 means TRUE
  DECLARE jobs_sites_flag tinyint;  -- Check if the custmer needs jobs, sites to be integrated - 0 means FALSE and 1 means TRUE
  DECLARE positions_flag tinyint;   -- Check if the custmer needs positions to be integrated - 0 means FALSE and 1 means TRUE

  SET continue_flag = 0;
  SET jobs_sites_flag = 0;

  -- Integration settings are stored in the system_settings table and fetched and stored in variables
  SET integration_type = (SELECT
      sys_setting_value
    FROM system_settings
    WHERE sys_setting_name = 'INTEGRATION_TYPE');

  SET integration_employee = (SELECT
      sys_setting_value
    FROM system_settings
    WHERE sys_setting_name = 'INTEGRATION_EMPLOYEES');

  SET integration_training = (SELECT
      sys_setting_value
    FROM system_settings
    WHERE sys_setting_name = 'INTEGRATION_TRAINING');
  SET jobs_sites_flag = (SELECT
      sys_setting_value
    FROM system_settings
    WHERE sys_setting_name = 'INTEGRATE_JOBS_SITES');

  SET positions_flag = (SELECT
      sys_setting_value
    FROM system_settings
    WHERE sys_setting_name = 'INTEGRATE_POSITIONS');


  -- EMPLOYEE INTEGRATION --
  -- Check if the customer requires Employee integration
  IF integration_employee = 1 THEN

    IF integration_type = 1 THEN
      SET continue_flag = 1;
      -- This procedure adds the records from temp to integration_person by employee number
      CALL int_add_integration_records_by_employee_number();

    ELSEIF integration_type = 2 THEN
      SET continue_flag = 1;
      -- This procedure adds the records from temp to integration_person by employee email
      CALL int_add_integration_records_by_employee_email();
    END IF;

  END IF;

  IF continue_flag = 1 THEN

    IF jobs_sites_flag = 1 THEN

      CALL int_process_jobs();
      CALL int_process_sites();



    END IF;

    IF positions_flag = 1 THEN

      CALL int_process_positions();

    END IF;

    CALL int_process_person();
    CALL int_process_employee();
    #CALL int_process_employee();
    CALL int_process_address();
    CALL int_process_personal_emergency_contact();
    CALL int_process_phone();

  END IF;

  IF jobs_sites_flag = 1 THEN
    CALL int_process_employee_jobs();
    CALL int_process_employee_sites();
  END IF;

  -- TRAINING INTEGRATION --
  -- Check if the customer requires Training integration
  IF integration_training = 1 THEN

    -- procedures
    CALL int_add_integration_training_records_by_employee_number();
    CALL int_process_training_codes();

    -- CALL int_process_training_institutions(); - not recorded by Technica, may be used by other clients

    CALL int_process_training();
  END IF;

END
$$

DELIMITER ;

--
-- Drop procedure `rpt_all_targets_detail_planned_vs_actual`
--
DROP PROCEDURE IF EXISTS rpt_all_targets_detail_planned_vs_actual;

DELIMITER $$

--
-- Create procedure `rpt_all_targets_detail_planned_vs_actual`
--
CREATE PROCEDURE IF NOT EXISTS rpt_all_targets_detail_planned_vs_actual (IN start_date varchar(255), IN end_date varchar(255), IN sup_ids text, IN role_ids text, IN site_ids text, IN language_id varchar(10))
BEGIN

  /*
    Created By : Bob/Pragati
    Created Date: 2022-06-18
    Purpose: SOF-11022 - Created new SP for the updated Target Status reports
  
    Modified By : Pragati/Vishnu/Sarath 
    Modified Date: 2022-08-22
    Purpose: SOF-11022 - Updated the SP for the updated Target Status reports to work with all the 3 Target reports
  
    Modified By : Pragati 
    Modified Date: 2022-09-06
    Purpose: SOF-11022 - Added site and role name column
  
    Modified By : Pragati
    Modified Date: 2022-09-15
    Purpose: SOF-12079 - Custom targets - Updated the SP with the form_type, custom form name and tag type columns.
  
    Modified By : Pragati
    Modified Date: 2022-11-03
    Purpose: SOF-12728 - Added sta_enable = 1 and Target != 0 in the WHERE clause
  
    Modified By: Jazmyn Zarichney
    Modified Date: 2023-03-30
    Description: SOF-13837 Adding in esi_enable = 1 on the joins
  
    Modified By: Sarath Sontam
    Modified Date: 2023-05-02
    Description: SOF-14001 - replace joining employee_site and employee_job with employee_membership_site and employee_membership_job

    Modified By: Sarath Sontam
    Modified Date: 2023-10-11
    Description: SOF-14751 - Update employee_membership_site to employee_membership_site_all
  
     Modified By  : James Coles
     Modified Date: 2024-02-12
     Reason        : PD-2254   Change to use sta_per_id

  */

  SELECT DISTINCT
    SupervisorTargets.FrequencyID,
    COALESCE(SUBSTRING(SupervisorTargets.EffectiveEnd, 1, 7), SUBSTRING(end_date, 1, 7)) AS EffectiveEnd,
    COALESCE(SUBSTRING(SupervisorTargets.EffectiveOn, 1, 7), SUBSTRING(start_date, 1, 7)) AS EffectiveOn,
    SupervisorTargets.sta_per_id AS SupervisorID,
    SupervisorTargets.Target AS Target_Monthly,
    CASE WHEN SupervisorTargets.sta_fob_id
        IS NULL THEN SupervisorTargets.FDFormID ELSE SupervisorTargets.sta_fob_id END AS FDFormID,
    CASE WHEN SupervisorTargets.sta_fob_id
        IS NULL THEN 'pre_defined_form' ELSE 'custom_form' END AS form_type,
    (SELECT
        ltr_text
      FROM language_translation
      WHERE ltr_tag_type = (CASE WHEN SupervisorTargets.sta_fob_id
          IS NULL THEN 1 ELSE 2 END)
      AND ltr_lng_id = language_id
      AND ltr_enable = 1
      AND ltr_tag = (CASE WHEN SupervisorTargets.sta_fob_id IS NULL THEN (SELECT
                FormName
              FROM FormDescription
              WHERE SupervisorTargets.FDFormID = FormDescription.FormID LIMIT 1) ELSE (SELECT
              fob_name
            FROM form_builder
            WHERE SupervisorTargets.sta_fob_id = form_builder.fob_id LIMIT 1) END)) AS Form_Name,
    SupervisorTargets.ID,
    v_employee_profile.per_full_name,
    v_employee_profile.per_id,
    v_employee_profile.roles,
    (SELECT
        GROUP_CONCAT(ltr_text)
      FROM auth_role_sofvie
        JOIN language_translation
          ON ltr_tag = aro_name
          AND ltr_tag_type = aro_tag_type
      WHERE ltr_lng_id = language_id
      AND FIND_IN_SET(aro_id, v_employee_profile.roles)
      AND ltr_enable = 1) AS role_names,
    employee_membership_site_all.site_id AS esi_sit_id
  FROM SupervisorTargets
    LEFT JOIN v_employee_profile
      ON SupervisorTargets.sta_per_id = v_employee_profile.per_id

    INNER JOIN auth_user_role_sofvie
      ON auth_user_role_sofvie.aur_user_id = v_employee_profile.user_id
    INNER JOIN auth_role_sofvie
      ON auth_role_sofvie.aro_id = auth_user_role_sofvie.aur_aro_id

    LEFT JOIN v_employee
      ON v_employee.per_id = v_employee_profile.per_id
    LEFT JOIN employee_membership_site_all
      ON employee_membership_site_all.emp_id = v_employee.emp_id
      AND employee_membership_site_all.esi_enable = 1
  WHERE (SupervisorTargets.EffectiveOn <= end_date)

  AND (IF(sup_ids IS NOT NULL,
  ((FIND_IN_SET(v_employee.per_id, sup_ids) > 0)
  OR (sup_ids IS NULL)), v_employee.per_id IS NULL
  OR v_employee.per_id IS NOT NULL))
  AND (IF(site_ids IS NOT NULL,
  (IF(v_employee.emp_membership = 2, FIND_IN_SET(employee_membership_site_all.site_id, site_ids) > 0, 1 = 1)
  OR (site_ids IS NULL)), employee_membership_site_all.site_id IS NULL
  OR employee_membership_site_all.site_id IS NOT NULL))
  AND (IF(role_ids IS NOT NULL,
  ((FIND_IN_SET(auth_role_sofvie.aro_id, role_ids) > 0)
  OR (role_ids IS NULL)), auth_role_sofvie.aro_id IS NULL
  OR auth_role_sofvie.aro_id IS NOT NULL))
  AND SupervisorTargets.sta_enable = 1
  AND SupervisorTargets.Target != 0;


END
$$

DELIMITER ;

--
-- Drop procedure `rpt_all_targets_change_details_data`
--
DROP PROCEDURE IF EXISTS rpt_all_targets_change_details_data;

DELIMITER $$

--
-- Create procedure `rpt_all_targets_change_details_data`
--
CREATE PROCEDURE IF NOT EXISTS rpt_all_targets_change_details_data (IN start_date date, IN end_date date, IN per_id text, IN pre_defined_form_ids text, IN custom_form_ids text, IN language_id int)
BEGIN

  /*
    Created By: Bob/Pragati
    Created Date: 2023-01-17
    Purpose: SOF-13316 - Created new SP to get the Traget counts details
  
    Modified By : Bob/Pragati
    Modified Date: 2023-01-18
    Purpose: SOF-13316 - Added per full name column 

    Modified By : Pragati Das
    Modified Date: 2024-08-23
    Purpose: PD-2768 - Updated the WHERE clause with the created_date

    Modified By : Naveen Kumar Vadlamudi
    Modified Date: 2024-11-04
    Purpose: PD-2649 - Target Status Summary - Change Log with Context Field

    Modified By : Naveen Kumar Vadlamudi
    Modified Date: 2024-01-30
    Purpose: PD-2709 - Target Status Summary - Added an extra timestamp condition to handle data anomalies.

  */
  DECLARE get_translated_data varchar(50);
  SET get_translated_data = get_translation(9990, language_id, 1);


  SELECT
    change_log.stc_created_date AS stc_created_date, #created_date,
    change_log.stc_formId,
    change_log.stc_fob_id,
    change_log.modified_by_person,
    change_log.formname,
    change_log.employee_name,
    CASE WHEN GROUP_CONCAT(change_log.action) IS NULL THEN get_translated_data ELSE GROUP_CONCAT(change_log.action) END AS action,
    GROUP_CONCAT(context) AS context,
    GROUP_CONCAT(change_log.Target) AS Target,
    GROUP_CONCAT(change_log.frequency) AS frequency,
    GROUP_CONCAT(change_log.effective) effective,
    GROUP_CONCAT(change_log.Comments) AS Comments
  FROM (SELECT
      DENSE_RANK() OVER (PARTITION BY t.stc_per_id, t.stc_formId, t.stc_fob_id ORDER BY DATE_FORMAT(t.stc_created_date, '%Y-%m-%d %H:%i') ASC) AS crank,
      ROW_NUMBER() OVER (PARTITION BY t.stc_per_id, t.stc_formId, t.stc_fob_id ORDER BY DATE_FORMAT(t.stc_created_date, '%Y-%m-%d %H:%i') ASC) AS row_number,
      t.stc_created_date,
      t.stc_formId,
      t.stc_fob_id,
      CASE WHEN t.stc_formid IS NOT NULL THEN CONCAT(t.stc_formid, '|', t.stc_created_date) ELSE CONCAT(t.stc_fob_id, '|', t.stc_created_date) END AS unique_ts,
      e.per_full_name AS modified_by_person,
      ename.per_full_name AS employee_name,
      CASE WHEN rl.ltr_text IS NULL THEN get_translation(f.fob_name, language_id, 2) ELSE rl.ltr_text END AS FormName,
      CASE WHEN l.ltr_tag = 1060 THEN get_translation(t.stc_comment, language_id, 1) END AS action,
      CASE WHEN l.ltr_tag = 1342 THEN t.stc_comment END AS context,
      CASE WHEN l.ltr_tag = 1107 THEN CAST(t.stc_comment AS int) END AS Target,
      CASE WHEN l.ltr_tag = 1106 THEN get_translation(t.stc_comment, language_id, 1) END AS frequency,
      CASE WHEN l.ltr_tag = 2448 THEN t.stc_comment END AS effective,
      CASE WHEN l.ltr_tag = 3915 THEN CASE WHEN t.stc_comment REGEXP '^-?[0-9]+$' THEN CASE WHEN MOD(t.stc_comment, 1) = 0 THEN get_translation(t.stc_comment, language_id, 1) END ELSE t.stc_comment END END AS Comments


    FROM supervisor_target_comment t

      INNER JOIN v_employee_profile e
        ON e.per_id = t.stc_created_by_per_id

      LEFT JOIN Reports r
        ON r.SingleFormReportID = t.stc_formId

      LEFT JOIN form_builder f
        ON f.fob_id = t.stc_fob_id

      LEFT JOIN language_translation rl
        ON rl.ltr_tag = r.ReportName
        AND rl.ltr_tag_type = 1
        AND rl.ltr_lng_id = language_id

      INNER JOIN language_translation l
        ON l.ltr_tag = t.stc_change_type
        AND l.ltr_tag_type = 1
        AND l.ltr_lng_id = language_id

      INNER JOIN v_employee_profile ename
        ON ename.per_id = t.stc_per_id

    WHERE t.stc_per_id = per_id
    AND (IF(pre_defined_form_ids IS NOT NULL,
    FIND_IN_SET(t.stc_formId, pre_defined_form_ids), 1 = 1)
    OR IF(custom_form_ids IS NOT NULL,
    FIND_IN_SET(t.stc_fob_id, custom_form_ids), 1 = 1))
    AND DATE(t.stc_created_date) BETWEEN CAST(start_date AS date) AND CAST(end_date AS date)) AS change_log

  GROUP BY DATE_FORMAT(change_log.stc_created_date, '%Y-%m-%d %H:%i'),
           DATE_FORMAT(change_log.unique_ts, '%Y-%m-%d %H:%i'),
           change_log.crank,
           change_log.modified_by_person,
           change_log.employee_name,
           change_log.formname;


END
$$

DELIMITER ;

--
-- Drop procedure `rpt_all_targets`
--
DROP PROCEDURE IF EXISTS rpt_all_targets;

DELIMITER $$

--
-- Create procedure `rpt_all_targets`
--
CREATE PROCEDURE IF NOT EXISTS rpt_all_targets (IN start_date varchar(255), IN end_date varchar(255), IN all_ids text, IN language_id int, IN frequency int, IN report_type varchar(10))
BEGIN

  /*
    Created By : Bob/Pragati
    Created Date: 2022-06-18
    Purpose: SOF-11022 - Created new SP for the updated Target Status reports
  
    Modified By : Pragati/Vishnu/Sarath 
    Modified Date: 2022-08-22
    Purpose: SOF-11022 - Updated the SP for the updated Target Status reports to work with all the 3 Target reports
  
    Modified By : Pragati/Sarath
    Modified Date: 2022-08-31
    Purpose: SOF-11022 - Updated the where clause for the start date.
  
    Modified By : Pragati
    Modified Date: 2022-09-12
    Purpose: SOF-12079 - Custom targets - Updated the SELECT statement with CASE WHEN condition for FDFormID.
  
    Modified By : Pragati
    Modified Date: 2022-09-13
    Purpose: SOF-12079 - Custom targets - Updated the SP with the form_type, custom form name and tag type columns.
  
  
    Modified By : Pragati
    Modified Date: 2022-10-21
    Purpose: SOF-12542- Target Report by Department/Job - Updated the SP for the Targets by Job report
    
    Modified By :  Sarath Sontam
    Modified Date: 02-05-2023
    Purpose: remove additional cases for job and site, as we are now going with new SPs for site and job report types

    Modified By :  Pragati Das
    Modified Date: 2025-02-11
    Purpose: Updated the supervisor_id to sta_per_id
  */

  DECLARE rowcount int;
  DECLARE DELIMITTER varchar(20);


  SET DELIMITTER := ',';
  SET rowcount := (LENGTH(all_ids) - LENGTH(REPLACE(all_ids, DELIMITTER, ''))) + 1;

  CREATE TEMPORARY TABLE IF NOT EXISTS temp_all_ids (
    all_id int
  );

  SET @c = 1;
  WHILE @c <= rowcount DO
    INSERT INTO temp_all_ids
      SELECT
        SUBSTRING_INDEX (SUBSTRING_INDEX (all_ids, DELIMITTER, @c), DELIMITTER, -1) AS val;
    SET @c := @c + 1;
  END WHILE;


  SELECT DISTINCT
    COALESCE(SUBSTRING(SupervisorTargets.EffectiveEnd, 1, 7), SUBSTRING(end_date, 1, 7)) AS EffectiveEnd,
    COALESCE(SUBSTRING(SupervisorTargets.EffectiveOn, 1, 7), SUBSTRING(start_date, 1, 7)) AS EffectiveOn,
    SupervisorTargets.sta_per_id AS SupervisorID,
    SupervisorTargets.Target AS Target_Monthly,
    SupervisorTargets.FrequencyID,
    CASE WHEN SupervisorTargets.sta_fob_id
        IS NULL THEN SupervisorTargets.FDFormID ELSE SupervisorTargets.sta_fob_id END AS FDFormID,

    CASE WHEN SupervisorTargets.sta_fob_id
        IS NULL THEN 'pre_defined_form' ELSE 'custom_form' END AS form_type,

    get_translation((CASE WHEN SupervisorTargets.sta_fob_id IS NULL THEN (SELECT
              FormName
            FROM FormDescription
            WHERE SupervisorTargets.FDFormID = FormDescription.FormID
            GROUP BY FormDescription.FormID) ELSE (SELECT
            fob_name
          FROM form_builder
          WHERE SupervisorTargets.sta_fob_id = form_builder.fob_id) END), language_id, (CASE WHEN SupervisorTargets.sta_fob_id
        IS NULL THEN 1 ELSE 2 END)) AS Form_Name,
    SupervisorTargets.ID,
    v_employee_profile.per_full_name,
    v_employee_profile.per_id,

    CASE WHEN report_type = 'role' THEN auth_role_sofvie.aro_id ELSE v_employee_profile.roles END AS role_ids
  FROM SupervisorTargets
    LEFT JOIN v_employee_profile
      ON SupervisorTargets.sta_per_id = v_employee_profile.per_id

    INNER JOIN auth_user_role_sofvie
      ON auth_user_role_sofvie.aur_user_id = v_employee_profile.user_id
    INNER JOIN auth_role_sofvie
      ON auth_role_sofvie.aro_id = auth_user_role_sofvie.aur_aro_id

    LEFT JOIN v_employee
      ON v_employee.per_id = v_employee_profile.per_id

  WHERE FrequencyID = frequency
  AND (SupervisorTargets.EffectiveOn <= end_date)
  AND (CASE WHEN report_type = 'employee' THEN (IF(rowcount IS NOT NULL, (v_employee_profile.per_id IN (SELECT
            all_id
          FROM temp_all_ids)), v_employee_profile.per_id)) WHEN report_type = 'role' THEN (IF(rowcount IS NOT NULL, (auth_role_sofvie.aro_id IN (SELECT
            all_id
          FROM temp_all_ids)), auth_role_sofvie.aro_id)) ELSE 1 = 1 END)
  ;

  DROP TABLE IF EXISTS temp_all_ids;

END
$$

DELIMITER ;

--
-- Drop procedure `int_maintenance`
--
DROP PROCEDURE IF EXISTS int_maintenance;

DELIMITER $$

--
-- Create procedure `int_maintenance`
--
CREATE PROCEDURE IF NOT EXISTS int_maintenance ()
BEGIN
  /*
    Creation Date: 2022-08-02
    Created By: Suman Marlapudi & James Coles
    Description: Weekly integration maintenance which archives the integration records
  */

  INSERT INTO integration_log (ilg_info, ilg_event_time)
    VALUES ('Start of integration maintenance', NOW());

  -- The query below is used when the processing is taking too long (int_process_employee is a culprit)
  -- Archive the integration_person table before truncating

  INSERT INTO integration_person_archive (int_record_is_integrated, int_date_integrated, int_email, int_per_first_name, int_per_middle_name, int_per_last_name,
  int_per_full_name, int_per_dob, int_per_gender, int_emp_employee_number, int_emp_start_date, int_emp_end_date, int_position_name, int_position_code, int_position_description,
  int_site_code, int_site_name, int_site_description, int_job_code, int_job_name, int_job_description, int_add_line_1, int_add_line_2, int_add_line_3,
  int_add_city, int_add_province_code, int_add_province_name, int_add_postal_code, int_add_country_code, int_add_country_name, int_add_home_phone, int_add_work_phone,
  int_add_mobile_phone, int_pec_first_name, int_pec_last_name, int_pec_full_name, int_pec_relationship, int_pec_home_phone, int_pec_work_phone, int_pec_mobile_phone,
  int_pec_email, int_enable, int_norcat_id)
    SELECT
      int_record_is_integrated,
      int_date_integrated,
      int_email,
      int_per_first_name,
      int_per_middle_name,
      int_per_last_name,
      int_per_full_name,
      int_per_dob,
      int_per_gender,
      int_emp_employee_number,
      int_emp_start_date,
      int_emp_end_date,
      int_position_name,
      int_position_code,
      int_position_description,
      int_site_code,
      int_site_name,
      int_site_description,
      int_job_code,
      int_job_name,
      int_job_description,
      int_add_line_1,
      int_add_line_2,
      int_add_line_3,
      int_add_city,
      int_add_province_code,
      int_add_province_name,
      int_add_postal_code,
      int_add_country_code,
      int_add_country_name,
      int_add_home_phone,
      int_add_work_phone,
      int_add_mobile_phone,
      int_pec_first_name,
      int_pec_last_name,
      int_pec_full_name,
      int_pec_relationship,
      int_pec_home_phone,
      int_pec_work_phone,
      int_pec_mobile_phone,
      int_pec_email,
      int_enable,
      int_norcat_id
    FROM integration_person;

  TRUNCATE integration_person;   


  -- Archive the integration_training table before truncating
  INSERT INTO integration_training_archive (int_record_is_integrated, int_date_integrated, int_emp_employee_number, int_training_type_code,
  int_training_type_name, int_training_type_description, int_training_institution_code, int_training_institution_name,
  int_training_institution_description, int_training_code, int_training_name, int_training_description,
  int_etr_completion_date, int_etr_expiry_date, int_etr_external_source)
    SELECT
      int_record_is_integrated,
      int_date_integrated,
      int_emp_employee_number,
      int_training_type_code,
      int_training_type_name,
      int_training_type_description,
      int_training_institution_code,
      int_training_institution_name,
      int_training_institution_description,
      int_training_code,
      int_training_name,
      int_training_description,
      int_etr_completion_date,
      int_etr_expiry_date,
      int_etr_external_source
    FROM integration_training;

  TRUNCATE integration_training;

  INSERT INTO integration_log (ilg_info, ilg_event_time)
    VALUES ('End of integration maintenance', NOW());


END
$$

DELIMITER ;

--
-- Enable foreign keys
--
/*!40014 SET foreign_key_checks = @OLD_FOREIGN_KEY_CHECKS */;


-- Data Changes
-- PD-955
UPDATE person
SET per_gender = NULL
WHERE per_gender = 0;

-- PD-2844
CALL workplacelevels();
-- Remove SP workplacelevels
DROP PROCEDURE IF EXISTS workplacelevels;

-- PD-3209 
UPDATE Incidents i
SET i.inc_minimum_incident_date = get_min_header_date(i.id);

-- PD-3270
UPDATE preop_equipment_type
SET pet_start_photos_required = 1,
    pet_end_photos_required = 1
WHERE pet_enable = 1;



-- PD-3203
UPDATE distribution_group_email dge
SET dge.dge_enable = 0,
    dge.dge_enote = CONCAT(dge.dge_enote, 'PD-3203-Removing disabled persons from distribution groups.\n'),
    dge.dge_modified_by_per_id = get_support_account()
WHERE dge.dge_email IN (SELECT
    email
  FROM auth_user_sofvie a
    INNER JOIN person
      ON a.user_per_id = person.per_id
  WHERE person.per_enable = 0);

-- PD-3206
INSERT INTO system_settings (sys_setting_type, sys_setting_name, sys_setting_value, sys_setting_text_value, sys_created_date, sys_created_by_per_id, sys_modified_date, sys_modified_by_per_id, sys_enable, sys_enote)
  SELECT
    11,
    'DISABLE_EMAIL_VERIFICATION',
    0,
    NULL,
    NOW(),
    get_support_account(),
    NULL,
    NULL,
    1,
    NULL
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM system_settings
    WHERE system_settings.sys_setting_type = 11
    AND system_settings.sys_setting_name = 'DISABLE_EMAIL_VERIFICATION');

-- PD-2623
UPDATE preop_checkpoint_type
SET pct_enable = 0
WHERE pct_field_label = 9181;
INSERT INTO preop_checkpoint_type (pct_field_label, pct_additional_info, pct_is_static, pct_created_date, pct_created_by_per_id, pct_enable, pct_enote)
  SELECT
    22,
    0,
    1,
    NOW(),
    get_support_account(),
    1,
    'PD-2623'
  WHERE NOT EXISTS (SELECT
      1
    FROM preop_checkpoint_type
    WHERE pct_field_label = 22);

-- PD-2609
UPDATE distribution_group_email
JOIN auth_user_sofvie
  ON auth_user_sofvie.email = distribution_group_email.dge_email
SET distribution_group_email.dge_per_id = auth_user_sofvie.user_per_id,
    dge_modified_date = NOW(),
    dge_enote =left( CONCAT('PD-2609 - Update dge_email to per_id/edl_id.\n', IFNULL(dge_enote, '')),200);

UPDATE distribution_group_email
JOIN external_distribution_list
  ON external_distribution_list.edl_email = distribution_group_email.dge_email
SET distribution_group_email.dge_edl_id = external_distribution_list.edl_id,
    dge_modified_date = NOW(),
    dge_enote =LEFT(CONCAT('PD-2609 - Update dge_email to per_id/edl_id.\n', IFNULL(dge_enote, '')), 200);

UPDATE SubmissionDetails_Explode
JOIN FormFieldDescription
  ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
  AND FormFieldDescription.fieldKey LIKE '%distribution%'
JOIN auth_user_sofvie
  ON auth_user_sofvie.email = SubmissionDetails_Explode.value
SET SubmissionDetails_Explode.value = CONCAT('account-', auth_user_sofvie.user_per_id)
WHERE value != ''
AND value IS NOT NULL;

UPDATE SubmissionDetails_Explode
JOIN FormFieldDescription
  ON FormFieldDescription.ID = SubmissionDetails_Explode.FormFieldDescriptionID
  AND FormFieldDescription.fieldKey LIKE '%distribution%'
JOIN external_distribution_list
  ON external_distribution_list.edl_email = SubmissionDetails_Explode.value
SET SubmissionDetails_Explode.value = CONCAT('external-', external_distribution_list.edl_id)
WHERE value != ''
AND value IS NOT NULL;




INSERT INTO Reports (ReportName, ReportDescription, ReportCategory, ReportURL, SSRSReportName, 
                    rpt_submitted_date, rpt_output_type, rpt_submitted_by_per_id, 
                    rpt_created_date, rpt_created_by_per_id, rpt_enable, rpt_allow_future_dates)
SELECT 10028 AS ReportName, '10029' AS ReportDescription,
       'Report' AS ReportCategory, 'pre_op_submissions_breakdown_summary' AS ReportURL,
       NULL AS SSRSReportName,
       NOW() AS rpt_submitted_date,
       'pageable/pdf' AS rpt_output_type, NULL AS rpt_submitted_by_per_id,
       '2025-01-20 14:28:57' AS rpt_created_date,
       NULL AS rpt_created_by_per_id,
       1 AS rpt_enable,
       0 AS rpt_allow_future_dates 
FROM dual
WHERE NOT EXISTS (
    SELECT 1 FROM Reports
    WHERE ReportName = 10028 AND ReportDescription = '10029'
    AND ReportCategory = 'Report'
    AND ReportURL = 'pre_op_submissions_breakdown_summary'
    AND SSRSReportName IS NULL
    AND rpt_output_type = 'pageable/pdf'
);

SET @id = (SELECT LAST_INSERT_ID());


-- By breakdown
INSERT INTO Reports (rpt_rpt_id, ReportName, ReportDescription, ReportCategory, ReportURL, SSRSReportName, 
                    rpt_submitted_date, rpt_output_type, rpt_submitted_by_per_id, 
                    rpt_created_date, rpt_created_by_per_id, rpt_enable, rpt_allow_future_dates)
SELECT @id  AS rpt_rpt_id, 10028 AS ReportName, NULL AS ReportDescription,
       'Report' AS ReportCategory, 'pre_op_submissions_breakdown' AS ReportURL,
       NULL AS SSRSReportName,
       NOW() AS rpt_submitted_date,
       'pageable/pdf' AS rpt_output_type, NULL AS rpt_submitted_by_per_id,
       NULL AS rpt_created_date,
       NULL AS rpt_created_by_per_id,
       0 AS rpt_enable,
       1 AS rpt_allow_future_dates 
FROM dual
WHERE NOT EXISTS (
    SELECT 1 FROM Reports
    WHERE rpt_rpt_id = 124 AND ReportName = 10028 AND ReportDescription IS NULL
    AND ReportCategory = 'Report'
    AND ReportURL = 'pre_op_submissions_breakdown'
    AND SSRSReportName IS NULL
    AND rpt_output_type = 'pageable/pdf'
);
-- By site
INSERT INTO Reports (rpt_rpt_id, ReportName, ReportDescription, ReportCategory, ReportURL, SSRSReportName, 
                    rpt_submitted_date, rpt_output_type, rpt_submitted_by_per_id, 
                    rpt_created_date, rpt_created_by_per_id, rpt_enable, rpt_allow_future_dates)
SELECT @id  AS rpt_rpt_id, 10030 AS ReportName, NULL AS ReportDescription,
       'Report' AS ReportCategory, 'pre_op_submissions_by_site_breakdown' AS ReportURL,
       NULL AS SSRSReportName,
       NOW() AS rpt_submitted_date,
       'pageable/pdf' AS rpt_output_type, NULL AS rpt_submitted_by_per_id,
       NULL AS rpt_created_date,
       NULL AS rpt_created_by_per_id,
       0 AS rpt_enable,
       1 AS rpt_allow_future_dates 
FROM dual
WHERE NOT EXISTS (
    SELECT 1 FROM Reports
    WHERE rpt_rpt_id = 124 AND ReportName = 10030 AND ReportDescription IS NULL
    AND ReportCategory = 'Report'
    AND ReportURL = 'pre_op_submissions_by_site_breakdown'
    AND SSRSReportName IS NULL
    AND rpt_output_type = 'pageable/pdf'
);

-- By jOb
INSERT INTO Reports (rpt_rpt_id, ReportName, ReportDescription, ReportCategory, ReportURL, SSRSReportName, 
                    rpt_submitted_date, rpt_output_type, rpt_submitted_by_per_id, 
                    rpt_created_date, rpt_created_by_per_id, rpt_enable, rpt_allow_future_dates)
SELECT @id  AS rpt_rpt_id, 10031 AS ReportName, NULL AS ReportDescription,
       'Report' AS ReportCategory, 'pre_op_submissions_by_job_breakdown' AS ReportURL,
       NULL AS SSRSReportName,
       NOW() AS rpt_submitted_date,
       'pageable/pdf' AS rpt_output_type, NULL AS rpt_submitted_by_per_id,
       NULL AS rpt_created_date,
       NULL AS rpt_created_by_per_id,
       0 AS rpt_enable,
       1 AS rpt_allow_future_dates 
FROM dual
WHERE NOT EXISTS (
    SELECT 1 FROM Reports
    WHERE rpt_rpt_id = 124 AND ReportName = 10031 AND ReportDescription IS NULL
    AND ReportCategory = 'Report'
    AND ReportURL = 'pre_op_submissions_by_job_breakdown'
    AND SSRSReportName IS NULL
    AND rpt_output_type = 'pageable/pdf'
);

-- By User
INSERT INTO Reports (rpt_rpt_id, ReportName, ReportDescription, ReportCategory, ReportURL, SSRSReportName, 
                    rpt_submitted_date, rpt_output_type, rpt_submitted_by_per_id, 
                    rpt_created_date, rpt_created_by_per_id, rpt_enable, rpt_allow_future_dates)
SELECT @id  AS rpt_rpt_id, 10032 AS ReportName, NULL AS ReportDescription,
       'Report' AS ReportCategory, 'pre_op_submissions_by_user_breakdown' AS ReportURL,
       NULL AS SSRSReportName,
       NOW() AS rpt_submitted_date,
       'pageable/pdf' AS rpt_output_type, NULL AS rpt_submitted_by_per_id,
       NULL AS rpt_created_date,
       NULL AS rpt_created_by_per_id,
       0 AS rpt_enable,
       1 AS rpt_allow_future_dates 
FROM dual
WHERE NOT EXISTS (
    SELECT 1 FROM Reports
    WHERE rpt_rpt_id = 124 AND ReportName = 10032 AND ReportDescription IS NULL
    AND ReportCategory = 'Report'
    AND ReportURL = 'pre_op_submissions_by_user_breakdown'
    AND SSRSReportName IS NULL
    AND rpt_output_type = 'pageable/pdf'
);

-- By equipment
INSERT INTO Reports (rpt_rpt_id, ReportName, ReportDescription, ReportCategory, ReportURL, SSRSReportName, 
                    rpt_submitted_date, rpt_output_type, rpt_submitted_by_per_id, 
                    rpt_created_date, rpt_created_by_per_id, rpt_enable, rpt_allow_future_dates)
SELECT @id  AS rpt_rpt_id, 10033 AS ReportName, NULL AS ReportDescription,
       'Report' AS ReportCategory, 'pre_op_submissions_by_equipment_breakdown' AS ReportURL,
       NULL AS SSRSReportName,
       NOW() AS rpt_submitted_date,
       'pageable/pdf' AS rpt_output_type, NULL AS rpt_submitted_by_per_id,
       NULL AS rpt_created_date,
       NULL AS rpt_created_by_per_id,
       0 AS rpt_enable,
       1 AS rpt_allow_future_dates 
FROM dual
WHERE NOT EXISTS (
    SELECT 1 FROM Reports
    WHERE rpt_rpt_id = 124 AND ReportName = 10030 AND ReportDescription IS NULL
    AND ReportCategory = 'Report'
    AND ReportURL = 'pre_op_submissions_by_equipment_breakdown'
    AND SSRSReportName IS NULL
    AND rpt_output_type = 'pageable/pdf'
);




-- INSERT query to add mapping filter types to pre_op_submissions_breakdown_summary

INSERT INTO report_filter_type_mapping(rfm_rpt_id, rfm_rft_id, rfm_is_mandatory, rfm_created_date, rfm_created_by_per_id, rfm_enable, rfm_enote)
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='report_selection'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'report_selection'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='date_range'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'date_range'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='start_date'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'start_date'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='end_date'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'end_date'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='days_from_today'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'days_from_today'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='offset_date_range'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'offset_date_range'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='site_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'site_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='job_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'job_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='user_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'user_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='full_equipment_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'full_equipment_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='display_inactive_site_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'display_inactive_site_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='display_inactive_job_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'display_inactive_job_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='display_user_user_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'display_user_user_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='display_employee_user_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'display_employee_user_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='display_inactive_user_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'display_inactive_user_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown_summary'), (SELECT rft_id FROM report_filter_type where rft_name='display_inactive_equipment_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown_summary') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'display_inactive_equipment_ids'));


-- INSERT query to add mapping filter types to pre_op_submissions_by_user_breakdown

INSERT INTO report_filter_type_mapping(rfm_rpt_id, rfm_rft_id, rfm_is_mandatory, rfm_created_date, rfm_created_by_per_id, rfm_enable, rfm_enote)
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_user_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='date_range'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_user_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'date_range'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_user_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='start_date'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_user_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'start_date'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_user_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='end_date'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_user_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'end_date'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_user_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='days_from_today'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_user_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'days_from_today'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_user_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='offset_date_range'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_user_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'offset_date_range'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_user_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='user_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_user_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'user_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_user_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='display_user_user_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_user_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'display_user_user_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_user_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='display_employee_user_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_user_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'display_employee_user_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_user_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='display_inactive_user_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_user_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'display_inactive_user_ids'));


-- INSERT query to add mapping filter types to pre_op_submissions_by_job_breakdown

INSERT INTO report_filter_type_mapping(rfm_rpt_id, rfm_rft_id, rfm_is_mandatory, rfm_created_date, rfm_created_by_per_id, rfm_enable, rfm_enote)
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_job_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='date_range'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_job_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'date_range'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_job_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='start_date'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_job_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'start_date'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_job_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='end_date'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_job_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'end_date'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_job_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='days_from_today'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_job_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'days_from_today'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_job_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='offset_date_range'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_job_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'offset_date_range'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_job_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='job_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_job_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'job_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_job_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='display_inactive_job_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_job_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'display_inactive_job_ids'));


-- INSERT query to add mapping filter types to pre_op_submissions_by_site_breakdown

INSERT INTO report_filter_type_mapping(rfm_rpt_id, rfm_rft_id, rfm_is_mandatory, rfm_created_date, rfm_created_by_per_id, rfm_enable, rfm_enote)
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_site_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='date_range'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_site_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'date_range'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_site_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='start_date'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_site_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'start_date'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_site_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='end_date'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_site_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'end_date'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_site_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='days_from_today'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_site_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'days_from_today'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_site_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='offset_date_range'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_site_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'offset_date_range'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_site_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='site_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_site_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'site_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_site_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='display_inactive_site_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_site_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'display_inactive_site_ids'));


-- INSERT query to add mapping filter types to pre_op_submissions_by_equipment_breakdown

INSERT INTO report_filter_type_mapping(rfm_rpt_id, rfm_rft_id, rfm_is_mandatory, rfm_created_date, rfm_created_by_per_id, rfm_enable, rfm_enote)
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_equipment_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='date_range'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_equipment_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'date_range'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_equipment_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='start_date'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_equipment_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'start_date'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_equipment_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='end_date'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_equipment_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'end_date'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_equipment_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='days_from_today'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_equipment_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'days_from_today'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_equipment_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='offset_date_range'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_equipment_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'offset_date_range'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_equipment_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='full_equipment_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_equipment_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'full_equipment_ids'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_by_equipment_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='display_inactive_equipment_ids'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_by_equipment_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'display_inactive_equipment_ids'));


-- INSERT query to add mapping filter types to pre_op_submissions_breakdown
INSERT INTO report_filter_type_mapping(rfm_rpt_id, rfm_rft_id, rfm_is_mandatory, rfm_created_date, rfm_created_by_per_id, rfm_enable, rfm_enote)
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='date_range'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'date_range'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='start_date'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'start_date'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='end_date'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'end_date'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='days_from_today'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'days_from_today'))
UNION
SELECT (SELECT ID FROM Reports WHERE ReportURL = 'pre_op_submissions_breakdown'), (SELECT rft_id FROM report_filter_type where rft_name='offset_date_range'), 1, NOW(), 
get_support_account(), 1, 'PD-3321 - Add New Filter type mapping for new reprot' FROM DUAL WHERE NOT EXISTS 
(SELECT 1 FROM report_filter_type_mapping where rfm_rpt_id = (SELECT ID from Reports where ReportURL = 'pre_op_submissions_breakdown') and rfm_rft_id = (SELECT rft_id FROM report_filter_type where rft_name = 'offset_date_range'));



-- PD-2869
/*Inserting userful_links into the table*/
INSERT INTO ref_list_detail (rld_rlh_id,
rld_parent_detail_rld_id,
rld_code,
rld_score,
rld_name,
rld_description,
rld_tag_type,
rld_option,
rld_is_active,
rld_created_date,
rld_created_by_per_id,
rld_modified_date,
rld_modified_by_per_id,
rld_enable,
rld_enote)
  SELECT
    110,
    NULL,
    'useful_links',
    NULL,
    1773,
    NULL,
    1,
    NULL,
    1,
    NOW(),
    get_support_account(),
    NULL,
    NULL,
    1,
    'PD-2869 Archived Items - Data and Date Updates'
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM ref_list_detail
    WHERE rld_rlh_id = 110
    AND rld_code = 'useful_links'
    AND rld_name = 1773);


-- Views:
CREATE OR REPLACE
VIEW ref_site
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 1;
CREATE OR REPLACE
VIEW ref_level
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 2;
CREATE OR REPLACE
VIEW ref_job
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 3;
CREATE OR REPLACE
VIEW ref_context
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 4;
CREATE OR REPLACE
VIEW ref_content
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 5;
CREATE OR REPLACE
VIEW ref_days_of_rotation
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 6;
CREATE OR REPLACE
VIEW ref_demonstration_reason
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 7;
CREATE OR REPLACE
VIEW ref_action_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 8;
CREATE OR REPLACE
VIEW ref_climate
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 9;
CREATE OR REPLACE
VIEW ref_duration
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 10;
CREATE OR REPLACE
VIEW ref_event_shift_schedule
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 11;
CREATE OR REPLACE
VIEW ref_frequency
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 12;
CREATE OR REPLACE
VIEW ref_hazard_identification
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 13;
CREATE OR REPLACE
VIEW ref_actual_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 14;
CREATE OR REPLACE
VIEW ref_hazard_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 15;
CREATE OR REPLACE
VIEW ref_actual_incident_type_category
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 16;
CREATE OR REPLACE
VIEW ref_actual_incident_type_detail
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 17;
CREATE OR REPLACE
VIEW ref_hours_summary
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 18;
CREATE OR REPLACE
VIEW ref_basic_cause_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 19;
CREATE OR REPLACE
VIEW ref_basic_cause_category
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 20;
CREATE OR REPLACE
VIEW ref_basic_cause
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 21;
CREATE OR REPLACE
VIEW ref_immediate_cause_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 25;
CREATE OR REPLACE
VIEW ref_immediate_cause
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 26;
CREATE OR REPLACE
VIEW ref_incident_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 27;
CREATE OR REPLACE
VIEW ref_inspection_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 28;
CREATE OR REPLACE
VIEW ref_position
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 29;
CREATE OR REPLACE
VIEW ref_potential_loss
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 30;
CREATE OR REPLACE
VIEW ref_potential_risk
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 31;
CREATE OR REPLACE
VIEW ref_preliminary_incident_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 32;
CREATE OR REPLACE
VIEW ref_preliminary_incident_type_category
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 33;
CREATE OR REPLACE
VIEW ref_preliminary_incident_type_detail
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 34;
CREATE OR REPLACE
VIEW ref_recognition_given
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 35;
CREATE OR REPLACE
VIEW ref_recognition_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 36;
CREATE OR REPLACE
VIEW ref_special_ppe
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 37;
CREATE OR REPLACE
VIEW ref_temperature
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 38;
CREATE OR REPLACE
VIEW ref_topic_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 39;
CREATE OR REPLACE
VIEW ref_training_audit_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 40;
CREATE OR REPLACE
VIEW ref_equipment
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 41;
CREATE OR REPLACE
VIEW ref_classification
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 42;
CREATE OR REPLACE
VIEW ref_work_rest_established
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 43;
CREATE OR REPLACE
VIEW ref_involvement
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 44;
CREATE OR REPLACE
VIEW ref_preparation
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 45;
CREATE OR REPLACE
VIEW ref_testing
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 46;
CREATE OR REPLACE
VIEW ref_knowledge
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 47;
CREATE OR REPLACE
VIEW ref_audit_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 48;
CREATE OR REPLACE
VIEW ref_record_status
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 49;
CREATE OR REPLACE
VIEW ref_shift
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 50;
CREATE OR REPLACE
VIEW ref_training_code
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 51;
CREATE OR REPLACE
VIEW ref_training_institution
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 52;
CREATE OR REPLACE
VIEW ref_training_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 53;
CREATE OR REPLACE
VIEW ref_general_action
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 54;
CREATE OR REPLACE
VIEW ref_document_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 55;
CREATE OR REPLACE
VIEW ref_crew
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 56;
CREATE OR REPLACE
VIEW ref_likelihood
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 57;
CREATE OR REPLACE
VIEW ref_severity
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 58;
CREATE OR REPLACE
VIEW ref_risk_category
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 59;
CREATE OR REPLACE
VIEW ref_event_category
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 60;
CREATE OR REPLACE
VIEW ref_major_unwanted_event
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 61;
CREATE OR REPLACE
VIEW ref_color_list
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 62;
CREATE OR REPLACE
VIEW ref_reason_departure
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 63;
CREATE OR REPLACE
VIEW ref_employee_performance
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 64;
CREATE OR REPLACE
VIEW ref_assets_collected
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 65;
CREATE OR REPLACE
VIEW ref_rescue_plan_retrieval_equipment
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 66;
CREATE OR REPLACE
VIEW ref_hazards_present_rp
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 67;
CREATE OR REPLACE
VIEW ref_communication_strategy
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 68;
CREATE OR REPLACE
VIEW ref_rescue_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 69;
CREATE OR REPLACE
VIEW ref_key_contacts_rp
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 70;
CREATE OR REPLACE
VIEW ref_hot_work_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 71;
CREATE OR REPLACE
VIEW ref_hot_work_hazards
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 72;
CREATE OR REPLACE
VIEW ref_determine_controls_equipment
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 73;
CREATE OR REPLACE
VIEW ref_personal_protective_equipment
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 74;
CREATE OR REPLACE
VIEW ref_rescue_special_ppe
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 75;
CREATE OR REPLACE
VIEW ref_high_risk_precautions
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 76;
CREATE OR REPLACE
VIEW ref_potential_hazards_wh
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 77;
CREATE OR REPLACE
VIEW ref_determine_controls_wh
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 78;
CREATE OR REPLACE
VIEW ref_special_ppe_wh
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 79;
CREATE OR REPLACE
VIEW ref_occupation
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 80;
CREATE OR REPLACE
VIEW ref_am_task_contract
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 81;
CREATE OR REPLACE
VIEW ref_am_task_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 82;
CREATE OR REPLACE
VIEW ref_am_supplies_location
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 83;
CREATE OR REPLACE
VIEW ref_am_supplies_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 84;
CREATE OR REPLACE
VIEW ref_work_card_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 85;
CREATE OR REPLACE
VIEW ref_work_accomplished
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 86;
CREATE OR REPLACE
VIEW ref_rule_breaking
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 87;
CREATE OR REPLACE
VIEW ref_sanctions
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 88;
CREATE OR REPLACE
VIEW ref_preop_measure_unit
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 89;
CREATE OR REPLACE
VIEW ref_training_status
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 90;
CREATE OR REPLACE
VIEW ref_service_type
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 91;
CREATE OR REPLACE
VIEW ref_equipment_status
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 92;
CREATE OR REPLACE
VIEW ref_report_schedule_period
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 93;
CREATE OR REPLACE
VIEW ref_report_schedule_frequency
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 94;
CREATE OR REPLACE
VIEW ref_report_schedule_end
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 95;
CREATE OR REPLACE
VIEW ref_drilling_time_and_delays_code
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 96;
CREATE OR REPLACE
VIEW ref_drilling_code
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 97;
CREATE OR REPLACE
VIEW ref_drilling_status_code
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 98;
CREATE OR REPLACE
VIEW ref_drilling_log_code
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 99;
CREATE OR REPLACE
VIEW ref_drilling_bit_size
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 100;
CREATE OR REPLACE
VIEW ref_drilling_material_used
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 101;
CREATE OR REPLACE
VIEW ref_energy_source
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 102;
CREATE OR REPLACE
VIEW ref_lockout_devices
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 103;
CREATE OR REPLACE
VIEW ref_source_and_location
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 104;
CREATE OR REPLACE
VIEW ref_accessories
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 105;
CREATE OR REPLACE
VIEW ref_type_intervention
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 106;
CREATE OR REPLACE
VIEW ref_loto_status
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 107;
CREATE OR REPLACE
VIEW ref_atmospheric_gases
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 108;
CREATE OR REPLACE
VIEW ref_days_of_the_week
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 109;
CREATE OR REPLACE
VIEW ref_module_list
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 110;
CREATE OR REPLACE
VIEW ref_risk_level
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 111;
CREATE OR REPLACE
VIEW ref_work_card_risk
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 112;
CREATE OR REPLACE
VIEW ref_work_card_control
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 113;
CREATE OR REPLACE
VIEW ref_preop_equipment_status
AS
SELECT
  rld.rld_id AS rld_id,
  rld.rld_rlh_id AS rld_rlh_id,
  rld.rld_code AS rld_code,
  rld.rld_name AS rld_name,
  lt.ltr_text AS ltr_text,
  rld.rld_description,
  rld.rld_tag_type AS rld_tag_type,
  rld.rld_is_active AS rld_is_active,
  lt.ltr_lng_id AS lng_id,
  NOT rld.rld_enable AS rld_deleted,
  rld.rld_enable AS rld_enable
FROM (ref_list_detail rld
  LEFT JOIN language_translation lt
    ON (lt.ltr_tag = rld.rld_name)
    AND lt.ltr_tag_type = rld.rld_tag_type)
WHERE rld.rld_rlh_id = 114;


-- languages

-- INSERTS
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10000,
    'Delete Step',
    1,
    '2025-01-15 13:10:54.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10000
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10000,
    'Supprimer l’étape',
    1,
    '2025-01-15 13:10:54.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10000
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10000,
    'Eliminar paso',
    1,
    '2025-01-15 13:10:54.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10000
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10000,
    'Apagar etapa',
    1,
    '2025-01-15 13:10:54.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10000
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10001,
    'Next',
    1,
    '2025-01-15 13:10:54.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10001
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10001,
    'Suivant',
    1,
    '2025-01-15 13:10:54.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10001
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10001,
    'Siguiente',
    1,
    '2025-01-15 13:10:54.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10001
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10001,
    'Seguinte',
    1,
    '2025-01-15 13:10:54.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10001
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10002,
    'Cannot remove last active item.',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10002
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10002,
    'Impossible de supprimer le dernier item actif.',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10002
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10002,
    'No se puede eliminar el último elemento activo.',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10002
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10002,
    'Não é possível remover o último item ativo.',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10002
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10003,
    'Cannot delete last item in a list.',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10003
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10003,
    'Impossible de supprimer le dernier élément de la liste.',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10003
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10003,
    'No se puede eliminar el último elemento de una lista.',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10003
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10003,
    'Não é possível eliminar o último item de uma lista.',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10003
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10004,
    'Close Preview',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10004
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10004,
    'Fermer l’aperçu',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10004
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10004,
    'Cerrar vista preliminar',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10004
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10004,
    'Fechar visualização',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10004
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10005,
    'Uploading Files',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10005
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10005,
    'Chargement des fichiers',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10005
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10005,
    'Cargando archivos',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10005
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10005,
    'Carregando ficheiros',
    1,
    '2025-01-21 07:25:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10005
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10006,
    'Reviewed by me',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10006
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10006,
    'Revue par moi',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10006
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10006,
    'Revisado por mi',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10006
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10006,
    'Avaliado por mim',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10006
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10009,
    'Equipment Photos',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10009
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10009,
    'Photos d’équipement',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10009
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10009,
    'Fotos de equipos',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10009
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10009,
    'Fotos do equipamento',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10009
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10007,
    'If the checkbox is checked, all past submitted records that contain this value, will be updated. This action is permanent.',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10007
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10007,
    'Si la case est cochée, tous les formulaires soumis précédemment qui contiennent cette valeur seront mis à jour. Cette action est permanente.',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10007
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10007,
    'Si la casilla de verificación está marcada, se actualizarán todos los registros enviados anteriormente que contengan este valor. Esta acción es permanente.',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10007
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10007,
    'Se a caixa de seleção estiver marcada, todos os registos enviados anteriormente que contenham esse valor serão atualizados. Esta ação é permanente.',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10007
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10008,
    'Update value in submitted records',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10008
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10008,
    'Mettre à jour la valeur dans les formulaires soumis',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10008
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10008,
    'Fotos de equipos',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10008
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10008,
    'Atualizar valor em registos enviados',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10008
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10011,
    'End of Shift Equipment Photos Required',
    1,
    '2025-01-31 08:43:11.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10011
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10011,
    'Photos de l’équipement requis a la fin de la journée de travail',
    1,
    '2025-01-31 08:43:12.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10011
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10011,
    'Se requieren fotografías del equipo al final del turno',
    1,
    '2025-01-31 08:43:12.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10011
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10011,
    'Fotos do equipamento de fim de turno necessárias',
    1,
    '2025-01-31 08:43:12.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10011
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10010,
    'Start of Shift Equipment Photos Required',
    1,
    '2025-01-31 08:43:12.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10010
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10010,
    'Photos de l’équipement requis au début de la journée de travail',
    1,
    '2025-01-31 08:43:12.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10010
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10010,
    'Se requieren fotografías del equipo al inicio del turno',
    1,
    '2025-01-31 08:43:12.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10010
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10010,
    'Início do turno Fotos do equipamento necessárias',
    1,
    '2025-01-31 08:43:12.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10010
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10013,
    'You can only create one form version at a time. Please select one form and try again.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10013
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10013,
    'Vous ne pouvez pas créer plus d’une version de formulaire à la fois. Veuillez sélectionner un formulaire et réessayer.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10013
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10013,
    'Solo puedes crear una versión de formulario a la vez. Selecciona un formulario y vuelve a intentarlo.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10013
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10013,
    'Só pode criar uma versão de formulário de cada vez. Selecione um formulário e tente novamente.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10013
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10012,
    'Origin',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10012
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10012,
    'L’origine',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10012
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10012,
    'Origen',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10012
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10012,
    'Origem',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10012
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10014,
    'A draft version of this form already exists. Please revise the draft form or create a new document.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10014
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10014,
    'Un brouillon de ce formulaire existe déjà. Veuillez réviser le brouillon ou créer un nouveau document.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10014
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10014,
    'Ya existe una versión preliminar de este formulario. Revise el borrador del formulario o cree un documento nuevo.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10014
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10014,
    'Já existe uma versão preliminar deste formulário. Reveja o rascunho do formulário ou crie um novo documento.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10014
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10016,
    'Publishing this form version will automatically set the previous form version to the Retired status. This action is permanent. Are you sure you want to proceed?',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10016
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10016,
    'La publication de cette version du formulaire placera automatiquement la version précédente dans le statut « Retiré ». Cette action est permanente. Êtes-vous sûr de vouloir continuer?',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10016
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10016,
    'Al publicar esta versión del formulario, la versión anterior del formulario pasará automáticamente al estado Retirado. Esta acción es permanente. ¿Está seguro de que desea continuar?',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10016
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10016,
    'A publicação desta versão do formulário definirá automaticamente a versão anterior do formulário para o estado Descontinuado. Esta ação é permanente. Tem a certeza de que pretende prosseguir?',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10016
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10017,
    'Please select a site to start working on the Job Risk Assessment.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10017
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10017,
    'Veuillez sélectionner un site pour commencer à utiliser l’analyse des risques liés à l’activité',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10017
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10017,
    'Por favor seleccione un sitio para comenzar a trabajar en la evaluación de riesgos laborales.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10017
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10017,
    'Selecione um site para começar a trabalhar na Avaliação de Riscos Laborais.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10017
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10018,
    'Please select a site to start working on the Project Risk Assessment.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10018
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10018,
    'Veuillez sélectionner un site pour commencer à utiliser l’analyse des risques liés aux projets et aux processus',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10018
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10018,
    'Por favor seleccione un sitio para comenzar a trabajar en la Evaluación de Riesgos del Proyecto.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10018
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10018,
    'Selecione um local para começar a trabalhar na Avaliação de Risco do Projeto.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10018
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10019,
    'Please select a site to start working on the Organization Risk Assessment.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10019
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10019,
    'Veuillez sélectionner un site pour commencer à utiliser l’analyse des risques organisationnels',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10019
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10019,
    'Por favor seleccione un sitio para comenzar a trabajar en la Evaluación de Riesgos de la Organización.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10019
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10019,
    'Selecione um site para começar a trabalhar na Avaliação de Riscos da Organização.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10019
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10020,
    'Please select a site to start working on the Bowtie Risk Assessment.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10020
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10020,
    'Veuillez sélectionner un site pour commencer à utiliser l’évaluation des risques Bowtie.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10020
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10020,
    'Por favor seleccione un sitio para comenzar a trabajar en la evaluación de riesgos de Bowtie.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10020
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10020,
    'Selecione um site para começar a trabalhar na Avaliação de Risco Bowtie.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10020
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10021,
    'Please select a site to start working on the Decision Log.',
    1,
    '2025-02-12 10:37:32.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10021
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10021,
    'Veuillez sélectionner un site pour commencer à utiliser le registre des décisions.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10021
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10021,
    'Por favor seleccione un sitio para comenzar a trabajar en el Registro de decisiones.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10021
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10021,
    'Selecione um site para começar a trabalhar no Registo de Decisões.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10021
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10015,
    'Version History',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10015
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10015,
    'Historique de la version',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10015
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10015,
    'Historial de versiones',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10015
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10015,
    'Histórico de versões',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10015
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10022,
    'Please select a site to start working on the Lessons Learned.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10022
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10022,
    'Veuillez sélectionner un site pour commencer à utiliser les leçons apprises.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10022
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10022,
    'Por favor seleccione un sitio para comenzar a trabajar en las lecciones aprendidas.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10022
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10022,
    'Selecione um site para começar a trabalhar nas Lições Aprendidas.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10022
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10024,
    'Only one site can be selected when the comments log is included in the report.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10024
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10024,
    'Un seul site peut être sélectionné lorsque le journal des commentaires est inclus dans le rapport.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10024
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10024,
    'Solo se puede seleccionar un sitio cuando el registro de comentarios se incluye en el informe.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10024
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10024,
    'Apenas um site pode ser selecionado quando o registo de alterações é incluído no relatório.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10024
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10025,
    'Only one job can be selected when the comments log is included in the report.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10025
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10025,
    'Une seule tâche peut être sélectionnée lorsque le journal des commentaires est inclus dans le rapport.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10025
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10025,
    'Solo se puede seleccionar un trabajo cuando el registro de comentarios está incluido en el informe.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10025
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10025,
    'Apenas um trabalho pode ser selecionado quando o registo de alterações é incluído no relatório.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10025
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10027,
    'Employees need to be selected manually when the comments log is included in the report.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10027
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10027,
    'Les employés doivent être sélectionnés manuellement lorsque le journal des commentaires est inclus dans le rapport.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10027
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10027,
    'Los empleados deben seleccionarse manualmente cuando el registro de comentarios se incluye en el informe.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10027
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10027,
    'Os colaboradores precisam de ser selecionados manualmente quando o registo de alterações é incluído no relatório.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10027
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10023,
    'Please select a site to start working on the Lockout / Tagout.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10023
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10023,
    'Veuillez sélectionner un site pour commencer à utiliser la cadenassage / étiquetage.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10023
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10023,
    'Por favor seleccione un sitio para comenzar a trabajar en el bloqueo/etiquetado.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10023
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10023,
    'Selecione um local para começar a trabalhar no bloqueio/sinalização.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10023
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10026,
    'Only one role can be selected when the comments log is included in the report.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10026
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10026,
    'Un seul rôle peut être sélectionné lorsque le journal des commentaires est inclus dans le rapport.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10026
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10026,
    'Solo se puede seleccionar un rol cuando el registro de comentarios se incluye en el informe.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10026
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10026,
    'Apenas uma função pode ser selecionada quando o registo de alterações é incluído no relatório.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10026
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10029,
    'The Pre-Op Submission Breakdown Report provides detailed analytics, charts, and trends to track Equipment Pre-Op activity and compliance.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10029
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10029,
    'Le rapport sur la répartition des soumissions pré-opératoires fournit des analyses détaillées, des graphiques et des tendances permettant de suivre l’activité pré-opératoire de l’équipement et sa conformité.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10029
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10029,
    'El informe desglose de envíos preoperatorios proporciona análisis detallados, gráficos y tendencias para realizar un seguimiento de la actividad y el cumplimiento de los equipos preoperatorios.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10029
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10029,
    'O Relatório de detalhe do envio pré-operatório fornece análises detalhadas, gráficos e tendências para acompanhar a atividade e a conformidade do equipamento pré-operatório.',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10029
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10028,
    'Pre-Op Submissions Breakdown',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10028
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10028,
    'Répartition des soumissions pré-opératoires',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10028
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10028,
    'Desglose de envíos preoperatorios',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10028
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10028,
    'Análise das submissões pré-operatórias',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10028
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10030,
    'Pre-Op Submission Breakdown by Site',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10030
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10030,
    'Répartition des soumissions pré-opératoires par site',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10030
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10030,
    'Desglose de envíos preoperatorios por sitio',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10030
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10030,
    'Divisão de submissão pré-operatória por local',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10030
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10032,
    'Pre-Op Submission Breakdown by User',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10032
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10032,
    'Répartition des soumissions pré-opératoires par utilisateurs',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10032
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10032,
    'Desglose de envíos preoperatorios por usuario',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10032
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10032,
    'Análise de submissão pré-operatória por utilizador',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10032
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10033,
    'Pre-Op Submission Breakdown by Equipment',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10033
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10033,
    'Répartition des soumissions pré-opératoires par équipement',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10033
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10033,
    'Desglose de envíos preoperatorios por equipo',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10033
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10033,
    'Divisão de submissão pré-operatória por equipamento',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10033
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10031,
    'Pre-Op Submission Breakdown by Job',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10031
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10031,
    'Répartition des soumissions pré-opératoires par job',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10031
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10031,
    'Desglose de envíos preoperatorios por trabajo',
    1,
    '2025-02-12 10:37:33.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10031
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10031,
    'Divisão de submissão pré-operatória por trabalho',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10031
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10034,
    'Pre-Op Submission Count Trend',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10034
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10034,
    'Tendance du nombre de soumissions pré-opératoires',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10034
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10034,
    'Tendencia del recuento de envíos preoperatorios',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10034
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10034,
    'Tendência de contagem de submissões pré-operatórias',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10034
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10035,
    'Total Pre-Ops Submitted',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10035
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10035,
    'Total des soumissions pré-opératoires',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10035
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10035,
    'Total de preoperatorios enviados',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10035
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10035,
    'Total de pré-operatórios enviados',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10035
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10036,
    'Pre-Op Submission Frequency',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10036
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10036,
    'Fréquence des soumissions pré-opératoires',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10036
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10036,
    'Frecuencia de envío de preoperatorios',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10036
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10036,
    'Frequência de submissão pré-operatória',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10036
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10038,
    'Equipment Pre-Op Submission Insight',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10038
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10038,
    'Aperçu des soumissions pré-opératoires d’équipements',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10038
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10038,
    'Información sobre el envío de preoperatorios de equipos',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10038
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10038,
    'Visão geral do envio pré-operatório do equipamento',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10038
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10039,
    'Top 10 Sites with Most Submitted Pre-Ops',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10039
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10039,
    'Top 10 sites avec le plus de soumissions pré-opératoire',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10039
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10039,
    'Los 10 sitios principales con más preoperatorios enviados',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10039
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10039,
    'Os 10 principais sites com mais pré-operações enviadas',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10039
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10040,
    'Top 10 Sites with Least Submitted Pre-Ops',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10040
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10040,
    'Top 10 sites avec le moins de soumissions pré-opératoire',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10040
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10040,
    'Los 10 sitios principales con menos preoperatorios enviados',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10040
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10040,
    'Os 10 principais sites com menos pré-operações enviadas',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10040
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10041,
    'Pre-Op Submissions Sparkline',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10041
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10041,
    'Soumissions pré-opératoires ’Sparkline’',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10041
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10041,
    'Minigráfico de envíos preoperatorios ’Sparkline’',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10041
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10041,
    'Submissões pré-operatóriasLinha de faísca ’Sparkline’',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10041
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10043,
    'Top 10 Users with Most Submitted Pre-Ops',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10043
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10043,
    'Top 10 utilisateurs avec le plus de soumissions pré-opératoire',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10043
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10043,
    'Los 10 usuarios con más preoperatorios enviados',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10043
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10043,
    'Top 10 utilizadores com mais pré-operações enviadas',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10043
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10044,
    'Top 10 Equipment with Most Submitted Pre-Ops',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10044
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10044,
    'Top 10 équipements avec le plus de soumissions pré-opératoire',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10044
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10044,
    'Los 10 equipos con más preoperatorios enviados',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10044
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10044,
    'Top 10 Equipamentos com Mais Pré-Operações Enviadas',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10044
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10042,
    'Top 10 Jobs with Most Submitted Pre-Ops',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10042
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10042,
    'Top 10 job avec le plus de soumissions pré-opératoire',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10042
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10042,
    'Los 10 trabajos con más preoperatorios enviados',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10042
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10042,
    'Top 10 empregos com mais pré-operações submetidas',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10042
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10045,
    'Top 10 Equipment with Least Submitted Pre-Ops',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10045
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10045,
    'Top 10 équipements avec le moins de soumissions pré-opératoire',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10045
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10045,
    'Los 10 equipos con menos preoperatorios enviados',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10045
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10045,
    'Top 10 Equipamentos com Menos Pré-Operações Submetidas',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10045
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    1,
    10037,
    'Pre-Op Submission Count',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 1
    AND ltr_tag = 10037
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    2,
    10037,
    'Compte des soumissions pré-opératoires',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 2
    AND ltr_tag = 10037
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    3,
    10037,
    'Recuento de envíos preoperatorios',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 3
    AND ltr_tag = 10037
    AND ltr_tag_type = 1);
INSERT INTO language_translation (ltr_lng_id, ltr_tag, ltr_text, ltr_tag_type, ltr_created_date, ltr_modified_date, ltr_created_by_per_id, ltr_modified_by_per_id, ltr_enable, ltr_enote, ltr_translated)
  SELECT
    4,
    10037,
    'Contagem de submissões pré-operatórias',
    1,
    '2025-02-12 10:37:34.000000',
    NULL,
    get_support_account(),
    NULL,
    1,
    '',
    1
  FROM DUAL
  WHERE NOT EXISTS (SELECT
      1
    FROM language_translation
    WHERE ltr_lng_id = 4
    AND ltr_tag = 10037
    AND ltr_tag_type = 1);

UPDATE language_translation
SET ltr_text = 'Target Deleted'
WHERE ltr_tag = 8696
AND ltr_lng_id = 1
AND ltr_tag_type = 1
AND ltr_text = 'Target deleted';

UPDATE language_translation
SET ltr_text = 'Target Created'
WHERE ltr_tag = 8698
AND ltr_lng_id = 1
AND ltr_tag_type = 1
AND ltr_text = 'Target created';


